// The Module object: Our interface to the outside world. We import
// and export values on it, and do the work to get that through
// closure compiler if necessary. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to do an eval in order to handle the closure compiler
// case, where this code here is minified but Module was defined
// elsewhere (e.g. case 4 above). We also need to check if Module
// already exists (e.g. case 3 above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module;
if (!Module) Module = (typeof Module !== 'undefined' ? Module : null) || {};

// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
for (var key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}

// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;

if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  if (!Module['print']) Module['print'] = function print(x) {
    process['stdout'].write(x + '\n');
  };
  if (!Module['printErr']) Module['printErr'] = function printErr(x) {
    process['stderr'].write(x + '\n');
  };

  var nodeFS = require('fs');
  var nodePath = require('path');

  Module['read'] = function read(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };

  Module['readBinary'] = function readBinary(filename) { return Module['read'](filename, true) };

  Module['load'] = function load(f) {
    globalEval(read(f));
  };

  if (process['argv'].length > 1) {
    Module['thisProgram'] = process['argv'][1].replace(/\\/g, '/');
  } else {
    Module['thisProgram'] = 'unknown-program';
  }

  Module['arguments'] = process['argv'].slice(2);

  if (typeof module !== 'undefined') {
    module['exports'] = Module;
  }

  process['on']('uncaughtException', function(ex) {
    // suppress ExitStatus exceptions from showing an error
    if (!(ex instanceof ExitStatus)) {
      throw ex;
    }
  });
}
else if (ENVIRONMENT_IS_SHELL) {
  if (!Module['print']) Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm

  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function read() { throw 'no read() available (jsc?)' };
  }

  Module['readBinary'] = function readBinary(f) {
    if (typeof readbuffer === 'function') {
      return new Uint8Array(readbuffer(f));
    }
    var data = read(f, 'binary');
    assert(typeof data === 'object');
    return data;
  };

  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  this['Module'] = Module;

}
else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function read(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };

  if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  if (typeof console !== 'undefined') {
    if (!Module['print']) Module['print'] = function print(x) {
      console.log(x);
    };
    if (!Module['printErr']) Module['printErr'] = function printErr(x) {
      console.log(x);
    };
  } else {
    // Probably a worker, and without console.log. We can do very little here...
    var TRY_USE_DUMP = false;
    if (!Module['print']) Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
  }

  if (ENVIRONMENT_IS_WEB) {
    window['Module'] = Module;
  } else {
    Module['load'] = importScripts;
  }
}
else {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}

function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] && Module['read']) {
  Module['load'] = function load(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
if (!Module['thisProgram']) {
  Module['thisProgram'] = './this.program';
}

// *** Environment setup code ***

// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];

// Callbacks
Module['preRun'] = [];
Module['postRun'] = [];

// Merge back in the overrides
for (var key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}



// === Preamble library stuff ===

// Documentation for the public APIs defined in this file must be updated in: 
//    site/source/docs/api_reference/preamble.js.rst
// A prebuilt local version of the documentation is available at: 
//    site/build/text/docs/api_reference/preamble.js.txt
// You can also build docs locally as HTML or other formats in site/
// An online HTML version (which may be of a different version of Emscripten)
//    is up at http://kripken.github.io/emscripten-site/docs/api_reference/preamble.js.html

//========================================
// Runtime code shared with compiler
//========================================

var Runtime = {
  setTempRet0: function (value) {
    tempRet0 = value;
  },
  getTempRet0: function () {
    return tempRet0;
  },
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  getNativeTypeSize: function (type) {
    switch (type) {
      case 'i1': case 'i8': return 1;
      case 'i16': return 2;
      case 'i32': return 4;
      case 'i64': return 8;
      case 'float': return 4;
      case 'double': return 8;
      default: {
        if (type[type.length-1] === '*') {
          return Runtime.QUANTUM_SIZE; // A pointer
        } else if (type[0] === 'i') {
          var bits = parseInt(type.substr(1));
          assert(bits % 8 === 0);
          return bits/8;
        } else {
          return 0;
        }
      }
    }
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  STACK_ALIGN: 16,
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (!vararg && (type == 'i64' || type == 'double')) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2*(1 + i);
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  getAsmConst: function (code, numArgs) {
    // code is a constant string on the heap, so we can cache these
    if (!Runtime.asmConstCache) Runtime.asmConstCache = {};
    var func = Runtime.asmConstCache[code];
    if (func) return func;
    var args = [];
    for (var i = 0; i < numArgs; i++) {
      args.push(String.fromCharCode(36) + i); // $0, $1 etc
    }
    var source = Pointer_stringify(code);
    if (source[0] === '"') {
      // tolerate EM_ASM("..code..") even though EM_ASM(..code..) is correct
      if (source.indexOf('"', 1) === source.length-1) {
        source = source.substr(1, source.length-2);
      } else {
        // something invalid happened, e.g. EM_ASM("..code($0)..", input)
        abort('invalid EM_ASM input |' + source + '|. Please use EM_ASM(..code..) (no quotes) or EM_ASM({ ..code($0).. }, input) (to input values)');
      }
    }
    try {
      // Module is the only 'upvar', which we provide directly. We also provide FS for legacy support.
      var evalled = eval('(function(Module, FS) { return function(' + args.join(',') + '){ ' + source + ' } })')(Module, typeof FS !== 'undefined' ? FS : null);
    } catch(e) {
      Module.printErr('error in executing inline EM_ASM code: ' + e + ' on: \n\n' + source + '\n\nwith args |' + args + '| (make sure to use the right one out of EM_ASM, EM_ASM_ARGS, etc.)');
      throw e;
    }
    return Runtime.asmConstCache[code] = evalled;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[sig]) {
      Runtime.funcWrappers[sig] = {};
    }
    var sigCache = Runtime.funcWrappers[sig];
    if (!sigCache[func]) {
      sigCache[func] = function dynCall_wrapper() {
        return Runtime.dynCall(sig, func, arguments);
      };
    }
    return sigCache[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xFF;

      if (buffer.length == 0) {
        if ((code & 0x80) == 0x00) {        // 0xxxxxxx
          return String.fromCharCode(code);
        }
        buffer.push(code);
        if ((code & 0xE0) == 0xC0) {        // 110xxxxx
          needed = 1;
        } else if ((code & 0xF0) == 0xE0) { // 1110xxxx
          needed = 2;
        } else {                            // 11110xxx
          needed = 3;
        }
        return '';
      }

      if (needed) {
        buffer.push(code);
        needed--;
        if (needed > 0) return '';
      }

      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var c4 = buffer[3];
      var ret;
      if (buffer.length == 2) {
        ret = String.fromCharCode(((c1 & 0x1F) << 6)  | (c2 & 0x3F));
      } else if (buffer.length == 3) {
        ret = String.fromCharCode(((c1 & 0x0F) << 12) | ((c2 & 0x3F) << 6)  | (c3 & 0x3F));
      } else {
        // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
        var codePoint = ((c1 & 0x07) << 18) | ((c2 & 0x3F) << 12) |
                        ((c3 & 0x3F) << 6)  | (c4 & 0x3F);
        ret = String.fromCharCode(
          (((codePoint - 0x10000) / 0x400)|0) + 0xD800,
          (codePoint - 0x10000) % 0x400 + 0xDC00);
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function processJSString(string) {
      /* TODO: use TextEncoder when present,
        var encoder = new TextEncoder();
        encoder['encoding'] = "utf-8";
        var utf8Array = encoder['encode'](aMsg.data);
      */
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  getCompilerSetting: function (name) {
    throw 'You must build with -s RETAIN_COMPILER_SETTINGS=1 for Runtime.getCompilerSetting or emscripten_get_compiler_setting to work';
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = (((STACKTOP)+15)&-16); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = (((STATICTOP)+15)&-16); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + size)|0;DYNAMICTOP = (((DYNAMICTOP)+15)&-16); if (DYNAMICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 16))*(quantum ? quantum : 16); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+((low>>>0)))+((+((high>>>0)))*4294967296.0)) : ((+((low>>>0)))+((+((high|0)))*4294967296.0))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}


Module['Runtime'] = Runtime;









//========================================
// Runtime essentials
//========================================

var __THREW__ = 0; // Used in checking for thrown exceptions.

var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var EXITSTATUS = 0;

var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD, tempDouble, tempFloat;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;

function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}

var globalScope = this;

// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  var func = Module['_' + ident]; // closure exported function
  if (!func) {
    try {
      func = eval('_' + ident); // explicit lookup
    } catch(e) {}
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}

var cwrap, ccall;
(function(){
  var stack = 0;
  var JSfuncs = {
    'stackSave' : function() {
      stack = Runtime.stackSave();
    },
    'stackRestore' : function() {
      Runtime.stackRestore(stack);
    },
    // type conversion from js to c
    'arrayToC' : function(arr) {
      var ret = Runtime.stackAlloc(arr.length);
      writeArrayToMemory(arr, ret);
      return ret;
    },
    'stringToC' : function(str) {
      var ret = 0;
      if (str !== null && str !== undefined && str !== 0) { // null string
        // at most 4 bytes per UTF-8 code point, +1 for the trailing '\0'
        ret = Runtime.stackAlloc((str.length << 2) + 1);
        writeStringToMemory(str, ret);
      }
      return ret;
    }
  };
  // For fast lookup of conversion functions
  var toC = {'string' : JSfuncs['stringToC'], 'array' : JSfuncs['arrayToC']};

  // C calling interface. 
  ccall = function ccallFunc(ident, returnType, argTypes, args) {
    var func = getCFunc(ident);
    var cArgs = [];
    if (args) {
      for (var i = 0; i < args.length; i++) {
        var converter = toC[argTypes[i]];
        if (converter) {
          if (stack === 0) stack = Runtime.stackSave();
          cArgs[i] = converter(args[i]);
        } else {
          cArgs[i] = args[i];
        }
      }
    }
    var ret = func.apply(null, cArgs);
    if (returnType === 'string') ret = Pointer_stringify(ret);
    if (stack !== 0) JSfuncs['stackRestore']();
    return ret;
  }

  var sourceRegex = /^function\s*\(([^)]*)\)\s*{\s*([^*]*?)[\s;]*(?:return\s*(.*?)[;\s]*)?}$/;
  function parseJSFunc(jsfunc) {
    // Match the body and the return value of a javascript function source
    var parsed = jsfunc.toString().match(sourceRegex).slice(1);
    return {arguments : parsed[0], body : parsed[1], returnValue: parsed[2]}
  }
  var JSsource = {};
  for (var fun in JSfuncs) {
    if (JSfuncs.hasOwnProperty(fun)) {
      // Elements of toCsource are arrays of three items:
      // the code, and the return value
      JSsource[fun] = parseJSFunc(JSfuncs[fun]);
    }
  }

  
  cwrap = function cwrap(ident, returnType, argTypes) {
    argTypes = argTypes || [];
    var cfunc = getCFunc(ident);
    // When the function takes numbers and returns a number, we can just return
    // the original function
    var numericArgs = argTypes.every(function(type){ return type === 'number'});
    var numericRet = (returnType !== 'string');
    if ( numericRet && numericArgs) {
      return cfunc;
    }
    // Creation of the arguments list (["$1","$2",...,"$nargs"])
    var argNames = argTypes.map(function(x,i){return '$'+i});
    var funcstr = "(function(" + argNames.join(',') + ") {";
    var nargs = argTypes.length;
    if (!numericArgs) {
      // Generate the code needed to convert the arguments from javascript
      // values to pointers
      funcstr += JSsource['stackSave'].body + ';';
      for (var i = 0; i < nargs; i++) {
        var arg = argNames[i], type = argTypes[i];
        if (type === 'number') continue;
        var convertCode = JSsource[type + 'ToC']; // [code, return]
        funcstr += 'var ' + convertCode.arguments + ' = ' + arg + ';';
        funcstr += convertCode.body + ';';
        funcstr += arg + '=' + convertCode.returnValue + ';';
      }
    }

    // When the code is compressed, the name of cfunc is not literally 'cfunc' anymore
    var cfuncname = parseJSFunc(function(){return cfunc}).returnValue;
    // Call the function
    funcstr += 'var ret = ' + cfuncname + '(' + argNames.join(',') + ');';
    if (!numericRet) { // Return type can only by 'string' or 'number'
      // Convert the result to a string
      var strgfy = parseJSFunc(function(){return Pointer_stringify}).returnValue;
      funcstr += 'ret = ' + strgfy + '(ret);';
    }
    if (!numericArgs) {
      // If we had a stack, restore it
      funcstr += JSsource['stackRestore'].body + ';';
    }
    funcstr += 'return ret})';
    return eval(funcstr);
  };
})();
Module["cwrap"] = cwrap;
Module["ccall"] = ccall;


function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[((ptr)>>0)]=value; break;
      case 'i8': HEAP8[((ptr)>>0)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;


function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[((ptr)>>0)];
      case 'i8': return HEAP8[((ptr)>>0)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;

var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_DYNAMIC'] = ALLOC_DYNAMIC;
Module['ALLOC_NONE'] = ALLOC_NONE;

// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }

  var singleType = typeof types === 'string' ? types : null;

  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }

  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)>>0)]=0;
    }
    return ret;
  }

  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }

  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];

    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }

    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }

    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later

    setValue(ret+i, curr, type);

    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }

  return ret;
}
Module['allocate'] = allocate;

function Pointer_stringify(ptr, /* optional */ length) {
  if (length === 0 || !ptr) return '';
  // TODO: use TextDecoder
  // Find the length, and check for UTF while doing so
  var hasUtf = false;
  var t;
  var i = 0;
  while (1) {
    t = HEAPU8[(((ptr)+(i))>>0)];
    if (t >= 128) hasUtf = true;
    else if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;

  var ret = '';

  if (!hasUtf) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }

  var utf8 = new Runtime.UTF8Processor();
  for (i = 0; i < length; i++) {
    t = HEAPU8[(((ptr)+(i))>>0)];
    ret += utf8.processCChar(t);
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;

function UTF16ToString(ptr) {
  var i = 0;

  var str = '';
  while (1) {
    var codeUnit = HEAP16[(((ptr)+(i*2))>>1)];
    if (codeUnit == 0)
      return str;
    ++i;
    // fromCharCode constructs a character from a UTF-16 code unit, so we can pass the UTF16 string right through.
    str += String.fromCharCode(codeUnit);
  }
}
Module['UTF16ToString'] = UTF16ToString;


function stringToUTF16(str, outPtr) {
  for(var i = 0; i < str.length; ++i) {
    // charCodeAt returns a UTF-16 encoded code unit, so it can be directly written to the HEAP.
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    HEAP16[(((outPtr)+(i*2))>>1)]=codeUnit;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP16[(((outPtr)+(str.length*2))>>1)]=0;
}
Module['stringToUTF16'] = stringToUTF16;


function UTF32ToString(ptr) {
  var i = 0;

  var str = '';
  while (1) {
    var utf32 = HEAP32[(((ptr)+(i*4))>>2)];
    if (utf32 == 0)
      return str;
    ++i;
    // Gotcha: fromCharCode constructs a character from a UTF-16 encoded code (pair), not from a Unicode code point! So encode the code point to UTF-16 for constructing.
    if (utf32 >= 0x10000) {
      var ch = utf32 - 0x10000;
      str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
    } else {
      str += String.fromCharCode(utf32);
    }
  }
}
Module['UTF32ToString'] = UTF32ToString;


function stringToUTF32(str, outPtr) {
  var iChar = 0;
  for(var iCodeUnit = 0; iCodeUnit < str.length; ++iCodeUnit) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    var codeUnit = str.charCodeAt(iCodeUnit); // possibly a lead surrogate
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) {
      var trailSurrogate = str.charCodeAt(++iCodeUnit);
      codeUnit = 0x10000 + ((codeUnit & 0x3FF) << 10) | (trailSurrogate & 0x3FF);
    }
    HEAP32[(((outPtr)+(iChar*4))>>2)]=codeUnit;
    ++iChar;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP32[(((outPtr)+(iChar*4))>>2)]=0;
}
Module['stringToUTF32'] = stringToUTF32;

function demangle(func) {
  var hasLibcxxabi = !!Module['___cxa_demangle'];
  if (hasLibcxxabi) {
    try {
      var buf = _malloc(func.length);
      writeStringToMemory(func.substr(1), buf);
      var status = _malloc(4);
      var ret = Module['___cxa_demangle'](buf, 0, 0, status);
      if (getValue(status, 'i32') === 0 && ret) {
        return Pointer_stringify(ret);
      }
      // otherwise, libcxxabi failed, we can try ours which may return a partial result
    } catch(e) {
      // failure when using libcxxabi, we can try ours which may return a partial result
    } finally {
      if (buf) _free(buf);
      if (status) _free(status);
      if (ret) _free(ret);
    }
  }
  var i = 3;
  // params, etc.
  var basicTypes = {
    'v': 'void',
    'b': 'bool',
    'c': 'char',
    's': 'short',
    'i': 'int',
    'l': 'long',
    'f': 'float',
    'd': 'double',
    'w': 'wchar_t',
    'a': 'signed char',
    'h': 'unsigned char',
    't': 'unsigned short',
    'j': 'unsigned int',
    'm': 'unsigned long',
    'x': 'long long',
    'y': 'unsigned long long',
    'z': '...'
  };
  var subs = [];
  var first = true;
  function dump(x) {
    //return;
    if (x) Module.print(x);
    Module.print(func);
    var pre = '';
    for (var a = 0; a < i; a++) pre += ' ';
    Module.print (pre + '^');
  }
  function parseNested() {
    i++;
    if (func[i] === 'K') i++; // ignore const
    var parts = [];
    while (func[i] !== 'E') {
      if (func[i] === 'S') { // substitution
        i++;
        var next = func.indexOf('_', i);
        var num = func.substring(i, next) || 0;
        parts.push(subs[num] || '?');
        i = next+1;
        continue;
      }
      if (func[i] === 'C') { // constructor
        parts.push(parts[parts.length-1]);
        i += 2;
        continue;
      }
      var size = parseInt(func.substr(i));
      var pre = size.toString().length;
      if (!size || !pre) { i--; break; } // counter i++ below us
      var curr = func.substr(i + pre, size);
      parts.push(curr);
      subs.push(curr);
      i += pre + size;
    }
    i++; // skip E
    return parts;
  }
  function parse(rawList, limit, allowVoid) { // main parser
    limit = limit || Infinity;
    var ret = '', list = [];
    function flushList() {
      return '(' + list.join(', ') + ')';
    }
    var name;
    if (func[i] === 'N') {
      // namespaced N-E
      name = parseNested().join('::');
      limit--;
      if (limit === 0) return rawList ? [name] : name;
    } else {
      // not namespaced
      if (func[i] === 'K' || (first && func[i] === 'L')) i++; // ignore const and first 'L'
      var size = parseInt(func.substr(i));
      if (size) {
        var pre = size.toString().length;
        name = func.substr(i + pre, size);
        i += pre + size;
      }
    }
    first = false;
    if (func[i] === 'I') {
      i++;
      var iList = parse(true);
      var iRet = parse(true, 1, true);
      ret += iRet[0] + ' ' + name + '<' + iList.join(', ') + '>';
    } else {
      ret = name;
    }
    paramLoop: while (i < func.length && limit-- > 0) {
      //dump('paramLoop');
      var c = func[i++];
      if (c in basicTypes) {
        list.push(basicTypes[c]);
      } else {
        switch (c) {
          case 'P': list.push(parse(true, 1, true)[0] + '*'); break; // pointer
          case 'R': list.push(parse(true, 1, true)[0] + '&'); break; // reference
          case 'L': { // literal
            i++; // skip basic type
            var end = func.indexOf('E', i);
            var size = end - i;
            list.push(func.substr(i, size));
            i += size + 2; // size + 'EE'
            break;
          }
          case 'A': { // array
            var size = parseInt(func.substr(i));
            i += size.toString().length;
            if (func[i] !== '_') throw '?';
            i++; // skip _
            list.push(parse(true, 1, true)[0] + ' [' + size + ']');
            break;
          }
          case 'E': break paramLoop;
          default: ret += '?' + c; break paramLoop;
        }
      }
    }
    if (!allowVoid && list.length === 1 && list[0] === 'void') list = []; // avoid (void)
    if (rawList) {
      if (ret) {
        list.push(ret + '?');
      }
      return list;
    } else {
      return ret + flushList();
    }
  }
  var final = func;
  try {
    // Special-case the entry point, since its name differs from other name mangling.
    if (func == 'Object._main' || func == '_main') {
      return 'main()';
    }
    if (typeof func === 'number') func = Pointer_stringify(func);
    if (func[0] !== '_') return func;
    if (func[1] !== '_') return func; // C function
    if (func[2] !== 'Z') return func;
    switch (func[3]) {
      case 'n': return 'operator new()';
      case 'd': return 'operator delete()';
    }
    final = parse();
  } catch(e) {
    final += '?';
  }
  if (final.indexOf('?') >= 0 && !hasLibcxxabi) {
    Runtime.warnOnce('warning: a problem occurred in builtin C++ name demangling; build with  -s DEMANGLE_SUPPORT=1  to link in libcxxabi demangling');
  }
  return final;
}

function demangleAll(text) {
  return text.replace(/__Z[\w\d_]+/g, function(x) { var y = demangle(x); return x === y ? x : (x + ' [' + y + ']') });
}

function jsStackTrace() {
  var err = new Error();
  if (!err.stack) {
    // IE10+ special cases: It does have callstack info, but it is only populated if an Error object is thrown,
    // so try that as a special-case.
    try {
      throw new Error(0);
    } catch(e) {
      err = e;
    }
    if (!err.stack) {
      return '(no stack trace available)';
    }
  }
  return err.stack.toString();
}

function stackTrace() {
  return demangleAll(jsStackTrace());
}
Module['stackTrace'] = stackTrace;

// Memory management

var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return (x+4095)&-4096;
}

var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;

var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk

function enlargeMemory() {
  abort('Cannot enlarge memory arrays. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value ' + TOTAL_MEMORY + ', (2) compile with ALLOW_MEMORY_GROWTH which adjusts the size at runtime but prevents some optimizations, or (3) set Module.TOTAL_MEMORY before the program runs.');
}


var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 33554432;
var FAST_MEMORY = Module['FAST_MEMORY'] || 2097152;

var totalMemory = 64*1024;
while (totalMemory < TOTAL_MEMORY || totalMemory < 2*TOTAL_STACK) {
  if (totalMemory < 16*1024*1024) {
    totalMemory *= 2;
  } else {
    totalMemory += 16*1024*1024
  }
}
if (totalMemory !== TOTAL_MEMORY) {
  Module.printErr('increasing TOTAL_MEMORY to ' + totalMemory + ' to be compliant with the asm.js spec');
  TOTAL_MEMORY = totalMemory;
}

// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(typeof Int32Array !== 'undefined' && typeof Float64Array !== 'undefined' && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'JS engine does not provide full typed array support');

var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);

// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');

Module['HEAP'] = HEAP;
Module['buffer'] = buffer;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;

function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}

var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the runtime has exited

var runtimeInitialized = false;
var runtimeExited = false;

function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}

function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}

function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}

function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
  runtimeExited = true;
}

function postRun() {
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}

function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}
Module['addOnPreRun'] = Module.addOnPreRun = addOnPreRun;

function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}
Module['addOnInit'] = Module.addOnInit = addOnInit;

function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}
Module['addOnPreMain'] = Module.addOnPreMain = addOnPreMain;

function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}
Module['addOnExit'] = Module.addOnExit = addOnExit;

function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}
Module['addOnPostRun'] = Module.addOnPostRun = addOnPostRun;

// Tools


function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;

function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;

function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))>>0)]=chr;
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;

function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[(((buffer)+(i))>>0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;

function writeAsciiToMemory(str, buffer, dontAddNull) {
  for (var i = 0; i < str.length; i++) {
    HEAP8[(((buffer)+(i))>>0)]=str.charCodeAt(i);
  }
  if (!dontAddNull) HEAP8[(((buffer)+(str.length))>>0)]=0;
}
Module['writeAsciiToMemory'] = writeAsciiToMemory;

function unSign(value, bits, ignore) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}

// check for imul support, and also for correctness ( https://bugs.webkit.org/show_bug.cgi?id=126345 )
if (!Math['imul'] || Math['imul'](0xffffffff, 5) !== -5) Math['imul'] = function imul(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
Math.imul = Math['imul'];


var Math_abs = Math.abs;
var Math_cos = Math.cos;
var Math_sin = Math.sin;
var Math_tan = Math.tan;
var Math_acos = Math.acos;
var Math_asin = Math.asin;
var Math_atan = Math.atan;
var Math_atan2 = Math.atan2;
var Math_exp = Math.exp;
var Math_log = Math.log;
var Math_sqrt = Math.sqrt;
var Math_ceil = Math.ceil;
var Math_floor = Math.floor;
var Math_pow = Math.pow;
var Math_imul = Math.imul;
var Math_fround = Math.fround;
var Math_min = Math.min;

// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyWatcher = null;
var dependenciesFulfilled = null; // overridden to take different actions when all run dependencies are fulfilled

function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    }
    if (dependenciesFulfilled) {
      var callback = dependenciesFulfilled;
      dependenciesFulfilled = null;
      callback(); // can add another dependenciesFulfilled
    }
  }
}
Module['removeRunDependency'] = removeRunDependency;

Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data


var memoryInitializer = null;

// === Body ===





STATIC_BASE = 8;

STATICTOP = STATIC_BASE + 145440;
  /* global initializers */ __ATINIT__.push();
  

/* memory initializer */ allocate([129,1,29,90,14,2,134,37,16,3,20,17,18,4,11,8,20,5,216,3,23,6,218,1,25,7,229,0,28,8,111,0,30,9,54,0,33,10,26,0,35,11,13,0,9,12,6,0,10,13,3,0,12,13,1,0,143,15,127,90,36,16,37,63,38,17,242,44,39,18,124,32,40,19,185,23,42,20,130,17,43,21,239,12,45,22,161,9,46,23,47,7,48,24,92,5,49,25,6,4,51,26,3,3,52,27,64,2,54,28,177,1,56,29,68,1,57,30,245,0,59,31,183,0,60,32,138,0,62,33,104,0,63,34,78,0,32,35,59,0,33,9,44,0,165,37,225,90,64,38,76,72,65,39,13,58,67,40,241,46,68,41,31,38,69,42,51,31,70,43,168,25,72,44,24,21,73,45,119,17,74,46,116,14,75,47,251,11,77,48,248,9,78,49,97,8,79,50,6,7,48,51,205,5,50,52,222,4,50,53,15,4,51,54,99,3,52,55,212,2,53,56,92,2,54,57,248,1,55,58,164,1,56,59,96,1,57,60,37,1,58,61,246,0,59,62,203,0,61,63,171,0,61,32,143,0,193,65,18,91,80,66,4,77,81,67,44,65,82,68,216,55,83,69,232,47,84,70,60,41,86,71,121,35,87,72,223,30,87,73,169,26,72,74,78,23,72,75,36,20,74,76,156,17,74,77,107,15,75,78,81,13,77,79,182,11,77,48,64,10,208,81,50,88,88,82,28,77,89,83,142,67,90,84,221,59,91,85,238,52,92,86,174,46,93,87,154,41,86,71,22,37,216,89,112,85,95,90,169,76,96,91,217,68,97,92,34,62,99,93,36,56,99,94,180,50,93,86,23,46,223,96,168,86,101,97,70,79,102,98,229,71,103,99,207,65,104,100,61,60,99,93,94,55,105,102,49,82,106,103,15,76,107,104,57,70,103,99,94,65,233,106,39,86,108,107,231,80,109,103,133,75,110,109,151,85,111,107,79,80,238,111,16,90,112,109,34,85,240,111,235,89,113,113,29,90,255,255,255,255,255,255,255,255,3,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,3,0,0,0,4,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,255,255,255,255,0,0,0,0,0,1,2,2,3,3,3,3,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE);
/* memory initializer */ allocate([14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+10240);
/* memory initializer */ allocate([15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+20480);
/* memory initializer */ allocate([15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+30720);
/* memory initializer */ allocate([16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+40960);
/* memory initializer */ allocate([16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+51200);
/* memory initializer */ allocate([16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,64,197,88,159,83,66,75,0,64,73,50,163,34,168,17,197,88,33,123,252,115,98,104,197,88,191,69,11,48,126,24,159,83,252,115,65,109,84,98,159,83,179,65,65,45,18,23,66,75,98,104,84,98,126,88,66,75,33,59,186,40,195,20,0,64,197,88,159,83,66,75,0,64,73,50,163,34,168,17,73,50,191,69,179,65,33,59,73,50,130,39,55,27,224,13,163,34,11,48,65,45,186,40,163,34,55,27,191,18,142,9,168,17,126,24,18,23,195,20,168,17,224,13,142,9,223,4,0,0,0,0,0,0,240,63,239,97,72,177,80,49,246,63,202,111,77,145,174,231,244,63,170,17,108,239,98,208,242,63,0,0,0,0,0,0,240,63,59,191,167,192,105,36,233,63,187,32,199,123,122,81,225,63,93,171,114,222,85,168,209,63,0,1,2,2,3,3,3,3,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+61440);
/* memory initializer */ allocate([13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+71680);
/* memory initializer */ allocate([14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+81920);
/* memory initializer */ allocate([15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+92160);
/* memory initializer */ allocate([16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+102400);
/* memory initializer */ allocate([16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+112640);
/* memory initializer */ allocate([16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,83,67,65,78,32,0,0,0,37,115,37,100,0,0,0,0,0,0,0,0,0,0,0,0,44,0,0,0,0,0,0,0,58,32,37,100,32,37,100,0,32,37,100,32,37,100,0,0,16,0,0,0,11,0,0,0,10,0,0,0,16,0,0,0,24,0,0,0,40,0,0,0,51,0,0,0,61,0,0,0,12,0,0,0,12,0,0,0,14,0,0,0,19,0,0,0,26,0,0,0,58,0,0,0,60,0,0,0,55,0,0,0,14,0,0,0,13,0,0,0,16,0,0,0,24,0,0,0,40,0,0,0,57,0,0,0,69,0,0,0,56,0,0,0,14,0,0,0,17,0,0,0,22,0,0,0,29,0,0,0,51,0,0,0,87,0,0,0,80,0,0,0,62,0,0,0,18,0,0,0,22,0,0,0,37,0,0,0,56,0,0,0,68,0,0,0,109,0,0,0,103,0,0,0,77,0,0,0,24,0,0,0,35,0,0,0,55,0,0,0,64,0,0,0,81,0,0,0,104,0,0,0,113,0,0,0,92,0,0,0,49,0,0,0,64,0,0,0,78,0,0,0,87,0,0,0,103,0,0,0,121,0,0,0,120,0,0,0,101,0,0,0,72,0,0,0,92,0,0,0,95,0,0,0,98,0,0,0,112,0,0,0,100,0,0,0,103,0,0,0,99,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,12,0,0,0,17,0,0,0,20,0,0,0,21,0,0,0,30,0,0,0,34,0,0,0,56,0,0,0,63,0,0,0,18,0,0,0,20,0,0,0,20,0,0,0,26,0,0,0,28,0,0,0,51,0,0,0,61,0,0,0,55,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,26,0,0,0,33,0,0,0,58,0,0,0,69,0,0,0,55,0,0,0,26,0,0,0,26,0,0,0,26,0,0,0,30,0,0,0,46,0,0,0,87,0,0,0,86,0,0,0,66,0,0,0,31,0,0,0,33,0,0,0,36,0,0,0,40,0,0,0,46,0,0,0,96,0,0,0,100,0,0,0,73,0,0,0,40,0,0,0,35,0,0,0,46,0,0,0,62,0,0,0,81,0,0,0,100,0,0,0,111,0,0,0,91,0,0,0,46,0,0,0,66,0,0,0,76,0,0,0,86,0,0,0,102,0,0,0,121,0,0,0,120,0,0,0,101,0,0,0,68,0,0,0,90,0,0,0,90,0,0,0,96,0,0,0,113,0,0,0,102,0,0,0,105,0,0,0,103,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,18,0,0,0,25,0,0,0,37,0,0,0,56,0,0,0,85,0,0,0,16,0,0,0,17,0,0,0,20,0,0,0,27,0,0,0,34,0,0,0,40,0,0,0,53,0,0,0,75,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,31,0,0,0,43,0,0,0,62,0,0,0,91,0,0,0,135,0,0,0,18,0,0,0,27,0,0,0,31,0,0,0,40,0,0,0,53,0,0,0,74,0,0,0,106,0,0,0,156,0,0,0,25,0,0,0,34,0,0,0,43,0,0,0,53,0,0,0,69,0,0,0,94,0,0,0,131,0,0,0,189,0,0,0,37,0,0,0,40,0,0,0,62,0,0,0,74,0,0,0,94,0,0,0,124,0,0,0,169,0,0,0,238,0,0,0,56,0,0,0,53,0,0,0,91,0,0,0,106,0,0,0,131,0,0,0,169,0,0,0,226,0,0,0,55,1,0,0,85,0,0,0,75,0,0,0,135,0,0,0,156,0,0,0,189,0,0,0,238,0,0,0,55,1,0,0,162,1,0,0,9,0,0,0,10,0,0,0,12,0,0,0,14,0,0,0,27,0,0,0,32,0,0,0,51,0,0,0,62,0,0,0,11,0,0,0,12,0,0,0,14,0,0,0,19,0,0,0,27,0,0,0,44,0,0,0,59,0,0,0,73,0,0,0,12,0,0,0,14,0,0,0,18,0,0,0,25,0,0,0,42,0,0,0,59,0,0,0,79,0,0,0,78,0,0,0,17,0,0,0,18,0,0,0,25,0,0,0,42,0,0,0,61,0,0,0,92,0,0,0,87,0,0,0,92,0,0,0,23,0,0,0,28,0,0,0,42,0,0,0,75,0,0,0,79,0,0,0,112,0,0,0,112,0,0,0,99,0,0,0,40,0,0,0,42,0,0,0,59,0,0,0,84,0,0,0,88,0,0,0,124,0,0,0,132,0,0,0,111,0,0,0,42,0,0,0,64,0,0,0,78,0,0,0,95,0,0,0,105,0,0,0,126,0,0,0,125,0,0,0,99,0,0,0,70,0,0,0,75,0,0,0,100,0,0,0,102,0,0,0,116,0,0,0,100,0,0,0,107,0,0,0,98], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+122880);
/* memory initializer */ allocate([10,0,0,0,12,0,0,0,14,0,0,0,19,0,0,0,26,0,0,0,38,0,0,0,57,0,0,0,86,0,0,0,12,0,0,0,18,0,0,0,21,0,0,0,28,0,0,0,35,0,0,0,41,0,0,0,54,0,0,0,76,0,0,0,14,0,0,0,21,0,0,0,25,0,0,0,32,0,0,0,44,0,0,0,63,0,0,0,92,0,0,0,136,0,0,0,19,0,0,0,28,0,0,0,32,0,0,0,41,0,0,0,54,0,0,0,75,0,0,0,107,0,0,0,157,0,0,0,26,0,0,0,35,0,0,0,44,0,0,0,54,0,0,0,70,0,0,0,95,0,0,0,132,0,0,0,190,0,0,0,38,0,0,0,41,0,0,0,63,0,0,0,75,0,0,0,95,0,0,0,125,0,0,0,170,0,0,0,239,0,0,0,57,0,0,0,54,0,0,0,92,0,0,0,107,0,0,0,132,0,0,0,170,0,0,0,227,0,0,0,56,1,0,0,86,0,0,0,76,0,0,0,136,0,0,0,157,0,0,0,190,0,0,0,239,0,0,0,56,1,0,0,163,1,0,0,7,0,0,0,8,0,0,0,10,0,0,0,14,0,0,0,23,0,0,0,44,0,0,0,95,0,0,0,241,0,0,0,8,0,0,0,8,0,0,0,11,0,0,0,15,0,0,0,25,0,0,0,47,0,0,0,102,0,0,0,255,0,0,0,10,0,0,0,11,0,0,0,13,0,0,0,19,0,0,0,31,0,0,0,58,0,0,0,127,0,0,0,255,0,0,0,14,0,0,0,15,0,0,0,19,0,0,0,27,0,0,0,44,0,0,0,83,0,0,0,181,0,0,0,255,0,0,0,23,0,0,0,25,0,0,0,31,0,0,0,44,0,0,0,72,0,0,0,136,0,0,0,255,0,0,0,255,0,0,0,44,0,0,0,47,0,0,0,58,0,0,0,83,0,0,0,136,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,95,0,0,0,102,0,0,0,127,0,0,0,181,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,241,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,15,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,15,0,0,0,19,0,0,0,25,0,0,0,32,0,0,0,11,0,0,0,13,0,0,0,10,0,0,0,10,0,0,0,12,0,0,0,15,0,0,0,19,0,0,0,24,0,0,0,11,0,0,0,10,0,0,0,14,0,0,0,14,0,0,0,16,0,0,0,18,0,0,0,22,0,0,0,27,0,0,0,12,0,0,0,10,0,0,0,14,0,0,0,18,0,0,0,21,0,0,0,24,0,0,0,28,0,0,0,33,0,0,0,15,0,0,0,12,0,0,0,16,0,0,0,21,0,0,0,26,0,0,0,31,0,0,0,36,0,0,0,42,0,0,0,19,0,0,0,15,0,0,0,18,0,0,0,24,0,0,0,31,0,0,0,38,0,0,0,45,0,0,0,53,0,0,0,25,0,0,0,19,0,0,0,22,0,0,0,28,0,0,0,36,0,0,0,45,0,0,0,55,0,0,0,65,0,0,0,32,0,0,0,24,0,0,0,27,0,0,0,33,0,0,0,42,0,0,0,53,0,0,0,65,0,0,0,77,0,0,0,14,0,0,0,10,0,0,0,11,0,0,0,14,0,0,0,19,0,0,0,25,0,0,0,34,0,0,0,45,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,15,0,0,0,20,0,0,0,26,0,0,0,33,0,0,0,11,0,0,0,11,0,0,0,15,0,0,0,18,0,0,0,21,0,0,0,25,0,0,0,31,0,0,0,38,0,0,0,14,0,0,0,12,0,0,0,18,0,0,0,24,0,0,0,28,0,0,0,33,0,0,0,39,0,0,0,47,0,0,0,19,0,0,0,15,0,0,0,21,0,0,0,28,0,0,0,36,0,0,0,43,0,0,0,51,0,0,0,59,0,0,0,25,0,0,0,20,0,0,0,25,0,0,0,33,0,0,0,43,0,0,0,54,0,0,0,64,0,0,0,74,0,0,0,34,0,0,0,26,0,0,0,31,0,0,0,39,0,0,0,51,0,0,0,64,0,0,0,77,0,0,0,91,0,0,0,45,0,0,0,33,0,0,0,38,0,0,0,47,0,0,0,59,0,0,0,74,0,0,0,91,0,0,0,108,0,0,0,17,0,0,0,18,0,0,0,24,0,0,0,47,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,18,0,0,0,21,0,0,0,26,0,0,0,66,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,24,0,0,0,26,0,0,0,56,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,47,0,0,0,66,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,8,0,0,0,12,0,0,0,15,0,0,0,15,0,0,0,86,0,0,0,96,0,0,0,96,0,0,0,98,0,0,0,13,0,0,0,13,0,0,0,15,0,0,0,26,0,0,0,90,0,0,0,96,0,0,0,99,0,0,0,98,0,0,0,12,0,0,0,15,0,0,0,18,0,0,0,96,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,17,0,0,0,16,0,0,0,90,0,0,0,96,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,96,0,0,0,96,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,18,0,0,0,25,0,0,0,37,0,0,0,56,0,0,0,85,0,0,0,16,0,0,0,17,0,0,0,20,0,0,0,27,0,0,0,34,0,0,0,40,0,0,0,53,0,0,0,75,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,31,0,0,0,43,0,0,0,62,0,0,0,91,0,0,0,135,0,0,0,18,0,0,0,27,0,0,0,31,0,0,0,40,0,0,0,53,0,0,0,74,0,0,0,106,0,0,0,156,0,0,0,25,0,0,0,34,0,0,0,43,0,0,0,53,0,0,0,69,0,0,0,94,0,0,0,131,0,0,0,189,0,0,0,37,0,0,0,40,0,0,0,62,0,0,0,74,0,0,0,94,0,0,0,124,0,0,0,169,0,0,0,238,0,0,0,56,0,0,0,53,0,0,0,91,0,0,0,106,0,0,0,131,0,0,0,169,0,0,0,226,0,0,0,55,1,0,0,85,0,0,0,75,0,0,0,135,0,0,0,156,0,0,0,189,0,0,0,238,0,0,0,55,1,0,0,162,1,0,0,9,0,0,0,10,0,0,0,17,0,0,0,19,0,0,0,62,0,0,0,89,0,0,0,91,0,0,0,97,0,0,0,12,0,0,0,13,0,0,0,18,0,0,0,29,0,0,0,84,0,0,0,91,0,0,0,88,0,0,0,98,0,0,0,14,0,0,0,19,0,0,0,29,0,0,0,93,0,0,0,95,0,0,0,95,0,0,0,98,0,0,0,97,0,0,0,20,0,0,0,26,0,0,0,84,0,0,0,88,0,0,0,95,0,0,0,95,0,0,0,98,0,0,0,94,0,0,0,26,0,0,0,86,0,0,0,91,0,0,0,93,0,0,0,97,0,0,0,99,0,0,0,98,0,0,0,99,0,0,0,99,0,0,0,100,0,0,0,98,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,97,0,0,0,97,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,97,0,0,0,99,0,0,0,10,0,0,0,12,0,0,0,14,0,0,0,19,0,0,0,26,0,0,0,38,0,0,0,57,0,0,0,86,0,0,0,12,0,0,0,18,0,0,0,21,0,0,0,28,0,0,0,35,0,0,0,41,0,0,0,54,0,0,0,76,0,0,0,14,0,0,0,21,0,0,0,25,0,0,0,32,0,0,0,44,0,0,0,63,0,0,0,92,0,0,0,136,0,0,0,19,0,0,0,28,0,0,0,32,0,0,0,41,0,0,0,54,0,0,0,75,0,0,0,107,0,0,0,157,0,0,0,26,0,0,0,35,0,0,0,44,0,0,0,54,0,0,0,70,0,0,0,95,0,0,0,132,0,0,0,190,0,0,0,38,0,0,0,41,0,0,0,63,0,0,0,75,0,0,0,95,0,0,0,125,0,0,0,170,0,0,0,239,0,0,0,57,0,0,0,54,0,0,0,92,0,0,0,107,0,0,0,132,0,0,0,170,0,0,0,227,0,0,0,56,1,0,0,86,0,0,0,76,0,0,0,136,0,0,0,157,0,0,0,190,0,0,0,239,0,0,0,56,1,0,0,163,1,0,0,7,0,0,0,8,0,0,0,10,0,0,0,14,0,0,0,23,0,0,0,44,0,0,0,95,0,0,0,241,0,0,0,8,0,0,0,8,0,0,0,11,0,0,0,15,0,0,0,25,0,0,0,47,0,0,0,102,0,0,0,255,0,0,0,10,0,0,0,11,0,0,0,13,0,0,0,19,0,0,0,31,0,0,0,58,0,0,0,127,0,0,0,255,0,0,0,14,0,0,0,15,0,0,0,19,0,0,0,27,0,0,0,44,0,0,0,83,0,0,0,181,0,0,0,255,0,0,0,23,0,0,0,25,0,0,0,31,0,0,0,44,0,0,0,72,0,0,0,136,0,0,0,255,0,0,0,255,0,0,0,44,0,0,0,47,0,0,0,58,0,0,0,83,0,0,0,136,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,95,0,0,0,102,0,0,0,127,0,0,0,181,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,241,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,15,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,15,0,0,0,19,0,0,0,25,0,0,0,32,0,0,0,11,0,0,0,13,0,0,0,10,0,0,0,10,0,0,0,12,0,0,0,15,0,0,0,19,0,0,0,24,0,0,0,11,0,0,0,10,0,0,0,14,0,0,0,14,0,0,0,16,0,0,0,18,0,0,0,22,0,0,0,27,0,0,0,12,0,0,0,10,0,0,0,14,0,0,0,18,0,0,0,21,0,0,0,24,0,0,0,28,0,0,0,33,0,0,0,15,0,0,0,12,0,0,0,16,0,0,0,21,0,0,0,26,0,0,0,31,0,0,0,36,0,0,0,42,0,0,0,19,0,0,0,15,0,0,0,18,0,0,0,24,0,0,0,31,0,0,0,38,0,0,0,45,0,0,0,53,0,0,0,25,0,0,0,19,0,0,0,22,0,0,0,28,0,0,0,36,0,0,0,45,0,0,0,55,0,0,0,65,0,0,0,32,0,0,0,24,0,0,0,27,0,0,0,33,0,0,0,42,0,0,0,53,0,0,0,65,0,0,0,77,0,0,0,14,0,0,0,10,0,0,0,11,0,0,0,14,0,0,0,19,0,0,0,25,0,0,0,34,0,0,0,45,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,15,0,0,0,20,0,0,0,26,0,0,0,33,0,0,0,11,0,0,0,11,0,0,0,15,0,0,0,18,0,0,0,21,0,0,0,25,0,0,0,31,0,0,0,38,0,0,0,14,0,0,0,12,0,0,0,18,0,0,0,24,0,0,0,28,0,0,0,33,0,0,0,39,0,0,0,47,0,0,0,19,0,0,0,15,0,0,0,21,0,0,0,28,0,0,0,36,0,0,0,43,0,0,0,51,0,0,0,59,0,0,0,25,0,0,0,20,0,0,0,25,0,0,0,33,0,0,0,43,0,0,0,54,0,0,0,64,0,0,0,74,0,0,0,34,0,0,0,26,0,0,0,31,0,0,0,39,0,0,0,51,0,0,0,64,0,0,0,77,0,0,0,91,0,0,0,45,0,0,0,33,0,0,0,38,0,0,0,47,0,0,0,59,0,0,0,74,0,0,0,91,0,0,0,108,0,0,0,2,0,0,0,8,0,0,0,5,0,0,0,12,0,0,0,18,0,0,0,0,0,0,0,0,0,1,5,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,0,0,0,0,0,0,3,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,0,0,0,0,0,0,2,1,3,3,2,4,3,5,5,4,4,0,0,1,125,0,0,0,0,0,0,0,1,2,3,0,4,17,5,18,33,49,65,6,19,81,97,7,34,113,20,50,129,145,161,8,35,66,177,193,21,82,209,240,36,51,98,114,130,9,10,22,23,24,25,26,37,38,39,40,41,42,52,53,54,55,56,57,58,67,68,69,70,71,72,73,74,83,84,85,86,87,88,89,90,99,100,101,102,103,104,105,106,115,116,117,118,119,120,121,122,131,132,133,134,135,136,137,138,146,147,148,149,150,151,152,153,154,162,163,164,165,166,167,168,169,170,178,179,180,181,182,183,184,185,186,194,195,196,197,198,199,200,201,202,210,211,212,213,214,215,216,217,218,225,226,227,228,229,230,231,232,233,234,241,242,243,244,245,246,247,248,249,250,0,0,0,0,0,0,0,0,2,1,2,4,4,3,4,7,5,4,4,0,1,2,119,0,0,0,0,0,0,0,0,1,2,3,17,4,5,33,49,6,18,65,81,7,97,113,19,34,50,129,8,20,66,145,161,177,193,9,35,51,82,240,21,98,114,209,10,22,36,52,225,37,241,23,24,25,26,38,39,40,41,42,53,54,55,56,57,58,67,68,69,70,71,72,73,74,83,84,85,86,87,88,89,90,99,100,101,102,103,104,105,106,115,116,117,118,119,120,121,122,130,131,132,133,134,135,136,137,138,146,147,148,149,150,151,152,153,154,162,163,164,165,166,167,168,169,170,178,179,180,181,182,183,184,185,186,194,195,196,197,198,199,200,201,202,210,211,212,213,214,215,216,217,218,226,227,228,229,230,231,232,233,234,242,243,244,245,246,247,248,249,250,0,0,0,0,0,0,66,111,103,117,115,32,109,101,115,115,97,103,101,32,99,111,100,101,32,37,100,0,0,0,83,111,114,114,121,44,32,97,114,105,116,104,109,101,116,105,99,32,99,111,100,105,110,103,32,105,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,0,0,0,0,0,65,76,73,71,78,95,84,89,80,69,32,105,115,32,119,114,111,110,103,44,32,112,108,101,97,115,101,32,102,105,120,0,77,65,88,95,65,76,76,79,67,95,67,72,85,78,75,32,105,115,32,119,114,111,110,103,44,32,112,108,101,97,115,101,32,102,105,120,0,0,0,0,66,111,103,117,115,32,98,117,102,102,101,114,32,99,111,110,116,114,111,108,32,109,111,100,101,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,111,109,112,111,110,101,110,116,32,73,68,32,37,100,32,105,110,32,83,79,83,0,0,68,67,84,32,99,111,101,102,102,105,99,105,101,110,116,32,111,117,116,32,111,102,32,114,97,110,103,101,0,0,0,0,73,68,67,84,32,111,117,116,112,117,116,32,98,108,111,99,107,32,115,105,122,101,32,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,66,111,103,117,115,32,72,117,102,102,109,97,110,32,116,97,98,108,101,32,100,101,102,105,110,105,116,105,111,110,0,0,66,111,103,117,115,32,105,110,112,117,116,32,99,111,108,111,114,115,112,97,99,101,0,0,66,111,103,117,115,32,74,80,69,71,32,99,111,108,111,114,115,112,97,99,101,0,0,0,66,111,103,117,115,32,109,97,114,107,101,114,32,108,101,110,103,116,104,0,0,0,0,0,87,114,111,110,103,32,74,80,69,71,32,108,105,98,114,97,114,121,32,118,101,114,115,105,111,110,58,32,108,105,98,114,97,114,121,32,105,115,32,37,100,44,32,99,97,108,108,101,114,32,101,120,112,101,99,116,115,32,37,100,0,0,0,0,83,97,109,112,108,105,110,103,32,102,97,99,116,111,114,115,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,105,110,116,101,114,108,101,97,118,101,100,32,115,99,97,110,0,73,110,118,97,108,105,100,32,109,101,109,111,114,121,32,112,111,111,108,32,99,111,100,101,32,37,100,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,74,80,69,71,32,100,97,116,97,32,112,114,101,99,105,115,105,111,110,32,37,100,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,114,111,103,114,101,115,115,105,118,101,32,112,97,114,97,109,101,116,101,114,115,32,83,115,61,37,100,32,83,101,61,37,100,32,65,104,61,37,100,32,65,108,61,37,100,0,0,73,110,118,97,108,105,100,32,112,114,111,103,114,101,115,115,105,118,101,32,112,97,114,97,109,101,116,101,114,115,32,97,116,32,115,99,97,110,32,115,99,114,105,112,116,32,101,110,116,114,121,32,37,100,0,0,66,111,103,117,115,32,115,97,109,112,108,105,110,103,32,102,97,99,116,111,114,115,0,0,73,110,118,97,108,105,100,32,115,99,97,110,32,115,99,114,105,112,116,32,97,116,32,101,110,116,114,121,32,37,100,0,73,109,112,114,111,112,101,114,32,99,97,108,108,32,116,111,32,74,80,69,71,32,108,105,98,114,97,114,121,32,105,110,32,115,116,97,116,101,32,37,100,0,0,0,0,0,0,0,74,80,69,71,32,112,97,114,97,109,101,116,101,114,32,115,116,114,117,99,116,32,109,105,115,109,97,116,99,104,58,32,108,105,98,114,97,114,121,32,116,104,105,110,107,115,32,115,105,122,101,32,105,115,32,37,117,44,32,99,97,108,108,101,114,32,101,120,112,101,99,116,115,32,37,117,0,0,0,0,66,111,103,117,115,32,118,105,114,116,117,97,108,32,97,114,114,97,121,32,97,99,99,101,115,115,0,0,0,0,0,0,66,117,102,102,101,114,32,112,97,115,115,101,100,32,116,111,32,74,80,69,71,32,108,105,98,114,97,114,121,32,105,115,32,116,111,111,32,115,109,97,108,108,0,0,0,0,0,0,83,117,115,112,101,110,115,105,111,110,32,110,111,116,32,97,108,108,111,119,101,100,32,104,101,114,101,0,0,0,0,0,67,67,73,82,54,48,49,32,115,97,109,112,108,105,110,103,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,32,121,101,116,0,0,0,0,84,111,111,32,109,97,110,121,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,115,58,32,37,100,44,32,109,97,120,32,37,100,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,108,111,114,32,99,111,110,118,101,114,115,105,111,110,32,114,101,113,117,101,115,116,0,0,0,0,66,111,103,117,115,32,68,65,67,32,105,110,100,101,120,32,37,100,0,0,0,0,0,0,66,111,103,117,115,32,68,65,67,32,118,97,108,117,101,32,48,120,37,120,0,0,0,0,66,111,103,117,115,32,68,72,84,32,105,110,100,101,120,32,37,100,0,0,0,0,0,0,66,111,103,117,115,32,68,81,84,32,105,110,100,101,120,32,37,100,0,0,0,0,0,0,69,109,112,116,121,32,74,80,69,71,32,105,109,97,103,101,32,40,68,78,76,32,110,111,116,32,115,117,112,112,111,114,116,101,100,41,0,0,0,0,82,101,97,100,32,102,114,111,109,32,69,77,83,32,102,97,105,108,101,100,0,0,0,0,87,114,105,116,101,32,116,111,32,69,77,83,32,102,97,105,108,101,100,0,0,0,0,0,68,105,100,110,39,116,32,101,120,112,101,99,116,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,115,99,97,110,0,0,0,0,0,0,0,0,73,110,112,117,116,32,102,105,108,101,32,114,101,97,100,32,101,114,114,111,114,0,0,0,79,117,116,112,117,116,32,102,105,108,101,32,119,114,105,116,101,32,101,114,114,111,114,32,45,45,45,32,111,117,116,32,111,102,32,100,105,115,107,32,115,112,97,99,101,63,0,0,70,114,97,99,116,105,111,110,97,108,32,115,97,109,112,108,105,110,103,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,32,121,101,116,0,72,117,102,102,109,97,110,32,99,111,100,101,32,115,105,122,101,32,116,97,98,108,101,32,111,118,101,114,102,108,111,119,0,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,72,117,102,102,109,97,110,32,99,111,100,101,32,116,97,98,108,101,32,101,110,116,114,121,0,0,0,0,0,0,0,0,77,97,120,105,109,117,109,32,115,117,112,112,111,114,116,101,100,32,105,109,97,103,101,32,100,105,109,101,110,115,105,111,110,32,105,115,32,37,117,32,112,105,120,101,108,115,0,0,69,109,112,116,121,32,105,110,112,117,116,32,102,105,108,101,0,0,0,0,0,0,0,0,80,114,101,109,97,116,117,114,101,32,101,110,100,32,111,102,32,105,110,112,117,116,32,102,105,108,101,0,0,0,0,0,67,97,110,110,111,116,32,116,114,97,110,115,99,111,100,101,32,100,117,101,32,116,111,32,109,117,108,116,105,112,108,101,32,117,115,101,32,111,102,32,113,117,97,110,116,105,122,97,116,105,111,110,32,116,97,98,108,101,32,37,100,0,0,0,83,99,97,110,32,115,99,114,105,112,116,32,100,111,101,115,32,110,111,116,32,116,114,97,110,115,109,105,116,32,97,108,108,32,100,97,116,97,0,0,73,110,118,97,108,105,100,32,99,111,108,111,114,32,113,117,97,110,116,105,122,97,116,105,111,110,32,109,111,100,101,32,99,104,97,110,103,101,0,0,78,111,116,32,105,109,112,108,101,109,101,110,116,101,100,32,121,101,116,0,0,0,0,0,82,101,113,117,101,115,116,101,100,32,102,101,97,116,117,114,101,32,119,97,115,32,111,109,105,116,116,101,100,32,97,116,32,99,111,109,112,105,108,101,32,116,105,109,101,0,0,0,66,97,99,107,105,110,103,32,115,116,111,114,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,0,0,0,0,72,117,102,102,109,97,110,32,116,97,98,108,101,32,48,120,37,48,50,120,32,119,97,115,32,110,111,116,32,100,101,102,105,110,101,100,0,0,0,0,74,80,69,71,32,100,97,116,97,115,116,114,101,97,109,32,99,111,110,116,97,105,110,115,32,110,111,32,105,109,97,103,101,0,0,0,0,0,0,0,81,117,97,110,116,105,122,97,116,105,111,110,32,116,97,98,108,101,32,48,120,37,48,50,120,32,119,97,115,32,110,111,116,32,100,101,102,105,110,101,100,0,0,0,0,0,0,0,78,111,116,32,97,32,74,80,69,71,32,102,105,108,101,58,32,115,116,97,114,116,115,32,119,105,116,104,32,48,120,37,48,50,120,32,48,120,37,48,50,120,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,109,101,109,111,114,121,32,40,99,97,115,101,32,37,100,41,0,0,0,67,97,110,110,111,116,32,113,117,97,110,116,105,122,101,32,109,111,114,101,32,116,104,97,110,32,37,100,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,115,0,0,0,67,97,110,110,111,116,32,113,117,97,110,116,105,122,101,32,116,111,32,102,101,119,101,114,32,116,104,97,110,32,37,100,32,99,111,108,111,114,115,0,67,97,110,110,111,116,32,113,117,97,110,116,105,122,101,32,116,111,32,109,111,114,101,32,116,104,97,110,32,37,100,32,99,111,108,111,114,115,0,0,73,110,118,97,108,105,100,32,74,80,69,71,32,102,105,108,101,32,115,116,114,117,99,116,117,114,101,58,32,116,119,111,32,83,79,70,32,109,97,114,107,101,114,115,0,0,0,0,73,110,118,97,108,105,100,32,74,80,69,71,32,102,105,108,101,32,115,116,114,117,99,116,117,114,101,58,32,109,105,115,115,105,110,103,32,83,79,83,32,109,97,114,107,101,114,0,85,110,115,117,112,112,111,114,116,101,100,32,74,80,69,71,32,112,114,111,99,101,115,115,58,32,83,79,70,32,116,121,112,101,32,48,120,37,48,50,120,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,74,80,69,71,32,102,105,108,101,32,115,116,114,117,99,116,117,114,101,58,32,116,119,111,32,83,79,73,32,109,97,114,107,101,114,115,0,0,0,0,73,110,118,97,108,105,100,32,74,80,69,71,32,102,105,108,101,32,115,116,114,117,99,116,117,114,101,58,32,83,79,83,32,98,101,102,111,114,101,32,83,79,70,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,116,101,109,112,111,114,97,114,121,32,102,105,108,101,32,37,115,0,0,0,0,0,0,82,101,97,100,32,102,97,105,108,101,100,32,111,110,32,116,101,109,112,111,114,97,114,121,32,102,105,108,101,0,0,0,83,101,101,107,32,102,97,105,108,101,100,32,111,110,32,116,101,109,112,111,114,97,114,121,32,102,105,108,101,0,0,0,87,114,105,116,101,32,102,97,105,108,101,100,32,111,110,32,116,101,109,112,111,114,97,114,121,32,102,105,108,101,32,45,45,45,32,111,117,116,32,111,102,32,100,105,115,107,32,115,112,97,99,101,63,0,0,0,65,112,112,108,105,99,97,116,105,111,110,32,116,114,97,110,115,102,101,114,114,101,100,32,116,111,111,32,102,101,119,32,115,99,97,110,108,105,110,101,115,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,109,97,114,107,101,114,32,116,121,112,101,32,48,120,37,48,50,120,0,0,86,105,114,116,117,97,108,32,97,114,114,97,121,32,99,111,110,116,114,111,108,108,101,114,32,109,101,115,115,101,100,32,117,112,0,0,0,0,0,0,73,109,97,103,101,32,116,111,111,32,119,105,100,101,32,102,111,114,32,116,104,105,115,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,0,0,82,101,97,100,32,102,114,111,109,32,88,77,83,32,102,97,105,108,101,100,0,0,0,0,87,114,105,116,101,32,116,111,32,88,77,83,32,102,97,105,108,101,100,0,0,0,0,0,67,111,112,121,114,105,103,104,116,32,40,67,41,32,49,57,57,49,45,50,48,49,52,32,84,104,101,32,108,105,98,106,112,101,103,45,116,117,114,98,111,32,80,114,111,106,101,99,116,32,97,110,100,32,109,97,110,121,32,111,116,104,101,114,115,0,0,0,0,0,0,0,54,98,32,32,50,55,45,77,97,114,45,49,57,57,56,0,67,97,117,116,105,111,110,58,32,113,117,97,110,116,105,122,97,116,105,111,110,32,116,97,98,108,101,115,32,97,114,101,32,116,111,111,32,99,111,97,114,115,101,32,102,111,114,32,98,97,115,101,108,105,110,101,32,74,80,69,71,0,0,0,65,100,111,98,101,32,65,80,80,49,52,32,109,97,114,107,101,114,58,32,118,101,114,115,105,111,110,32,37,100,44,32,102,108,97,103,115,32,48,120,37,48,52,120,32,48,120,37,48,52,120,44,32,116,114,97,110,115,102,111,114,109,32,37,100,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,65,80,80,48,32,109,97,114,107,101,114,32,40,110,111,116,32,74,70,73,70,41,44,32,108,101,110,103,116,104,32,37,117,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,65,80,80,49,52,32,109,97,114,107,101,114,32,40,110,111,116,32,65,100,111,98,101,41,44,32,108,101,110,103,116,104,32,37,117,0,0,0,0,0,68,101,102,105,110,101,32,65,114,105,116,104,109,101,116,105,99,32,84,97,98,108,101,32,48,120,37,48,50,120,58,32,48,120,37,48,50,120,0,0,68,101,102,105,110,101,32,72,117,102,102,109,97,110,32,84,97,98,108,101,32,48,120,37,48,50,120,0,0,0,0,0,68,101,102,105,110,101,32,81,117,97,110,116,105,122,97,116,105,111,110,32,84,97,98,108,101,32,37,100,32,32,112,114,101,99,105,115,105,111,110,32,37,100,0,0,0,0,0,0,68,101,102,105,110,101,32,82,101,115,116,97,114,116,32,73,110,116,101,114,118,97,108,32,37,117,0,0,0,0,0,0,70,114,101,101,100,32,69,77,83,32,104,97,110,100,108,101,32,37,117,0,0,0,0,0,79,98,116,97,105,110,101,100,32,69,77,83,32,104,97,110,100,108,101,32,37,117,0,0,69,110,100,32,79,102,32,73,109,97,103,101,0,0,0,0,32,32,32,32,32,32,32,32,37,51,100,32,37,51,100,32,37,51,100,32,37,51,100,32,37,51,100,32,37,51,100,32,37,51,100,32,37,51,100,0,74,70,73,70,32,65,80,80,48,32,109,97,114,107,101,114,58,32,118,101,114,115,105,111,110,32,37,100,46,37,48,50,100,44,32,100,101,110,115,105,116,121,32,37,100,120,37,100,32,32,37,100,0,0,0,0,87,97,114,110,105,110,103,58,32,116,104,117,109,98,110,97,105,108,32,105,109,97,103,101,32,115,105,122,101,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,100,97,116,97,32,108,101,110,103,116,104,32,37,117,0,0,0,0,0,74,70,73,70,32,101,120,116,101,110,115,105,111,110,32,109,97,114,107,101,114,58,32,116,121,112,101,32,48,120,37,48,50,120,44,32,108,101,110,103,116,104,32,37,117,0,0,0,32,32,32,32,119,105,116,104,32,37,100,32,120,32,37,100,32,116,104,117,109,98,110,97,105,108,32,105,109,97,103,101,0,0,0,0,0,0,0,0,77,105,115,99,101,108,108,97,110,101,111,117,115,32,109,97,114,107,101,114,32,48,120,37,48,50,120,44,32,108,101,110,103,116,104,32,37,117,0,0,85,110,101,120,112,101,99,116,101,100,32,109,97,114,107,101,114,32,48,120,37,48,50,120,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,37,52,117,32,37,52,117,32,37,52,117,32,37,52,117,32,37,52,117,32,37,52,117,32,37,52,117,32,37,52,117,0,81,117,97,110,116,105,122,105,110,103,32,116,111,32,37,100,32,61,32,37,100,42,37,100,42,37,100,32,99,111,108,111,114,115,0,0,0,0,0,0,81,117,97,110,116,105,122,105,110,103,32,116,111,32,37,100,32,99,111,108,111,114,115,0,83,101,108,101,99,116,101,100,32,37,100,32,99,111,108,111,114,115,32,102,111,114,32,113,117,97,110,116,105,122,97,116,105,111,110,0,0,0,0,0,65,116,32,109,97,114,107,101,114,32,48,120,37,48,50,120,44,32,114,101,99,111,118,101,114,121,32,97,99,116,105,111,110,32,37,100,0,0,0,0,82,83,84,37,100,0,0,0,83,109,111,111,116,104,105,110,103,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,119,105,116,104,32,110,111,110,115,116,97,110,100,97,114,100,32,115,97,109,112,108,105,110,103,32,114,97,116,105,111,115,0,0,0,0,0,0,0,0,83,116,97,114,116,32,79,102,32,70,114,97,109,101,32,48,120,37,48,50,120,58,32,119,105,100,116,104,61,37,117,44,32,104,101,105,103,104,116,61,37,117,44,32,99,111,109,112,111,110,101,110,116,115,61,37,100,0,0,0,0,0,0,0,32,32,32,32,67,111,109,112,111,110,101,110,116,32,37,100,58,32,37,100,104,120,37,100,118,32,113,61,37,100,0,0,83,116,97,114,116,32,111,102,32,73,109,97,103,101,0,0,83,116,97,114,116,32,79,102,32,83,99,97,110,58,32,37,100,32,99,111,109,112,111,110,101,110,116,115,0,0,0,0,32,32,32,32,67,111,109,112,111,110,101,110,116,32,37,100,58,32,100,99,61,37,100,32,97,99,61,37,100,0,0,0,32,32,83,115,61,37,100,44,32,83,101,61,37,100,44,32,65,104,61,37,100,44,32,65,108,61,37,100,0,0,0,0,67,108,111,115,101,100,32,116,101,109,112,111,114,97,114,121,32,102,105,108,101,32,37,115,0,0,0,0,0,0,0,0,79,112,101,110,101,100,32,116,101,109,112,111,114,97,114,121,32,102,105,108,101,32,37,115,0,0,0,0,0,0,0,0,74,70,73,70,32,101,120,116,101,110,115,105,111,110,32,109,97,114,107,101,114,58,32,74,80,69,71,45,99,111,109,112,114,101,115,115,101,100,32,116,104,117,109,98,110,97,105,108,32,105,109,97,103,101,44,32,108,101,110,103,116,104,32,37,117,0,0,0,0,0,0,0,74,70,73,70,32,101,120,116,101,110,115,105,111,110,32,109,97,114,107,101,114,58,32,112,97,108,101,116,116,101,32,116,104,117,109,98,110,97,105,108,32,105,109,97,103,101,44,32,108,101,110,103,116,104,32,37,117,0,0,0,0,0,0,0,74,70,73,70,32,101,120,116,101,110,115,105,111,110,32,109,97,114,107,101,114,58,32,82,71,66,32,116,104,117,109,98,110,97,105,108,32,105,109,97,103,101,44,32,108,101,110,103,116,104,32,37,117,0,0,0,85,110,114,101,99,111,103,110,105,122,101,100,32,99,111,109,112,111,110,101,110,116,32,73,68,115,32,37,100,32,37,100,32,37,100,44,32,97,115,115,117,109,105,110,103,32,89,67,98,67,114,0,0,0,0,0,70,114,101,101,100,32,88,77,83,32,104,97,110,100,108,101,32,37,117,0,0,0,0,0,79,98,116,97,105,110,101,100,32,88,77,83,32,104,97,110,100,108,101,32,37,117,0,0,85,110,107,110,111,119,110,32,65,100,111,98,101,32,99,111,108,111,114,32,116,114,97,110,115,102,111,114,109,32,99,111,100,101,32,37,100,0,0,0,73,110,99,111,110,115,105,115,116,101,110,116,32,112,114,111,103,114,101,115,115,105,111,110,32,115,101,113,117,101,110,99,101,32,102,111,114,32,99,111,109,112,111,110,101,110,116,32,37,100,32,99,111,101,102,102,105,99,105,101,110,116,32,37,100,0,0,0,0,0,0,0,67,111,114,114,117,112,116,32,74,80,69,71,32,100,97,116,97,58,32,37,117,32,101,120,116,114,97,110,101,111,117,115,32,98,121,116,101,115,32,98,101,102,111,114,101,32,109,97,114,107,101,114,32,48,120,37,48,50,120,0,0,0,0,0,67,111,114,114,117,112,116,32,74,80,69,71,32,100,97,116,97,58,32,112,114,101,109,97,116,117,114,101,32,101,110,100,32,111,102,32,100,97,116,97,32,115,101,103,109,101,110,116,0,0,0,0,0,0,0,0,67,111,114,114,117,112,116,32,74,80,69,71,32,100,97,116,97,58,32,98,97,100,32,72,117,102,102,109,97,110,32,99,111,100,101,0,0,0,0,0,87,97,114,110,105,110,103,58,32,117,110,107,110,111,119,110,32,74,70,73,70,32,114,101,118,105,115,105,111,110,32,110,117,109,98,101,114,32,37,100,46,37,48,50,100,0,0,0,80,114,101,109,97,116,117,114,101,32,101,110,100,32,111,102,32,74,80,69,71,32,102,105,108,101,0,0,0,0,0,0,67,111,114,114,117,112,116,32,74,80,69,71,32,100,97,116,97,58,32,102,111,117,110,100,32,109,97,114,107,101,114,32,48,120,37,48,50,120,32,105,110,115,116,101,97,100,32,111,102,32,82,83,84,37,100,0,73,110,118,97,108,105,100,32,83,79,83,32,112,97,114,97,109,101,116,101,114,115,32,102,111,114,32,115,101,113,117,101,110,116,105,97,108,32,74,80,69,71,0,0,0,0,0,0,65,112,112,108,105,99,97,116,105,111,110,32,116,114,97,110,115,102,101,114,114,101,100,32,116,111,111,32,109,97,110,121,32,115,99,97,110,108,105,110,101,115,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,114,111,112,32,114,101,113,117,101,115,116,0,0,0,0,65,114,105,116,104,109,101,116,105,99,32,116,97,98,108,101,32,48,120,37,48,50,120,32,119,97,115,32,110,111,116,32,100,101,102,105,110,101,100,0,67,111,114,114,117,112,116,32,74,80,69,71,32,100,97,116,97,58,32,98,97,100,32,97,114,105,116,104,109,101,116,105,99,32,99,111,100,101,0,0,66,111,103,117,115,32,112,97,114,97,109,101,116,101,114,0,66,111,103,117,115,32,112,97,114,97,109,101,116,101,114,32,118,97,108,117,101,0,0,0,73,47,79,32,115,117,115,112,101,110,115,105,111,110,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,115,99,97,110,32,111,112,116,105,109,105,122,97,116,105,111,110,0,0,0,0,0,0,0,240,22,2,0,8,23,2,0,56,23,2,0,88,23,2,0,128,23,2,0,160,23,2,0,192,23,2,0,224,23,2,0,8,24,2,0,40,24,2,0,64,24,2,0,88,24,2,0,112,24,2,0,176,24,2,0,224,24,2,0,0,25,2,0,40,25,2,0,96,25,2,0,152,25,2,0,176,25,2,0,208,25,2,0,0,26,2,0,80,26,2,0,112,26,2,0,160,26,2,0,192,26,2,0,232,26,2,0,16,27,2,0,56,27,2,0,80,27,2,0,104,27,2,0,128,27,2,0,152,27,2,0,192,27,2,0,216,27,2,0,240,27,2,0,24,28,2,0,48,28,2,0,96,28,2,0,136,28,2,0,176,28,2,0,216,28,2,0,8,29,2,0,32,29,2,0,64,29,2,0,128,29,2,0,168,29,2,0,208,29,2,0,232,29,2,0,24,30,2,0,56,30,2,0,96,30,2,0,136,30,2,0,184,30,2,0,232,30,2,0,8,31,2,0,56,31,2,0,96,31,2,0,136,31,2,0,184,31,2,0,232,31,2,0,24,32,2,0,72,32,2,0,120,32,2,0,160,32,2,0,192,32,2,0,224,32,2,0,24,33,2,0,72,33,2,0,104,33,2,0,144,33,2,0,184,33,2,0,208,33,2,0,232,33,2,0,48,34,2,0,64,34,2,0,128,34,2,0,200,34,2,0,248,34,2,0,40,35,2,0,80,35,2,0,112,35,2,0,160,35,2,0,192,35,2,0,216,35,2,0,240,35,2,0,0,36,2,0,40,36,2,0,96,36,2,0,160,36,2,0,208,36,2,0,248,36,2,0,32,37,2,0,64,37,2,0,104,37,2,0,144,37,2,0,168,37,2,0,208,37,2,0,248,37,2,0,0,38,2,0,64,38,2,0,128,38,2,0,160,38,2,0,176,38,2,0,208,38,2,0,240,38,2,0,16,39,2,0,48,39,2,0,80,39,2,0,152,39,2,0,216,39,2,0,16,40,2,0,72,40,2,0,96,40,2,0,120,40,2,0,160,40,2,0,232,40,2,0,40,41,2,0,96,41,2,0,136,41,2,0,184,41,2,0,216,41,2,0,16,42,2,0,64,42,2,0,112,42,2,0,136,42,2,0,176,42,2,0,216,42,2,0,232,42,2,0,0,43,2,0,0,0,0,0,0,0,0,0,37,115,10,0,0,0,0,0,74,80,69,71,77,69,77,0,37,108,100,37,99,0,0,0,64,6,0,0,128,62,0,0,0,0,0,0,136,19,0,0,0,0,0,0,1,0,0,0,8,0,0,0,16,0,0,0,9,0,0,0,2,0,0,0,3,0,0,0,10,0,0,0,17,0,0,0,24,0,0,0,32,0,0,0,25,0,0,0,18,0,0,0,11,0,0,0,4,0,0,0,5,0,0,0,12,0,0,0,19,0,0,0,26,0,0,0,33,0,0,0,40,0,0,0,48,0,0,0,41,0,0,0,34,0,0,0,27,0,0,0,20,0,0,0,13,0,0,0,6,0,0,0,7,0,0,0,14,0,0,0,21,0,0,0,28,0,0,0,35,0,0,0,42,0,0,0,49,0,0,0,56,0,0,0,57,0,0,0,50,0,0,0,43,0,0,0,36,0,0,0,29,0,0,0,22,0,0,0,15,0,0,0,23,0,0,0,30,0,0,0,37,0,0,0,44,0,0,0,51,0,0,0,58,0,0,0,59,0,0,0,52,0,0,0,45,0,0,0,38,0,0,0,31,0,0,0,39,0,0,0,46,0,0,0,53,0,0,0,60,0,0,0,61,0,0,0,54,0,0,0,47,0,0,0,55,0,0,0,62,0,0,0,63,0,0,0,63,0,0,0,63,0,0,0,63,0,0,0,63,0,0,0,63,0,0,0,63,0,0,0,63,0,0,0,63,0,0,0,63,0,0,0,63,0,0,0,63,0,0,0,63,0,0,0,63,0,0,0,63,0,0,0,63,0,0,0,63,0,0,0,78,111,32,101,114,114,111,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,104,97,110,100,108,101,0,0,116,106,73,110,105,116,67,111,109,112,114,101,115,115,40,41,58,32,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,117,114,101,0,0,0,0,0,37,115,0,0,0,0,0,0,8,0,0,0,16,0,0,0,16,0,0,0,8,0,0,0,8,0,0,0,32,0,0,0,8,0,0,0,8,0,0,0,16,0,0,0,8,0,0,0,16,0,0,0,8,0,0,0,116,106,67,111,109,112,114,101,115,115,50,40,41,58,32,73,110,115,116,97,110,99,101,32], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+133120);
/* memory initializer */ allocate([104,97,115,32,110,111,116,32,98,101,101,110,32,105,110,105,116,105,97,108,105,122,101,100,32,102,111,114,32,99,111,109,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,116,106,67,111,109,112,114,101,115,115,50,40,41,58,32,73,110,118,97,108,105,100,32,97,114,103,117,109,101,110,116,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,1,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,74,83,73,77,68,95,70,79,82,67,69,77,77,88,61,49,0,0,0,0,0,0,0,0,74,83,73,77,68,95,70,79,82,67,69,83,83,69,61,49,0,0,0,0,0,0,0,0,74,83,73,77,68,95,70,79,82,67,69,83,83,69,50,61,49,0,0,0,0,0,0,0,116,106,67,111,109,112,114,101,115,115,50,40,41,58,32,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,117,114,101,0,0,0,0,0,0,0,0,84,74,95,82,69,86,69,82,84,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,84,74,95,79,80,84,73,77,73,90,69,0,0,0,0,0,84,74,95,65,82,73,84,72,77,69,84,73,67,0,0,0,84,74,95,82,69,83,84,65,82,84,0,0,0,0,0,0,37,100,37,99,0,0,0,0,2,0,0,192,3,0,0,192,4,0,0,192,5,0,0,192,6,0,0,192,7,0,0,192,8,0,0,192,9,0,0,192,10,0,0,192,11,0,0,192,12,0,0,192,13,0,0,192,14,0,0,192,15,0,0,192,16,0,0,192,17,0,0,192,18,0,0,192,19,0,0,192,20,0,0,192,21,0,0,192,22,0,0,192,23,0,0,192,24,0,0,192,25,0,0,192,26,0,0,192,27,0,0,192,28,0,0,192,29,0,0,192,30,0,0,192,31,0,0,192,0,0,0,179,1,0,0,195,2,0,0,195,3,0,0,195,4,0,0,195,5,0,0,195,6,0,0,195,7,0,0,195,8,0,0,195,9,0,0,195,10,0,0,195,11,0,0,195,12,0,0,195,13,0,0,211,14,0,0,195,15,0,0,195,0,0,12,187,1,0,12,195,2,0,12,195,3,0,12,195,4,0,12,211,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,1,2,3,4,5,6,7,8,9,255,255,255,255,255,255,255,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,255,255,255,255,255,255,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,1,2,4,7,3,6,5,0,0,0,0,0,0,0,0,105,110,102,105,110,105,116,121,0,0,0,0,0,0,0,0,110,97,110,0,0,0,0,0,95,112,137,0,255,9,47,15,10,0,0,0,100,0,0,0,232,3,0,0,16,39,0,0,160,134,1,0,64,66,15,0,128,150,152,0,0,225,245,5,17,0,10,0,17,17,17,0,0,0,0,5,0,0,0,0,0,0,9,0,0,0,0,11,0,0,0,0,0,0,0,0,17,0,15,10,17,17,17,3,10,7,0,1,19,9,11,11,0,0,9,6,11,0,0,11,0,6,17,0,0,0,17,17,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,17,0,10,10,17,17,17,0,10,0,0,2,0,9,11,0,0,0,9,0,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,0,0,0,9,12,0,0,0,0,0,12,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,4,13,0,0,0,0,9,14,0,0,0,0,0,14,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,15,0,0,0,0,9,16,0,0,0,0,0,16,0,0,16,0,0,18,0,0,0,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,18,18,18,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,10,0,0,0,0,9,11,0,0,0,0,0,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,0,0,0,9,12,0,0,0,0,0,12,0,0,12,0,0,45,43,32,32,32,48,88,48,120,0,0,0,0,0,0,0,40,110,117,108,108,41,0,0,45,48,88,43,48,88,32,48,88,45,48,120,43,48,120,32,48,120,0,0,0,0,0,0,105,110,102,0,0,0,0,0,73,78,70,0,0,0,0,0,110,97,110,0,0,0,0,0,78,65,78,0,0,0,0,0,48,49,50,51,52,53,54,55,56,57,65,66,67,68,69,70,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+143360);




var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);

assert(tempDoublePtr % 8 == 0);

function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

}

function copyTempDouble(ptr) {

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];

  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];

  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];

  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];

}


   
  Module["_i64Subtract"] = _i64Subtract;

  
  
  var ___errno_state=0;function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      HEAP32[((___errno_state)>>2)]=value;
      return value;
    }
  
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:42,EIDRM:43,ECHRNG:44,EL2NSYNC:45,EL3HLT:46,EL3RST:47,ELNRNG:48,EUNATCH:49,ENOCSI:50,EL2HLT:51,EDEADLK:35,ENOLCK:37,EBADE:52,EBADR:53,EXFULL:54,ENOANO:55,EBADRQC:56,EBADSLT:57,EDEADLOCK:35,EBFONT:59,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:72,EDOTDOT:73,EBADMSG:74,ENOTUNIQ:76,EBADFD:77,EREMCHG:78,ELIBACC:79,ELIBBAD:80,ELIBSCN:81,ELIBMAX:82,ELIBEXEC:83,ENOSYS:38,ENOTEMPTY:39,ENAMETOOLONG:36,ELOOP:40,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:97,EPROTOTYPE:91,ENOTSOCK:88,ENOPROTOOPT:92,ESHUTDOWN:108,ECONNREFUSED:111,EADDRINUSE:98,ECONNABORTED:103,ENETUNREACH:101,ENETDOWN:100,ETIMEDOUT:110,EHOSTDOWN:112,EHOSTUNREACH:113,EINPROGRESS:115,EALREADY:114,EDESTADDRREQ:89,EMSGSIZE:90,EPROTONOSUPPORT:93,ESOCKTNOSUPPORT:94,EADDRNOTAVAIL:99,ENETRESET:102,EISCONN:106,ENOTCONN:107,ETOOMANYREFS:109,EUSERS:87,EDQUOT:122,ESTALE:116,ENOTSUP:95,ENOMEDIUM:123,EILSEQ:84,EOVERFLOW:75,ECANCELED:125,ENOTRECOVERABLE:131,EOWNERDEAD:130,ESTRPIPE:86};function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 30: return PAGE_SIZE;
        case 132:
        case 133:
        case 12:
        case 137:
        case 138:
        case 15:
        case 235:
        case 16:
        case 17:
        case 18:
        case 19:
        case 20:
        case 149:
        case 13:
        case 10:
        case 236:
        case 153:
        case 9:
        case 21:
        case 22:
        case 159:
        case 154:
        case 14:
        case 77:
        case 78:
        case 139:
        case 80:
        case 81:
        case 79:
        case 82:
        case 68:
        case 67:
        case 164:
        case 11:
        case 29:
        case 47:
        case 48:
        case 95:
        case 52:
        case 51:
        case 46:
          return 200809;
        case 27:
        case 246:
        case 127:
        case 128:
        case 23:
        case 24:
        case 160:
        case 161:
        case 181:
        case 182:
        case 242:
        case 183:
        case 184:
        case 243:
        case 244:
        case 245:
        case 165:
        case 178:
        case 179:
        case 49:
        case 50:
        case 168:
        case 169:
        case 175:
        case 170:
        case 171:
        case 172:
        case 97:
        case 76:
        case 32:
        case 173:
        case 35:
          return -1;
        case 176:
        case 177:
        case 7:
        case 155:
        case 8:
        case 157:
        case 125:
        case 126:
        case 92:
        case 93:
        case 129:
        case 130:
        case 131:
        case 94:
        case 91:
          return 1;
        case 74:
        case 60:
        case 69:
        case 70:
        case 4:
          return 1024;
        case 31:
        case 42:
        case 72:
          return 32;
        case 87:
        case 26:
        case 33:
          return 2147483647;
        case 34:
        case 1:
          return 47839;
        case 38:
        case 36:
          return 99;
        case 43:
        case 37:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 28: return 32768;
        case 44: return 32767;
        case 75: return 16384;
        case 39: return 1000;
        case 89: return 700;
        case 71: return 256;
        case 40: return 255;
        case 2: return 100;
        case 180: return 64;
        case 25: return 20;
        case 5: return 16;
        case 6: return 6;
        case 73: return 4;
        case 84: {
          if (typeof navigator === 'object') return navigator['hardwareConcurrency'] || 1;
          return 1;
        }
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }

  function ___errno_location() {
      return ___errno_state;
    }

   
  Module["_memset"] = _memset;

  var _BDtoILow=true;

  var _ceilf=Math_ceil;

  
  
  var ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"File locking deadlock error",36:"File or path name too long",37:"No record locks available",38:"Function not implemented",39:"Directory not empty",40:"Too many symbolic links",42:"No message of desired type",43:"Identifier removed",44:"Channel number out of range",45:"Level 2 not synchronized",46:"Level 3 halted",47:"Level 3 reset",48:"Link number out of range",49:"Protocol driver not attached",50:"No CSI structure available",51:"Level 2 halted",52:"Invalid exchange",53:"Invalid request descriptor",54:"Exchange full",55:"No anode",56:"Invalid request code",57:"Invalid slot",59:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",72:"Multihop attempted",73:"Cross mount point (not really error)",74:"Trying to read unreadable message",75:"Value too large for defined data type",76:"Given log. name not unique",77:"f.d. invalid for this operation",78:"Remote address changed",79:"Can   access a needed shared lib",80:"Accessing a corrupted shared lib",81:".lib section in a.out corrupted",82:"Attempting to link in too many libs",83:"Attempting to exec a shared library",84:"Illegal byte sequence",86:"Streams pipe error",87:"Too many users",88:"Socket operation on non-socket",89:"Destination address required",90:"Message too long",91:"Protocol wrong type for socket",92:"Protocol not available",93:"Unknown protocol",94:"Socket type not supported",95:"Not supported",96:"Protocol family not supported",97:"Address family not supported by protocol family",98:"Address already in use",99:"Address not available",100:"Network interface is not configured",101:"Network is unreachable",102:"Connection reset by network",103:"Connection aborted",104:"Connection reset by peer",105:"No buffer space available",106:"Socket is already connected",107:"Socket is not connected",108:"Can't send after socket shutdown",109:"Too many references",110:"Connection timed out",111:"Connection refused",112:"Host is down",113:"Host is unreachable",114:"Socket already connected",115:"Connection already in progress",116:"Stale file handle",122:"Quota exceeded",123:"No medium (in tape drive)",125:"Operation canceled",130:"Previous owner died",131:"State not recoverable"};function _strerror_r(errnum, strerrbuf, buflen) {
      if (errnum in ERRNO_MESSAGES) {
        if (ERRNO_MESSAGES[errnum].length > buflen - 1) {
          return ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          var msg = ERRNO_MESSAGES[errnum];
          writeAsciiToMemory(msg, strerrbuf);
          return 0;
        }
      } else {
        return ___setErrNo(ERRNO_CODES.EINVAL);
      }
    }function _strerror(errnum) {
      if (!_strerror.buffer) _strerror.buffer = _malloc(256);
      _strerror_r(errnum, _strerror.buffer, 256);
      return _strerror.buffer;
    }

   
  Module["_bitshift64Shl"] = _bitshift64Shl;

  function _abort() {
      Module['abort']();
    }

  
  
  
  var PATH={splitPath:function (filename) {
        var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
        return splitPathRe.exec(filename).slice(1);
      },normalizeArray:function (parts, allowAboveRoot) {
        // if the path tries to go above the root, `up` ends up > 0
        var up = 0;
        for (var i = parts.length - 1; i >= 0; i--) {
          var last = parts[i];
          if (last === '.') {
            parts.splice(i, 1);
          } else if (last === '..') {
            parts.splice(i, 1);
            up++;
          } else if (up) {
            parts.splice(i, 1);
            up--;
          }
        }
        // if the path is allowed to go above the root, restore leading ..s
        if (allowAboveRoot) {
          for (; up--; up) {
            parts.unshift('..');
          }
        }
        return parts;
      },normalize:function (path) {
        var isAbsolute = path.charAt(0) === '/',
            trailingSlash = path.substr(-1) === '/';
        // Normalize the path
        path = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), !isAbsolute).join('/');
        if (!path && !isAbsolute) {
          path = '.';
        }
        if (path && trailingSlash) {
          path += '/';
        }
        return (isAbsolute ? '/' : '') + path;
      },dirname:function (path) {
        var result = PATH.splitPath(path),
            root = result[0],
            dir = result[1];
        if (!root && !dir) {
          // No dirname whatsoever
          return '.';
        }
        if (dir) {
          // It has a dirname, strip trailing slash
          dir = dir.substr(0, dir.length - 1);
        }
        return root + dir;
      },basename:function (path) {
        // EMSCRIPTEN return '/'' for '/', not an empty string
        if (path === '/') return '/';
        var lastSlash = path.lastIndexOf('/');
        if (lastSlash === -1) return path;
        return path.substr(lastSlash+1);
      },extname:function (path) {
        return PATH.splitPath(path)[3];
      },join:function () {
        var paths = Array.prototype.slice.call(arguments, 0);
        return PATH.normalize(paths.join('/'));
      },join2:function (l, r) {
        return PATH.normalize(l + '/' + r);
      },resolve:function () {
        var resolvedPath = '',
          resolvedAbsolute = false;
        for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
          var path = (i >= 0) ? arguments[i] : FS.cwd();
          // Skip empty and invalid entries
          if (typeof path !== 'string') {
            throw new TypeError('Arguments to path.resolve must be strings');
          } else if (!path) {
            return ''; // an invalid portion invalidates the whole thing
          }
          resolvedPath = path + '/' + resolvedPath;
          resolvedAbsolute = path.charAt(0) === '/';
        }
        // At this point the path should be resolved to a full absolute path, but
        // handle relative paths to be safe (might happen when process.cwd() fails)
        resolvedPath = PATH.normalizeArray(resolvedPath.split('/').filter(function(p) {
          return !!p;
        }), !resolvedAbsolute).join('/');
        return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
      },relative:function (from, to) {
        from = PATH.resolve(from).substr(1);
        to = PATH.resolve(to).substr(1);
        function trim(arr) {
          var start = 0;
          for (; start < arr.length; start++) {
            if (arr[start] !== '') break;
          }
          var end = arr.length - 1;
          for (; end >= 0; end--) {
            if (arr[end] !== '') break;
          }
          if (start > end) return [];
          return arr.slice(start, end - start + 1);
        }
        var fromParts = trim(from.split('/'));
        var toParts = trim(to.split('/'));
        var length = Math.min(fromParts.length, toParts.length);
        var samePartsLength = length;
        for (var i = 0; i < length; i++) {
          if (fromParts[i] !== toParts[i]) {
            samePartsLength = i;
            break;
          }
        }
        var outputParts = [];
        for (var i = samePartsLength; i < fromParts.length; i++) {
          outputParts.push('..');
        }
        outputParts = outputParts.concat(toParts.slice(samePartsLength));
        return outputParts.join('/');
      }};
  
  var TTY={ttys:[],init:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // currently, FS.init does not distinguish if process.stdin is a file or TTY
        //   // device, it always assumes it's a TTY device. because of this, we're forcing
        //   // process.stdin to UTF8 encoding to at least make stdin reading compatible
        //   // with text files until FS.init can be refactored.
        //   process['stdin']['setEncoding']('utf8');
        // }
      },shutdown:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // inolen: any idea as to why node -e 'process.stdin.read()' wouldn't exit immediately (with process.stdin being a tty)?
        //   // isaacs: because now it's reading from the stream, you've expressed interest in it, so that read() kicks off a _read() which creates a ReadReq operation
        //   // inolen: I thought read() in that case was a synchronous operation that just grabbed some amount of buffered data if it exists?
        //   // isaacs: it is. but it also triggers a _read() call, which calls readStart() on the handle
        //   // isaacs: do process.stdin.pause() and i'd think it'd probably close the pending call
        //   process['stdin']['pause']();
        // }
      },register:function (dev, ops) {
        TTY.ttys[dev] = { input: [], output: [], ops: ops };
        FS.registerDevice(dev, TTY.stream_ops);
      },stream_ops:{open:function (stream) {
          var tty = TTY.ttys[stream.node.rdev];
          if (!tty) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          stream.tty = tty;
          stream.seekable = false;
        },close:function (stream) {
          // flush any pending line data
          if (stream.tty.output.length) {
            stream.tty.ops.put_char(stream.tty, 10);
          }
        },read:function (stream, buffer, offset, length, pos /* ignored */) {
          if (!stream.tty || !stream.tty.ops.get_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var bytesRead = 0;
          for (var i = 0; i < length; i++) {
            var result;
            try {
              result = stream.tty.ops.get_char(stream.tty);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            if (result === undefined && bytesRead === 0) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
            if (result === null || result === undefined) break;
            bytesRead++;
            buffer[offset+i] = result;
          }
          if (bytesRead) {
            stream.node.timestamp = Date.now();
          }
          return bytesRead;
        },write:function (stream, buffer, offset, length, pos) {
          if (!stream.tty || !stream.tty.ops.put_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          for (var i = 0; i < length; i++) {
            try {
              stream.tty.ops.put_char(stream.tty, buffer[offset+i]);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
          }
          if (length) {
            stream.node.timestamp = Date.now();
          }
          return i;
        }},default_tty_ops:{get_char:function (tty) {
          if (!tty.input.length) {
            var result = null;
            if (ENVIRONMENT_IS_NODE) {
              result = process['stdin']['read']();
              if (!result) {
                if (process['stdin']['_readableState'] && process['stdin']['_readableState']['ended']) {
                  return null;  // EOF
                }
                return undefined;  // no data available
              }
            } else if (typeof window != 'undefined' &&
              typeof window.prompt == 'function') {
              // Browser.
              result = window.prompt('Input: ');  // returns null on cancel
              if (result !== null) {
                result += '\n';
              }
            } else if (typeof readline == 'function') {
              // Command line.
              result = readline();
              if (result !== null) {
                result += '\n';
              }
            }
            if (!result) {
              return null;
            }
            tty.input = intArrayFromString(result, true);
          }
          return tty.input.shift();
        },put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['print'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }},default_tty1_ops:{put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['printErr'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }}};
  
  var MEMFS={ops_table:null,mount:function (mount) {
        return MEMFS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createNode:function (parent, name, mode, dev) {
        if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
          // no supported
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (!MEMFS.ops_table) {
          MEMFS.ops_table = {
            dir: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                lookup: MEMFS.node_ops.lookup,
                mknod: MEMFS.node_ops.mknod,
                rename: MEMFS.node_ops.rename,
                unlink: MEMFS.node_ops.unlink,
                rmdir: MEMFS.node_ops.rmdir,
                readdir: MEMFS.node_ops.readdir,
                symlink: MEMFS.node_ops.symlink
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek
              }
            },
            file: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek,
                read: MEMFS.stream_ops.read,
                write: MEMFS.stream_ops.write,
                allocate: MEMFS.stream_ops.allocate,
                mmap: MEMFS.stream_ops.mmap
              }
            },
            link: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                readlink: MEMFS.node_ops.readlink
              },
              stream: {}
            },
            chrdev: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: FS.chrdev_stream_ops
            },
          };
        }
        var node = FS.createNode(parent, name, mode, dev);
        if (FS.isDir(node.mode)) {
          node.node_ops = MEMFS.ops_table.dir.node;
          node.stream_ops = MEMFS.ops_table.dir.stream;
          node.contents = {};
        } else if (FS.isFile(node.mode)) {
          node.node_ops = MEMFS.ops_table.file.node;
          node.stream_ops = MEMFS.ops_table.file.stream;
          node.usedBytes = 0; // The actual number of bytes used in the typed array, as opposed to contents.buffer.byteLength which gives the whole capacity.
          // When the byte data of the file is populated, this will point to either a typed array, or a normal JS array. Typed arrays are preferred
          // for performance, and used by default. However, typed arrays are not resizable like normal JS arrays are, so there is a small disk size
          // penalty involved for appending file writes that continuously grow a file similar to std::vector capacity vs used -scheme.
          node.contents = null; 
        } else if (FS.isLink(node.mode)) {
          node.node_ops = MEMFS.ops_table.link.node;
          node.stream_ops = MEMFS.ops_table.link.stream;
        } else if (FS.isChrdev(node.mode)) {
          node.node_ops = MEMFS.ops_table.chrdev.node;
          node.stream_ops = MEMFS.ops_table.chrdev.stream;
        }
        node.timestamp = Date.now();
        // add the new node to the parent
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },getFileDataAsRegularArray:function (node) {
        if (node.contents && node.contents.subarray) {
          var arr = [];
          for (var i = 0; i < node.usedBytes; ++i) arr.push(node.contents[i]);
          return arr; // Returns a copy of the original data.
        }
        return node.contents; // No-op, the file contents are already in a JS array. Return as-is.
      },getFileDataAsTypedArray:function (node) {
        if (!node.contents) return new Uint8Array;
        if (node.contents.subarray) return node.contents.subarray(0, node.usedBytes); // Make sure to not return excess unused bytes.
        return new Uint8Array(node.contents);
      },expandFileStorage:function (node, newCapacity) {
  
        // If we are asked to expand the size of a file that already exists, revert to using a standard JS array to store the file
        // instead of a typed array. This makes resizing the array more flexible because we can just .push() elements at the back to
        // increase the size.
        if (node.contents && node.contents.subarray && newCapacity > node.contents.length) {
          node.contents = MEMFS.getFileDataAsRegularArray(node);
          node.usedBytes = node.contents.length; // We might be writing to a lazy-loaded file which had overridden this property, so force-reset it.
        }
  
        if (!node.contents || node.contents.subarray) { // Keep using a typed array if creating a new storage, or if old one was a typed array as well.
          var prevCapacity = node.contents ? node.contents.buffer.byteLength : 0;
          if (prevCapacity >= newCapacity) return; // No need to expand, the storage was already large enough.
          // Don't expand strictly to the given requested limit if it's only a very small increase, but instead geometrically grow capacity.
          // For small filesizes (<1MB), perform size*2 geometric increase, but for large sizes, do a much more conservative size*1.125 increase to
          // avoid overshooting the allocation cap by a very large margin.
          var CAPACITY_DOUBLING_MAX = 1024 * 1024;
          newCapacity = Math.max(newCapacity, (prevCapacity * (prevCapacity < CAPACITY_DOUBLING_MAX ? 2.0 : 1.125)) | 0);
          if (prevCapacity != 0) newCapacity = Math.max(newCapacity, 256); // At minimum allocate 256b for each file when expanding.
          var oldContents = node.contents;
          node.contents = new Uint8Array(newCapacity); // Allocate new storage.
          if (node.usedBytes > 0) node.contents.set(oldContents.subarray(0, node.usedBytes), 0); // Copy old data over to the new storage.
          return;
        }
        // Not using a typed array to back the file storage. Use a standard JS array instead.
        if (!node.contents && newCapacity > 0) node.contents = [];
        while (node.contents.length < newCapacity) node.contents.push(0);
      },resizeFileStorage:function (node, newSize) {
        if (node.usedBytes == newSize) return;
        if (newSize == 0) {
          node.contents = null; // Fully decommit when requesting a resize to zero.
          node.usedBytes = 0;
          return;
        }
  
        if (!node.contents || node.contents.subarray) { // Resize a typed array if that is being used as the backing store.
          var oldContents = node.contents;
          node.contents = new Uint8Array(new ArrayBuffer(newSize)); // Allocate new storage.
          if (oldContents) {
            node.contents.set(oldContents.subarray(0, Math.min(newSize, node.usedBytes))); // Copy old data over to the new storage.
          }
          node.usedBytes = newSize;
          return;
        }
        // Backing with a JS array.
        if (!node.contents) node.contents = [];
        if (node.contents.length > newSize) node.contents.length = newSize;
        else while (node.contents.length < newSize) node.contents.push(0);
        node.usedBytes = newSize;
      },node_ops:{getattr:function (node) {
          var attr = {};
          // device numbers reuse inode numbers.
          attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
          attr.ino = node.id;
          attr.mode = node.mode;
          attr.nlink = 1;
          attr.uid = 0;
          attr.gid = 0;
          attr.rdev = node.rdev;
          if (FS.isDir(node.mode)) {
            attr.size = 4096;
          } else if (FS.isFile(node.mode)) {
            attr.size = node.usedBytes;
          } else if (FS.isLink(node.mode)) {
            attr.size = node.link.length;
          } else {
            attr.size = 0;
          }
          attr.atime = new Date(node.timestamp);
          attr.mtime = new Date(node.timestamp);
          attr.ctime = new Date(node.timestamp);
          // NOTE: In our implementation, st_blocks = Math.ceil(st_size/st_blksize),
          //       but this is not required by the standard.
          attr.blksize = 4096;
          attr.blocks = Math.ceil(attr.size / attr.blksize);
          return attr;
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
          if (attr.size !== undefined) {
            MEMFS.resizeFileStorage(node, attr.size);
          }
        },lookup:function (parent, name) {
          throw FS.genericErrors[ERRNO_CODES.ENOENT];
        },mknod:function (parent, name, mode, dev) {
          return MEMFS.createNode(parent, name, mode, dev);
        },rename:function (old_node, new_dir, new_name) {
          // if we're overwriting a directory at new_name, make sure it's empty.
          if (FS.isDir(old_node.mode)) {
            var new_node;
            try {
              new_node = FS.lookupNode(new_dir, new_name);
            } catch (e) {
            }
            if (new_node) {
              for (var i in new_node.contents) {
                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
              }
            }
          }
          // do the internal rewiring
          delete old_node.parent.contents[old_node.name];
          old_node.name = new_name;
          new_dir.contents[new_name] = old_node;
          old_node.parent = new_dir;
        },unlink:function (parent, name) {
          delete parent.contents[name];
        },rmdir:function (parent, name) {
          var node = FS.lookupNode(parent, name);
          for (var i in node.contents) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
          }
          delete parent.contents[name];
        },readdir:function (node) {
          var entries = ['.', '..']
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newname, oldpath) {
          var node = MEMFS.createNode(parent, newname, 511 /* 0777 */ | 40960, 0);
          node.link = oldpath;
          return node;
        },readlink:function (node) {
          if (!FS.isLink(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return node.link;
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          var contents = stream.node.contents;
          if (position >= stream.node.usedBytes) return 0;
          var size = Math.min(stream.node.usedBytes - position, length);
          assert(size >= 0);
          if (size > 8 && contents.subarray) { // non-trivial, and typed array
            buffer.set(contents.subarray(position, position + size), offset);
          } else
          {
            for (var i = 0; i < size; i++) buffer[offset + i] = contents[position + i];
          }
          return size;
        },write:function (stream, buffer, offset, length, position, canOwn) {
          if (!length) return 0;
          var node = stream.node;
          node.timestamp = Date.now();
  
          if (buffer.subarray && (!node.contents || node.contents.subarray)) { // This write is from a typed array to a typed array?
            if (canOwn) { // Can we just reuse the buffer we are given?
              node.contents = buffer.subarray(offset, offset + length);
              node.usedBytes = length;
              return length;
            } else if (node.usedBytes === 0 && position === 0) { // If this is a simple first write to an empty file, do a fast set since we don't need to care about old data.
              node.contents = new Uint8Array(buffer.subarray(offset, offset + length));
              node.usedBytes = length;
              return length;
            } else if (position + length <= node.usedBytes) { // Writing to an already allocated and used subrange of the file?
              node.contents.set(buffer.subarray(offset, offset + length), position);
              return length;
            }
          }
          // Appending to an existing file and we need to reallocate, or source data did not come as a typed array.
          MEMFS.expandFileStorage(node, position+length);
          if (node.contents.subarray && buffer.subarray) node.contents.set(buffer.subarray(offset, offset + length), position); // Use typed array write if available.
          else
            for (var i = 0; i < length; i++) {
             node.contents[position + i] = buffer[offset + i]; // Or fall back to manual write if not.
            }
          node.usedBytes = Math.max(node.usedBytes, position+length);
          return length;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.usedBytes;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return position;
        },allocate:function (stream, offset, length) {
          MEMFS.expandFileStorage(stream.node, offset + length);
          stream.node.usedBytes = Math.max(stream.node.usedBytes, offset + length);
        },mmap:function (stream, buffer, offset, length, position, prot, flags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          var ptr;
          var allocated;
          var contents = stream.node.contents;
          // Only make a new copy when MAP_PRIVATE is specified.
          if ( !(flags & 2) &&
                (contents.buffer === buffer || contents.buffer === buffer.buffer) ) {
            // We can't emulate MAP_SHARED when the file is not backed by the buffer
            // we're mapping to (e.g. the HEAP buffer).
            allocated = false;
            ptr = contents.byteOffset;
          } else {
            // Try to avoid unnecessary slices.
            if (position > 0 || position + length < stream.node.usedBytes) {
              if (contents.subarray) {
                contents = contents.subarray(position, position + length);
              } else {
                contents = Array.prototype.slice.call(contents, position, position + length);
              }
            }
            allocated = true;
            ptr = _malloc(length);
            if (!ptr) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
            }
            buffer.set(contents, ptr);
          }
          return { ptr: ptr, allocated: allocated };
        }}};
  
  var IDBFS={dbs:{},indexedDB:function () {
        if (typeof indexedDB !== 'undefined') return indexedDB;
        var ret = null;
        if (typeof window === 'object') ret = window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
        assert(ret, 'IDBFS used, but indexedDB not supported');
        return ret;
      },DB_VERSION:21,DB_STORE_NAME:"FILE_DATA",mount:function (mount) {
        // reuse all of the core MEMFS functionality
        return MEMFS.mount.apply(null, arguments);
      },syncfs:function (mount, populate, callback) {
        IDBFS.getLocalSet(mount, function(err, local) {
          if (err) return callback(err);
  
          IDBFS.getRemoteSet(mount, function(err, remote) {
            if (err) return callback(err);
  
            var src = populate ? remote : local;
            var dst = populate ? local : remote;
  
            IDBFS.reconcile(src, dst, callback);
          });
        });
      },getDB:function (name, callback) {
        // check the cache first
        var db = IDBFS.dbs[name];
        if (db) {
          return callback(null, db);
        }
  
        var req;
        try {
          req = IDBFS.indexedDB().open(name, IDBFS.DB_VERSION);
        } catch (e) {
          return callback(e);
        }
        req.onupgradeneeded = function(e) {
          var db = e.target.result;
          var transaction = e.target.transaction;
  
          var fileStore;
  
          if (db.objectStoreNames.contains(IDBFS.DB_STORE_NAME)) {
            fileStore = transaction.objectStore(IDBFS.DB_STORE_NAME);
          } else {
            fileStore = db.createObjectStore(IDBFS.DB_STORE_NAME);
          }
  
          fileStore.createIndex('timestamp', 'timestamp', { unique: false });
        };
        req.onsuccess = function() {
          db = req.result;
  
          // add to the cache
          IDBFS.dbs[name] = db;
          callback(null, db);
        };
        req.onerror = function() {
          callback(this.error);
        };
      },getLocalSet:function (mount, callback) {
        var entries = {};
  
        function isRealDir(p) {
          return p !== '.' && p !== '..';
        };
        function toAbsolute(root) {
          return function(p) {
            return PATH.join2(root, p);
          }
        };
  
        var check = FS.readdir(mount.mountpoint).filter(isRealDir).map(toAbsolute(mount.mountpoint));
  
        while (check.length) {
          var path = check.pop();
          var stat;
  
          try {
            stat = FS.stat(path);
          } catch (e) {
            return callback(e);
          }
  
          if (FS.isDir(stat.mode)) {
            check.push.apply(check, FS.readdir(path).filter(isRealDir).map(toAbsolute(path)));
          }
  
          entries[path] = { timestamp: stat.mtime };
        }
  
        return callback(null, { type: 'local', entries: entries });
      },getRemoteSet:function (mount, callback) {
        var entries = {};
  
        IDBFS.getDB(mount.mountpoint, function(err, db) {
          if (err) return callback(err);
  
          var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readonly');
          transaction.onerror = function() { callback(this.error); };
  
          var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
          var index = store.index('timestamp');
  
          index.openKeyCursor().onsuccess = function(event) {
            var cursor = event.target.result;
  
            if (!cursor) {
              return callback(null, { type: 'remote', db: db, entries: entries });
            }
  
            entries[cursor.primaryKey] = { timestamp: cursor.key };
  
            cursor.continue();
          };
        });
      },loadLocalEntry:function (path, callback) {
        var stat, node;
  
        try {
          var lookup = FS.lookupPath(path);
          node = lookup.node;
          stat = FS.stat(path);
        } catch (e) {
          return callback(e);
        }
  
        if (FS.isDir(stat.mode)) {
          return callback(null, { timestamp: stat.mtime, mode: stat.mode });
        } else if (FS.isFile(stat.mode)) {
          // Performance consideration: storing a normal JavaScript array to a IndexedDB is much slower than storing a typed array.
          // Therefore always convert the file contents to a typed array first before writing the data to IndexedDB.
          node.contents = MEMFS.getFileDataAsTypedArray(node);
          return callback(null, { timestamp: stat.mtime, mode: stat.mode, contents: node.contents });
        } else {
          return callback(new Error('node type not supported'));
        }
      },storeLocalEntry:function (path, entry, callback) {
        try {
          if (FS.isDir(entry.mode)) {
            FS.mkdir(path, entry.mode);
          } else if (FS.isFile(entry.mode)) {
            FS.writeFile(path, entry.contents, { encoding: 'binary', canOwn: true });
          } else {
            return callback(new Error('node type not supported'));
          }
  
          FS.chmod(path, entry.mode);
          FS.utime(path, entry.timestamp, entry.timestamp);
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },removeLocalEntry:function (path, callback) {
        try {
          var lookup = FS.lookupPath(path);
          var stat = FS.stat(path);
  
          if (FS.isDir(stat.mode)) {
            FS.rmdir(path);
          } else if (FS.isFile(stat.mode)) {
            FS.unlink(path);
          }
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },loadRemoteEntry:function (store, path, callback) {
        var req = store.get(path);
        req.onsuccess = function(event) { callback(null, event.target.result); };
        req.onerror = function() { callback(this.error); };
      },storeRemoteEntry:function (store, path, entry, callback) {
        var req = store.put(entry, path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function() { callback(this.error); };
      },removeRemoteEntry:function (store, path, callback) {
        var req = store.delete(path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function() { callback(this.error); };
      },reconcile:function (src, dst, callback) {
        var total = 0;
  
        var create = [];
        Object.keys(src.entries).forEach(function (key) {
          var e = src.entries[key];
          var e2 = dst.entries[key];
          if (!e2 || e.timestamp > e2.timestamp) {
            create.push(key);
            total++;
          }
        });
  
        var remove = [];
        Object.keys(dst.entries).forEach(function (key) {
          var e = dst.entries[key];
          var e2 = src.entries[key];
          if (!e2) {
            remove.push(key);
            total++;
          }
        });
  
        if (!total) {
          return callback(null);
        }
  
        var errored = false;
        var completed = 0;
        var db = src.type === 'remote' ? src.db : dst.db;
        var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readwrite');
        var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= total) {
            return callback(null);
          }
        };
  
        transaction.onerror = function() { done(this.error); };
  
        // sort paths in ascending order so directory entries are created
        // before the files inside them
        create.sort().forEach(function (path) {
          if (dst.type === 'local') {
            IDBFS.loadRemoteEntry(store, path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeLocalEntry(path, entry, done);
            });
          } else {
            IDBFS.loadLocalEntry(path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeRemoteEntry(store, path, entry, done);
            });
          }
        });
  
        // sort paths in descending order so files are deleted before their
        // parent directories
        remove.sort().reverse().forEach(function(path) {
          if (dst.type === 'local') {
            IDBFS.removeLocalEntry(path, done);
          } else {
            IDBFS.removeRemoteEntry(store, path, done);
          }
        });
      }};
  
  var NODEFS={isWindows:false,staticInit:function () {
        NODEFS.isWindows = !!process.platform.match(/^win/);
      },mount:function (mount) {
        assert(ENVIRONMENT_IS_NODE);
        return NODEFS.createNode(null, '/', NODEFS.getMode(mount.opts.root), 0);
      },createNode:function (parent, name, mode, dev) {
        if (!FS.isDir(mode) && !FS.isFile(mode) && !FS.isLink(mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node = FS.createNode(parent, name, mode);
        node.node_ops = NODEFS.node_ops;
        node.stream_ops = NODEFS.stream_ops;
        return node;
      },getMode:function (path) {
        var stat;
        try {
          stat = fs.lstatSync(path);
          if (NODEFS.isWindows) {
            // On Windows, directories return permission bits 'rw-rw-rw-', even though they have 'rwxrwxrwx', so 
            // propagate write bits to execute bits.
            stat.mode = stat.mode | ((stat.mode & 146) >> 1);
          }
        } catch (e) {
          if (!e.code) throw e;
          throw new FS.ErrnoError(ERRNO_CODES[e.code]);
        }
        return stat.mode;
      },realPath:function (node) {
        var parts = [];
        while (node.parent !== node) {
          parts.push(node.name);
          node = node.parent;
        }
        parts.push(node.mount.opts.root);
        parts.reverse();
        return PATH.join.apply(null, parts);
      },flagsToPermissionStringMap:{0:"r",1:"r+",2:"r+",64:"r",65:"r+",66:"r+",129:"rx+",193:"rx+",514:"w+",577:"w",578:"w+",705:"wx",706:"wx+",1024:"a",1025:"a",1026:"a+",1089:"a",1090:"a+",1153:"ax",1154:"ax+",1217:"ax",1218:"ax+",4096:"rs",4098:"rs+"},flagsToPermissionString:function (flags) {
        if (flags in NODEFS.flagsToPermissionStringMap) {
          return NODEFS.flagsToPermissionStringMap[flags];
        } else {
          return flags;
        }
      },node_ops:{getattr:function (node) {
          var path = NODEFS.realPath(node);
          var stat;
          try {
            stat = fs.lstatSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          // node.js v0.10.20 doesn't report blksize and blocks on Windows. Fake them with default blksize of 4096.
          // See http://support.microsoft.com/kb/140365
          if (NODEFS.isWindows && !stat.blksize) {
            stat.blksize = 4096;
          }
          if (NODEFS.isWindows && !stat.blocks) {
            stat.blocks = (stat.size+stat.blksize-1)/stat.blksize|0;
          }
          return {
            dev: stat.dev,
            ino: stat.ino,
            mode: stat.mode,
            nlink: stat.nlink,
            uid: stat.uid,
            gid: stat.gid,
            rdev: stat.rdev,
            size: stat.size,
            atime: stat.atime,
            mtime: stat.mtime,
            ctime: stat.ctime,
            blksize: stat.blksize,
            blocks: stat.blocks
          };
        },setattr:function (node, attr) {
          var path = NODEFS.realPath(node);
          try {
            if (attr.mode !== undefined) {
              fs.chmodSync(path, attr.mode);
              // update the common node structure mode as well
              node.mode = attr.mode;
            }
            if (attr.timestamp !== undefined) {
              var date = new Date(attr.timestamp);
              fs.utimesSync(path, date, date);
            }
            if (attr.size !== undefined) {
              fs.truncateSync(path, attr.size);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },lookup:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          var mode = NODEFS.getMode(path);
          return NODEFS.createNode(parent, name, mode);
        },mknod:function (parent, name, mode, dev) {
          var node = NODEFS.createNode(parent, name, mode, dev);
          // create the backing node for this in the fs root as well
          var path = NODEFS.realPath(node);
          try {
            if (FS.isDir(node.mode)) {
              fs.mkdirSync(path, node.mode);
            } else {
              fs.writeFileSync(path, '', { mode: node.mode });
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return node;
        },rename:function (oldNode, newDir, newName) {
          var oldPath = NODEFS.realPath(oldNode);
          var newPath = PATH.join2(NODEFS.realPath(newDir), newName);
          try {
            fs.renameSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },unlink:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.unlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },rmdir:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.rmdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readdir:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },symlink:function (parent, newName, oldPath) {
          var newPath = PATH.join2(NODEFS.realPath(parent), newName);
          try {
            fs.symlinkSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readlink:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        }},stream_ops:{open:function (stream) {
          var path = NODEFS.realPath(stream.node);
          try {
            if (FS.isFile(stream.node.mode)) {
              stream.nfd = fs.openSync(path, NODEFS.flagsToPermissionString(stream.flags));
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },close:function (stream) {
          try {
            if (FS.isFile(stream.node.mode) && stream.nfd) {
              fs.closeSync(stream.nfd);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },read:function (stream, buffer, offset, length, position) {
          if (length === 0) return 0; // node errors on 0 length reads
          // FIXME this is terrible.
          var nbuffer = new Buffer(length);
          var res;
          try {
            res = fs.readSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          if (res > 0) {
            for (var i = 0; i < res; i++) {
              buffer[offset + i] = nbuffer[i];
            }
          }
          return res;
        },write:function (stream, buffer, offset, length, position) {
          // FIXME this is terrible.
          var nbuffer = new Buffer(buffer.subarray(offset, offset + length));
          var res;
          try {
            res = fs.writeSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return res;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              try {
                var stat = fs.fstatSync(stream.nfd);
                position += stat.size;
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES[e.code]);
              }
            }
          }
  
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
  
          return position;
        }}};
  
  var _stdin=allocate(1, "i32*", ALLOC_STATIC);
  
  var _stdout=allocate(1, "i32*", ALLOC_STATIC);
  
  var _stderr=allocate(1, "i32*", ALLOC_STATIC);
  
  function _fflush(stream) {
      // int fflush(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fflush.html
      // we don't currently perform any user-space buffering of data
    }var FS={root:null,mounts:[],devices:[null],streams:[],nextInode:1,nameTable:null,currentPath:"/",initialized:false,ignorePermissions:true,trackingDelegate:{},tracking:{openFlags:{READ:1,WRITE:2}},ErrnoError:null,genericErrors:{},handleFSError:function (e) {
        if (!(e instanceof FS.ErrnoError)) throw e + ' : ' + stackTrace();
        return ___setErrNo(e.errno);
      },lookupPath:function (path, opts) {
        path = PATH.resolve(FS.cwd(), path);
        opts = opts || {};
  
        if (!path) return { path: '', node: null };
  
        var defaults = {
          follow_mount: true,
          recurse_count: 0
        };
        for (var key in defaults) {
          if (opts[key] === undefined) {
            opts[key] = defaults[key];
          }
        }
  
        if (opts.recurse_count > 8) {  // max recursive lookup of 8
          throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
        }
  
        // split the path
        var parts = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), false);
  
        // start at the root
        var current = FS.root;
        var current_path = '/';
  
        for (var i = 0; i < parts.length; i++) {
          var islast = (i === parts.length-1);
          if (islast && opts.parent) {
            // stop resolving
            break;
          }
  
          current = FS.lookupNode(current, parts[i]);
          current_path = PATH.join2(current_path, parts[i]);
  
          // jump to the mount's root node if this is a mountpoint
          if (FS.isMountpoint(current)) {
            if (!islast || (islast && opts.follow_mount)) {
              current = current.mounted.root;
            }
          }
  
          // by default, lookupPath will not follow a symlink if it is the final path component.
          // setting opts.follow = true will override this behavior.
          if (!islast || opts.follow) {
            var count = 0;
            while (FS.isLink(current.mode)) {
              var link = FS.readlink(current_path);
              current_path = PATH.resolve(PATH.dirname(current_path), link);
              
              var lookup = FS.lookupPath(current_path, { recurse_count: opts.recurse_count });
              current = lookup.node;
  
              if (count++ > 40) {  // limit max consecutive symlinks to 40 (SYMLOOP_MAX).
                throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
              }
            }
          }
        }
  
        return { path: current_path, node: current };
      },getPath:function (node) {
        var path;
        while (true) {
          if (FS.isRoot(node)) {
            var mount = node.mount.mountpoint;
            if (!path) return mount;
            return mount[mount.length-1] !== '/' ? mount + '/' + path : mount + path;
          }
          path = path ? node.name + '/' + path : node.name;
          node = node.parent;
        }
      },hashName:function (parentid, name) {
        var hash = 0;
  
  
        for (var i = 0; i < name.length; i++) {
          hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
        }
        return ((parentid + hash) >>> 0) % FS.nameTable.length;
      },hashAddNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        node.name_next = FS.nameTable[hash];
        FS.nameTable[hash] = node;
      },hashRemoveNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        if (FS.nameTable[hash] === node) {
          FS.nameTable[hash] = node.name_next;
        } else {
          var current = FS.nameTable[hash];
          while (current) {
            if (current.name_next === node) {
              current.name_next = node.name_next;
              break;
            }
            current = current.name_next;
          }
        }
      },lookupNode:function (parent, name) {
        var err = FS.mayLookup(parent);
        if (err) {
          throw new FS.ErrnoError(err, parent);
        }
        var hash = FS.hashName(parent.id, name);
        for (var node = FS.nameTable[hash]; node; node = node.name_next) {
          var nodeName = node.name;
          if (node.parent.id === parent.id && nodeName === name) {
            return node;
          }
        }
        // if we failed to find it in the cache, call into the VFS
        return FS.lookup(parent, name);
      },createNode:function (parent, name, mode, rdev) {
        if (!FS.FSNode) {
          FS.FSNode = function(parent, name, mode, rdev) {
            if (!parent) {
              parent = this;  // root node sets parent to itself
            }
            this.parent = parent;
            this.mount = parent.mount;
            this.mounted = null;
            this.id = FS.nextInode++;
            this.name = name;
            this.mode = mode;
            this.node_ops = {};
            this.stream_ops = {};
            this.rdev = rdev;
          };
  
          FS.FSNode.prototype = {};
  
          // compatibility
          var readMode = 292 | 73;
          var writeMode = 146;
  
          // NOTE we must use Object.defineProperties instead of individual calls to
          // Object.defineProperty in order to make closure compiler happy
          Object.defineProperties(FS.FSNode.prototype, {
            read: {
              get: function() { return (this.mode & readMode) === readMode; },
              set: function(val) { val ? this.mode |= readMode : this.mode &= ~readMode; }
            },
            write: {
              get: function() { return (this.mode & writeMode) === writeMode; },
              set: function(val) { val ? this.mode |= writeMode : this.mode &= ~writeMode; }
            },
            isFolder: {
              get: function() { return FS.isDir(this.mode); },
            },
            isDevice: {
              get: function() { return FS.isChrdev(this.mode); },
            },
          });
        }
  
        var node = new FS.FSNode(parent, name, mode, rdev);
  
        FS.hashAddNode(node);
  
        return node;
      },destroyNode:function (node) {
        FS.hashRemoveNode(node);
      },isRoot:function (node) {
        return node === node.parent;
      },isMountpoint:function (node) {
        return !!node.mounted;
      },isFile:function (mode) {
        return (mode & 61440) === 32768;
      },isDir:function (mode) {
        return (mode & 61440) === 16384;
      },isLink:function (mode) {
        return (mode & 61440) === 40960;
      },isChrdev:function (mode) {
        return (mode & 61440) === 8192;
      },isBlkdev:function (mode) {
        return (mode & 61440) === 24576;
      },isFIFO:function (mode) {
        return (mode & 61440) === 4096;
      },isSocket:function (mode) {
        return (mode & 49152) === 49152;
      },flagModes:{"r":0,"rs":1052672,"r+":2,"w":577,"wx":705,"xw":705,"w+":578,"wx+":706,"xw+":706,"a":1089,"ax":1217,"xa":1217,"a+":1090,"ax+":1218,"xa+":1218},modeStringToFlags:function (str) {
        var flags = FS.flagModes[str];
        if (typeof flags === 'undefined') {
          throw new Error('Unknown file open mode: ' + str);
        }
        return flags;
      },flagsToPermissionString:function (flag) {
        var accmode = flag & 2097155;
        var perms = ['r', 'w', 'rw'][accmode];
        if ((flag & 512)) {
          perms += 'w';
        }
        return perms;
      },nodePermissions:function (node, perms) {
        if (FS.ignorePermissions) {
          return 0;
        }
        // return 0 if any user, group or owner bits are set.
        if (perms.indexOf('r') !== -1 && !(node.mode & 292)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('w') !== -1 && !(node.mode & 146)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('x') !== -1 && !(node.mode & 73)) {
          return ERRNO_CODES.EACCES;
        }
        return 0;
      },mayLookup:function (dir) {
        var err = FS.nodePermissions(dir, 'x');
        if (err) return err;
        if (!dir.node_ops.lookup) return ERRNO_CODES.EACCES;
        return 0;
      },mayCreate:function (dir, name) {
        try {
          var node = FS.lookupNode(dir, name);
          return ERRNO_CODES.EEXIST;
        } catch (e) {
        }
        return FS.nodePermissions(dir, 'wx');
      },mayDelete:function (dir, name, isdir) {
        var node;
        try {
          node = FS.lookupNode(dir, name);
        } catch (e) {
          return e.errno;
        }
        var err = FS.nodePermissions(dir, 'wx');
        if (err) {
          return err;
        }
        if (isdir) {
          if (!FS.isDir(node.mode)) {
            return ERRNO_CODES.ENOTDIR;
          }
          if (FS.isRoot(node) || FS.getPath(node) === FS.cwd()) {
            return ERRNO_CODES.EBUSY;
          }
        } else {
          if (FS.isDir(node.mode)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return 0;
      },mayOpen:function (node, flags) {
        if (!node) {
          return ERRNO_CODES.ENOENT;
        }
        if (FS.isLink(node.mode)) {
          return ERRNO_CODES.ELOOP;
        } else if (FS.isDir(node.mode)) {
          if ((flags & 2097155) !== 0 ||  // opening for write
              (flags & 512)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
      },MAX_OPEN_FDS:4096,nextfd:function (fd_start, fd_end) {
        fd_start = fd_start || 0;
        fd_end = fd_end || FS.MAX_OPEN_FDS;
        for (var fd = fd_start; fd <= fd_end; fd++) {
          if (!FS.streams[fd]) {
            return fd;
          }
        }
        throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
      },getStream:function (fd) {
        return FS.streams[fd];
      },createStream:function (stream, fd_start, fd_end) {
        if (!FS.FSStream) {
          FS.FSStream = function(){};
          FS.FSStream.prototype = {};
          // compatibility
          Object.defineProperties(FS.FSStream.prototype, {
            object: {
              get: function() { return this.node; },
              set: function(val) { this.node = val; }
            },
            isRead: {
              get: function() { return (this.flags & 2097155) !== 1; }
            },
            isWrite: {
              get: function() { return (this.flags & 2097155) !== 0; }
            },
            isAppend: {
              get: function() { return (this.flags & 1024); }
            }
          });
        }
        // clone it, so we can return an instance of FSStream
        var newStream = new FS.FSStream();
        for (var p in stream) {
          newStream[p] = stream[p];
        }
        stream = newStream;
        var fd = FS.nextfd(fd_start, fd_end);
        stream.fd = fd;
        FS.streams[fd] = stream;
        return stream;
      },closeStream:function (fd) {
        FS.streams[fd] = null;
      },getStreamFromPtr:function (ptr) {
        return FS.streams[ptr - 1];
      },getPtrForStream:function (stream) {
        return stream ? stream.fd + 1 : 0;
      },chrdev_stream_ops:{open:function (stream) {
          var device = FS.getDevice(stream.node.rdev);
          // override node's stream ops with the device's
          stream.stream_ops = device.stream_ops;
          // forward the open call
          if (stream.stream_ops.open) {
            stream.stream_ops.open(stream);
          }
        },llseek:function () {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }},major:function (dev) {
        return ((dev) >> 8);
      },minor:function (dev) {
        return ((dev) & 0xff);
      },makedev:function (ma, mi) {
        return ((ma) << 8 | (mi));
      },registerDevice:function (dev, ops) {
        FS.devices[dev] = { stream_ops: ops };
      },getDevice:function (dev) {
        return FS.devices[dev];
      },getMounts:function (mount) {
        var mounts = [];
        var check = [mount];
  
        while (check.length) {
          var m = check.pop();
  
          mounts.push(m);
  
          check.push.apply(check, m.mounts);
        }
  
        return mounts;
      },syncfs:function (populate, callback) {
        if (typeof(populate) === 'function') {
          callback = populate;
          populate = false;
        }
  
        var mounts = FS.getMounts(FS.root.mount);
        var completed = 0;
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= mounts.length) {
            callback(null);
          }
        };
  
        // sync all mounts
        mounts.forEach(function (mount) {
          if (!mount.type.syncfs) {
            return done(null);
          }
          mount.type.syncfs(mount, populate, done);
        });
      },mount:function (type, opts, mountpoint) {
        var root = mountpoint === '/';
        var pseudo = !mountpoint;
        var node;
  
        if (root && FS.root) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        } else if (!root && !pseudo) {
          var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
          mountpoint = lookup.path;  // use the absolute path
          node = lookup.node;
  
          if (FS.isMountpoint(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
          }
  
          if (!FS.isDir(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
          }
        }
  
        var mount = {
          type: type,
          opts: opts,
          mountpoint: mountpoint,
          mounts: []
        };
  
        // create a root node for the fs
        var mountRoot = type.mount(mount);
        mountRoot.mount = mount;
        mount.root = mountRoot;
  
        if (root) {
          FS.root = mountRoot;
        } else if (node) {
          // set as a mountpoint
          node.mounted = mount;
  
          // add the new mount to the current mount's children
          if (node.mount) {
            node.mount.mounts.push(mount);
          }
        }
  
        return mountRoot;
      },unmount:function (mountpoint) {
        var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
        if (!FS.isMountpoint(lookup.node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
  
        // destroy the nodes for this mount, and all its child mounts
        var node = lookup.node;
        var mount = node.mounted;
        var mounts = FS.getMounts(mount);
  
        Object.keys(FS.nameTable).forEach(function (hash) {
          var current = FS.nameTable[hash];
  
          while (current) {
            var next = current.name_next;
  
            if (mounts.indexOf(current.mount) !== -1) {
              FS.destroyNode(current);
            }
  
            current = next;
          }
        });
  
        // no longer a mountpoint
        node.mounted = null;
  
        // remove this mount from the child mounts
        var idx = node.mount.mounts.indexOf(mount);
        assert(idx !== -1);
        node.mount.mounts.splice(idx, 1);
      },lookup:function (parent, name) {
        return parent.node_ops.lookup(parent, name);
      },mknod:function (path, mode, dev) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        if (!name || name === '.' || name === '..') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.mayCreate(parent, name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.mknod) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.mknod(parent, name, mode, dev);
      },create:function (path, mode) {
        mode = mode !== undefined ? mode : 438 /* 0666 */;
        mode &= 4095;
        mode |= 32768;
        return FS.mknod(path, mode, 0);
      },mkdir:function (path, mode) {
        mode = mode !== undefined ? mode : 511 /* 0777 */;
        mode &= 511 | 512;
        mode |= 16384;
        return FS.mknod(path, mode, 0);
      },mkdev:function (path, mode, dev) {
        if (typeof(dev) === 'undefined') {
          dev = mode;
          mode = 438 /* 0666 */;
        }
        mode |= 8192;
        return FS.mknod(path, mode, dev);
      },symlink:function (oldpath, newpath) {
        if (!PATH.resolve(oldpath)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        var lookup = FS.lookupPath(newpath, { parent: true });
        var parent = lookup.node;
        if (!parent) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        var newname = PATH.basename(newpath);
        var err = FS.mayCreate(parent, newname);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.symlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.symlink(parent, newname, oldpath);
      },rename:function (old_path, new_path) {
        var old_dirname = PATH.dirname(old_path);
        var new_dirname = PATH.dirname(new_path);
        var old_name = PATH.basename(old_path);
        var new_name = PATH.basename(new_path);
        // parents must exist
        var lookup, old_dir, new_dir;
        try {
          lookup = FS.lookupPath(old_path, { parent: true });
          old_dir = lookup.node;
          lookup = FS.lookupPath(new_path, { parent: true });
          new_dir = lookup.node;
        } catch (e) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        if (!old_dir || !new_dir) throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        // need to be part of the same mount
        if (old_dir.mount !== new_dir.mount) {
          throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
        }
        // source must exist
        var old_node = FS.lookupNode(old_dir, old_name);
        // old path should not be an ancestor of the new path
        var relative = PATH.relative(old_path, new_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        // new path should not be an ancestor of the old path
        relative = PATH.relative(new_path, old_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
        }
        // see if the new path already exists
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {
          // not fatal
        }
        // early out if nothing needs to change
        if (old_node === new_node) {
          return;
        }
        // we'll need to delete the old entry
        var isdir = FS.isDir(old_node.mode);
        var err = FS.mayDelete(old_dir, old_name, isdir);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // need delete permissions if we'll be overwriting.
        // need create permissions if new doesn't already exist.
        err = new_node ?
          FS.mayDelete(new_dir, new_name, isdir) :
          FS.mayCreate(new_dir, new_name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!old_dir.node_ops.rename) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // if we are going to change the parent, check write permissions
        if (new_dir !== old_dir) {
          err = FS.nodePermissions(old_dir, 'w');
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        try {
          if (FS.trackingDelegate['willMovePath']) {
            FS.trackingDelegate['willMovePath'](old_path, new_path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willMovePath']('"+old_path+"', '"+new_path+"') threw an exception: " + e.message);
        }
        // remove the node from the lookup hash
        FS.hashRemoveNode(old_node);
        // do the underlying fs rename
        try {
          old_dir.node_ops.rename(old_node, new_dir, new_name);
        } catch (e) {
          throw e;
        } finally {
          // add the node back to the hash (in case node_ops.rename
          // changed its name)
          FS.hashAddNode(old_node);
        }
        try {
          if (FS.trackingDelegate['onMovePath']) FS.trackingDelegate['onMovePath'](old_path, new_path);
        } catch(e) {
          console.log("FS.trackingDelegate['onMovePath']('"+old_path+"', '"+new_path+"') threw an exception: " + e.message);
        }
      },rmdir:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, true);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.rmdir) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        try {
          if (FS.trackingDelegate['willDeletePath']) {
            FS.trackingDelegate['willDeletePath'](path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willDeletePath']('"+path+"') threw an exception: " + e.message);
        }
        parent.node_ops.rmdir(parent, name);
        FS.destroyNode(node);
        try {
          if (FS.trackingDelegate['onDeletePath']) FS.trackingDelegate['onDeletePath'](path);
        } catch(e) {
          console.log("FS.trackingDelegate['onDeletePath']('"+path+"') threw an exception: " + e.message);
        }
      },readdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        if (!node.node_ops.readdir) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        return node.node_ops.readdir(node);
      },unlink:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, false);
        if (err) {
          // POSIX says unlink should set EPERM, not EISDIR
          if (err === ERRNO_CODES.EISDIR) err = ERRNO_CODES.EPERM;
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.unlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        try {
          if (FS.trackingDelegate['willDeletePath']) {
            FS.trackingDelegate['willDeletePath'](path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willDeletePath']('"+path+"') threw an exception: " + e.message);
        }
        parent.node_ops.unlink(parent, name);
        FS.destroyNode(node);
        try {
          if (FS.trackingDelegate['onDeletePath']) FS.trackingDelegate['onDeletePath'](path);
        } catch(e) {
          console.log("FS.trackingDelegate['onDeletePath']('"+path+"') threw an exception: " + e.message);
        }
      },readlink:function (path) {
        var lookup = FS.lookupPath(path);
        var link = lookup.node;
        if (!link) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!link.node_ops.readlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        return link.node_ops.readlink(link);
      },stat:function (path, dontFollow) {
        var lookup = FS.lookupPath(path, { follow: !dontFollow });
        var node = lookup.node;
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!node.node_ops.getattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return node.node_ops.getattr(node);
      },lstat:function (path) {
        return FS.stat(path, true);
      },chmod:function (path, mode, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          mode: (mode & 4095) | (node.mode & ~4095),
          timestamp: Date.now()
        });
      },lchmod:function (path, mode) {
        FS.chmod(path, mode, true);
      },fchmod:function (fd, mode) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chmod(stream.node, mode);
      },chown:function (path, uid, gid, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          timestamp: Date.now()
          // we ignore the uid / gid for now
        });
      },lchown:function (path, uid, gid) {
        FS.chown(path, uid, gid, true);
      },fchown:function (fd, uid, gid) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chown(stream.node, uid, gid);
      },truncate:function (path, len) {
        if (len < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: true });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!FS.isFile(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.nodePermissions(node, 'w');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        node.node_ops.setattr(node, {
          size: len,
          timestamp: Date.now()
        });
      },ftruncate:function (fd, len) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        FS.truncate(stream.node, len);
      },utime:function (path, atime, mtime) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        node.node_ops.setattr(node, {
          timestamp: Math.max(atime, mtime)
        });
      },open:function (path, flags, mode, fd_start, fd_end) {
        if (path === "") {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        flags = typeof flags === 'string' ? FS.modeStringToFlags(flags) : flags;
        mode = typeof mode === 'undefined' ? 438 /* 0666 */ : mode;
        if ((flags & 64)) {
          mode = (mode & 4095) | 32768;
        } else {
          mode = 0;
        }
        var node;
        if (typeof path === 'object') {
          node = path;
        } else {
          path = PATH.normalize(path);
          try {
            var lookup = FS.lookupPath(path, {
              follow: !(flags & 131072)
            });
            node = lookup.node;
          } catch (e) {
            // ignore
          }
        }
        // perhaps we need to create the node
        var created = false;
        if ((flags & 64)) {
          if (node) {
            // if O_CREAT and O_EXCL are set, error out if the node already exists
            if ((flags & 128)) {
              throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
            }
          } else {
            // node doesn't exist, try to create it
            node = FS.mknod(path, mode, 0);
            created = true;
          }
        }
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        // can't truncate a device
        if (FS.isChrdev(node.mode)) {
          flags &= ~512;
        }
        // check permissions, if this is not a file we just created now (it is ok to
        // create and write to a file with read-only permissions; it is read-only
        // for later use)
        if (!created) {
          var err = FS.mayOpen(node, flags);
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        // do truncation if necessary
        if ((flags & 512)) {
          FS.truncate(node, 0);
        }
        // we've already handled these, don't pass down to the underlying vfs
        flags &= ~(128 | 512);
  
        // register the stream with the filesystem
        var stream = FS.createStream({
          node: node,
          path: FS.getPath(node),  // we want the absolute path to the node
          flags: flags,
          seekable: true,
          position: 0,
          stream_ops: node.stream_ops,
          // used by the file family libc calls (fopen, fwrite, ferror, etc.)
          ungotten: [],
          error: false
        }, fd_start, fd_end);
        // call the new stream's open function
        if (stream.stream_ops.open) {
          stream.stream_ops.open(stream);
        }
        if (Module['logReadFiles'] && !(flags & 1)) {
          if (!FS.readFiles) FS.readFiles = {};
          if (!(path in FS.readFiles)) {
            FS.readFiles[path] = 1;
            Module['printErr']('read file: ' + path);
          }
        }
        try {
          if (FS.trackingDelegate['onOpenFile']) {
            var trackingFlags = 0;
            if ((flags & 2097155) !== 1) {
              trackingFlags |= FS.tracking.openFlags.READ;
            }
            if ((flags & 2097155) !== 0) {
              trackingFlags |= FS.tracking.openFlags.WRITE;
            }
            FS.trackingDelegate['onOpenFile'](path, trackingFlags);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['onOpenFile']('"+path+"', flags) threw an exception: " + e.message);
        }
        return stream;
      },close:function (stream) {
        try {
          if (stream.stream_ops.close) {
            stream.stream_ops.close(stream);
          }
        } catch (e) {
          throw e;
        } finally {
          FS.closeStream(stream.fd);
        }
      },llseek:function (stream, offset, whence) {
        if (!stream.seekable || !stream.stream_ops.llseek) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        stream.position = stream.stream_ops.llseek(stream, offset, whence);
        stream.ungotten = [];
        return stream.position;
      },read:function (stream, buffer, offset, length, position) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.read) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
        if (!seeking) stream.position += bytesRead;
        return bytesRead;
      },write:function (stream, buffer, offset, length, position, canOwn) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.write) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if (stream.flags & 1024) {
          // seek to the end before writing in append mode
          FS.llseek(stream, 0, 2);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
        if (!seeking) stream.position += bytesWritten;
        try {
          if (stream.path && FS.trackingDelegate['onWriteToFile']) FS.trackingDelegate['onWriteToFile'](stream.path);
        } catch(e) {
          console.log("FS.trackingDelegate['onWriteToFile']('"+path+"') threw an exception: " + e.message);
        }
        return bytesWritten;
      },allocate:function (stream, offset, length) {
        if (offset < 0 || length <= 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!FS.isFile(stream.node.mode) && !FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        if (!stream.stream_ops.allocate) {
          throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
        }
        stream.stream_ops.allocate(stream, offset, length);
      },mmap:function (stream, buffer, offset, length, position, prot, flags) {
        // TODO if PROT is PROT_WRITE, make sure we have write access
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EACCES);
        }
        if (!stream.stream_ops.mmap) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
      },ioctl:function (stream, cmd, arg) {
        if (!stream.stream_ops.ioctl) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
        }
        return stream.stream_ops.ioctl(stream, cmd, arg);
      },readFile:function (path, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'r';
        opts.encoding = opts.encoding || 'binary';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var ret;
        var stream = FS.open(path, opts.flags);
        var stat = FS.stat(path);
        var length = stat.size;
        var buf = new Uint8Array(length);
        FS.read(stream, buf, 0, length, 0);
        if (opts.encoding === 'utf8') {
          ret = '';
          var utf8 = new Runtime.UTF8Processor();
          for (var i = 0; i < length; i++) {
            ret += utf8.processCChar(buf[i]);
          }
        } else if (opts.encoding === 'binary') {
          ret = buf;
        }
        FS.close(stream);
        return ret;
      },writeFile:function (path, data, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'w';
        opts.encoding = opts.encoding || 'utf8';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var stream = FS.open(path, opts.flags, opts.mode);
        if (opts.encoding === 'utf8') {
          var utf8 = new Runtime.UTF8Processor();
          var buf = new Uint8Array(utf8.processJSString(data));
          FS.write(stream, buf, 0, buf.length, 0, opts.canOwn);
        } else if (opts.encoding === 'binary') {
          FS.write(stream, data, 0, data.length, 0, opts.canOwn);
        }
        FS.close(stream);
      },cwd:function () {
        return FS.currentPath;
      },chdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        if (!FS.isDir(lookup.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        var err = FS.nodePermissions(lookup.node, 'x');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        FS.currentPath = lookup.path;
      },createDefaultDirectories:function () {
        FS.mkdir('/tmp');
        FS.mkdir('/home');
        FS.mkdir('/home/web_user');
      },createDefaultDevices:function () {
        // create /dev
        FS.mkdir('/dev');
        // setup /dev/null
        FS.registerDevice(FS.makedev(1, 3), {
          read: function() { return 0; },
          write: function() { return 0; }
        });
        FS.mkdev('/dev/null', FS.makedev(1, 3));
        // setup /dev/tty and /dev/tty1
        // stderr needs to print output using Module['printErr']
        // so we register a second tty just for it.
        TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
        TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
        FS.mkdev('/dev/tty', FS.makedev(5, 0));
        FS.mkdev('/dev/tty1', FS.makedev(6, 0));
        // setup /dev/[u]random
        var random_device;
        if (typeof crypto !== 'undefined') {
          // for modern web browsers
          var randomBuffer = new Uint8Array(1);
          random_device = function() { crypto.getRandomValues(randomBuffer); return randomBuffer[0]; };
        } else if (ENVIRONMENT_IS_NODE) {
          // for nodejs
          random_device = function() { return require('crypto').randomBytes(1)[0]; };
        } else {
          // default for ES5 platforms
          random_device = function() { return (Math.random()*256)|0; };
        }
        FS.createDevice('/dev', 'random', random_device);
        FS.createDevice('/dev', 'urandom', random_device);
        // we're not going to emulate the actual shm device,
        // just create the tmp dirs that reside in it commonly
        FS.mkdir('/dev/shm');
        FS.mkdir('/dev/shm/tmp');
      },createStandardStreams:function () {
        // TODO deprecate the old functionality of a single
        // input / output callback and that utilizes FS.createDevice
        // and instead require a unique set of stream ops
  
        // by default, we symlink the standard streams to the
        // default tty devices. however, if the standard streams
        // have been overwritten we create a unique device for
        // them instead.
        if (Module['stdin']) {
          FS.createDevice('/dev', 'stdin', Module['stdin']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdin');
        }
        if (Module['stdout']) {
          FS.createDevice('/dev', 'stdout', null, Module['stdout']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdout');
        }
        if (Module['stderr']) {
          FS.createDevice('/dev', 'stderr', null, Module['stderr']);
        } else {
          FS.symlink('/dev/tty1', '/dev/stderr');
        }
  
        // open default streams for the stdin, stdout and stderr devices
        var stdin = FS.open('/dev/stdin', 'r');
        HEAP32[((_stdin)>>2)]=FS.getPtrForStream(stdin);
        assert(stdin.fd === 0, 'invalid handle for stdin (' + stdin.fd + ')');
  
        var stdout = FS.open('/dev/stdout', 'w');
        HEAP32[((_stdout)>>2)]=FS.getPtrForStream(stdout);
        assert(stdout.fd === 1, 'invalid handle for stdout (' + stdout.fd + ')');
  
        var stderr = FS.open('/dev/stderr', 'w');
        HEAP32[((_stderr)>>2)]=FS.getPtrForStream(stderr);
        assert(stderr.fd === 2, 'invalid handle for stderr (' + stderr.fd + ')');
      },ensureErrnoError:function () {
        if (FS.ErrnoError) return;
        FS.ErrnoError = function ErrnoError(errno, node) {
          this.node = node;
          this.setErrno = function(errno) {
            this.errno = errno;
            for (var key in ERRNO_CODES) {
              if (ERRNO_CODES[key] === errno) {
                this.code = key;
                break;
              }
            }
          };
          this.setErrno(errno);
          this.message = ERRNO_MESSAGES[errno];
        };
        FS.ErrnoError.prototype = new Error();
        FS.ErrnoError.prototype.constructor = FS.ErrnoError;
        // Some errors may happen quite a bit, to avoid overhead we reuse them (and suffer a lack of stack info)
        [ERRNO_CODES.ENOENT].forEach(function(code) {
          FS.genericErrors[code] = new FS.ErrnoError(code);
          FS.genericErrors[code].stack = '<generic error, no stack>';
        });
      },staticInit:function () {
        FS.ensureErrnoError();
  
        FS.nameTable = new Array(4096);
  
        FS.mount(MEMFS, {}, '/');
  
        FS.createDefaultDirectories();
        FS.createDefaultDevices();
      },init:function (input, output, error) {
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
  
        FS.ensureErrnoError();
  
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        Module['stdin'] = input || Module['stdin'];
        Module['stdout'] = output || Module['stdout'];
        Module['stderr'] = error || Module['stderr'];
  
        FS.createStandardStreams();
      },quit:function () {
        FS.init.initialized = false;
        for (var i = 0; i < FS.streams.length; i++) {
          var stream = FS.streams[i];
          if (!stream) {
            continue;
          }
          FS.close(stream);
        }
      },getMode:function (canRead, canWrite) {
        var mode = 0;
        if (canRead) mode |= 292 | 73;
        if (canWrite) mode |= 146;
        return mode;
      },joinPath:function (parts, forceRelative) {
        var path = PATH.join.apply(null, parts);
        if (forceRelative && path[0] == '/') path = path.substr(1);
        return path;
      },absolutePath:function (relative, base) {
        return PATH.resolve(base, relative);
      },standardizePath:function (path) {
        return PATH.normalize(path);
      },findObject:function (path, dontResolveLastLink) {
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },analyzePath:function (path, dontResolveLastLink) {
        // operate from within the context of the symlink's target
        try {
          var lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          path = lookup.path;
        } catch (e) {
        }
        var ret = {
          isRoot: false, exists: false, error: 0, name: null, path: null, object: null,
          parentExists: false, parentPath: null, parentObject: null
        };
        try {
          var lookup = FS.lookupPath(path, { parent: true });
          ret.parentExists = true;
          ret.parentPath = lookup.path;
          ret.parentObject = lookup.node;
          ret.name = PATH.basename(path);
          lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          ret.exists = true;
          ret.path = lookup.path;
          ret.object = lookup.node;
          ret.name = lookup.node.name;
          ret.isRoot = lookup.path === '/';
        } catch (e) {
          ret.error = e.errno;
        };
        return ret;
      },createFolder:function (parent, name, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.mkdir(path, mode);
      },createPath:function (parent, path, canRead, canWrite) {
        parent = typeof parent === 'string' ? parent : FS.getPath(parent);
        var parts = path.split('/').reverse();
        while (parts.length) {
          var part = parts.pop();
          if (!part) continue;
          var current = PATH.join2(parent, part);
          try {
            FS.mkdir(current);
          } catch (e) {
            // ignore EEXIST
          }
          parent = current;
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.create(path, mode);
      },createDataFile:function (parent, name, data, canRead, canWrite, canOwn) {
        var path = name ? PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name) : parent;
        var mode = FS.getMode(canRead, canWrite);
        var node = FS.create(path, mode);
        if (data) {
          if (typeof data === 'string') {
            var arr = new Array(data.length);
            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
            data = arr;
          }
          // make sure we can write to the file
          FS.chmod(node, mode | 146);
          var stream = FS.open(node, 'w');
          FS.write(stream, data, 0, data.length, 0, canOwn);
          FS.close(stream);
          FS.chmod(node, mode);
        }
        return node;
      },createDevice:function (parent, name, input, output) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(!!input, !!output);
        if (!FS.createDevice.major) FS.createDevice.major = 64;
        var dev = FS.makedev(FS.createDevice.major++, 0);
        // Create a fake device that a set of stream ops to emulate
        // the old behavior.
        FS.registerDevice(dev, {
          open: function(stream) {
            stream.seekable = false;
          },
          close: function(stream) {
            // flush any pending line data
            if (output && output.buffer && output.buffer.length) {
              output(10);
            }
          },
          read: function(stream, buffer, offset, length, pos /* ignored */) {
            var bytesRead = 0;
            for (var i = 0; i < length; i++) {
              var result;
              try {
                result = input();
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
              if (result === undefined && bytesRead === 0) {
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              buffer[offset+i] = result;
            }
            if (bytesRead) {
              stream.node.timestamp = Date.now();
            }
            return bytesRead;
          },
          write: function(stream, buffer, offset, length, pos) {
            for (var i = 0; i < length; i++) {
              try {
                output(buffer[offset+i]);
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
            }
            if (length) {
              stream.node.timestamp = Date.now();
            }
            return i;
          }
        });
        return FS.mkdev(path, mode, dev);
      },createLink:function (parent, name, target, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        return FS.symlink(target, path);
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
            obj.usedBytes = obj.contents.length;
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
        function LazyUint8Array() {
          this.lengthKnown = false;
          this.chunks = []; // Loaded chunks. Index is the chunk number
        }
        LazyUint8Array.prototype.get = function LazyUint8Array_get(idx) {
          if (idx > this.length-1 || idx < 0) {
            return undefined;
          }
          var chunkOffset = idx % this.chunkSize;
          var chunkNum = (idx / this.chunkSize)|0;
          return this.getter(chunkNum)[chunkOffset];
        }
        LazyUint8Array.prototype.setDataGetter = function LazyUint8Array_setDataGetter(getter) {
          this.getter = getter;
        }
        LazyUint8Array.prototype.cacheLength = function LazyUint8Array_cacheLength() {
          // Find length
          var xhr = new XMLHttpRequest();
          xhr.open('HEAD', url, false);
          xhr.send(null);
          if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
          var datalength = Number(xhr.getResponseHeader("Content-length"));
          var header;
          var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
          var chunkSize = 1024*1024; // Chunk size in bytes
  
          if (!hasByteServing) chunkSize = datalength;
  
          // Function to get a range from the remote URL.
          var doXHR = (function(from, to) {
            if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
            if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
  
            // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
            var xhr = new XMLHttpRequest();
            xhr.open('GET', url, false);
            if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
  
            // Some hints to the browser that we want binary data.
            if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
            if (xhr.overrideMimeType) {
              xhr.overrideMimeType('text/plain; charset=x-user-defined');
            }
  
            xhr.send(null);
            if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
            if (xhr.response !== undefined) {
              return new Uint8Array(xhr.response || []);
            } else {
              return intArrayFromString(xhr.responseText || '', true);
            }
          });
          var lazyArray = this;
          lazyArray.setDataGetter(function(chunkNum) {
            var start = chunkNum * chunkSize;
            var end = (chunkNum+1) * chunkSize - 1; // including this byte
            end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
              lazyArray.chunks[chunkNum] = doXHR(start, end);
            }
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
            return lazyArray.chunks[chunkNum];
          });
  
          this._length = datalength;
          this._chunkSize = chunkSize;
          this.lengthKnown = true;
        }
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          var lazyArray = new LazyUint8Array();
          Object.defineProperty(lazyArray, "length", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._length;
              }
          });
          Object.defineProperty(lazyArray, "chunkSize", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._chunkSize;
              }
          });
  
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
  
        var node = FS.createFile(parent, name, properties, canRead, canWrite);
        // This is a total hack, but I want to get this lazy file code out of the
        // core of MEMFS. If we want to keep this lazy file concept I feel it should
        // be its own thin LAZYFS proxying calls to MEMFS.
        if (properties.contents) {
          node.contents = properties.contents;
        } else if (properties.url) {
          node.contents = null;
          node.url = properties.url;
        }
        // Add a function that defers querying the file size until it is asked the first time.
        Object.defineProperty(node, "usedBytes", {
            get: function() { return this.contents.length; }
        });
        // override each stream op with one that tries to force load the lazy file first
        var stream_ops = {};
        var keys = Object.keys(node.stream_ops);
        keys.forEach(function(key) {
          var fn = node.stream_ops[key];
          stream_ops[key] = function forceLoadLazyFile() {
            if (!FS.forceLoadFile(node)) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            return fn.apply(null, arguments);
          };
        });
        // use a custom read function
        stream_ops.read = function stream_ops_read(stream, buffer, offset, length, position) {
          if (!FS.forceLoadFile(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          var contents = stream.node.contents;
          if (position >= contents.length)
            return 0;
          var size = Math.min(contents.length - position, length);
          assert(size >= 0);
          if (contents.slice) { // normal array
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          } else {
            for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
              buffer[offset + i] = contents.get(position + i);
            }
          }
          return size;
        };
        node.stream_ops = stream_ops;
        return node;
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn) {
        Browser.init();
        // TODO we should allow people to just pass in a complete filename instead
        // of parent and name being that we just join them anyways
        var fullname = name ? PATH.resolve(PATH.join2(parent, name)) : parent;
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_NAME:function () {
        return 'EM_FS_' + window.location.pathname;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = function openRequest_onupgradeneeded() {
          console.log('creating db');
          var db = openRequest.result;
          db.createObjectStore(FS.DB_STORE_NAME);
        };
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          var transaction = db.transaction([FS.DB_STORE_NAME], 'readwrite');
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
            putRequest.onsuccess = function putRequest_onsuccess() { ok++; if (ok + fail == total) finish() };
            putRequest.onerror = function putRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },loadFilesFromDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = onerror; // no database to load from
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          try {
            var transaction = db.transaction([FS.DB_STORE_NAME], 'readonly');
          } catch(e) {
            onerror(e);
            return;
          }
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var getRequest = files.get(path);
            getRequest.onsuccess = function getRequest_onsuccess() {
              if (FS.analyzePath(path).exists) {
                FS.unlink(path);
              }
              FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
              ok++;
              if (ok + fail == total) finish();
            };
            getRequest.onerror = function getRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      }};
  
  
  
  
  function _mkport() { throw 'TODO' }var SOCKFS={mount:function (mount) {
        // If Module['websocket'] has already been defined (e.g. for configuring
        // the subprotocol/url) use that, if not initialise it to a new object.
        Module['websocket'] = (Module['websocket'] && 
                               ('object' === typeof Module['websocket'])) ? Module['websocket'] : {};
  
        // Add the Event registration mechanism to the exported websocket configuration
        // object so we can register network callbacks from native JavaScript too.
        // For more documentation see system/include/emscripten/emscripten.h
        Module['websocket']._callbacks = {};
        Module['websocket']['on'] = function(event, callback) {
  	    if ('function' === typeof callback) {
  		  this._callbacks[event] = callback;
          }
  	    return this;
        };
  
        Module['websocket'].emit = function(event, param) {
  	    if ('function' === typeof this._callbacks[event]) {
  		  this._callbacks[event].call(this, param);
          }
        };
  
        // If debug is enabled register simple default logging callbacks for each Event.
  
        return FS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createSocket:function (family, type, protocol) {
        var streaming = type == 1;
        if (protocol) {
          assert(streaming == (protocol == 6)); // if SOCK_STREAM, must be tcp
        }
  
        // create our internal socket structure
        var sock = {
          family: family,
          type: type,
          protocol: protocol,
          server: null,
          error: null, // Used in getsockopt for SOL_SOCKET/SO_ERROR test
          peers: {},
          pending: [],
          recv_queue: [],
          sock_ops: SOCKFS.websocket_sock_ops
        };
  
        // create the filesystem node to store the socket structure
        var name = SOCKFS.nextname();
        var node = FS.createNode(SOCKFS.root, name, 49152, 0);
        node.sock = sock;
  
        // and the wrapping stream that enables library functions such
        // as read and write to indirectly interact with the socket
        var stream = FS.createStream({
          path: name,
          node: node,
          flags: FS.modeStringToFlags('r+'),
          seekable: false,
          stream_ops: SOCKFS.stream_ops
        });
  
        // map the new stream to the socket structure (sockets have a 1:1
        // relationship with a stream)
        sock.stream = stream;
  
        return sock;
      },getSocket:function (fd) {
        var stream = FS.getStream(fd);
        if (!stream || !FS.isSocket(stream.node.mode)) {
          return null;
        }
        return stream.node.sock;
      },stream_ops:{poll:function (stream) {
          var sock = stream.node.sock;
          return sock.sock_ops.poll(sock);
        },ioctl:function (stream, request, varargs) {
          var sock = stream.node.sock;
          return sock.sock_ops.ioctl(sock, request, varargs);
        },read:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          var msg = sock.sock_ops.recvmsg(sock, length);
          if (!msg) {
            // socket is closed
            return 0;
          }
          buffer.set(msg.buffer, offset);
          return msg.buffer.length;
        },write:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          return sock.sock_ops.sendmsg(sock, buffer, offset, length);
        },close:function (stream) {
          var sock = stream.node.sock;
          sock.sock_ops.close(sock);
        }},nextname:function () {
        if (!SOCKFS.nextname.current) {
          SOCKFS.nextname.current = 0;
        }
        return 'socket[' + (SOCKFS.nextname.current++) + ']';
      },websocket_sock_ops:{createPeer:function (sock, addr, port) {
          var ws;
  
          if (typeof addr === 'object') {
            ws = addr;
            addr = null;
            port = null;
          }
  
          if (ws) {
            // for sockets that've already connected (e.g. we're the server)
            // we can inspect the _socket property for the address
            if (ws._socket) {
              addr = ws._socket.remoteAddress;
              port = ws._socket.remotePort;
            }
            // if we're just now initializing a connection to the remote,
            // inspect the url property
            else {
              var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
              if (!result) {
                throw new Error('WebSocket URL must be in the format ws(s)://address:port');
              }
              addr = result[1];
              port = parseInt(result[2], 10);
            }
          } else {
            // create the actual websocket object and connect
            try {
              // runtimeConfig gets set to true if WebSocket runtime configuration is available.
              var runtimeConfig = (Module['websocket'] && ('object' === typeof Module['websocket']));
  
              // The default value is 'ws://' the replace is needed because the compiler replaces '//' comments with '#'
              // comments without checking context, so we'd end up with ws:#, the replace swaps the '#' for '//' again.
              var url = 'ws:#'.replace('#', '//');
  
              if (runtimeConfig) {
                if ('string' === typeof Module['websocket']['url']) {
                  url = Module['websocket']['url']; // Fetch runtime WebSocket URL config.
                }
              }
  
              if (url === 'ws://' || url === 'wss://') { // Is the supplied URL config just a prefix, if so complete it.
                var parts = addr.split('/');
                url = url + parts[0] + ":" + port + "/" + parts.slice(1).join('/');
              }
  
              // Make the WebSocket subprotocol (Sec-WebSocket-Protocol) default to binary if no configuration is set.
              var subProtocols = 'binary'; // The default value is 'binary'
  
              if (runtimeConfig) {
                if ('string' === typeof Module['websocket']['subprotocol']) {
                  subProtocols = Module['websocket']['subprotocol']; // Fetch runtime WebSocket subprotocol config.
                }
              }
  
              // The regex trims the string (removes spaces at the beginning and end, then splits the string by
              // <any space>,<any space> into an Array. Whitespace removal is important for Websockify and ws.
              subProtocols = subProtocols.replace(/^ +| +$/g,"").split(/ *, */);
  
              // The node ws library API for specifying optional subprotocol is slightly different than the browser's.
              var opts = ENVIRONMENT_IS_NODE ? {'protocol': subProtocols.toString()} : subProtocols;
  
              // If node we use the ws library.
              var WebSocket = ENVIRONMENT_IS_NODE ? require('ws') : window['WebSocket'];
              ws = new WebSocket(url, opts);
              ws.binaryType = 'arraybuffer';
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH);
            }
          }
  
  
          var peer = {
            addr: addr,
            port: port,
            socket: ws,
            dgram_send_queue: []
          };
  
          SOCKFS.websocket_sock_ops.addPeer(sock, peer);
          SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);
  
          // if this is a bound dgram socket, send the port number first to allow
          // us to override the ephemeral port reported to us by remotePort on the
          // remote end.
          if (sock.type === 2 && typeof sock.sport !== 'undefined') {
            peer.dgram_send_queue.push(new Uint8Array([
                255, 255, 255, 255,
                'p'.charCodeAt(0), 'o'.charCodeAt(0), 'r'.charCodeAt(0), 't'.charCodeAt(0),
                ((sock.sport & 0xff00) >> 8) , (sock.sport & 0xff)
            ]));
          }
  
          return peer;
        },getPeer:function (sock, addr, port) {
          return sock.peers[addr + ':' + port];
        },addPeer:function (sock, peer) {
          sock.peers[peer.addr + ':' + peer.port] = peer;
        },removePeer:function (sock, peer) {
          delete sock.peers[peer.addr + ':' + peer.port];
        },handlePeerEvents:function (sock, peer) {
          var first = true;
  
          var handleOpen = function () {
  
            Module['websocket'].emit('open', sock.stream.fd);
  
            try {
              var queued = peer.dgram_send_queue.shift();
              while (queued) {
                peer.socket.send(queued);
                queued = peer.dgram_send_queue.shift();
              }
            } catch (e) {
              // not much we can do here in the way of proper error handling as we've already
              // lied and said this data was sent. shut it down.
              peer.socket.close();
            }
          };
  
          function handleMessage(data) {
            assert(typeof data !== 'string' && data.byteLength !== undefined);  // must receive an ArrayBuffer
            data = new Uint8Array(data);  // make a typed array view on the array buffer
  
  
            // if this is the port message, override the peer's port with it
            var wasfirst = first;
            first = false;
            if (wasfirst &&
                data.length === 10 &&
                data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 &&
                data[4] === 'p'.charCodeAt(0) && data[5] === 'o'.charCodeAt(0) && data[6] === 'r'.charCodeAt(0) && data[7] === 't'.charCodeAt(0)) {
              // update the peer's port and it's key in the peer map
              var newport = ((data[8] << 8) | data[9]);
              SOCKFS.websocket_sock_ops.removePeer(sock, peer);
              peer.port = newport;
              SOCKFS.websocket_sock_ops.addPeer(sock, peer);
              return;
            }
  
            sock.recv_queue.push({ addr: peer.addr, port: peer.port, data: data });
            Module['websocket'].emit('message', sock.stream.fd);
          };
  
          if (ENVIRONMENT_IS_NODE) {
            peer.socket.on('open', handleOpen);
            peer.socket.on('message', function(data, flags) {
              if (!flags.binary) {
                return;
              }
              handleMessage((new Uint8Array(data)).buffer);  // copy from node Buffer -> ArrayBuffer
            });
            peer.socket.on('close', function() {
              Module['websocket'].emit('close', sock.stream.fd);
            });
            peer.socket.on('error', function(error) {
              // Although the ws library may pass errors that may be more descriptive than
              // ECONNREFUSED they are not necessarily the expected error code e.g. 
              // ENOTFOUND on getaddrinfo seems to be node.js specific, so using ECONNREFUSED
              // is still probably the most useful thing to do.
              sock.error = ERRNO_CODES.ECONNREFUSED; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
              Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'ECONNREFUSED: Connection refused']);
              // don't throw
            });
          } else {
            peer.socket.onopen = handleOpen;
            peer.socket.onclose = function() {
              Module['websocket'].emit('close', sock.stream.fd);
            };
            peer.socket.onmessage = function peer_socket_onmessage(event) {
              handleMessage(event.data);
            };
            peer.socket.onerror = function(error) {
              // The WebSocket spec only allows a 'simple event' to be thrown on error,
              // so we only really know as much as ECONNREFUSED.
              sock.error = ERRNO_CODES.ECONNREFUSED; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
              Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'ECONNREFUSED: Connection refused']);
            };
          }
        },poll:function (sock) {
          if (sock.type === 1 && sock.server) {
            // listen sockets should only say they're available for reading
            // if there are pending clients.
            return sock.pending.length ? (64 | 1) : 0;
          }
  
          var mask = 0;
          var dest = sock.type === 1 ?  // we only care about the socket state for connection-based sockets
            SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) :
            null;
  
          if (sock.recv_queue.length ||
              !dest ||  // connection-less sockets are always ready to read
              (dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {  // let recv return 0 once closed
            mask |= (64 | 1);
          }
  
          if (!dest ||  // connection-less sockets are always ready to write
              (dest && dest.socket.readyState === dest.socket.OPEN)) {
            mask |= 4;
          }
  
          if ((dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {
            mask |= 16;
          }
  
          return mask;
        },ioctl:function (sock, request, arg) {
          switch (request) {
            case 21531:
              var bytes = 0;
              if (sock.recv_queue.length) {
                bytes = sock.recv_queue[0].data.length;
              }
              HEAP32[((arg)>>2)]=bytes;
              return 0;
            default:
              return ERRNO_CODES.EINVAL;
          }
        },close:function (sock) {
          // if we've spawned a listen server, close it
          if (sock.server) {
            try {
              sock.server.close();
            } catch (e) {
            }
            sock.server = null;
          }
          // close any peer connections
          var peers = Object.keys(sock.peers);
          for (var i = 0; i < peers.length; i++) {
            var peer = sock.peers[peers[i]];
            try {
              peer.socket.close();
            } catch (e) {
            }
            SOCKFS.websocket_sock_ops.removePeer(sock, peer);
          }
          return 0;
        },bind:function (sock, addr, port) {
          if (typeof sock.saddr !== 'undefined' || typeof sock.sport !== 'undefined') {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already bound
          }
          sock.saddr = addr;
          sock.sport = port || _mkport();
          // in order to emulate dgram sockets, we need to launch a listen server when
          // binding on a connection-less socket
          // note: this is only required on the server side
          if (sock.type === 2) {
            // close the existing server if it exists
            if (sock.server) {
              sock.server.close();
              sock.server = null;
            }
            // swallow error operation not supported error that occurs when binding in the
            // browser where this isn't supported
            try {
              sock.sock_ops.listen(sock, 0);
            } catch (e) {
              if (!(e instanceof FS.ErrnoError)) throw e;
              if (e.errno !== ERRNO_CODES.EOPNOTSUPP) throw e;
            }
          }
        },connect:function (sock, addr, port) {
          if (sock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
  
          // TODO autobind
          // if (!sock.addr && sock.type == 2) {
          // }
  
          // early out if we're already connected / in the middle of connecting
          if (typeof sock.daddr !== 'undefined' && typeof sock.dport !== 'undefined') {
            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
            if (dest) {
              if (dest.socket.readyState === dest.socket.CONNECTING) {
                throw new FS.ErrnoError(ERRNO_CODES.EALREADY);
              } else {
                throw new FS.ErrnoError(ERRNO_CODES.EISCONN);
              }
            }
          }
  
          // add the socket to our peer list and set our
          // destination address / port to match
          var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
          sock.daddr = peer.addr;
          sock.dport = peer.port;
  
          // always "fail" in non-blocking mode
          throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS);
        },listen:function (sock, backlog) {
          if (!ENVIRONMENT_IS_NODE) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
          if (sock.server) {
             throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already listening
          }
          var WebSocketServer = require('ws').Server;
          var host = sock.saddr;
          sock.server = new WebSocketServer({
            host: host,
            port: sock.sport
            // TODO support backlog
          });
          Module['websocket'].emit('listen', sock.stream.fd); // Send Event with listen fd.
  
          sock.server.on('connection', function(ws) {
            if (sock.type === 1) {
              var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);
  
              // create a peer on the new socket
              var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
              newsock.daddr = peer.addr;
              newsock.dport = peer.port;
  
              // push to queue for accept to pick up
              sock.pending.push(newsock);
              Module['websocket'].emit('connection', newsock.stream.fd);
            } else {
              // create a peer on the listen socket so calling sendto
              // with the listen socket and an address will resolve
              // to the correct client
              SOCKFS.websocket_sock_ops.createPeer(sock, ws);
              Module['websocket'].emit('connection', sock.stream.fd);
            }
          });
          sock.server.on('closed', function() {
            Module['websocket'].emit('close', sock.stream.fd);
            sock.server = null;
          });
          sock.server.on('error', function(error) {
            // Although the ws library may pass errors that may be more descriptive than
            // ECONNREFUSED they are not necessarily the expected error code e.g. 
            // ENOTFOUND on getaddrinfo seems to be node.js specific, so using EHOSTUNREACH
            // is still probably the most useful thing to do. This error shouldn't
            // occur in a well written app as errors should get trapped in the compiled
            // app's own getaddrinfo call.
            sock.error = ERRNO_CODES.EHOSTUNREACH; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
            Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'EHOSTUNREACH: Host is unreachable']);
            // don't throw
          });
        },accept:function (listensock) {
          if (!listensock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          var newsock = listensock.pending.shift();
          newsock.stream.flags = listensock.stream.flags;
          return newsock;
        },getname:function (sock, peer) {
          var addr, port;
          if (peer) {
            if (sock.daddr === undefined || sock.dport === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            }
            addr = sock.daddr;
            port = sock.dport;
          } else {
            // TODO saddr and sport will be set for bind()'d UDP sockets, but what
            // should we be returning for TCP sockets that've been connect()'d?
            addr = sock.saddr || 0;
            port = sock.sport || 0;
          }
          return { addr: addr, port: port };
        },sendmsg:function (sock, buffer, offset, length, addr, port) {
          if (sock.type === 2) {
            // connection-less sockets will honor the message address,
            // and otherwise fall back to the bound destination address
            if (addr === undefined || port === undefined) {
              addr = sock.daddr;
              port = sock.dport;
            }
            // if there was no address to fall back to, error out
            if (addr === undefined || port === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ);
            }
          } else {
            // connection-based sockets will only use the bound
            addr = sock.daddr;
            port = sock.dport;
          }
  
          // find the peer for the destination address
          var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);
  
          // early out if not connected with a connection-based socket
          if (sock.type === 1) {
            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            } else if (dest.socket.readyState === dest.socket.CONNECTING) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
  
          // create a copy of the incoming data to send, as the WebSocket API
          // doesn't work entirely with an ArrayBufferView, it'll just send
          // the entire underlying buffer
          var data;
          if (buffer instanceof Array || buffer instanceof ArrayBuffer) {
            data = buffer.slice(offset, offset + length);
          } else {  // ArrayBufferView
            data = buffer.buffer.slice(buffer.byteOffset + offset, buffer.byteOffset + offset + length);
          }
  
          // if we're emulating a connection-less dgram socket and don't have
          // a cached connection, queue the buffer to send upon connect and
          // lie, saying the data was sent now.
          if (sock.type === 2) {
            if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
              // if we're not connected, open a new connection
              if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
              }
              dest.dgram_send_queue.push(data);
              return length;
            }
          }
  
          try {
            // send the actual data
            dest.socket.send(data);
            return length;
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
        },recvmsg:function (sock, length) {
          // http://pubs.opengroup.org/onlinepubs/7908799/xns/recvmsg.html
          if (sock.type === 1 && sock.server) {
            // tcp servers should not be recv()'ing on the listen socket
            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
          }
  
          var queued = sock.recv_queue.shift();
          if (!queued) {
            if (sock.type === 1) {
              var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
  
              if (!dest) {
                // if we have a destination address but are not connected, error out
                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
              }
              else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                // return null if the socket has closed
                return null;
              }
              else {
                // else, our socket is in a valid state but truly has nothing available
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
            } else {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
  
          // queued.data will be an ArrayBuffer if it's unadulterated, but if it's
          // requeued TCP data it'll be an ArrayBufferView
          var queuedLength = queued.data.byteLength || queued.data.length;
          var queuedOffset = queued.data.byteOffset || 0;
          var queuedBuffer = queued.data.buffer || queued.data;
          var bytesRead = Math.min(length, queuedLength);
          var res = {
            buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
            addr: queued.addr,
            port: queued.port
          };
  
  
          // push back any unread data for TCP connections
          if (sock.type === 1 && bytesRead < queuedLength) {
            var bytesRemaining = queuedLength - bytesRead;
            queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
            sock.recv_queue.unshift(queued);
          }
  
          return res;
        }}};function _send(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _write(fd, buf, len);
    }
  
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
  
  
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  
  function _fileno(stream) {
      // int fileno(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fileno.html
      stream = FS.getStreamFromPtr(stream);
      if (!stream) return -1;
      return stream.fd;
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var fd = _fileno(stream);
      var bytesWritten = _write(fd, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        var streamObj = FS.getStreamFromPtr(stream);
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        return (bytesWritten / size)|0;
      }
    }
  
  
   
  Module["_strlen"] = _strlen;
  
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = (HEAP32[((tempDoublePtr)>>2)]=HEAP32[(((varargs)+(argIndex))>>2)],HEAP32[(((tempDoublePtr)+(4))>>2)]=HEAP32[(((varargs)+((argIndex)+(4)))>>2)],(+(HEAPF64[(tempDoublePtr)>>3])));
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+4))>>2)]];
  
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Runtime.getNativeFieldSize(type);
        return ret;
      }
  
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[((textIndex)>>0)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)>>0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          var flagPadSign = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              case 32:
                flagPadSign = true;
                break;
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
          }
  
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)>>0)];
            }
          }
  
          // Handle precision.
          var precisionSet = false, precision = -1;
          if (next == 46) {
            precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)>>0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)>>0)];
          }
          if (precision < 0) {
            precision = 6; // Standard default.
            precisionSet = false;
          }
  
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)>>0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)>>0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)>>0)];
  
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
  
              // Add sign if needed
              if (currArg >= 0) {
                if (flagAlwaysSigned) {
                  prefix = '+' + prefix;
                } else if (flagPadSign) {
                  prefix = ' ' + prefix;
                }
              }
  
              // Move sign to prefix so we zero-pad after the sign
              if (argText.charAt(0) == '-') {
                prefix = '-' + prefix;
                argText = argText.substr(1);
              }
  
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
  
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
  
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
  
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
  
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
  
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
  
                // Add sign.
                if (currArg >= 0) {
                  if (flagAlwaysSigned) {
                    argText = '+' + argText;
                  } else if (flagPadSign) {
                    argText = ' ' + argText;
                  }
                }
              }
  
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
  
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
  
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)>>0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length;
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[((i)>>0)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }

  var _emscripten_prep_setjmp=true;


  var _emscripten_check_longjmp=true;

  function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)>>0)]=chr;
      var fd = _fileno(stream);
      var ret = _write(fd, _fputc.ret, 1);
      if (ret == -1) {
        var streamObj = FS.getStreamFromPtr(stream);
        if (streamObj) streamObj.error = true;
        return -1;
      } else {
        return chr;
      }
    }

   
  Module["_i64Add"] = _i64Add;

  var _emscripten_postinvoke=true;


  
  function _putchar(c) {
      // int putchar(int c);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/putchar.html
      return _fputc(c, HEAP32[((_stdout)>>2)]);
    } 
  Module["_saveSetjmp"] = _saveSetjmp;

  
  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      Module['exit'](status);
    }function _exit(status) {
      __exit(status);
    }

  var _emscripten_get_longjmp_result=true;

  function _time(ptr) {
      var ret = (Date.now()/1000)|0;
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret;
      }
      return ret;
    }

  
  
  function _emscripten_set_main_loop_timing(mode, value) {
      Browser.mainLoop.timingMode = mode;
      Browser.mainLoop.timingValue = value;
  
      if (!Browser.mainLoop.func) {
        return 1; // Return non-zero on failure, can't set timing mode when there is no main loop.
      }
  
      if (mode == 0 /*EM_TIMING_SETTIMEOUT*/) {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler() {
          setTimeout(Browser.mainLoop.runner, value); // doing this each time means that on exception, we stop
        };
        Browser.mainLoop.method = 'timeout';
      } else if (mode == 1 /*EM_TIMING_RAF*/) {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler() {
          Browser.requestAnimationFrame(Browser.mainLoop.runner);
        };
        Browser.mainLoop.method = 'rAF';
      }
      return 0;
    }function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop, arg) {
      Module['noExitRuntime'] = true;
  
      assert(!Browser.mainLoop.func, 'emscripten_set_main_loop: there can only be one main loop function at once: call emscripten_cancel_main_loop to cancel the previous one before setting a new one with different parameters.');
  
      Browser.mainLoop.func = func;
      Browser.mainLoop.arg = arg;
  
      var thisMainLoopId = Browser.mainLoop.currentlyRunningMainloop;
  
      Browser.mainLoop.runner = function Browser_mainLoop_runner() {
        if (ABORT) return;
        if (Browser.mainLoop.queue.length > 0) {
          var start = Date.now();
          var blocker = Browser.mainLoop.queue.shift();
          blocker.func(blocker.arg);
          if (Browser.mainLoop.remainingBlockers) {
            var remaining = Browser.mainLoop.remainingBlockers;
            var next = remaining%1 == 0 ? remaining-1 : Math.floor(remaining);
            if (blocker.counted) {
              Browser.mainLoop.remainingBlockers = next;
            } else {
              // not counted, but move the progress along a tiny bit
              next = next + 0.5; // do not steal all the next one's progress
              Browser.mainLoop.remainingBlockers = (8*remaining + next)/9;
            }
          }
          console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + ' ms'); //, left: ' + Browser.mainLoop.remainingBlockers);
          Browser.mainLoop.updateStatus();
          setTimeout(Browser.mainLoop.runner, 0);
          return;
        }
  
        // catch pauses from non-main loop sources
        if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop) return;
  
        // Implement very basic swap interval control
        Browser.mainLoop.currentFrameNumber = Browser.mainLoop.currentFrameNumber + 1 | 0;
        if (Browser.mainLoop.timingMode == 1/*EM_TIMING_RAF*/ && Browser.mainLoop.timingValue > 1 && Browser.mainLoop.currentFrameNumber % Browser.mainLoop.timingValue != 0) {
          // Not the scheduled time to render this frame - skip.
          Browser.mainLoop.scheduler();
          return;
        }
  
        // Signal GL rendering layer that processing of a new frame is about to start. This helps it optimize
        // VBO double-buffering and reduce GPU stalls.
  
        if (Browser.mainLoop.method === 'timeout' && Module.ctx) {
          Module.printErr('Looks like you are rendering without using requestAnimationFrame for the main loop. You should use 0 for the frame rate in emscripten_set_main_loop in order to use requestAnimationFrame, as that can greatly improve your frame rates!');
          Browser.mainLoop.method = ''; // just warn once per call to set main loop
        }
  
        Browser.mainLoop.runIter(function() {
          if (typeof arg !== 'undefined') {
            Runtime.dynCall('vi', func, [arg]);
          } else {
            Runtime.dynCall('v', func);
          }
        });
  
        // catch pauses from the main loop itself
        if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop) return;
  
        // Queue new audio data. This is important to be right after the main loop invocation, so that we will immediately be able
        // to queue the newest produced audio samples.
        // TODO: Consider adding pre- and post- rAF callbacks so that GL.newRenderingFrameStarted() and SDL.audio.queueNewAudioData()
        //       do not need to be hardcoded into this function, but can be more generic.
        if (typeof SDL === 'object' && SDL.audio && SDL.audio.queueNewAudioData) SDL.audio.queueNewAudioData();
  
        Browser.mainLoop.scheduler();
      }
  
      if (fps && fps > 0) _emscripten_set_main_loop_timing(0/*EM_TIMING_SETTIMEOUT*/, 1000.0 / fps);
      else _emscripten_set_main_loop_timing(1/*EM_TIMING_RAF*/, 1); // Do rAF by rendering each frame (no decimating)
  
      Browser.mainLoop.scheduler();
  
      if (simulateInfiniteLoop) {
        throw 'SimulateInfiniteLoop';
      }
    }var Browser={mainLoop:{scheduler:null,method:"",currentlyRunningMainloop:0,func:null,arg:0,timingMode:0,timingValue:0,currentFrameNumber:0,queue:[],pause:function () {
          Browser.mainLoop.scheduler = null;
          Browser.mainLoop.currentlyRunningMainloop++; // Incrementing this signals the previous main loop that it's now become old, and it must return.
        },resume:function () {
          Browser.mainLoop.currentlyRunningMainloop++;
          var timingMode = Browser.mainLoop.timingMode;
          var timingValue = Browser.mainLoop.timingValue;
          var func = Browser.mainLoop.func;
          Browser.mainLoop.func = null;
          _emscripten_set_main_loop(func, 0, false, Browser.mainLoop.arg);
          _emscripten_set_main_loop_timing(timingMode, timingValue);
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        },runIter:function (func) {
          if (ABORT) return;
          if (Module['preMainLoop']) {
            var preRet = Module['preMainLoop']();
            if (preRet === false) {
              return; // |return false| skips a frame
            }
          }
          try {
            func();
          } catch (e) {
            if (e instanceof ExitStatus) {
              return;
            } else {
              if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
              throw e;
            }
          }
          if (Module['postMainLoop']) Module['postMainLoop']();
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
  
        if (Browser.initted) return;
        Browser.initted = true;
  
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : undefined;
        if (!Module.noImageDecoding && typeof Browser.URLObject === 'undefined') {
          console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
          Module.noImageDecoding = true;
        }
  
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
  
        var imagePlugin = {};
        imagePlugin['canHandle'] = function imagePlugin_canHandle(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function imagePlugin_handle(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: Browser.getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: Browser.getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function img_onload() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function img_onerror(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
  
        var audioPlugin = {};
        audioPlugin['canHandle'] = function audioPlugin_canHandle(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function audioPlugin_handle(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: Browser.getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function audio_onerror(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
  
        // Canvas event setup
  
        var canvas = Module['canvas'];
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas ||
                                document['msPointerLockElement'] === canvas;
        }
        if (canvas) {
          // forced aspect ratio can be enabled by defining 'forcedAspectRatio' on Module
          // Module['forcedAspectRatio'] = 4 / 3;
          
          canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                      canvas['mozRequestPointerLock'] ||
                                      canvas['webkitRequestPointerLock'] ||
                                      canvas['msRequestPointerLock'] ||
                                      function(){};
          canvas.exitPointerLock = document['exitPointerLock'] ||
                                   document['mozExitPointerLock'] ||
                                   document['webkitExitPointerLock'] ||
                                   document['msExitPointerLock'] ||
                                   function(){}; // no-op if function does not exist
          canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
  
  
          document.addEventListener('pointerlockchange', pointerLockChange, false);
          document.addEventListener('mozpointerlockchange', pointerLockChange, false);
          document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
          document.addEventListener('mspointerlockchange', pointerLockChange, false);
  
          if (Module['elementPointerLock']) {
            canvas.addEventListener("click", function(ev) {
              if (!Browser.pointerLock && canvas.requestPointerLock) {
                canvas.requestPointerLock();
                ev.preventDefault();
              }
            }, false);
          }
        }
      },createContext:function (canvas, useWebGL, setInModule, webGLContextAttributes) {
        if (useWebGL && Module.ctx && canvas == Module.canvas) return Module.ctx; // no need to recreate GL context if it's already been created for this canvas.
  
        var ctx;
        var contextHandle;
        if (useWebGL) {
          // For GLES2/desktop GL compatibility, adjust a few defaults to be different to WebGL defaults, so that they align better with the desktop defaults.
          var contextAttributes = {
            antialias: false,
            alpha: false
          };
  
          if (webGLContextAttributes) {
            for (var attribute in webGLContextAttributes) {
              contextAttributes[attribute] = webGLContextAttributes[attribute];
            }
          }
  
          contextHandle = GL.createContext(canvas, contextAttributes);
          if (contextHandle) {
            ctx = GL.getContext(contextHandle).GLctx;
          }
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
        } else {
          ctx = canvas.getContext('2d');
        }
  
        if (!ctx) return null;
  
        if (setInModule) {
          if (!useWebGL) assert(typeof GLctx === 'undefined', 'cannot set in module if GLctx is used, but we are a non-GL context that would replace it');
  
          Module.ctx = ctx;
          if (useWebGL) GL.makeContextCurrent(contextHandle);
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
  
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          var canvasContainer = canvas.parentNode;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement'] ||
               document['msFullScreenElement'] || document['msFullscreenElement'] ||
               document['webkitCurrentFullScreenElement']) === canvasContainer) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'] ||
                                      document['msExitFullscreen'] ||
                                      document['exitFullscreen'] ||
                                      function() {};
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else {
            
            // remove the full screen specific parent of the canvas again to restore the HTML structure from before going full screen
            canvasContainer.parentNode.insertBefore(canvas, canvasContainer);
            canvasContainer.parentNode.removeChild(canvasContainer);
            
            if (Browser.resizeCanvas) Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
          Browser.updateCanvasDimensions(canvas);
        }
  
        if (!Browser.fullScreenHandlersInstalled) {
          Browser.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
          document.addEventListener('MSFullscreenChange', fullScreenChange, false);
        }
  
        // create a new parent to ensure the canvas has no siblings. this allows browsers to optimize full screen performance when its parent is the full screen root
        var canvasContainer = document.createElement("div");
        canvas.parentNode.insertBefore(canvasContainer, canvas);
        canvasContainer.appendChild(canvas);
        
        // use parent of canvas as full screen root to allow aspect ratio correction (Firefox stretches the root to screen size)
        canvasContainer.requestFullScreen = canvasContainer['requestFullScreen'] ||
                                            canvasContainer['mozRequestFullScreen'] ||
                                            canvasContainer['msRequestFullscreen'] ||
                                           (canvasContainer['webkitRequestFullScreen'] ? function() { canvasContainer['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvasContainer.requestFullScreen();
      },nextRAF:0,fakeRequestAnimationFrame:function (func) {
        // try to keep 60fps between calls to here
        var now = Date.now();
        if (Browser.nextRAF === 0) {
          Browser.nextRAF = now + 1000/60;
        } else {
          while (now + 2 >= Browser.nextRAF) { // fudge a little, to avoid timer jitter causing us to do lots of delay:0
            Browser.nextRAF += 1000/60;
          }
        }
        var delay = Math.max(Browser.nextRAF - now, 0);
        setTimeout(func, delay);
      },requestAnimationFrame:function requestAnimationFrame(func) {
        if (typeof window === 'undefined') { // Provide fallback to setTimeout if window is undefined (e.g. in Node.js)
          Browser.fakeRequestAnimationFrame(func);
        } else {
          if (!window.requestAnimationFrame) {
            window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                           window['mozRequestAnimationFrame'] ||
                                           window['webkitRequestAnimationFrame'] ||
                                           window['msRequestAnimationFrame'] ||
                                           window['oRequestAnimationFrame'] ||
                                           Browser.fakeRequestAnimationFrame;
          }
          window.requestAnimationFrame(func);
        }
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (!ABORT) func();
        });
      },safeSetTimeout:function (func, timeout) {
        Module['noExitRuntime'] = true;
        return setTimeout(function() {
          if (!ABORT) func();
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        Module['noExitRuntime'] = true;
        return setInterval(function() {
          if (!ABORT) func();
        }, timeout);
      },getMimetype:function (name) {
        return {
          'jpg': 'image/jpeg',
          'jpeg': 'image/jpeg',
          'png': 'image/png',
          'bmp': 'image/bmp',
          'ogg': 'audio/ogg',
          'wav': 'audio/wav',
          'mp3': 'audio/mpeg'
        }[name.substr(name.lastIndexOf('.')+1)];
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },getMouseWheelDelta:function (event) {
        var delta = 0;
        switch (event.type) {
          case 'DOMMouseScroll': 
            delta = event.detail;
            break;
          case 'mousewheel': 
            delta = event.wheelDelta;
            break;
          case 'wheel': 
            delta = event['deltaY'];
            break;
          default:
            throw 'unrecognized mouse wheel event: ' + event.type;
        }
        return delta;
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,touches:{},lastTouches:{},calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          var rect = Module["canvas"].getBoundingClientRect();
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
  
          // Neither .scrollX or .pageXOffset are defined in a spec, but
          // we prefer .scrollX because it is currently in a spec draft.
          // (see: http://www.w3.org/TR/2013/WD-cssom-view-20131217/)
          var scrollX = ((typeof window.scrollX !== 'undefined') ? window.scrollX : window.pageXOffset);
          var scrollY = ((typeof window.scrollY !== 'undefined') ? window.scrollY : window.pageYOffset);
  
          if (event.type === 'touchstart' || event.type === 'touchend' || event.type === 'touchmove') {
            var touch = event.touch;
            if (touch === undefined) {
              return; // the "touch" property is only defined in SDL
  
            }
            var adjustedX = touch.pageX - (scrollX + rect.left);
            var adjustedY = touch.pageY - (scrollY + rect.top);
  
            adjustedX = adjustedX * (cw / rect.width);
            adjustedY = adjustedY * (ch / rect.height);
  
            var coords = { x: adjustedX, y: adjustedY };
            
            if (event.type === 'touchstart') {
              Browser.lastTouches[touch.identifier] = coords;
              Browser.touches[touch.identifier] = coords;
            } else if (event.type === 'touchend' || event.type === 'touchmove') {
              Browser.lastTouches[touch.identifier] = Browser.touches[touch.identifier];
              Browser.touches[touch.identifier] = { x: adjustedX, y: adjustedY };
            } 
            return;
          }
  
          var x = event.pageX - (scrollX + rect.left);
          var y = event.pageY - (scrollY + rect.top);
  
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
  
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function xhr_onload() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        Browser.updateCanvasDimensions(canvas, width, height);
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },updateCanvasDimensions:function (canvas, wNative, hNative) {
        if (wNative && hNative) {
          canvas.widthNative = wNative;
          canvas.heightNative = hNative;
        } else {
          wNative = canvas.widthNative;
          hNative = canvas.heightNative;
        }
        var w = wNative;
        var h = hNative;
        if (Module['forcedAspectRatio'] && Module['forcedAspectRatio'] > 0) {
          if (w/h < Module['forcedAspectRatio']) {
            w = Math.round(h * Module['forcedAspectRatio']);
          } else {
            h = Math.round(w / Module['forcedAspectRatio']);
          }
        }
        if (((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
             document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
             document['fullScreenElement'] || document['fullscreenElement'] ||
             document['msFullScreenElement'] || document['msFullscreenElement'] ||
             document['webkitCurrentFullScreenElement']) === canvas.parentNode) && (typeof screen != 'undefined')) {
           var factor = Math.min(screen.width / w, screen.height / h);
           w = Math.round(w * factor);
           h = Math.round(h * factor);
        }
        if (Browser.resizeCanvas) {
          if (canvas.width  != w) canvas.width  = w;
          if (canvas.height != h) canvas.height = h;
          if (typeof canvas.style != 'undefined') {
            canvas.style.removeProperty( "width");
            canvas.style.removeProperty("height");
          }
        } else {
          if (canvas.width  != wNative) canvas.width  = wNative;
          if (canvas.height != hNative) canvas.height = hNative;
          if (typeof canvas.style != 'undefined') {
            if (w != wNative || h != hNative) {
              canvas.style.setProperty( "width", w + "px", "important");
              canvas.style.setProperty("height", h + "px", "important");
            } else {
              canvas.style.removeProperty( "width");
              canvas.style.removeProperty("height");
            }
          }
        }
      },wgetRequests:{},nextWgetRequestHandle:0,getNextWgetRequestHandle:function () {
        var handle = Browser.nextWgetRequestHandle;
        Browser.nextWgetRequestHandle++;
        return handle;
      }};

  
  function _fmod(x, y) {
      return x % y;
    }function _fmodl() {
  return _fmod.apply(null, arguments)
  }

   
  Module["_bitshift64Lshr"] = _bitshift64Lshr;

  
   
  Module["_testSetjmp"] = _testSetjmp;function _longjmp(env, value) {
      asm['setThrew'](env, value || 1);
      throw 'longjmp';
    }

  var _BDtoIHigh=true;

  
  
  
  
  var _environ=allocate(1, "i32*", ALLOC_STATIC);var ___environ=_environ;function ___buildEnvironment(env) {
      // WARNING: Arbitrary limit!
      var MAX_ENV_VALUES = 64;
      var TOTAL_ENV_SIZE = 1024;
  
      // Statically allocate memory for the environment.
      var poolPtr;
      var envPtr;
      if (!___buildEnvironment.called) {
        ___buildEnvironment.called = true;
        // Set default values. Use string keys for Closure Compiler compatibility.
        ENV['USER'] = 'web_user';
        ENV['PATH'] = '/';
        ENV['PWD'] = '/';
        ENV['HOME'] = '/home/web_user';
        ENV['LANG'] = 'C';
        ENV['_'] = Module['thisProgram'];
        // Allocate memory.
        poolPtr = allocate(TOTAL_ENV_SIZE, 'i8', ALLOC_STATIC);
        envPtr = allocate(MAX_ENV_VALUES * 4,
                          'i8*', ALLOC_STATIC);
        HEAP32[((envPtr)>>2)]=poolPtr;
        HEAP32[((_environ)>>2)]=envPtr;
      } else {
        envPtr = HEAP32[((_environ)>>2)];
        poolPtr = HEAP32[((envPtr)>>2)];
      }
  
      // Collect key=value lines.
      var strings = [];
      var totalSize = 0;
      for (var key in env) {
        if (typeof env[key] === 'string') {
          var line = key + '=' + env[key];
          strings.push(line);
          totalSize += line.length;
        }
      }
      if (totalSize > TOTAL_ENV_SIZE) {
        throw new Error('Environment size exceeded TOTAL_ENV_SIZE!');
      }
  
      // Make new.
      var ptrSize = 4;
      for (var i = 0; i < strings.length; i++) {
        var line = strings[i];
        writeAsciiToMemory(line, poolPtr);
        HEAP32[(((envPtr)+(i * ptrSize))>>2)]=poolPtr;
        poolPtr += line.length + 1;
      }
      HEAP32[(((envPtr)+(strings.length * ptrSize))>>2)]=0;
    }var ENV={};function _getenv(name) {
      // char *getenv(const char *name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/getenv.html
      if (name === 0) return 0;
      name = Pointer_stringify(name);
      if (!ENV.hasOwnProperty(name)) return 0;
  
      if (_getenv.ret) _free(_getenv.ret);
      _getenv.ret = allocate(intArrayFromString(ENV[name]), 'i8', ALLOC_NORMAL);
      return _getenv.ret;
    }

  function _emscripten_longjmp(env, value) {
      _longjmp(env, value);
    }

  function _exp2(x) {
      return Math.pow(2, x);
    }

  
  function _emscripten_memcpy_big(dest, src, num) {
      HEAPU8.set(HEAPU8.subarray(src, src+num), dest);
      return dest;
    } 
  Module["_memcpy"] = _memcpy;

  var _log=Math_log;

  var _emscripten_setjmp=true;

  function _putenv(string) {
      // int putenv(char *string);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/putenv.html
      // WARNING: According to the standard (and the glibc implementation), the
      //          string is taken by reference so future changes are reflected.
      //          We copy it instead, possibly breaking some uses.
      if (string === 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      string = Pointer_stringify(string);
      var splitPoint = string.indexOf('=')
      if (string === '' || string.indexOf('=') === -1) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      var name = string.slice(0, splitPoint);
      var value = string.slice(splitPoint + 1);
      if (!(name in ENV) || ENV[name] !== value) {
        ENV[name] = value;
        ___buildEnvironment(ENV);
      }
      return 0;
    }

  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) self.alloc(bytes);
      return ret;  // Previous break location.
    }

  var _fabs=Math_abs;

  var _emscripten_preinvoke=true;

  var _BItoD=true;

  
  function _copysign(a, b) {
      return __reallyNegative(a) === __reallyNegative(b) ? a : -a;
    }function _copysignl() {
  return _copysign.apply(null, arguments)
  }

___errno_state = Runtime.staticAlloc(4); HEAP32[((___errno_state)>>2)]=0;
FS.staticInit();__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
__ATINIT__.unshift({ func: function() { TTY.init() } });__ATEXIT__.push({ func: function() { TTY.shutdown() } });TTY.utf8 = new Runtime.UTF8Processor();
if (ENVIRONMENT_IS_NODE) { var fs = require("fs"); NODEFS.staticInit(); }
__ATINIT__.push({ func: function() { SOCKFS.root = FS.mount(SOCKFS, {}, null); } });
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
Module["requestFullScreen"] = function Module_requestFullScreen(lockPointer, resizeCanvas) { Browser.requestFullScreen(lockPointer, resizeCanvas) };
  Module["requestAnimationFrame"] = function Module_requestAnimationFrame(func) { Browser.requestAnimationFrame(func) };
  Module["setCanvasSize"] = function Module_setCanvasSize(width, height, noUpdates) { Browser.setCanvasSize(width, height, noUpdates) };
  Module["pauseMainLoop"] = function Module_pauseMainLoop() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function Module_resumeMainLoop() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function Module_getUserMedia() { Browser.getUserMedia() }
___buildEnvironment(ENV);
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);

staticSealed = true; // seal the static portion of memory

STACK_MAX = STACK_BASE + TOTAL_STACK;

DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);

assert(DYNAMIC_BASE < TOTAL_MEMORY, "TOTAL_MEMORY not big enough for stack");

 var ctlz_i8 = allocate([8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_DYNAMIC);
 var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_DYNAMIC);


function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    return Module["dynCall_iiiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiii(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

Module.asmGlobalArg = { "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array };
Module.asmLibraryArg = { "abort": abort, "assert": assert, "min": Math_min, "invoke_iiii": invoke_iiii, "invoke_viiiiiii": invoke_viiiiiii, "invoke_viiiii": invoke_viiiii, "invoke_vi": invoke_vi, "invoke_vii": invoke_vii, "invoke_iiiiiii": invoke_iiiiiii, "invoke_ii": invoke_ii, "invoke_viii": invoke_viii, "invoke_viiiiiiii": invoke_viiiiiiii, "invoke_iiiii": invoke_iiiii, "invoke_iii": invoke_iii, "invoke_iiiiii": invoke_iiiiii, "invoke_viiii": invoke_viiii, "_fabs": _fabs, "_putenv": _putenv, "_send": _send, "_fmod": _fmod, "_emscripten_set_main_loop_timing": _emscripten_set_main_loop_timing, "___buildEnvironment": ___buildEnvironment, "_longjmp": _longjmp, "_fflush": _fflush, "_pwrite": _pwrite, "_strerror_r": _strerror_r, "__reallyNegative": __reallyNegative, "_ceilf": _ceilf, "_emscripten_memcpy_big": _emscripten_memcpy_big, "_fileno": _fileno, "_sysconf": _sysconf, "___setErrNo": ___setErrNo, "_putchar": _putchar, "_exp2": _exp2, "_mkport": _mkport, "_log": _log, "_write": _write, "_emscripten_set_main_loop": _emscripten_set_main_loop, "___errno_location": ___errno_location, "_copysign": _copysign, "_getenv": _getenv, "__exit": __exit, "_copysignl": _copysignl, "_abort": _abort, "_fwrite": _fwrite, "_time": _time, "_fprintf": _fprintf, "_strerror": _strerror, "_emscripten_longjmp": _emscripten_longjmp, "_sbrk": _sbrk, "__formatString": __formatString, "_fputc": _fputc, "_exit": _exit, "_fmodl": _fmodl, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8, "ctlz_i8": ctlz_i8, "NaN": NaN, "Infinity": Infinity, "_stderr": _stderr };
// EMSCRIPTEN_START_ASM
var asm = (function(global, env, buffer) {
  'use asm';
  
  var HEAP8 = new global.Int8Array(buffer);
  var HEAP16 = new global.Int16Array(buffer);
  var HEAP32 = new global.Int32Array(buffer);
  var HEAPU8 = new global.Uint8Array(buffer);
  var HEAPU16 = new global.Uint16Array(buffer);
  var HEAPU32 = new global.Uint32Array(buffer);
  var HEAPF32 = new global.Float32Array(buffer);
  var HEAPF64 = new global.Float64Array(buffer);


  var STACKTOP=env.STACKTOP|0;
  var STACK_MAX=env.STACK_MAX|0;
  var tempDoublePtr=env.tempDoublePtr|0;
  var ABORT=env.ABORT|0;
  var cttz_i8=env.cttz_i8|0;
  var ctlz_i8=env.ctlz_i8|0;
  var _stderr=env._stderr|0;

  var __THREW__ = 0;
  var threwValue = 0;
  var setjmpId = 0;
  var undef = 0;
  var nan = +env.NaN, inf = +env.Infinity;
  var tempInt = 0, tempBigInt = 0, tempBigIntP = 0, tempBigIntS = 0, tempBigIntR = 0.0, tempBigIntI = 0, tempBigIntD = 0, tempValue = 0, tempDouble = 0.0;

  var tempRet0 = 0;
  var tempRet1 = 0;
  var tempRet2 = 0;
  var tempRet3 = 0;
  var tempRet4 = 0;
  var tempRet5 = 0;
  var tempRet6 = 0;
  var tempRet7 = 0;
  var tempRet8 = 0;
  var tempRet9 = 0;
  var Math_floor=global.Math.floor;
  var Math_abs=global.Math.abs;
  var Math_sqrt=global.Math.sqrt;
  var Math_pow=global.Math.pow;
  var Math_cos=global.Math.cos;
  var Math_sin=global.Math.sin;
  var Math_tan=global.Math.tan;
  var Math_acos=global.Math.acos;
  var Math_asin=global.Math.asin;
  var Math_atan=global.Math.atan;
  var Math_atan2=global.Math.atan2;
  var Math_exp=global.Math.exp;
  var Math_log=global.Math.log;
  var Math_ceil=global.Math.ceil;
  var Math_imul=global.Math.imul;
  var abort=env.abort;
  var assert=env.assert;
  var Math_min=env.min;
  var invoke_iiii=env.invoke_iiii;
  var invoke_viiiiiii=env.invoke_viiiiiii;
  var invoke_viiiii=env.invoke_viiiii;
  var invoke_vi=env.invoke_vi;
  var invoke_vii=env.invoke_vii;
  var invoke_iiiiiii=env.invoke_iiiiiii;
  var invoke_ii=env.invoke_ii;
  var invoke_viii=env.invoke_viii;
  var invoke_viiiiiiii=env.invoke_viiiiiiii;
  var invoke_iiiii=env.invoke_iiiii;
  var invoke_iii=env.invoke_iii;
  var invoke_iiiiii=env.invoke_iiiiii;
  var invoke_viiii=env.invoke_viiii;
  var _fabs=env._fabs;
  var _putenv=env._putenv;
  var _send=env._send;
  var _fmod=env._fmod;
  var _emscripten_set_main_loop_timing=env._emscripten_set_main_loop_timing;
  var ___buildEnvironment=env.___buildEnvironment;
  var _longjmp=env._longjmp;
  var _fflush=env._fflush;
  var _pwrite=env._pwrite;
  var _strerror_r=env._strerror_r;
  var __reallyNegative=env.__reallyNegative;
  var _ceilf=env._ceilf;
  var _emscripten_memcpy_big=env._emscripten_memcpy_big;
  var _fileno=env._fileno;
  var _sysconf=env._sysconf;
  var ___setErrNo=env.___setErrNo;
  var _putchar=env._putchar;
  var _exp2=env._exp2;
  var _mkport=env._mkport;
  var _log=env._log;
  var _write=env._write;
  var _emscripten_set_main_loop=env._emscripten_set_main_loop;
  var ___errno_location=env.___errno_location;
  var _copysign=env._copysign;
  var _getenv=env._getenv;
  var __exit=env.__exit;
  var _copysignl=env._copysignl;
  var _abort=env._abort;
  var _fwrite=env._fwrite;
  var _time=env._time;
  var _fprintf=env._fprintf;
  var _strerror=env._strerror;
  var _emscripten_longjmp=env._emscripten_longjmp;
  var _sbrk=env._sbrk;
  var __formatString=env.__formatString;
  var _fputc=env._fputc;
  var _exit=env._exit;
  var _fmodl=env._fmodl;
  var tempFloat = 0.0;

// EMSCRIPTEN_START_FUNCS
function stackAlloc(size) {
  size = size|0;
  var ret = 0;
  ret = STACKTOP;
  STACKTOP = (STACKTOP + size)|0;
STACKTOP = (STACKTOP + 15)&-16;

  return ret|0;
}
function stackSave() {
  return STACKTOP|0;
}
function stackRestore(top) {
  top = top|0;
  STACKTOP = top;
}

function setThrew(threw, value) {
  threw = threw|0;
  value = value|0;
  if ((__THREW__|0) == 0) {
    __THREW__ = threw;
    threwValue = value;
  }
}
function copyTempFloat(ptr) {
  ptr = ptr|0;
  HEAP8[tempDoublePtr>>0] = HEAP8[ptr>>0];
  HEAP8[tempDoublePtr+1>>0] = HEAP8[ptr+1>>0];
  HEAP8[tempDoublePtr+2>>0] = HEAP8[ptr+2>>0];
  HEAP8[tempDoublePtr+3>>0] = HEAP8[ptr+3>>0];
}
function copyTempDouble(ptr) {
  ptr = ptr|0;
  HEAP8[tempDoublePtr>>0] = HEAP8[ptr>>0];
  HEAP8[tempDoublePtr+1>>0] = HEAP8[ptr+1>>0];
  HEAP8[tempDoublePtr+2>>0] = HEAP8[ptr+2>>0];
  HEAP8[tempDoublePtr+3>>0] = HEAP8[ptr+3>>0];
  HEAP8[tempDoublePtr+4>>0] = HEAP8[ptr+4>>0];
  HEAP8[tempDoublePtr+5>>0] = HEAP8[ptr+5>>0];
  HEAP8[tempDoublePtr+6>>0] = HEAP8[ptr+6>>0];
  HEAP8[tempDoublePtr+7>>0] = HEAP8[ptr+7>>0];
}
function setTempRet0(value) {
  value = value|0;
  tempRet0 = value;
}
function getTempRet0() {
  return tempRet0|0;
}

function _jpeg_CreateCompress($cinfo,$version,$structsize) {
 $cinfo = $cinfo|0;
 $version = $version|0;
 $structsize = $structsize|0;
 var $$pre$phi7Z2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = ($version|0)==(62);
 if (!($1)) {
  $2 = HEAP32[$cinfo>>2]|0;
  $3 = (($2) + 20|0);
  HEAP32[$3>>2] = 12;
  $4 = (($2) + 24|0);
  HEAP32[$4>>2] = 62;
  $5 = (($2) + 28|0);
  HEAP32[$5>>2] = $version;
  $6 = HEAP32[$2>>2]|0;
  FUNCTION_TABLE_vi[$6 & 63]($cinfo);
 }
 $7 = ($structsize|0)==(360);
 if ($7) {
  $$pre$phi7Z2D = $cinfo;
 } else {
  $8 = HEAP32[$cinfo>>2]|0;
  $9 = (($8) + 20|0);
  HEAP32[$9>>2] = 21;
  $10 = (($8) + 24|0);
  HEAP32[$10>>2] = 360;
  $11 = (($8) + 28|0);
  HEAP32[$11>>2] = $structsize;
  $12 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vi[$12 & 63]($cinfo);
  $$pre$phi7Z2D = $cinfo;
 }
 $13 = HEAP32[$cinfo>>2]|0;
 $14 = (($cinfo) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 _memset(($cinfo|0),0,360)|0;
 HEAP32[$cinfo>>2] = $13;
 HEAP32[$14>>2] = $15;
 $16 = (($cinfo) + 16|0);
 HEAP8[$16>>0] = 0;
 _jinit_memory_mgr($$pre$phi7Z2D);
 $17 = (($cinfo) + 8|0);
 HEAP32[$17>>2] = 0;
 $18 = (($cinfo) + 24|0);
 HEAP32[$18>>2] = 0;
 $19 = (($cinfo) + 68|0);
 $20 = (($cinfo) + 352|0);
 HEAP32[$20>>2] = 0;
 $21 = (($cinfo) + 48|0);
 dest=$19+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF64[$21>>3] = 1.0;
 $22 = (($cinfo) + 20|0);
 HEAP32[$22>>2] = 100;
 $23 = HEAP32[$0>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = (FUNCTION_TABLE_iiii[$24 & 7]($$pre$phi7Z2D,0,4992)|0);
 $26 = (($cinfo) + 316|0);
 HEAP32[$26>>2] = $25;
 _memset(($25|0),0,4992)|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 4120|0);
 HEAP32[$28>>2] = 1560820397;
 STACKTOP = sp;return;
}
function _jpeg_abort_compress($cinfo) {
 $cinfo = $cinfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _jpeg_abort($cinfo);
 STACKTOP = sp;return;
}
function _jpeg_suppress_tables($cinfo,$suppress) {
 $cinfo = $cinfo|0;
 $suppress = $suppress|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 128|0);
  HEAP8[$3>>0] = $suppress;
 }
 $4 = (($cinfo) + 76|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $37 = (($5) + 128|0);
  HEAP8[$37>>0] = $suppress;
 }
 $38 = (($cinfo) + 80|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0|0);
 if (!($40)) {
  $41 = (($39) + 128|0);
  HEAP8[$41>>0] = $suppress;
 }
 $42 = (($cinfo) + 84|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 if (!($44)) {
  $45 = (($43) + 128|0);
  HEAP8[$45>>0] = $suppress;
 }
 $46 = (($cinfo) + 88|0);
 $8 = HEAP32[$46>>2]|0;
 $47 = ($8|0)==(0|0);
 if (!($47)) {
  $7 = (($8) + 273|0);
  HEAP8[$7>>0] = $suppress;
 }
 $9 = (($cinfo) + 104|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = (($10) + 273|0);
  HEAP8[$12>>0] = $suppress;
 }
 $13 = (($cinfo) + 92|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $16 = (($14) + 273|0);
  HEAP8[$16>>0] = $suppress;
 }
 $17 = (($cinfo) + 108|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  $20 = (($18) + 273|0);
  HEAP8[$20>>0] = $suppress;
 }
 $21 = (($cinfo) + 96|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  $24 = (($22) + 273|0);
  HEAP8[$24>>0] = $suppress;
 }
 $25 = (($cinfo) + 112|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  $28 = (($26) + 273|0);
  HEAP8[$28>>0] = $suppress;
 }
 $29 = (($cinfo) + 100|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if (!($31)) {
  $32 = (($30) + 273|0);
  HEAP8[$32>>0] = $suppress;
 }
 $33 = (($cinfo) + 116|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 $36 = (($34) + 273|0);
 HEAP8[$36>>0] = $suppress;
 STACKTOP = sp;return;
}
function _jpeg_finish_compress($cinfo) {
 $cinfo = $cinfo|0;
 var $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $7 = 0, $8 = 0, $9 = 0, $iMCU_row$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 if ((($1|0) == 102) | (($1|0) == 101)) {
  $2 = (($cinfo) + 208|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($cinfo) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($3>>>0)<($5>>>0);
  if ($6) {
   $7 = HEAP32[$cinfo>>2]|0;
   $8 = (($7) + 20|0);
   HEAP32[$8>>2] = 67;
   $9 = HEAP32[$7>>2]|0;
   FUNCTION_TABLE_vi[$9 & 63]($cinfo);
  }
  $10 = (($cinfo) + 316|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vi[$13 & 63]($cinfo);
 } else if (!((($1|0) == 103))) {
  $14 = HEAP32[$cinfo>>2]|0;
  $15 = (($14) + 20|0);
  HEAP32[$15>>2] = 20;
  $16 = HEAP32[$0>>2]|0;
  $17 = (($14) + 24|0);
  HEAP32[$17>>2] = $16;
  $18 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_vi[$18 & 63]($cinfo);
 }
 $19 = (($cinfo) + 316|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 13|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if (!($23)) {
  $$pre$phiZ2D = $cinfo;
  $55 = (($cinfo) + 332|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (($56) + 12|0);
  $58 = HEAP32[$57>>2]|0;
  FUNCTION_TABLE_vi[$58 & 63]($cinfo);
  $59 = (($cinfo) + 24|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (($60) + 16|0);
  $62 = HEAP32[$61>>2]|0;
  FUNCTION_TABLE_vi[$62 & 63]($cinfo);
  _jpeg_abort($$pre$phiZ2D);
  STACKTOP = sp;return;
 }
 $24 = (($cinfo) + 224|0);
 $25 = (($cinfo) + 8|0);
 $26 = (($cinfo) + 328|0);
 $28 = $20;
 while(1) {
  $27 = HEAP32[$28>>2]|0;
  FUNCTION_TABLE_vi[$27 & 63]($cinfo);
  $29 = HEAP32[$24>>2]|0;
  $30 = ($29|0)==(0);
  if (!($30)) {
   $35 = $29;$iMCU_row$01 = 0;
   while(1) {
    $31 = HEAP32[$25>>2]|0;
    $32 = ($31|0)==(0|0);
    if (!($32)) {
     $33 = (($31) + 4|0);
     HEAP32[$33>>2] = $iMCU_row$01;
     $34 = (($31) + 8|0);
     HEAP32[$34>>2] = $35;
     $36 = HEAP32[$31>>2]|0;
     FUNCTION_TABLE_vi[$36 & 63]($cinfo);
    }
    $37 = HEAP32[$26>>2]|0;
    $38 = (($37) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (FUNCTION_TABLE_iii[$39 & 15]($cinfo,0)|0);
    $41 = ($40<<24>>24)==(0);
    if ($41) {
     $42 = HEAP32[$cinfo>>2]|0;
     $43 = (($42) + 20|0);
     HEAP32[$43>>2] = 24;
     $44 = HEAP32[$42>>2]|0;
     FUNCTION_TABLE_vi[$44 & 63]($cinfo);
    }
    $45 = (($iMCU_row$01) + 1)|0;
    $46 = HEAP32[$24>>2]|0;
    $47 = ($45>>>0)<($46>>>0);
    if ($47) {
     $35 = $46;$iMCU_row$01 = $45;
    } else {
     break;
    }
   }
  }
  $48 = HEAP32[$19>>2]|0;
  $49 = (($48) + 8|0);
  $50 = HEAP32[$49>>2]|0;
  FUNCTION_TABLE_vi[$50 & 63]($cinfo);
  $51 = HEAP32[$19>>2]|0;
  $52 = (($51) + 13|0);
  $53 = HEAP8[$52>>0]|0;
  $54 = ($53<<24>>24)==(0);
  if ($54) {
   $28 = $51;
  } else {
   $$pre$phiZ2D = $cinfo;
   break;
  }
 }
 $55 = (($cinfo) + 332|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + 12|0);
 $58 = HEAP32[$57>>2]|0;
 FUNCTION_TABLE_vi[$58 & 63]($cinfo);
 $59 = (($cinfo) + 24|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($60) + 16|0);
 $62 = HEAP32[$61>>2]|0;
 FUNCTION_TABLE_vi[$62 & 63]($cinfo);
 _jpeg_abort($$pre$phiZ2D);
 STACKTOP = sp;return;
}
function _jpeg_start_compress($cinfo,$write_all_tables) {
 $cinfo = $cinfo|0;
 $write_all_tables = $write_all_tables|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(100);
 if (!($2)) {
  $3 = HEAP32[$cinfo>>2]|0;
  $4 = (($3) + 20|0);
  HEAP32[$4>>2] = 20;
  $5 = HEAP32[$0>>2]|0;
  $6 = (($3) + 24|0);
  HEAP32[$6>>2] = $5;
  $7 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$7 & 63]($cinfo);
 }
 $8 = ($write_all_tables<<24>>24)==(0);
 if (!($8)) {
  _jpeg_suppress_tables($cinfo,0);
 }
 $9 = (($cinfo) + 316|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 4140|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 if ($13) {
  label = 8;
 } else {
  $14 = (($cinfo) + 172|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   label = 8;
  } else {
   $17 = (($cinfo) + 168|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0);
   if ($19) {
    label = 8;
   }
  }
 }
 if ((label|0) == 8) {
  $20 = (($10) + 14|0);
  HEAP8[$20>>0] = 0;
 }
 $21 = HEAP32[$cinfo>>2]|0;
 $22 = (($21) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_vi[$23 & 63]($cinfo);
 $24 = (($cinfo) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 FUNCTION_TABLE_vi[$27 & 63]($cinfo);
 _jinit_compress_master($cinfo);
 $28 = HEAP32[$9>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_vi[$29 & 63]($cinfo);
 $30 = (($cinfo) + 208|0);
 HEAP32[$30>>2] = 0;
 $31 = (($cinfo) + 176|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = ($32<<24>>24)!=(0);
 $34 = $33 ? 102 : 101;
 HEAP32[$0>>2] = $34;
 STACKTOP = sp;return;
}
function _jpeg_write_scanlines($cinfo,$scanlines,$num_lines) {
 $cinfo = $cinfo|0;
 $scanlines = $scanlines|0;
 $num_lines = $num_lines|0;
 var $$num_lines = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $row_ctr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $row_ctr = sp;
 $0 = (($cinfo) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(101);
 if (!($2)) {
  $3 = HEAP32[$cinfo>>2]|0;
  $4 = (($3) + 20|0);
  HEAP32[$4>>2] = 20;
  $5 = HEAP32[$0>>2]|0;
  $6 = (($3) + 24|0);
  HEAP32[$6>>2] = $5;
  $7 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$7 & 63]($cinfo);
 }
 $8 = (($cinfo) + 208|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($cinfo) + 32|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9>>>0)<($11>>>0);
 if (!($12)) {
  $13 = HEAP32[$cinfo>>2]|0;
  $14 = (($13) + 20|0);
  HEAP32[$14>>2] = 123;
  $15 = (($13) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  FUNCTION_TABLE_vii[$16 & 15]($cinfo,-1);
 }
 $17 = (($cinfo) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  $20 = HEAP32[$8>>2]|0;
  $21 = (($18) + 4|0);
  HEAP32[$21>>2] = $20;
  $22 = HEAP32[$10>>2]|0;
  $23 = (($18) + 8|0);
  HEAP32[$23>>2] = $22;
  $24 = HEAP32[$18>>2]|0;
  FUNCTION_TABLE_vi[$24 & 63]($cinfo);
 }
 $25 = (($cinfo) + 316|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 12|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = ($28<<24>>24)==(0);
 if (!($29)) {
  $30 = (($26) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vi[$31 & 63]($cinfo);
 }
 $32 = HEAP32[$10>>2]|0;
 $33 = HEAP32[$8>>2]|0;
 $34 = (($32) - ($33))|0;
 $35 = ($34>>>0)<($num_lines>>>0);
 $$num_lines = $35 ? $34 : $num_lines;
 HEAP32[$row_ctr>>2] = 0;
 $36 = (($cinfo) + 320|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 4|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_viiii[$39 & 15]($cinfo,$scanlines,$row_ctr,$$num_lines);
 $40 = HEAP32[$row_ctr>>2]|0;
 $41 = HEAP32[$8>>2]|0;
 $42 = (($41) + ($40))|0;
 HEAP32[$8>>2] = $42;
 STACKTOP = sp;return ($40|0);
}
function _jinit_arith_encoder($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 7]($cinfo,1,208)|0);
 $4 = (($cinfo) + 348|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$3>>2] = 1;
 $5 = (($3) + 8|0);
 HEAP32[$5>>2] = 1;
 $6 = (($3) + 76|0);
 $7 = (($3) + 140|0);
 HEAP32[$6>>2] = 0;
 HEAP32[$7>>2] = 0;
 $8 = (($3) + 80|0);
 HEAP32[$8>>2] = 0;
 $9 = (($3) + 144|0);
 HEAP32[$9>>2] = 0;
 $10 = (($3) + 84|0);
 HEAP32[$10>>2] = 0;
 $11 = (($3) + 148|0);
 HEAP32[$11>>2] = 0;
 $12 = (($3) + 88|0);
 HEAP32[$12>>2] = 0;
 $13 = (($3) + 152|0);
 HEAP32[$13>>2] = 0;
 $14 = (($3) + 92|0);
 HEAP32[$14>>2] = 0;
 $15 = (($3) + 156|0);
 HEAP32[$15>>2] = 0;
 $16 = (($3) + 96|0);
 HEAP32[$16>>2] = 0;
 $17 = (($3) + 160|0);
 HEAP32[$17>>2] = 0;
 $18 = (($3) + 100|0);
 HEAP32[$18>>2] = 0;
 $19 = (($3) + 164|0);
 HEAP32[$19>>2] = 0;
 $20 = (($3) + 104|0);
 HEAP32[$20>>2] = 0;
 $21 = (($3) + 168|0);
 HEAP32[$21>>2] = 0;
 $22 = (($3) + 108|0);
 HEAP32[$22>>2] = 0;
 $23 = (($3) + 172|0);
 HEAP32[$23>>2] = 0;
 $24 = (($3) + 112|0);
 HEAP32[$24>>2] = 0;
 $25 = (($3) + 176|0);
 HEAP32[$25>>2] = 0;
 $26 = (($3) + 116|0);
 HEAP32[$26>>2] = 0;
 $27 = (($3) + 180|0);
 HEAP32[$27>>2] = 0;
 $28 = (($3) + 120|0);
 HEAP32[$28>>2] = 0;
 $29 = (($3) + 184|0);
 HEAP32[$29>>2] = 0;
 $30 = (($3) + 124|0);
 HEAP32[$30>>2] = 0;
 $31 = (($3) + 188|0);
 HEAP32[$31>>2] = 0;
 $32 = (($3) + 128|0);
 HEAP32[$32>>2] = 0;
 $33 = (($3) + 192|0);
 HEAP32[$33>>2] = 0;
 $34 = (($3) + 132|0);
 HEAP32[$34>>2] = 0;
 $35 = (($3) + 196|0);
 HEAP32[$35>>2] = 0;
 $36 = (($3) + 136|0);
 HEAP32[$36>>2] = 0;
 $37 = (($3) + 200|0);
 HEAP32[$37>>2] = 0;
 $38 = (($3) + 204|0);
 HEAP8[$38>>0] = 113;
 STACKTOP = sp;return;
}
function _start_pass($cinfo,$gather_statistics) {
 $cinfo = $cinfo|0;
 $gather_statistics = $gather_statistics|0;
 var $$c = 0, $$ph = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $ci$05 = 0, $ci$05$us = 0, $phitmp = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($gather_statistics<<24>>24)==(0);
 if (!($2)) {
  $3 = HEAP32[$cinfo>>2]|0;
  $4 = (($3) + 20|0);
  HEAP32[$4>>2] = 48;
  $5 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$5 & 63]($cinfo);
 }
 $6 = (($cinfo) + 316|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 20|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 do {
  if ($10) {
   $11 = (($cinfo) + 212|0);
   $12 = HEAP8[$11>>0]|0;
   $phitmp = ($12<<24>>24)==(0);
   if ($phitmp) {
    label = 12;
   } else {
    $13 = (($cinfo) + 308|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==(0);
    $16 = (($cinfo) + 300|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0);
    $19 = (($1) + 4|0);
    if ($15) {
     if ($18) {
      HEAP32[$19>>2] = 1;
      $$ph = 0;
      break;
     } else {
      HEAP32[$19>>2] = 2;
      $$ph = 0;
      break;
     }
    } else {
     if ($18) {
      HEAP32[$19>>2] = 3;
      $$ph = 0;
      break;
     } else {
      HEAP32[$19>>2] = 4;
      $$ph = 0;
      break;
     }
    }
   }
  } else {
   label = 12;
  }
 } while(0);
 if ((label|0) == 12) {
  $20 = (($1) + 4|0);
  HEAP32[$20>>2] = 5;
  $$ph = 1;
 }
 $21 = (($cinfo) + 228|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)>(0);
 L19: do {
  if ($23) {
   $24 = (($1) + 76|0);
   $25 = (($cinfo) + 4|0);
   $26 = (($1) + 36|0);
   $27 = (($1) + 52|0);
   $28 = (($1) + 140|0);
   $29 = (($cinfo) + 304|0);
   $30 = (($cinfo) + 300|0);
   $31 = (($cinfo) + 308|0);
   if ($$ph) {
    $ci$05$us = 0;
    while(1) {
     $32 = ((($cinfo) + ($ci$05$us<<2)|0) + 232|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = (($33) + 20|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = ($35>>>0)>(15);
     if ($36) {
      $37 = HEAP32[$cinfo>>2]|0;
      $38 = (($37) + 20|0);
      HEAP32[$38>>2] = 125;
      $39 = (($37) + 24|0);
      HEAP32[$39>>2] = $35;
      $40 = HEAP32[$37>>2]|0;
      FUNCTION_TABLE_vi[$40 & 63]($cinfo);
     }
     $41 = (($24) + ($35<<2)|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==(0|0);
     if ($43) {
      $44 = HEAP32[$25>>2]|0;
      $45 = HEAP32[$44>>2]|0;
      $46 = (FUNCTION_TABLE_iiii[$45 & 7]($cinfo,1,64)|0);
      HEAP32[$41>>2] = $46;
      $47 = $46;
     } else {
      $47 = $42;
     }
     dest=$47+0|0; stop=dest+64|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
     $48 = (($26) + ($ci$05$us<<2)|0);
     HEAP32[$48>>2] = 0;
     $49 = (($27) + ($ci$05$us<<2)|0);
     HEAP32[$49>>2] = 0;
     $50 = (($33) + 24|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51>>>0)>(15);
     if ($52) {
      $53 = HEAP32[$cinfo>>2]|0;
      $54 = (($53) + 20|0);
      HEAP32[$54>>2] = 125;
      $55 = (($53) + 24|0);
      HEAP32[$55>>2] = $51;
      $56 = HEAP32[$53>>2]|0;
      FUNCTION_TABLE_vi[$56 & 63]($cinfo);
     }
     $57 = (($28) + ($51<<2)|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = ($58|0)==(0|0);
     if ($59) {
      $60 = HEAP32[$25>>2]|0;
      $61 = HEAP32[$60>>2]|0;
      $62 = (FUNCTION_TABLE_iiii[$61 & 7]($cinfo,1,256)|0);
      HEAP32[$57>>2] = $62;
      $63 = $62;
     } else {
      $63 = $58;
     }
     _memset(($63|0),0,256)|0;
     $64 = (($ci$05$us) + 1)|0;
     $65 = HEAP32[$21>>2]|0;
     $66 = ($64|0)<($65|0);
     if ($66) {
      $ci$05$us = $64;
     } else {
      break L19;
     }
    }
   } else {
    $ci$05 = 0;
   }
   while(1) {
    $67 = ((($cinfo) + ($ci$05<<2)|0) + 232|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = HEAP32[$30>>2]|0;
    $70 = ($69|0)==(0);
    if ($70) {
     $71 = HEAP32[$31>>2]|0;
     $72 = ($71|0)==(0);
     if ($72) {
      $73 = (($68) + 20|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = ($74>>>0)>(15);
      if ($75) {
       $76 = HEAP32[$cinfo>>2]|0;
       $77 = (($76) + 20|0);
       HEAP32[$77>>2] = 125;
       $78 = (($76) + 24|0);
       HEAP32[$78>>2] = $74;
       $79 = HEAP32[$76>>2]|0;
       FUNCTION_TABLE_vi[$79 & 63]($cinfo);
      }
      $80 = (($24) + ($74<<2)|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = ($81|0)==(0|0);
      if ($82) {
       $83 = HEAP32[$25>>2]|0;
       $84 = HEAP32[$83>>2]|0;
       $85 = (FUNCTION_TABLE_iiii[$84 & 7]($cinfo,1,64)|0);
       HEAP32[$80>>2] = $85;
       $86 = $85;
      } else {
       $86 = $81;
      }
      dest=$86+0|0; stop=dest+64|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
      $87 = (($26) + ($ci$05<<2)|0);
      HEAP32[$87>>2] = 0;
      $88 = (($27) + ($ci$05<<2)|0);
      HEAP32[$88>>2] = 0;
     }
    }
    $89 = HEAP32[$29>>2]|0;
    $90 = ($89|0)==(0);
    if (!($90)) {
     $91 = (($68) + 24|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = ($92>>>0)>(15);
     if ($93) {
      $94 = HEAP32[$cinfo>>2]|0;
      $95 = (($94) + 20|0);
      HEAP32[$95>>2] = 125;
      $96 = (($94) + 24|0);
      HEAP32[$96>>2] = $92;
      $97 = HEAP32[$94>>2]|0;
      FUNCTION_TABLE_vi[$97 & 63]($cinfo);
     }
     $98 = (($28) + ($92<<2)|0);
     $99 = HEAP32[$98>>2]|0;
     $100 = ($99|0)==(0|0);
     if ($100) {
      $101 = HEAP32[$25>>2]|0;
      $102 = HEAP32[$101>>2]|0;
      $103 = (FUNCTION_TABLE_iiii[$102 & 7]($cinfo,1,256)|0);
      HEAP32[$98>>2] = $103;
      $104 = $103;
     } else {
      $104 = $99;
     }
     _memset(($104|0),0,256)|0;
    }
    $105 = (($ci$05) + 1)|0;
    $106 = HEAP32[$21>>2]|0;
    $107 = ($105|0)<($106|0);
    if ($107) {
     $ci$05 = $105;
    } else {
     break;
    }
   }
  }
 } while(0);
 $108 = (($1) + 12|0);
 HEAP32[$108>>2] = 0;
 $109 = (($1) + 16|0);
 HEAP32[$109>>2] = (65536);
 $110 = (($1) + 20|0);
 HEAP32[$110>>2] = 0;
 $111 = (($1) + 24|0);
 HEAP32[$111>>2] = 0;
 $112 = (($1) + 28|0);
 HEAP32[$112>>2] = (11);
 $113 = (($1) + 32|0);
 HEAP32[$113>>2] = (-1);
 $114 = (($cinfo) + 188|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = (($1) + 68|0);
 $$c = $115;
 HEAP32[$116>>2] = $$c;
 $117 = (($1) + 72|0);
 HEAP32[$117>>2] = 0;
 STACKTOP = sp;return;
}
function _finish_pass($cinfo) {
 $cinfo = $cinfo|0;
 var $$c = 0, $$c1 = 0, $$c2 = 0, $$c3 = 0, $$c4 = 0, $$c5 = 0, $$c6 = 0, $$c7 = 0, $$c8 = 0, $$c9 = 0, $$pre = 0, $$pre46 = 0, $$pre52 = 0, $$pre54 = 0, $$pre56 = 0, $$pre58 = 0, $$pre60 = 0, $$pre62 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 $5 = (($1) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6))|0;
 $8 = $7 & -65536;
 $9 = ($8|0)<($6|0);
 if ($9) {
  $10 = $8 | 32768;
  $$c9 = $10;
  HEAP32[$5>>2] = $$c9;
  $14 = $10;
 } else {
  $$c = $8;
  HEAP32[$5>>2] = $$c;
  $14 = $8;
 }
 $11 = (($1) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $14 << $12;
 $$c1 = $13;
 HEAP32[$5>>2] = $$c1;
 $15 = ($13>>>0)>(134217727);
 $16 = (($1) + 32|0);
 $17 = HEAP32[$16>>2]|0;
 if ($15) {
  $18 = ($17|0)>(-1);
  $19 = (($1) + 24|0);
  if ($18) {
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0);
   $$pre = (($cinfo) + 24|0);
   $$pre46 = (($cinfo) + 316|0);
   if (!($21)) {
    while(1) {
     $22 = HEAP32[$$pre>>2]|0;
     $23 = HEAP32[$$pre46>>2]|0;
     $24 = (($23) + 20|0);
     $25 = HEAP8[$24>>0]|0;
     $26 = ($25<<24>>24)==(0);
     if ($26) {
      $27 = HEAP32[$22>>2]|0;
      $28 = (($27) + 1|0);
      HEAP32[$22>>2] = $28;
      HEAP8[$27>>0] = 0;
      $29 = (($22) + 4|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($30) + -1)|0;
      HEAP32[$29>>2] = $31;
      $32 = ($31|0)==(0);
      if ($32) {
       $33 = (($22) + 12|0);
       $34 = HEAP32[$33>>2]|0;
       $35 = (FUNCTION_TABLE_ii[$34 & 7]($cinfo)|0);
       $36 = ($35<<24>>24)==(0);
       if ($36) {
        $37 = HEAP32[$cinfo>>2]|0;
        $38 = (($37) + 20|0);
        HEAP32[$38>>2] = 24;
        $39 = HEAP32[$37>>2]|0;
        FUNCTION_TABLE_vi[$39 & 63]($cinfo);
       }
      }
     }
     $40 = HEAP32[$19>>2]|0;
     $41 = (($40) + -1)|0;
     $$c8 = $41;
     HEAP32[$19>>2] = $$c8;
     $42 = ($41|0)==(0);
     if ($42) {
      break;
     }
    }
   }
   $43 = HEAP32[$$pre>>2]|0;
   $44 = HEAP32[$$pre46>>2]|0;
   $45 = (($44) + 20|0);
   $46 = HEAP8[$45>>0]|0;
   $47 = ($46<<24>>24)==(0);
   if ($47) {
    $48 = HEAP32[$16>>2]|0;
    $49 = (($48) + 1)|0;
    $50 = $49&255;
    $51 = HEAP32[$43>>2]|0;
    $52 = (($51) + 1|0);
    HEAP32[$43>>2] = $52;
    HEAP8[$51>>0] = $50;
    $53 = (($43) + 4|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($54) + -1)|0;
    HEAP32[$53>>2] = $55;
    $56 = ($55|0)==(0);
    if ($56) {
     $57 = (($43) + 12|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = (FUNCTION_TABLE_ii[$58 & 7]($cinfo)|0);
     $60 = ($59<<24>>24)==(0);
     if ($60) {
      $61 = HEAP32[$cinfo>>2]|0;
      $62 = (($61) + 20|0);
      HEAP32[$62>>2] = 24;
      $63 = HEAP32[$61>>2]|0;
      FUNCTION_TABLE_vi[$63 & 63]($cinfo);
     }
    }
   }
   $64 = HEAP32[$16>>2]|0;
   $65 = ($64|0)==(254);
   if ($65) {
    $66 = HEAP32[$$pre>>2]|0;
    $67 = HEAP32[$$pre46>>2]|0;
    $68 = (($67) + 20|0);
    $69 = HEAP8[$68>>0]|0;
    $70 = ($69<<24>>24)==(0);
    if ($70) {
     $71 = HEAP32[$66>>2]|0;
     $72 = (($71) + 1|0);
     HEAP32[$66>>2] = $72;
     HEAP8[$71>>0] = 0;
     $73 = (($66) + 4|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = (($74) + -1)|0;
     HEAP32[$73>>2] = $75;
     $76 = ($75|0)==(0);
     if ($76) {
      $77 = (($66) + 12|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = (FUNCTION_TABLE_ii[$78 & 7]($cinfo)|0);
      $80 = ($79<<24>>24)==(0);
      if ($80) {
       $81 = HEAP32[$cinfo>>2]|0;
       $82 = (($81) + 20|0);
       HEAP32[$82>>2] = 24;
       $83 = HEAP32[$81>>2]|0;
       FUNCTION_TABLE_vi[$83 & 63]($cinfo);
      }
     }
    }
   }
  }
  $84 = (($1) + 20|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = HEAP32[$19>>2]|0;
  $87 = (($86) + ($85))|0;
  $$c7 = $87;
  HEAP32[$19>>2] = $$c7;
  HEAP32[$84>>2] = 0;
 } else {
  $88 = ($17|0)==(0);
  if ($88) {
   $89 = (($1) + 24|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($90) + 1)|0;
   $$c6 = $91;
   HEAP32[$89>>2] = $$c6;
  } else {
   $92 = ($17|0)>(-1);
   if ($92) {
    $93 = (($1) + 24|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = ($94|0)==(0);
    $$pre56 = (($cinfo) + 24|0);
    $$pre58 = (($cinfo) + 316|0);
    if (!($95)) {
     while(1) {
      $96 = HEAP32[$$pre56>>2]|0;
      $97 = HEAP32[$$pre58>>2]|0;
      $98 = (($97) + 20|0);
      $99 = HEAP8[$98>>0]|0;
      $100 = ($99<<24>>24)==(0);
      if ($100) {
       $101 = HEAP32[$96>>2]|0;
       $102 = (($101) + 1|0);
       HEAP32[$96>>2] = $102;
       HEAP8[$101>>0] = 0;
       $103 = (($96) + 4|0);
       $104 = HEAP32[$103>>2]|0;
       $105 = (($104) + -1)|0;
       HEAP32[$103>>2] = $105;
       $106 = ($105|0)==(0);
       if ($106) {
        $107 = (($96) + 12|0);
        $108 = HEAP32[$107>>2]|0;
        $109 = (FUNCTION_TABLE_ii[$108 & 7]($cinfo)|0);
        $110 = ($109<<24>>24)==(0);
        if ($110) {
         $111 = HEAP32[$cinfo>>2]|0;
         $112 = (($111) + 20|0);
         HEAP32[$112>>2] = 24;
         $113 = HEAP32[$111>>2]|0;
         FUNCTION_TABLE_vi[$113 & 63]($cinfo);
        }
       }
      }
      $114 = HEAP32[$93>>2]|0;
      $115 = (($114) + -1)|0;
      $$c5 = $115;
      HEAP32[$93>>2] = $$c5;
      $116 = ($115|0)==(0);
      if ($116) {
       break;
      }
     }
    }
    $117 = HEAP32[$$pre56>>2]|0;
    $118 = HEAP32[$$pre58>>2]|0;
    $119 = (($118) + 20|0);
    $120 = HEAP8[$119>>0]|0;
    $121 = ($120<<24>>24)==(0);
    if ($121) {
     $122 = HEAP32[$16>>2]|0;
     $123 = $122&255;
     $124 = HEAP32[$117>>2]|0;
     $125 = (($124) + 1|0);
     HEAP32[$117>>2] = $125;
     HEAP8[$124>>0] = $123;
     $126 = (($117) + 4|0);
     $127 = HEAP32[$126>>2]|0;
     $128 = (($127) + -1)|0;
     HEAP32[$126>>2] = $128;
     $129 = ($128|0)==(0);
     if ($129) {
      $130 = (($117) + 12|0);
      $131 = HEAP32[$130>>2]|0;
      $132 = (FUNCTION_TABLE_ii[$131 & 7]($cinfo)|0);
      $133 = ($132<<24>>24)==(0);
      if ($133) {
       $134 = HEAP32[$cinfo>>2]|0;
       $135 = (($134) + 20|0);
       HEAP32[$135>>2] = 24;
       $136 = HEAP32[$134>>2]|0;
       FUNCTION_TABLE_vi[$136 & 63]($cinfo);
      }
     }
    }
   }
  }
  $137 = (($1) + 20|0);
  $138 = HEAP32[$137>>2]|0;
  $139 = ($138|0)==(0);
  if (!($139)) {
   $140 = (($1) + 24|0);
   $141 = HEAP32[$140>>2]|0;
   $142 = ($141|0)==(0);
   $$pre60 = (($cinfo) + 24|0);
   $$pre62 = (($cinfo) + 316|0);
   if (!($142)) {
    while(1) {
     $143 = HEAP32[$$pre60>>2]|0;
     $144 = HEAP32[$$pre62>>2]|0;
     $145 = (($144) + 20|0);
     $146 = HEAP8[$145>>0]|0;
     $147 = ($146<<24>>24)==(0);
     if ($147) {
      $148 = HEAP32[$143>>2]|0;
      $149 = (($148) + 1|0);
      HEAP32[$143>>2] = $149;
      HEAP8[$148>>0] = 0;
      $150 = (($143) + 4|0);
      $151 = HEAP32[$150>>2]|0;
      $152 = (($151) + -1)|0;
      HEAP32[$150>>2] = $152;
      $153 = ($152|0)==(0);
      if ($153) {
       $154 = (($143) + 12|0);
       $155 = HEAP32[$154>>2]|0;
       $156 = (FUNCTION_TABLE_ii[$155 & 7]($cinfo)|0);
       $157 = ($156<<24>>24)==(0);
       if ($157) {
        $158 = HEAP32[$cinfo>>2]|0;
        $159 = (($158) + 20|0);
        HEAP32[$159>>2] = 24;
        $160 = HEAP32[$158>>2]|0;
        FUNCTION_TABLE_vi[$160 & 63]($cinfo);
       }
      }
     }
     $161 = HEAP32[$140>>2]|0;
     $162 = (($161) + -1)|0;
     $$c4 = $162;
     HEAP32[$140>>2] = $$c4;
     $163 = ($162|0)==(0);
     if ($163) {
      break;
     }
    }
   }
   while(1) {
    $164 = HEAP32[$$pre60>>2]|0;
    $165 = HEAP32[$$pre62>>2]|0;
    $166 = (($165) + 20|0);
    $167 = HEAP8[$166>>0]|0;
    $168 = ($167<<24>>24)==(0);
    if ($168) {
     $169 = HEAP32[$164>>2]|0;
     $170 = (($169) + 1|0);
     HEAP32[$164>>2] = $170;
     HEAP8[$169>>0] = -1;
     $171 = (($164) + 4|0);
     $172 = HEAP32[$171>>2]|0;
     $173 = (($172) + -1)|0;
     HEAP32[$171>>2] = $173;
     $174 = ($173|0)==(0);
     if ($174) {
      $175 = (($164) + 12|0);
      $176 = HEAP32[$175>>2]|0;
      $177 = (FUNCTION_TABLE_ii[$176 & 7]($cinfo)|0);
      $178 = ($177<<24>>24)==(0);
      if ($178) {
       $179 = HEAP32[$cinfo>>2]|0;
       $180 = (($179) + 20|0);
       HEAP32[$180>>2] = 24;
       $181 = HEAP32[$179>>2]|0;
       FUNCTION_TABLE_vi[$181 & 63]($cinfo);
      }
     }
    }
    $182 = HEAP32[$$pre60>>2]|0;
    $183 = HEAP32[$$pre62>>2]|0;
    $184 = (($183) + 20|0);
    $185 = HEAP8[$184>>0]|0;
    $186 = ($185<<24>>24)==(0);
    if ($186) {
     $187 = HEAP32[$182>>2]|0;
     $188 = (($187) + 1|0);
     HEAP32[$182>>2] = $188;
     HEAP8[$187>>0] = 0;
     $189 = (($182) + 4|0);
     $190 = HEAP32[$189>>2]|0;
     $191 = (($190) + -1)|0;
     HEAP32[$189>>2] = $191;
     $192 = ($191|0)==(0);
     if ($192) {
      $193 = (($182) + 12|0);
      $194 = HEAP32[$193>>2]|0;
      $195 = (FUNCTION_TABLE_ii[$194 & 7]($cinfo)|0);
      $196 = ($195<<24>>24)==(0);
      if ($196) {
       $197 = HEAP32[$cinfo>>2]|0;
       $198 = (($197) + 20|0);
       HEAP32[$198>>2] = 24;
       $199 = HEAP32[$197>>2]|0;
       FUNCTION_TABLE_vi[$199 & 63]($cinfo);
      }
     }
    }
    $200 = HEAP32[$137>>2]|0;
    $201 = (($200) + -1)|0;
    $$c3 = $201;
    HEAP32[$137>>2] = $$c3;
    $202 = ($201|0)==(0);
    if ($202) {
     break;
    }
   }
  }
 }
 $203 = HEAP32[$5>>2]|0;
 $204 = $203 & 134215680;
 $205 = ($204|0)==(0);
 if ($205) {
  STACKTOP = sp;return;
 }
 $206 = (($1) + 24|0);
 $207 = HEAP32[$206>>2]|0;
 $208 = ($207|0)==(0);
 $$pre52 = (($cinfo) + 24|0);
 $$pre54 = (($cinfo) + 316|0);
 if (!($208)) {
  while(1) {
   $209 = HEAP32[$$pre52>>2]|0;
   $210 = HEAP32[$$pre54>>2]|0;
   $211 = (($210) + 20|0);
   $212 = HEAP8[$211>>0]|0;
   $213 = ($212<<24>>24)==(0);
   if ($213) {
    $214 = HEAP32[$209>>2]|0;
    $215 = (($214) + 1|0);
    HEAP32[$209>>2] = $215;
    HEAP8[$214>>0] = 0;
    $216 = (($209) + 4|0);
    $217 = HEAP32[$216>>2]|0;
    $218 = (($217) + -1)|0;
    HEAP32[$216>>2] = $218;
    $219 = ($218|0)==(0);
    if ($219) {
     $220 = (($209) + 12|0);
     $221 = HEAP32[$220>>2]|0;
     $222 = (FUNCTION_TABLE_ii[$221 & 7]($cinfo)|0);
     $223 = ($222<<24>>24)==(0);
     if ($223) {
      $224 = HEAP32[$cinfo>>2]|0;
      $225 = (($224) + 20|0);
      HEAP32[$225>>2] = 24;
      $226 = HEAP32[$224>>2]|0;
      FUNCTION_TABLE_vi[$226 & 63]($cinfo);
     }
    }
   }
   $227 = HEAP32[$206>>2]|0;
   $228 = (($227) + -1)|0;
   $$c2 = $228;
   HEAP32[$206>>2] = $$c2;
   $229 = ($228|0)==(0);
   if ($229) {
    break;
   }
  }
 }
 $230 = HEAP32[$$pre52>>2]|0;
 $231 = HEAP32[$$pre54>>2]|0;
 $232 = (($231) + 20|0);
 $233 = HEAP8[$232>>0]|0;
 $234 = ($233<<24>>24)==(0);
 if ($234) {
  $235 = HEAP32[$5>>2]|0;
  $236 = $235 >>> 19;
  $237 = $236&255;
  $238 = HEAP32[$230>>2]|0;
  $239 = (($238) + 1|0);
  HEAP32[$230>>2] = $239;
  HEAP8[$238>>0] = $237;
  $240 = (($230) + 4|0);
  $241 = HEAP32[$240>>2]|0;
  $242 = (($241) + -1)|0;
  HEAP32[$240>>2] = $242;
  $243 = ($242|0)==(0);
  if ($243) {
   $244 = (($230) + 12|0);
   $245 = HEAP32[$244>>2]|0;
   $246 = (FUNCTION_TABLE_ii[$245 & 7]($cinfo)|0);
   $247 = ($246<<24>>24)==(0);
   if ($247) {
    $248 = HEAP32[$cinfo>>2]|0;
    $249 = (($248) + 20|0);
    HEAP32[$249>>2] = 24;
    $250 = HEAP32[$248>>2]|0;
    FUNCTION_TABLE_vi[$250 & 63]($cinfo);
   }
  }
 }
 $251 = HEAP32[$5>>2]|0;
 $252 = $251 & 133693440;
 $253 = ($252|0)==(133693440);
 if ($253) {
  $254 = HEAP32[$$pre52>>2]|0;
  $255 = HEAP32[$$pre54>>2]|0;
  $256 = (($255) + 20|0);
  $257 = HEAP8[$256>>0]|0;
  $258 = ($257<<24>>24)==(0);
  if ($258) {
   $259 = HEAP32[$254>>2]|0;
   $260 = (($259) + 1|0);
   HEAP32[$254>>2] = $260;
   HEAP8[$259>>0] = 0;
   $261 = (($254) + 4|0);
   $262 = HEAP32[$261>>2]|0;
   $263 = (($262) + -1)|0;
   HEAP32[$261>>2] = $263;
   $264 = ($263|0)==(0);
   if ($264) {
    $265 = (($254) + 12|0);
    $266 = HEAP32[$265>>2]|0;
    $267 = (FUNCTION_TABLE_ii[$266 & 7]($cinfo)|0);
    $268 = ($267<<24>>24)==(0);
    if ($268) {
     $269 = HEAP32[$cinfo>>2]|0;
     $270 = (($269) + 20|0);
     HEAP32[$270>>2] = 24;
     $271 = HEAP32[$269>>2]|0;
     FUNCTION_TABLE_vi[$271 & 63]($cinfo);
    }
   }
  }
 }
 $272 = HEAP32[$5>>2]|0;
 $273 = $272 & 522240;
 $274 = ($273|0)==(0);
 if ($274) {
  STACKTOP = sp;return;
 }
 $275 = HEAP32[$$pre52>>2]|0;
 $276 = HEAP32[$$pre54>>2]|0;
 $277 = (($276) + 20|0);
 $278 = HEAP8[$277>>0]|0;
 $279 = ($278<<24>>24)==(0);
 if ($279) {
  $280 = $272 >>> 11;
  $281 = $280&255;
  $282 = HEAP32[$275>>2]|0;
  $283 = (($282) + 1|0);
  HEAP32[$275>>2] = $283;
  HEAP8[$282>>0] = $281;
  $284 = (($275) + 4|0);
  $285 = HEAP32[$284>>2]|0;
  $286 = (($285) + -1)|0;
  HEAP32[$284>>2] = $286;
  $287 = ($286|0)==(0);
  if ($287) {
   $288 = (($275) + 12|0);
   $289 = HEAP32[$288>>2]|0;
   $290 = (FUNCTION_TABLE_ii[$289 & 7]($cinfo)|0);
   $291 = ($290<<24>>24)==(0);
   if ($291) {
    $292 = HEAP32[$cinfo>>2]|0;
    $293 = (($292) + 20|0);
    HEAP32[$293>>2] = 24;
    $294 = HEAP32[$292>>2]|0;
    FUNCTION_TABLE_vi[$294 & 63]($cinfo);
   }
  }
 }
 $295 = HEAP32[$5>>2]|0;
 $296 = $295 & 522240;
 $297 = ($296|0)==(522240);
 if (!($297)) {
  STACKTOP = sp;return;
 }
 $298 = HEAP32[$$pre52>>2]|0;
 $299 = HEAP32[$$pre54>>2]|0;
 $300 = (($299) + 20|0);
 $301 = HEAP8[$300>>0]|0;
 $302 = ($301<<24>>24)==(0);
 if (!($302)) {
  STACKTOP = sp;return;
 }
 $303 = HEAP32[$298>>2]|0;
 $304 = (($303) + 1|0);
 HEAP32[$298>>2] = $304;
 HEAP8[$303>>0] = 0;
 $305 = (($298) + 4|0);
 $306 = HEAP32[$305>>2]|0;
 $307 = (($306) + -1)|0;
 HEAP32[$305>>2] = $307;
 $308 = ($307|0)==(0);
 if (!($308)) {
  STACKTOP = sp;return;
 }
 $309 = (($298) + 12|0);
 $310 = HEAP32[$309>>2]|0;
 $311 = (FUNCTION_TABLE_ii[$310 & 7]($cinfo)|0);
 $312 = ($311<<24>>24)==(0);
 if (!($312)) {
  STACKTOP = sp;return;
 }
 $313 = HEAP32[$cinfo>>2]|0;
 $314 = (($313) + 20|0);
 HEAP32[$314>>2] = 24;
 $315 = HEAP32[$313>>2]|0;
 FUNCTION_TABLE_vi[$315 & 63]($cinfo);
 STACKTOP = sp;return;
}
function _jget_arith_rates($cinfo,$dc_tbl_no,$ac_tbl_no,$r) {
 $cinfo = $cinfo|0;
 $dc_tbl_no = $dc_tbl_no|0;
 $ac_tbl_no = $ac_tbl_no|0;
 $r = $r|0;
 var $$mask = 0, $$mask1 = 0, $$pre = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0.0;
 var $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0.0;
 var $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0, $75 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, $exitcond4 = 0, $i$03 = 0, $i$12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($cinfo) + ($dc_tbl_no)|0) + 120|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = (($r) + 2560|0);
 HEAP32[$5>>2] = $4;
 $6 = ((($cinfo) + ($dc_tbl_no)|0) + 136|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = (($r) + 2564|0);
 HEAP32[$9>>2] = $8;
 $10 = ((($cinfo) + ($ac_tbl_no)|0) + 152|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = (($r) + 2568|0);
 HEAP32[$13>>2] = $12;
 $14 = (($1) + 76|0);
 $15 = (($14) + ($dc_tbl_no<<2)|0);
 $$pre = HEAP32[$15>>2]|0;
 $i$03 = 0;
 while(1) {
  $18 = (($$pre) + ($i$03)|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = $19&255;
  $21 = $20 & 127;
  $22 = (8 + ($21<<2)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 >> 16;
  $25 = (+($24|0));
  $26 = $25 / 46340.949999999997;
  $27 = $26;
  $$mask1 = $20 & 128;
  $28 = ($$mask1|0)==(0);
  $29 = $27;
  if ($28) {
   $30 = 1.0 - $29;
   $32 = $30;
  } else {
   $32 = $29;
  }
  $31 = $32;
  $33 = $31;
  $34 = 1.0 - $31;
  $35 = (+Math_log((+$33)));
  $36 = -$35;
  $37 = $36 / 0.69314718055994529;
  $38 = $37;
  $39 = (($r) + ($i$03<<3)|0);
  HEAPF32[$39>>2] = $38;
  $40 = $34;
  $41 = (+Math_log((+$40)));
  $42 = -$41;
  $43 = $42 / 0.69314718055994529;
  $44 = $43;
  $45 = ((($r) + ($i$03<<3)|0) + 4|0);
  HEAPF32[$45>>2] = $44;
  $46 = (($i$03) + 1)|0;
  $exitcond4 = ($46|0)==(64);
  if ($exitcond4) {
   break;
  } else {
   $i$03 = $46;
  }
 }
 $16 = (($1) + 140|0);
 $17 = (($16) + ($ac_tbl_no<<2)|0);
 $$pre5 = HEAP32[$17>>2]|0;
 $i$12 = 0;
 while(1) {
  $47 = (($$pre5) + ($i$12)|0);
  $48 = HEAP8[$47>>0]|0;
  $49 = $48&255;
  $50 = $49 & 127;
  $51 = (8 + ($50<<2)|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = $52 >> 16;
  $54 = (+($53|0));
  $55 = $54 / 46340.949999999997;
  $56 = $55;
  $$mask = $49 & 128;
  $57 = ($$mask|0)==(0);
  $58 = $56;
  if ($57) {
   $59 = 1.0 - $58;
   $61 = $59;
  } else {
   $61 = $58;
  }
  $60 = $61;
  $62 = $60;
  $63 = 1.0 - $60;
  $64 = (+Math_log((+$62)));
  $65 = -$64;
  $66 = $65 / 0.69314718055994529;
  $67 = $66;
  $68 = ((($r) + ($i$12<<3)|0) + 512|0);
  HEAPF32[$68>>2] = $67;
  $69 = $63;
  $70 = (+Math_log((+$69)));
  $71 = -$70;
  $72 = $71 / 0.69314718055994529;
  $73 = $72;
  $74 = ((($r) + ($i$12<<3)|0) + 516|0);
  HEAPF32[$74>>2] = $73;
  $75 = (($i$12) + 1)|0;
  $exitcond = ($75|0)==(256);
  if ($exitcond) {
   break;
  } else {
   $i$12 = $75;
  }
 }
 STACKTOP = sp;return;
}
function _encode_mcu_DC_first($cinfo,$MCU_data) {
 $cinfo = $cinfo|0;
 $MCU_data = $MCU_data|0;
 var $$c = 0, $$c4 = 0, $$c5 = 0, $$sum = 0, $$sum1 = 0, $$sum1$pn = 0, $$sum2 = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $blkn$011 = 0, $m$07 = 0, $m$1 = 0, $st$0 = 0, $st$16 = 0, $st$2 = 0, $storemerge = 0;
 var $v$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 188|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = (($1) + 68|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $8 = (($1) + 72|0);
   $9 = HEAP32[$8>>2]|0;
   _emit_restart($cinfo,$9);
   $10 = HEAP32[$2>>2]|0;
   $$c4 = $10;
   HEAP32[$5>>2] = $$c4;
   $11 = HEAP32[$8>>2]|0;
   $12 = (($11) + 1)|0;
   $13 = $12 & 7;
   $$c5 = $13;
   HEAP32[$8>>2] = $$c5;
   $15 = $10;
  } else {
   $15 = $6;
  }
  $14 = (($15) + -1)|0;
  $$c = $14;
  HEAP32[$5>>2] = $$c;
 }
 $16 = (($cinfo) + 256|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)>(0);
 if (!($18)) {
  STACKTOP = sp;return 1;
 }
 $19 = (($cinfo) + 312|0);
 $20 = (($1) + 76|0);
 $21 = (($1) + 52|0);
 $22 = (($1) + 36|0);
 $blkn$011 = 0;
 while(1) {
  $23 = (($MCU_data) + ($blkn$011<<2)|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ((($cinfo) + ($blkn$011<<2)|0) + 260|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ((($cinfo) + ($26<<2)|0) + 232|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + 20|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP16[$24>>1]|0;
  $32 = $31 << 16 >> 16;
  $33 = HEAP32[$19>>2]|0;
  $34 = $32 >> $33;
  $35 = (($20) + ($30<<2)|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($21) + ($26<<2)|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + ($38)|0);
  $40 = (($22) + ($26<<2)|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($34) - ($41))|0;
  $43 = ($34|0)==($41|0);
  if ($43) {
   _arith_encode($cinfo,$39,0);
   HEAP32[$37>>2] = 0;
  } else {
   HEAP32[$40>>2] = $34;
   _arith_encode($cinfo,$39,1);
   $44 = ($42|0)>(0);
   if ($44) {
    $$sum2 = (($38) + 1)|0;
    $45 = (($36) + ($$sum2)|0);
    _arith_encode($cinfo,$45,0);
    $$sum3 = (($38) + 2)|0;
    $$sum1$pn = $$sum3;$storemerge = 4;$v$0 = $42;
   } else {
    $46 = (0 - ($42))|0;
    $$sum = (($38) + 1)|0;
    $47 = (($36) + ($$sum)|0);
    _arith_encode($cinfo,$47,1);
    $$sum1 = (($38) + 3)|0;
    $$sum1$pn = $$sum1;$storemerge = 8;$v$0 = $46;
   }
   $st$0 = (($36) + ($$sum1$pn)|0);
   HEAP32[$37>>2] = $storemerge;
   $48 = (($v$0) + -1)|0;
   $49 = ($48|0)==(0);
   if ($49) {
    $m$1 = 0;$st$2 = $st$0;
   } else {
    _arith_encode($cinfo,$st$0,1);
    $50 = HEAP32[$35>>2]|0;
    $51 = (($50) + 20|0);
    $52 = $48 >> 1;
    $53 = ($52|0)==(0);
    if ($53) {
     $m$1 = 1;$st$2 = $51;
    } else {
     $57 = $52;$m$07 = 1;$st$16 = $51;
     while(1) {
      _arith_encode($cinfo,$st$16,1);
      $54 = $m$07 << 1;
      $55 = (($st$16) + 1|0);
      $56 = $57 >> 1;
      $58 = ($56|0)==(0);
      if ($58) {
       $m$1 = $54;$st$2 = $55;
       break;
      } else {
       $57 = $56;$m$07 = $54;$st$16 = $55;
      }
     }
    }
   }
   _arith_encode($cinfo,$st$2,0);
   $59 = ((($cinfo) + ($30)|0) + 120|0);
   $60 = HEAP8[$59>>0]|0;
   $61 = $60&255;
   $62 = 1 << $61;
   $63 = $62 >> 1;
   $64 = ($m$1|0)<($63|0);
   if ($64) {
    HEAP32[$37>>2] = 0;
   } else {
    $65 = ((($cinfo) + ($30)|0) + 136|0);
    $66 = HEAP8[$65>>0]|0;
    $67 = $66&255;
    $68 = 1 << $67;
    $69 = $68 >> 1;
    $70 = ($m$1|0)>($69|0);
    if ($70) {
     $71 = HEAP32[$37>>2]|0;
     $72 = (($71) + 8)|0;
     HEAP32[$37>>2] = $72;
    }
   }
   $73 = (($st$2) + 14|0);
   $74 = $m$1 >> 1;
   $75 = ($74|0)==(0);
   if (!($75)) {
    $77 = $74;
    while(1) {
     $76 = $77 & $48;
     $78 = ($76|0)!=(0);
     $79 = $78&1;
     _arith_encode($cinfo,$73,$79);
     $80 = $77 >> 1;
     $81 = ($80|0)==(0);
     if ($81) {
      break;
     } else {
      $77 = $80;
     }
    }
   }
  }
  $82 = (($blkn$011) + 1)|0;
  $83 = HEAP32[$16>>2]|0;
  $84 = ($82|0)<($83|0);
  if ($84) {
   $blkn$011 = $82;
  } else {
   break;
  }
 }
 STACKTOP = sp;return 1;
}
function _encode_mcu_AC_first($cinfo,$MCU_data) {
 $cinfo = $cinfo|0;
 $MCU_data = $MCU_data|0;
 var $$c = 0, $$c1 = 0, $$c2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $k$0$lcssa = 0, $k$012 = 0, $k$1 = 0, $ke$0$lcssa = 0, $ke$017 = 0, $m$09 = 0, $m$1 = 0, $st$0 = 0, $st$18 = 0, $st$2 = 0, $v$0 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 188|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = (($1) + 68|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $8 = (($1) + 72|0);
   $9 = HEAP32[$8>>2]|0;
   _emit_restart($cinfo,$9);
   $10 = HEAP32[$2>>2]|0;
   $$c1 = $10;
   HEAP32[$5>>2] = $$c1;
   $11 = HEAP32[$8>>2]|0;
   $12 = (($11) + 1)|0;
   $13 = $12 & 7;
   $$c2 = $13;
   HEAP32[$8>>2] = $$c2;
   $15 = $10;
  } else {
   $15 = $6;
  }
  $14 = (($15) + -1)|0;
  $$c = $14;
  HEAP32[$5>>2] = $$c;
 }
 $16 = HEAP32[$MCU_data>>2]|0;
 $17 = (($cinfo) + 232|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($cinfo) + 304|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($cinfo) + 312|0);
 $24 = ($22|0)>(0);
 L7: do {
  if ($24) {
   $ke$017 = $22;
   while(1) {
    $25 = (142704 + ($ke$017<<2)|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($16) + ($26<<1)|0);
    $28 = HEAP16[$27>>1]|0;
    $29 = $28 << 16 >> 16;
    $30 = ($28<<16>>16)>(-1);
    if ($30) {
     $31 = HEAP32[$23>>2]|0;
     $32 = $29 >> $31;
     $33 = ($32|0)==(0);
     if (!($33)) {
      $ke$0$lcssa = $ke$017;
      break L7;
     }
    } else {
     $34 = (0 - ($29))|0;
     $35 = HEAP32[$23>>2]|0;
     $36 = $34 >> $35;
     $37 = ($36|0)==(0);
     if (!($37)) {
      $ke$0$lcssa = $ke$017;
      break L7;
     }
    }
    $38 = (($ke$017) + -1)|0;
    $39 = ($38|0)>(0);
    if ($39) {
     $ke$017 = $38;
    } else {
     $ke$0$lcssa = $38;
     break;
    }
   }
  } else {
   $ke$0$lcssa = $22;
  }
 } while(0);
 $40 = (($cinfo) + 300|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)>($ke$0$lcssa|0);
 if ($42) {
  $98 = $22;$k$0$lcssa = $41;
 } else {
  $43 = (($1) + 140|0);
  $44 = (($43) + ($20<<2)|0);
  $45 = (($1) + 204|0);
  $46 = ((($cinfo) + ($20)|0) + 152|0);
  $k$012 = $41;
  while(1) {
   $47 = HEAP32[$44>>2]|0;
   $48 = ($k$012*3)|0;
   $49 = (($48) + -3)|0;
   $50 = (($47) + ($49)|0);
   _arith_encode($cinfo,$50,0);
   $k$1 = $k$012;$st$0 = $50;
   while(1) {
    $51 = (142704 + ($k$1<<2)|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (($16) + ($52<<1)|0);
    $54 = HEAP16[$53>>1]|0;
    $55 = $54 << 16 >> 16;
    $56 = ($54<<16>>16)>(-1);
    if ($56) {
     $57 = HEAP32[$23>>2]|0;
     $58 = $55 >> $57;
     $59 = ($58|0)==(0);
     if (!($59)) {
      label = 15;
      break;
     }
    } else {
     $61 = (0 - ($55))|0;
     $62 = HEAP32[$23>>2]|0;
     $63 = $61 >> $62;
     $64 = ($63|0)==(0);
     if (!($64)) {
      label = 17;
      break;
     }
    }
    $66 = (($st$0) + 1|0);
    _arith_encode($cinfo,$66,0);
    $67 = (($st$0) + 3|0);
    $68 = (($k$1) + 1)|0;
    $k$1 = $68;$st$0 = $67;
   }
   if ((label|0) == 15) {
    label = 0;
    $60 = (($st$0) + 1|0);
    _arith_encode($cinfo,$60,1);
    _arith_encode($cinfo,$45,0);
    $v$0 = $58;
   }
   else if ((label|0) == 17) {
    label = 0;
    $65 = (($st$0) + 1|0);
    _arith_encode($cinfo,$65,1);
    _arith_encode($cinfo,$45,1);
    $v$0 = $63;
   }
   $69 = (($st$0) + 2|0);
   $70 = (($v$0) + -1)|0;
   $71 = ($70|0)==(0);
   if ($71) {
    $m$1 = 0;$st$2 = $69;
   } else {
    _arith_encode($cinfo,$69,1);
    $72 = ($70>>>0)<(2);
    if ($72) {
     $m$1 = 1;$st$2 = $69;
    } else {
     _arith_encode($cinfo,$69,1);
     $73 = HEAP32[$44>>2]|0;
     $74 = HEAP8[$46>>0]|0;
     $75 = $74&255;
     $76 = ($k$1|0)<=($75|0);
     $77 = $76 ? 189 : 217;
     $78 = (($73) + ($77)|0);
     $79 = $70 >> 2;
     $80 = ($79|0)==(0);
     if ($80) {
      $m$1 = 2;$st$2 = $78;
     } else {
      $84 = $79;$m$09 = 2;$st$18 = $78;
      while(1) {
       _arith_encode($cinfo,$st$18,1);
       $81 = $m$09 << 1;
       $82 = (($st$18) + 1|0);
       $83 = $84 >> 1;
       $85 = ($83|0)==(0);
       if ($85) {
        $m$1 = $81;$st$2 = $82;
        break;
       } else {
        $84 = $83;$m$09 = $81;$st$18 = $82;
       }
      }
     }
    }
   }
   _arith_encode($cinfo,$st$2,0);
   $86 = (($st$2) + 14|0);
   $87 = $m$1 >> 1;
   $88 = ($87|0)==(0);
   if (!($88)) {
    $90 = $87;
    while(1) {
     $89 = $90 & $70;
     $91 = ($89|0)!=(0);
     $92 = $91&1;
     _arith_encode($cinfo,$86,$92);
     $93 = $90 >> 1;
     $94 = ($93|0)==(0);
     if ($94) {
      break;
     } else {
      $90 = $93;
     }
    }
   }
   $95 = (($k$1) + 1)|0;
   $96 = ($k$1|0)<($ke$0$lcssa|0);
   if ($96) {
    $k$012 = $95;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$21>>2]|0;
  $98 = $$pre;$k$0$lcssa = $95;
 }
 $97 = ($k$0$lcssa|0)>($98|0);
 if ($97) {
  STACKTOP = sp;return 1;
 }
 $99 = (($1) + 140|0);
 $100 = (($99) + ($20<<2)|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ($k$0$lcssa*3)|0;
 $103 = (($102) + -3)|0;
 $104 = (($101) + ($103)|0);
 _arith_encode($cinfo,$104,1);
 STACKTOP = sp;return 1;
}
function _encode_mcu_DC_refine($cinfo,$MCU_data) {
 $cinfo = $cinfo|0;
 $MCU_data = $MCU_data|0;
 var $$c = 0, $$c1 = 0, $$c2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $blkn$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 188|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = (($1) + 68|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $8 = (($1) + 72|0);
   $9 = HEAP32[$8>>2]|0;
   _emit_restart($cinfo,$9);
   $10 = HEAP32[$2>>2]|0;
   $$c1 = $10;
   HEAP32[$5>>2] = $$c1;
   $11 = HEAP32[$8>>2]|0;
   $12 = (($11) + 1)|0;
   $13 = $12 & 7;
   $$c2 = $13;
   HEAP32[$8>>2] = $$c2;
   $15 = $10;
  } else {
   $15 = $6;
  }
  $14 = (($15) + -1)|0;
  $$c = $14;
  HEAP32[$5>>2] = $$c;
 }
 $16 = (($1) + 204|0);
 $17 = (($cinfo) + 312|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($cinfo) + 256|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)>(0);
 if ($21) {
  $blkn$03 = 0;
 } else {
  STACKTOP = sp;return 1;
 }
 while(1) {
  $22 = (($MCU_data) + ($blkn$03<<2)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = HEAP16[$23>>1]|0;
  $25 = $24 << 16 >> 16;
  $26 = $25 >>> $18;
  $27 = $26 & 1;
  _arith_encode($cinfo,$16,$27);
  $28 = (($blkn$03) + 1)|0;
  $29 = HEAP32[$19>>2]|0;
  $30 = ($28|0)<($29|0);
  if ($30) {
   $blkn$03 = $28;
  } else {
   break;
  }
 }
 STACKTOP = sp;return 1;
}
function _encode_mcu_AC_refine($cinfo,$MCU_data) {
 $cinfo = $cinfo|0;
 $MCU_data = $MCU_data|0;
 var $$c = 0, $$c1 = 0, $$c2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $k$0$lcssa = 0, $k$07 = 0, $k$1 = 0, $ke$0$lcssa27 = 0, $ke$014 = 0, $kex$0$lcssa = 0, $kex$09 = 0, $st$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 188|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = (($1) + 68|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $8 = (($1) + 72|0);
   $9 = HEAP32[$8>>2]|0;
   _emit_restart($cinfo,$9);
   $10 = HEAP32[$2>>2]|0;
   $$c1 = $10;
   HEAP32[$5>>2] = $$c1;
   $11 = HEAP32[$8>>2]|0;
   $12 = (($11) + 1)|0;
   $13 = $12 & 7;
   $$c2 = $13;
   HEAP32[$8>>2] = $$c2;
   $15 = $10;
  } else {
   $15 = $6;
  }
  $14 = (($15) + -1)|0;
  $$c = $14;
  HEAP32[$5>>2] = $$c;
 }
 $16 = HEAP32[$MCU_data>>2]|0;
 $17 = (($cinfo) + 232|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($cinfo) + 304|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($cinfo) + 312|0);
 $24 = ($22|0)>(0);
 L7: do {
  if ($24) {
   $ke$014 = $22;
   while(1) {
    $27 = (142704 + ($ke$014<<2)|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($16) + ($28<<1)|0);
    $30 = HEAP16[$29>>1]|0;
    $31 = $30 << 16 >> 16;
    $32 = ($30<<16>>16)>(-1);
    if ($32) {
     $33 = HEAP32[$23>>2]|0;
     $34 = $31 >> $33;
     $35 = ($34|0)==(0);
     if (!($35)) {
      break;
     }
    } else {
     $36 = (0 - ($31))|0;
     $37 = HEAP32[$23>>2]|0;
     $38 = $36 >> $37;
     $39 = ($38|0)==(0);
     if (!($39)) {
      break;
     }
    }
    $40 = (($ke$014) + -1)|0;
    $41 = ($40|0)>(0);
    if ($41) {
     $ke$014 = $40;
    } else {
     $ke$0$lcssa27 = $40;$kex$0$lcssa = $40;
     break L7;
    }
   }
   $25 = (($cinfo) + 308|0);
   $26 = ($ke$014|0)>(0);
   if ($26) {
    $kex$09 = $ke$014;
    while(1) {
     $42 = (142704 + ($kex$09<<2)|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = (($16) + ($43<<1)|0);
     $45 = HEAP16[$44>>1]|0;
     $46 = $45 << 16 >> 16;
     $47 = ($45<<16>>16)>(-1);
     if ($47) {
      $48 = HEAP32[$25>>2]|0;
      $49 = $46 >> $48;
      $50 = ($49|0)==(0);
      if (!($50)) {
       $ke$0$lcssa27 = $ke$014;$kex$0$lcssa = $kex$09;
       break L7;
      }
     } else {
      $51 = (0 - ($46))|0;
      $52 = HEAP32[$25>>2]|0;
      $53 = $51 >> $52;
      $54 = ($53|0)==(0);
      if (!($54)) {
       $ke$0$lcssa27 = $ke$014;$kex$0$lcssa = $kex$09;
       break L7;
      }
     }
     $55 = (($kex$09) + -1)|0;
     $56 = ($55|0)>(0);
     if ($56) {
      $kex$09 = $55;
     } else {
      $ke$0$lcssa27 = $ke$014;$kex$0$lcssa = $55;
      break;
     }
    }
   } else {
    $ke$0$lcssa27 = $ke$014;$kex$0$lcssa = $ke$014;
   }
  } else {
   $ke$0$lcssa27 = $22;$kex$0$lcssa = $22;
  }
 } while(0);
 $57 = (($cinfo) + 300|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58|0)>($ke$0$lcssa27|0);
 if ($59) {
  $95 = $22;$k$0$lcssa = $58;
 } else {
  $60 = (($1) + 140|0);
  $61 = (($60) + ($20<<2)|0);
  $62 = (($1) + 204|0);
  $k$07 = $58;
  while(1) {
   $63 = HEAP32[$61>>2]|0;
   $64 = ($k$07*3)|0;
   $65 = (($64) + -3)|0;
   $66 = (($63) + ($65)|0);
   $67 = ($k$07|0)>($kex$0$lcssa|0);
   if ($67) {
    _arith_encode($cinfo,$66,0);
    $k$1 = $k$07;$st$0 = $66;
   } else {
    $k$1 = $k$07;$st$0 = $66;
   }
   while(1) {
    $68 = (142704 + ($k$1<<2)|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($16) + ($69<<1)|0);
    $71 = HEAP16[$70>>1]|0;
    $72 = $71 << 16 >> 16;
    $73 = ($71<<16>>16)>(-1);
    if ($73) {
     $74 = HEAP32[$23>>2]|0;
     $75 = $72 >> $74;
     $76 = ($75|0)==(0);
     if (!($76)) {
      label = 21;
      break;
     }
    } else {
     $81 = (0 - ($72))|0;
     $82 = HEAP32[$23>>2]|0;
     $83 = $81 >> $82;
     $84 = ($83|0)==(0);
     if (!($84)) {
      label = 25;
      break;
     }
    }
    $89 = (($st$0) + 1|0);
    _arith_encode($cinfo,$89,0);
    $90 = (($st$0) + 3|0);
    $91 = (($k$1) + 1)|0;
    $k$1 = $91;$st$0 = $90;
   }
   do {
    if ((label|0) == 21) {
     label = 0;
     $77 = ($75>>>0)>(1);
     if ($77) {
      $78 = (($st$0) + 2|0);
      $79 = $75 & 1;
      _arith_encode($cinfo,$78,$79);
      break;
     } else {
      $80 = (($st$0) + 1|0);
      _arith_encode($cinfo,$80,1);
      _arith_encode($cinfo,$62,0);
      break;
     }
    }
    else if ((label|0) == 25) {
     label = 0;
     $85 = ($83>>>0)>(1);
     if ($85) {
      $86 = (($st$0) + 2|0);
      $87 = $83 & 1;
      _arith_encode($cinfo,$86,$87);
      break;
     } else {
      $88 = (($st$0) + 1|0);
      _arith_encode($cinfo,$88,1);
      _arith_encode($cinfo,$62,1);
      break;
     }
    }
   } while(0);
   $92 = (($k$1) + 1)|0;
   $93 = ($k$1|0)<($ke$0$lcssa27|0);
   if ($93) {
    $k$07 = $92;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$21>>2]|0;
  $95 = $$pre;$k$0$lcssa = $92;
 }
 $94 = ($k$0$lcssa|0)>($95|0);
 if ($94) {
  STACKTOP = sp;return 1;
 }
 $96 = (($1) + 140|0);
 $97 = (($96) + ($20<<2)|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = ($k$0$lcssa*3)|0;
 $100 = (($99) + -3)|0;
 $101 = (($98) + ($100)|0);
 _arith_encode($cinfo,$101,1);
 STACKTOP = sp;return 1;
}
function _encode_mcu($cinfo,$MCU_data) {
 $cinfo = $cinfo|0;
 $MCU_data = $MCU_data|0;
 var $$c = 0, $$c4 = 0, $$c5 = 0, $$lcssa = 0, $$lcssa13 = 0, $$lcssa14 = 0, $$sum = 0, $$sum1 = 0, $$sum1$pn = 0, $$sum2 = 0, $$sum3 = 0, $$sum40 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $blkn$037 = 0, $k$0$lcssa50 = 0, $k$033 = 0, $k$1$lcssa = 0, $k$116 = 0, $ke$012 = 0, $m$07 = 0, $m$1 = 0, $m$325 = 0, $m$4 = 0, $st$0 = 0, $st$16 = 0, $st$2 = 0, $st$3$lcssa = 0, $st$315 = 0;
 var $st$424 = 0, $st$5 = 0, $storemerge = 0, $v$0 = 0, $v$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 188|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = (($1) + 68|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $8 = (($1) + 72|0);
   $9 = HEAP32[$8>>2]|0;
   _emit_restart($cinfo,$9);
   $10 = HEAP32[$2>>2]|0;
   $$c4 = $10;
   HEAP32[$5>>2] = $$c4;
   $11 = HEAP32[$8>>2]|0;
   $12 = (($11) + 1)|0;
   $13 = $12 & 7;
   $$c5 = $13;
   HEAP32[$8>>2] = $$c5;
   $15 = $10;
  } else {
   $15 = $6;
  }
  $14 = (($15) + -1)|0;
  $$c = $14;
  HEAP32[$5>>2] = $$c;
 }
 $16 = (($cinfo) + 256|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)>(0);
 if (!($18)) {
  STACKTOP = sp;return 1;
 }
 $19 = (($1) + 76|0);
 $20 = (($1) + 52|0);
 $21 = (($1) + 36|0);
 $22 = (($1) + 140|0);
 $23 = (($1) + 204|0);
 $blkn$037 = 0;
 while(1) {
  $24 = (($MCU_data) + ($blkn$037<<2)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ((($cinfo) + ($blkn$037<<2)|0) + 260|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ((($cinfo) + ($27<<2)|0) + 232|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + 20|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($19) + ($31<<2)|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($20) + ($27<<2)|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($33) + ($35)|0);
  $37 = HEAP16[$25>>1]|0;
  $38 = $37 << 16 >> 16;
  $39 = (($21) + ($27<<2)|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($38) - ($40))|0;
  $42 = ($38|0)==($40|0);
  if ($42) {
   _arith_encode($cinfo,$36,0);
   HEAP32[$34>>2] = 0;
  } else {
   HEAP32[$39>>2] = $38;
   _arith_encode($cinfo,$36,1);
   $43 = ($41|0)>(0);
   if ($43) {
    $$sum2 = (($35) + 1)|0;
    $44 = (($33) + ($$sum2)|0);
    _arith_encode($cinfo,$44,0);
    $$sum3 = (($35) + 2)|0;
    $$sum1$pn = $$sum3;$storemerge = 4;$v$0 = $41;
   } else {
    $45 = (0 - ($41))|0;
    $$sum = (($35) + 1)|0;
    $46 = (($33) + ($$sum)|0);
    _arith_encode($cinfo,$46,1);
    $$sum1 = (($35) + 3)|0;
    $$sum1$pn = $$sum1;$storemerge = 8;$v$0 = $45;
   }
   $st$0 = (($33) + ($$sum1$pn)|0);
   HEAP32[$34>>2] = $storemerge;
   $47 = (($v$0) + -1)|0;
   $48 = ($47|0)==(0);
   if ($48) {
    $m$1 = 0;$st$2 = $st$0;
   } else {
    _arith_encode($cinfo,$st$0,1);
    $49 = HEAP32[$32>>2]|0;
    $50 = (($49) + 20|0);
    $51 = $47 >> 1;
    $52 = ($51|0)==(0);
    if ($52) {
     $m$1 = 1;$st$2 = $50;
    } else {
     $56 = $51;$m$07 = 1;$st$16 = $50;
     while(1) {
      _arith_encode($cinfo,$st$16,1);
      $53 = $m$07 << 1;
      $54 = (($st$16) + 1|0);
      $55 = $56 >> 1;
      $57 = ($55|0)==(0);
      if ($57) {
       $m$1 = $53;$st$2 = $54;
       break;
      } else {
       $56 = $55;$m$07 = $53;$st$16 = $54;
      }
     }
    }
   }
   _arith_encode($cinfo,$st$2,0);
   $58 = ((($cinfo) + ($31)|0) + 120|0);
   $59 = HEAP8[$58>>0]|0;
   $60 = $59&255;
   $61 = 1 << $60;
   $62 = $61 >> 1;
   $63 = ($m$1|0)<($62|0);
   if ($63) {
    HEAP32[$34>>2] = 0;
   } else {
    $64 = ((($cinfo) + ($31)|0) + 136|0);
    $65 = HEAP8[$64>>0]|0;
    $66 = $65&255;
    $67 = 1 << $66;
    $68 = $67 >> 1;
    $69 = ($m$1|0)>($68|0);
    if ($69) {
     $70 = HEAP32[$34>>2]|0;
     $71 = (($70) + 8)|0;
     HEAP32[$34>>2] = $71;
    }
   }
   $72 = (($st$2) + 14|0);
   $73 = $m$1 >> 1;
   $74 = ($73|0)==(0);
   if (!($74)) {
    $76 = $73;
    while(1) {
     $75 = $76 & $47;
     $77 = ($75|0)!=(0);
     $78 = $77&1;
     _arith_encode($cinfo,$72,$78);
     $79 = $76 >> 1;
     $80 = ($79|0)==(0);
     if ($80) {
      break;
     } else {
      $76 = $79;
     }
    }
   }
  }
  $81 = (($29) + 24|0);
  $82 = HEAP32[$81>>2]|0;
  $ke$012 = 63;
  while(1) {
   $85 = (142704 + ($ke$012<<2)|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = (($25) + ($86<<1)|0);
   $88 = HEAP16[$87>>1]|0;
   $89 = ($88<<16>>16)==(0);
   $83 = (($ke$012) + -1)|0;
   if (!($89)) {
    label = 24;
    break;
   }
   $84 = ($83|0)>(0);
   if ($84) {
    $ke$012 = $83;
   } else {
    $k$0$lcssa50 = 1;
    label = 40;
    break;
   }
  }
  if ((label|0) == 24) {
   label = 0;
   $90 = ($ke$012|0)<(1);
   if ($90) {
    $k$0$lcssa50 = 1;
    label = 40;
   } else {
    $91 = (($22) + ($82<<2)|0);
    $92 = ((($cinfo) + ($82)|0) + 152|0);
    $k$033 = 1;
    while(1) {
     $93 = HEAP32[$91>>2]|0;
     $94 = ($k$033*3)|0;
     $95 = (($94) + -3)|0;
     $96 = (($93) + ($95)|0);
     _arith_encode($cinfo,$96,0);
     $97 = (142704 + ($k$033<<2)|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = (($25) + ($98<<1)|0);
     $100 = HEAP16[$99>>1]|0;
     $101 = $100 << 16 >> 16;
     $102 = ($100<<16>>16)==(0);
     $$sum40 = (($94) + -2)|0;
     $103 = (($93) + ($$sum40)|0);
     if ($102) {
      $104 = $103;$k$116 = $k$033;$st$315 = $96;
      while(1) {
       _arith_encode($cinfo,$104,0);
       $105 = (($st$315) + 3|0);
       $106 = (($k$116) + 1)|0;
       $107 = (142704 + ($106<<2)|0);
       $108 = HEAP32[$107>>2]|0;
       $109 = (($25) + ($108<<1)|0);
       $110 = HEAP16[$109>>1]|0;
       $111 = ($110<<16>>16)==(0);
       $112 = (($st$315) + 4|0);
       if ($111) {
        $104 = $112;$k$116 = $106;$st$315 = $105;
       } else {
        break;
       }
      }
      $113 = $110 << 16 >> 16;
      $$lcssa = $110;$$lcssa13 = $113;$$lcssa14 = $112;$k$1$lcssa = $106;$st$3$lcssa = $105;
     } else {
      $$lcssa = $100;$$lcssa13 = $101;$$lcssa14 = $103;$k$1$lcssa = $k$033;$st$3$lcssa = $96;
     }
     _arith_encode($cinfo,$$lcssa14,1);
     $114 = ($$lcssa<<16>>16)>(0);
     if ($114) {
      _arith_encode($cinfo,$23,0);
      $v$1 = $$lcssa13;
     } else {
      $115 = (0 - ($$lcssa13))|0;
      _arith_encode($cinfo,$23,1);
      $v$1 = $115;
     }
     $116 = (($st$3$lcssa) + 2|0);
     $117 = (($v$1) + -1)|0;
     $118 = ($117|0)==(0);
     if ($118) {
      $m$4 = 0;$st$5 = $116;
     } else {
      _arith_encode($cinfo,$116,1);
      $119 = ($117>>>0)<(2);
      if ($119) {
       $m$4 = 1;$st$5 = $116;
      } else {
       _arith_encode($cinfo,$116,1);
       $120 = HEAP32[$91>>2]|0;
       $121 = HEAP8[$92>>0]|0;
       $122 = $121&255;
       $123 = ($k$1$lcssa|0)<=($122|0);
       $124 = $123 ? 189 : 217;
       $125 = (($120) + ($124)|0);
       $126 = $117 >> 2;
       $127 = ($126|0)==(0);
       if ($127) {
        $m$4 = 2;$st$5 = $125;
       } else {
        $131 = $126;$m$325 = 2;$st$424 = $125;
        while(1) {
         _arith_encode($cinfo,$st$424,1);
         $128 = $m$325 << 1;
         $129 = (($st$424) + 1|0);
         $130 = $131 >> 1;
         $132 = ($130|0)==(0);
         if ($132) {
          $m$4 = $128;$st$5 = $129;
          break;
         } else {
          $131 = $130;$m$325 = $128;$st$424 = $129;
         }
        }
       }
      }
     }
     _arith_encode($cinfo,$st$5,0);
     $133 = (($st$5) + 14|0);
     $134 = $m$4 >> 1;
     $135 = ($134|0)==(0);
     if (!($135)) {
      $137 = $134;
      while(1) {
       $136 = $137 & $117;
       $138 = ($136|0)!=(0);
       $139 = $138&1;
       _arith_encode($cinfo,$133,$139);
       $140 = $137 >> 1;
       $141 = ($140|0)==(0);
       if ($141) {
        break;
       } else {
        $137 = $140;
       }
      }
     }
     $142 = (($k$1$lcssa) + 1)|0;
     $143 = ($k$1$lcssa|0)<($ke$012|0);
     if ($143) {
      $k$033 = $142;
     } else {
      break;
     }
    }
    $144 = ($142|0)<(64);
    if ($144) {
     $k$0$lcssa50 = $142;
     label = 40;
    }
   }
  }
  if ((label|0) == 40) {
   label = 0;
   $145 = (($22) + ($82<<2)|0);
   $146 = HEAP32[$145>>2]|0;
   $147 = ($k$0$lcssa50*3)|0;
   $148 = (($147) + -3)|0;
   $149 = (($146) + ($148)|0);
   _arith_encode($cinfo,$149,1);
  }
  $150 = (($blkn$037) + 1)|0;
  $151 = HEAP32[$16>>2]|0;
  $152 = ($150|0)<($151|0);
  if ($152) {
   $blkn$037 = $150;
  } else {
   break;
  }
 }
 STACKTOP = sp;return 1;
}
function _emit_restart($cinfo,$restart_num) {
 $cinfo = $cinfo|0;
 $restart_num = $restart_num|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $ci$02 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 _finish_pass($cinfo);
 $2 = (($cinfo) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($cinfo) + 316|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 20|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  $9 = HEAP32[$3>>2]|0;
  $10 = (($9) + 1|0);
  HEAP32[$3>>2] = $10;
  HEAP8[$9>>0] = -1;
  $11 = (($3) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + -1)|0;
  HEAP32[$11>>2] = $13;
  $14 = ($13|0)==(0);
  if ($14) {
   $15 = (($3) + 12|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (FUNCTION_TABLE_ii[$16 & 7]($cinfo)|0);
   $18 = ($17<<24>>24)==(0);
   if ($18) {
    $19 = HEAP32[$cinfo>>2]|0;
    $20 = (($19) + 20|0);
    HEAP32[$20>>2] = 24;
    $21 = HEAP32[$19>>2]|0;
    FUNCTION_TABLE_vi[$21 & 63]($cinfo);
   }
  }
 }
 $22 = HEAP32[$2>>2]|0;
 $23 = HEAP32[$4>>2]|0;
 $24 = (($23) + 20|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  $27 = (($restart_num) + 208)|0;
  $28 = $27&255;
  $29 = HEAP32[$22>>2]|0;
  $30 = (($29) + 1|0);
  HEAP32[$22>>2] = $30;
  HEAP8[$29>>0] = $28;
  $31 = (($22) + 4|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + -1)|0;
  HEAP32[$31>>2] = $33;
  $34 = ($33|0)==(0);
  if ($34) {
   $35 = (($22) + 12|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (FUNCTION_TABLE_ii[$36 & 7]($cinfo)|0);
   $38 = ($37<<24>>24)==(0);
   if ($38) {
    $39 = HEAP32[$cinfo>>2]|0;
    $40 = (($39) + 20|0);
    HEAP32[$40>>2] = 24;
    $41 = HEAP32[$39>>2]|0;
    FUNCTION_TABLE_vi[$41 & 63]($cinfo);
   }
  }
 }
 $42 = (($cinfo) + 228|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)>(0);
 if (!($44)) {
  $78 = (($1) + 12|0);
  HEAP32[$78>>2] = 0;
  $79 = (($1) + 16|0);
  HEAP32[$79>>2] = (65536);
  $80 = (($1) + 20|0);
  HEAP32[$80>>2] = 0;
  $81 = (($1) + 24|0);
  HEAP32[$81>>2] = 0;
  $82 = (($1) + 28|0);
  HEAP32[$82>>2] = (11);
  $83 = (($1) + 32|0);
  HEAP32[$83>>2] = (-1);
  STACKTOP = sp;return;
 }
 $45 = (($cinfo) + 212|0);
 $46 = (($1) + 76|0);
 $47 = (($1) + 36|0);
 $48 = (($1) + 52|0);
 $49 = (($1) + 140|0);
 $50 = (($cinfo) + 304|0);
 $51 = (($cinfo) + 300|0);
 $52 = (($cinfo) + 308|0);
 $ci$02 = 0;
 while(1) {
  $53 = ((($cinfo) + ($ci$02<<2)|0) + 232|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = HEAP8[$45>>0]|0;
  $56 = ($55<<24>>24)==(0);
  if ($56) {
   label = 14;
  } else {
   $57 = HEAP32[$51>>2]|0;
   $58 = ($57|0)==(0);
   if ($58) {
    $59 = HEAP32[$52>>2]|0;
    $60 = ($59|0)==(0);
    if ($60) {
     label = 14;
    } else {
     $67 = $55;
    }
   } else {
    $67 = $55;
   }
  }
  if ((label|0) == 14) {
   label = 0;
   $61 = (($54) + 20|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = (($46) + ($62<<2)|0);
   $64 = HEAP32[$63>>2]|0;
   dest=$64+0|0; stop=dest+64|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   $65 = (($47) + ($ci$02<<2)|0);
   HEAP32[$65>>2] = 0;
   $66 = (($48) + ($ci$02<<2)|0);
   HEAP32[$66>>2] = 0;
   $$pre = HEAP8[$45>>0]|0;
   $67 = $$pre;
  }
  $68 = ($67<<24>>24)==(0);
  if ($68) {
   label = 17;
  } else {
   $69 = HEAP32[$50>>2]|0;
   $70 = ($69|0)==(0);
   if (!($70)) {
    label = 17;
   }
  }
  if ((label|0) == 17) {
   label = 0;
   $71 = (($54) + 24|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = (($49) + ($72<<2)|0);
   $74 = HEAP32[$73>>2]|0;
   _memset(($74|0),0,256)|0;
  }
  $75 = (($ci$02) + 1)|0;
  $76 = HEAP32[$42>>2]|0;
  $77 = ($75|0)<($76|0);
  if ($77) {
   $ci$02 = $75;
  } else {
   break;
  }
 }
 $78 = (($1) + 12|0);
 HEAP32[$78>>2] = 0;
 $79 = (($1) + 16|0);
 HEAP32[$79>>2] = (65536);
 $80 = (($1) + 20|0);
 HEAP32[$80>>2] = 0;
 $81 = (($1) + 24|0);
 HEAP32[$81>>2] = 0;
 $82 = (($1) + 28|0);
 HEAP32[$82>>2] = (11);
 $83 = (($1) + 32|0);
 HEAP32[$83>>2] = (-1);
 STACKTOP = sp;return;
}
function _arith_encode($cinfo,$st,$val) {
 $cinfo = $cinfo|0;
 $st = $st|0;
 $val = $val|0;
 var $$c = 0, $$c1 = 0, $$c10 = 0, $$c11 = 0, $$c12 = 0, $$c13 = 0, $$c14 = 0, $$c15 = 0, $$c16 = 0, $$c17 = 0, $$c18 = 0, $$c2 = 0, $$c3 = 0, $$c4 = 0, $$c5 = 0, $$c6 = 0, $$c7 = 0, $$c8 = 0, $$c9 = 0, $$pre = 0;
 var $$pre34 = 0, $$pre35 = 0, $$pre36 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $storemerge = 0, $storemerge$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$st>>0]|0;
 $3 = $2&255;
 $4 = $3 & 127;
 $5 = (8 + ($4<<2)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 >>> 8;
 $8 = $6 >> 16;
 $9 = (($1) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($8))|0;
 $$c = $11;
 HEAP32[$9>>2] = $$c;
 $12 = $3 >>> 7;
 $13 = ($12|0)==($val|0);
 if ($13) {
  $20 = ($11|0)>(32767);
  if ($20) {
   STACKTOP = sp;return;
  }
  $21 = ($11|0)<($8|0);
  if ($21) {
   $22 = (($1) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + ($11))|0;
   $$c15 = $24;
   HEAP32[$22>>2] = $$c15;
   $$c16 = $8;
   HEAP32[$9>>2] = $$c16;
  }
  $25 = $3 & 128;
  $26 = $25 ^ $7;
  $storemerge$in = $26;
 } else {
  $14 = ($11|0)<($8|0);
  if (!($14)) {
   $15 = (($1) + 12|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + ($11))|0;
   $$c17 = $17;
   HEAP32[$15>>2] = $$c17;
   $$c18 = $8;
   HEAP32[$9>>2] = $$c18;
  }
  $18 = $3 & 128;
  $19 = $18 ^ $6;
  $storemerge$in = $19;
 }
 $storemerge = $storemerge$in&255;
 HEAP8[$st>>0] = $storemerge;
 $27 = (($1) + 12|0);
 $28 = (($1) + 28|0);
 $29 = (($1) + 32|0);
 $30 = (($1) + 24|0);
 $31 = (($cinfo) + 24|0);
 $32 = (($cinfo) + 316|0);
 $33 = (($1) + 20|0);
 $$pre = HEAP32[$9>>2]|0;
 $$pre34 = HEAP32[$27>>2]|0;
 $$pre35 = HEAP32[$28>>2]|0;
 $35 = $$pre;$37 = $$pre34;$39 = $$pre35;
 while(1) {
  $34 = $35 << 1;
  $$c1 = $34;
  HEAP32[$9>>2] = $$c1;
  $36 = $37 << 1;
  $$c2 = $36;
  HEAP32[$27>>2] = $$c2;
  $38 = (($39) + -1)|0;
  $$c3 = $38;
  HEAP32[$28>>2] = $$c3;
  $40 = ($38|0)==(0);
  if ($40) {
   $41 = $36 >> 19;
   $42 = ($41|0)>(255);
   do {
    if ($42) {
     $43 = HEAP32[$29>>2]|0;
     $44 = ($43|0)>(-1);
     if ($44) {
      $45 = HEAP32[$30>>2]|0;
      $46 = ($45|0)==(0);
      if (!($46)) {
       while(1) {
        $47 = HEAP32[$31>>2]|0;
        $48 = HEAP32[$32>>2]|0;
        $49 = (($48) + 20|0);
        $50 = HEAP8[$49>>0]|0;
        $51 = ($50<<24>>24)==(0);
        if ($51) {
         $52 = HEAP32[$47>>2]|0;
         $53 = (($52) + 1|0);
         HEAP32[$47>>2] = $53;
         HEAP8[$52>>0] = 0;
         $54 = (($47) + 4|0);
         $55 = HEAP32[$54>>2]|0;
         $56 = (($55) + -1)|0;
         HEAP32[$54>>2] = $56;
         $57 = ($56|0)==(0);
         if ($57) {
          $58 = (($47) + 12|0);
          $59 = HEAP32[$58>>2]|0;
          $60 = (FUNCTION_TABLE_ii[$59 & 7]($cinfo)|0);
          $61 = ($60<<24>>24)==(0);
          if ($61) {
           $62 = HEAP32[$cinfo>>2]|0;
           $63 = (($62) + 20|0);
           HEAP32[$63>>2] = 24;
           $64 = HEAP32[$62>>2]|0;
           FUNCTION_TABLE_vi[$64 & 63]($cinfo);
          }
         }
        }
        $65 = HEAP32[$30>>2]|0;
        $66 = (($65) + -1)|0;
        $$c14 = $66;
        HEAP32[$30>>2] = $$c14;
        $67 = ($66|0)==(0);
        if ($67) {
         break;
        }
       }
      }
      $68 = HEAP32[$31>>2]|0;
      $69 = HEAP32[$32>>2]|0;
      $70 = (($69) + 20|0);
      $71 = HEAP8[$70>>0]|0;
      $72 = ($71<<24>>24)==(0);
      if ($72) {
       $73 = HEAP32[$29>>2]|0;
       $74 = (($73) + 1)|0;
       $75 = $74&255;
       $76 = HEAP32[$68>>2]|0;
       $77 = (($76) + 1|0);
       HEAP32[$68>>2] = $77;
       HEAP8[$76>>0] = $75;
       $78 = (($68) + 4|0);
       $79 = HEAP32[$78>>2]|0;
       $80 = (($79) + -1)|0;
       HEAP32[$78>>2] = $80;
       $81 = ($80|0)==(0);
       if ($81) {
        $82 = (($68) + 12|0);
        $83 = HEAP32[$82>>2]|0;
        $84 = (FUNCTION_TABLE_ii[$83 & 7]($cinfo)|0);
        $85 = ($84<<24>>24)==(0);
        if ($85) {
         $86 = HEAP32[$cinfo>>2]|0;
         $87 = (($86) + 20|0);
         HEAP32[$87>>2] = 24;
         $88 = HEAP32[$86>>2]|0;
         FUNCTION_TABLE_vi[$88 & 63]($cinfo);
        }
       }
      }
      $89 = HEAP32[$29>>2]|0;
      $90 = ($89|0)==(254);
      if ($90) {
       $91 = HEAP32[$31>>2]|0;
       $92 = HEAP32[$32>>2]|0;
       $93 = (($92) + 20|0);
       $94 = HEAP8[$93>>0]|0;
       $95 = ($94<<24>>24)==(0);
       if ($95) {
        $96 = HEAP32[$91>>2]|0;
        $97 = (($96) + 1|0);
        HEAP32[$91>>2] = $97;
        HEAP8[$96>>0] = 0;
        $98 = (($91) + 4|0);
        $99 = HEAP32[$98>>2]|0;
        $100 = (($99) + -1)|0;
        HEAP32[$98>>2] = $100;
        $101 = ($100|0)==(0);
        if ($101) {
         $102 = (($91) + 12|0);
         $103 = HEAP32[$102>>2]|0;
         $104 = (FUNCTION_TABLE_ii[$103 & 7]($cinfo)|0);
         $105 = ($104<<24>>24)==(0);
         if ($105) {
          $106 = HEAP32[$cinfo>>2]|0;
          $107 = (($106) + 20|0);
          HEAP32[$107>>2] = 24;
          $108 = HEAP32[$106>>2]|0;
          FUNCTION_TABLE_vi[$108 & 63]($cinfo);
         }
        }
       }
      }
     }
     $109 = HEAP32[$33>>2]|0;
     $110 = HEAP32[$30>>2]|0;
     $111 = (($110) + ($109))|0;
     $$c12 = $111;
     HEAP32[$30>>2] = $$c12;
     HEAP32[$33>>2] = 0;
     $112 = $41 & 255;
     $$c13 = $112;
     HEAP32[$29>>2] = $$c13;
    } else {
     $113 = ($41|0)==(255);
     if ($113) {
      $114 = HEAP32[$33>>2]|0;
      $115 = (($114) + 1)|0;
      $$c11 = $115;
      HEAP32[$33>>2] = $$c11;
      break;
     }
     $116 = HEAP32[$29>>2]|0;
     $117 = ($116|0)==(0);
     if ($117) {
      $118 = HEAP32[$30>>2]|0;
      $119 = (($118) + 1)|0;
      $$c10 = $119;
      HEAP32[$30>>2] = $$c10;
     } else {
      $120 = ($116|0)>(-1);
      if ($120) {
       $121 = HEAP32[$30>>2]|0;
       $122 = ($121|0)==(0);
       if (!($122)) {
        while(1) {
         $123 = HEAP32[$31>>2]|0;
         $124 = HEAP32[$32>>2]|0;
         $125 = (($124) + 20|0);
         $126 = HEAP8[$125>>0]|0;
         $127 = ($126<<24>>24)==(0);
         if ($127) {
          $128 = HEAP32[$123>>2]|0;
          $129 = (($128) + 1|0);
          HEAP32[$123>>2] = $129;
          HEAP8[$128>>0] = 0;
          $130 = (($123) + 4|0);
          $131 = HEAP32[$130>>2]|0;
          $132 = (($131) + -1)|0;
          HEAP32[$130>>2] = $132;
          $133 = ($132|0)==(0);
          if ($133) {
           $134 = (($123) + 12|0);
           $135 = HEAP32[$134>>2]|0;
           $136 = (FUNCTION_TABLE_ii[$135 & 7]($cinfo)|0);
           $137 = ($136<<24>>24)==(0);
           if ($137) {
            $138 = HEAP32[$cinfo>>2]|0;
            $139 = (($138) + 20|0);
            HEAP32[$139>>2] = 24;
            $140 = HEAP32[$138>>2]|0;
            FUNCTION_TABLE_vi[$140 & 63]($cinfo);
           }
          }
         }
         $141 = HEAP32[$30>>2]|0;
         $142 = (($141) + -1)|0;
         $$c9 = $142;
         HEAP32[$30>>2] = $$c9;
         $143 = ($142|0)==(0);
         if ($143) {
          break;
         }
        }
       }
       $144 = HEAP32[$31>>2]|0;
       $145 = HEAP32[$32>>2]|0;
       $146 = (($145) + 20|0);
       $147 = HEAP8[$146>>0]|0;
       $148 = ($147<<24>>24)==(0);
       if ($148) {
        $149 = HEAP32[$29>>2]|0;
        $150 = $149&255;
        $151 = HEAP32[$144>>2]|0;
        $152 = (($151) + 1|0);
        HEAP32[$144>>2] = $152;
        HEAP8[$151>>0] = $150;
        $153 = (($144) + 4|0);
        $154 = HEAP32[$153>>2]|0;
        $155 = (($154) + -1)|0;
        HEAP32[$153>>2] = $155;
        $156 = ($155|0)==(0);
        if ($156) {
         $157 = (($144) + 12|0);
         $158 = HEAP32[$157>>2]|0;
         $159 = (FUNCTION_TABLE_ii[$158 & 7]($cinfo)|0);
         $160 = ($159<<24>>24)==(0);
         if ($160) {
          $161 = HEAP32[$cinfo>>2]|0;
          $162 = (($161) + 20|0);
          HEAP32[$162>>2] = 24;
          $163 = HEAP32[$161>>2]|0;
          FUNCTION_TABLE_vi[$163 & 63]($cinfo);
         }
        }
       }
      }
     }
     $164 = HEAP32[$33>>2]|0;
     $165 = ($164|0)==(0);
     if (!($165)) {
      $166 = HEAP32[$30>>2]|0;
      $167 = ($166|0)==(0);
      if (!($167)) {
       while(1) {
        $168 = HEAP32[$31>>2]|0;
        $169 = HEAP32[$32>>2]|0;
        $170 = (($169) + 20|0);
        $171 = HEAP8[$170>>0]|0;
        $172 = ($171<<24>>24)==(0);
        if ($172) {
         $173 = HEAP32[$168>>2]|0;
         $174 = (($173) + 1|0);
         HEAP32[$168>>2] = $174;
         HEAP8[$173>>0] = 0;
         $175 = (($168) + 4|0);
         $176 = HEAP32[$175>>2]|0;
         $177 = (($176) + -1)|0;
         HEAP32[$175>>2] = $177;
         $178 = ($177|0)==(0);
         if ($178) {
          $179 = (($168) + 12|0);
          $180 = HEAP32[$179>>2]|0;
          $181 = (FUNCTION_TABLE_ii[$180 & 7]($cinfo)|0);
          $182 = ($181<<24>>24)==(0);
          if ($182) {
           $183 = HEAP32[$cinfo>>2]|0;
           $184 = (($183) + 20|0);
           HEAP32[$184>>2] = 24;
           $185 = HEAP32[$183>>2]|0;
           FUNCTION_TABLE_vi[$185 & 63]($cinfo);
          }
         }
        }
        $186 = HEAP32[$30>>2]|0;
        $187 = (($186) + -1)|0;
        $$c8 = $187;
        HEAP32[$30>>2] = $$c8;
        $188 = ($187|0)==(0);
        if ($188) {
         break;
        }
       }
      }
      while(1) {
       $189 = HEAP32[$31>>2]|0;
       $190 = HEAP32[$32>>2]|0;
       $191 = (($190) + 20|0);
       $192 = HEAP8[$191>>0]|0;
       $193 = ($192<<24>>24)==(0);
       if ($193) {
        $194 = HEAP32[$189>>2]|0;
        $195 = (($194) + 1|0);
        HEAP32[$189>>2] = $195;
        HEAP8[$194>>0] = -1;
        $196 = (($189) + 4|0);
        $197 = HEAP32[$196>>2]|0;
        $198 = (($197) + -1)|0;
        HEAP32[$196>>2] = $198;
        $199 = ($198|0)==(0);
        if ($199) {
         $200 = (($189) + 12|0);
         $201 = HEAP32[$200>>2]|0;
         $202 = (FUNCTION_TABLE_ii[$201 & 7]($cinfo)|0);
         $203 = ($202<<24>>24)==(0);
         if ($203) {
          $204 = HEAP32[$cinfo>>2]|0;
          $205 = (($204) + 20|0);
          HEAP32[$205>>2] = 24;
          $206 = HEAP32[$204>>2]|0;
          FUNCTION_TABLE_vi[$206 & 63]($cinfo);
         }
        }
       }
       $207 = HEAP32[$31>>2]|0;
       $208 = HEAP32[$32>>2]|0;
       $209 = (($208) + 20|0);
       $210 = HEAP8[$209>>0]|0;
       $211 = ($210<<24>>24)==(0);
       if ($211) {
        $212 = HEAP32[$207>>2]|0;
        $213 = (($212) + 1|0);
        HEAP32[$207>>2] = $213;
        HEAP8[$212>>0] = 0;
        $214 = (($207) + 4|0);
        $215 = HEAP32[$214>>2]|0;
        $216 = (($215) + -1)|0;
        HEAP32[$214>>2] = $216;
        $217 = ($216|0)==(0);
        if ($217) {
         $218 = (($207) + 12|0);
         $219 = HEAP32[$218>>2]|0;
         $220 = (FUNCTION_TABLE_ii[$219 & 7]($cinfo)|0);
         $221 = ($220<<24>>24)==(0);
         if ($221) {
          $222 = HEAP32[$cinfo>>2]|0;
          $223 = (($222) + 20|0);
          HEAP32[$223>>2] = 24;
          $224 = HEAP32[$222>>2]|0;
          FUNCTION_TABLE_vi[$224 & 63]($cinfo);
         }
        }
       }
       $225 = HEAP32[$33>>2]|0;
       $226 = (($225) + -1)|0;
       $$c7 = $226;
       HEAP32[$33>>2] = $$c7;
       $227 = ($226|0)==(0);
       if ($227) {
        break;
       }
      }
     }
     $228 = $41 & 255;
     $$c4 = $228;
     HEAP32[$29>>2] = $$c4;
    }
   } while(0);
   $229 = HEAP32[$27>>2]|0;
   $230 = $229 & 524287;
   $$c5 = $230;
   HEAP32[$27>>2] = $$c5;
   $231 = HEAP32[$28>>2]|0;
   $232 = (($231) + 8)|0;
   $$c6 = $232;
   HEAP32[$28>>2] = $$c6;
   $$pre36 = HEAP32[$9>>2]|0;
   $233 = $$pre36;$235 = $232;$236 = $230;
  } else {
   $233 = $34;$235 = $38;$236 = $36;
  }
  $234 = ($233|0)<(32768);
  if ($234) {
   $35 = $233;$37 = $236;$39 = $235;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _jinit_c_coef_controller($cinfo,$need_full_buffer) {
 $cinfo = $cinfo|0;
 $need_full_buffer = $need_full_buffer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $ci$03 = 0, $compptr$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 7]($cinfo,1,144)|0);
 $4 = (($cinfo) + 328|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$3>>2] = 2;
 $5 = ($need_full_buffer<<24>>24)==(0);
 if ($5) {
  $45 = HEAP32[$0>>2]|0;
  $46 = (($45) + 4|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (FUNCTION_TABLE_iiii[$47 & 7]($cinfo,1,1280)|0);
  $49 = (($3) + 24|0);
  HEAP32[$49>>2] = $48;
  $50 = (($48) + 128|0);
  $51 = (($3) + 28|0);
  HEAP32[$51>>2] = $50;
  $52 = (($48) + 256|0);
  $53 = (($3) + 32|0);
  HEAP32[$53>>2] = $52;
  $54 = (($48) + 384|0);
  $55 = (($3) + 36|0);
  HEAP32[$55>>2] = $54;
  $56 = (($48) + 512|0);
  $57 = (($3) + 40|0);
  HEAP32[$57>>2] = $56;
  $58 = (($48) + 640|0);
  $59 = (($3) + 44|0);
  HEAP32[$59>>2] = $58;
  $60 = (($48) + 768|0);
  $61 = (($3) + 48|0);
  HEAP32[$61>>2] = $60;
  $62 = (($48) + 896|0);
  $63 = (($3) + 52|0);
  HEAP32[$63>>2] = $62;
  $64 = (($48) + 1024|0);
  $65 = (($3) + 56|0);
  HEAP32[$65>>2] = $64;
  $66 = (($48) + 1152|0);
  $67 = (($3) + 60|0);
  HEAP32[$67>>2] = $66;
  $68 = (($3) + 64|0);
  HEAP32[$68>>2] = 0;
  STACKTOP = sp;return;
 }
 $6 = (($cinfo) + 60|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($cinfo) + 68|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($3) + 64|0);
 $12 = (($3) + 104|0);
 $ci$03 = 0;$compptr$02 = $10;
 while(1) {
  $13 = HEAP32[$0>>2]|0;
  $14 = (($13) + 20|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($compptr$02) + 28|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($compptr$02) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (_jround_up($17,$19)|0);
  $21 = (($compptr$02) + 32|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($compptr$02) + 12|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (_jround_up($22,$24)|0);
  $26 = HEAP32[$23>>2]|0;
  $27 = (FUNCTION_TABLE_iiiiiii[$15 & 3]($cinfo,1,0,$20,$25,$26)|0);
  $28 = (($11) + ($ci$03<<2)|0);
  HEAP32[$28>>2] = $27;
  $29 = HEAP32[$0>>2]|0;
  $30 = (($29) + 20|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$16>>2]|0;
  $33 = HEAP32[$18>>2]|0;
  $34 = (_jround_up($32,$33)|0);
  $35 = HEAP32[$21>>2]|0;
  $36 = HEAP32[$23>>2]|0;
  $37 = (_jround_up($35,$36)|0);
  $38 = HEAP32[$23>>2]|0;
  $39 = (FUNCTION_TABLE_iiiiiii[$31 & 3]($cinfo,1,0,$34,$37,$38)|0);
  $40 = (($12) + ($ci$03<<2)|0);
  HEAP32[$40>>2] = $39;
  $41 = (($ci$03) + 1)|0;
  $42 = (($compptr$02) + 84|0);
  $43 = HEAP32[$6>>2]|0;
  $44 = ($41|0)<($43|0);
  if ($44) {
   $ci$03 = $41;$compptr$02 = $42;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _start_pass_coef($cinfo,$pass_mode) {
 $cinfo = $cinfo|0;
 $pass_mode = $pass_mode|0;
 var $$c$i = 0, $$c1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 328|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($cinfo) + 228|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(1);
 do {
  if ($5) {
   $6 = (($1) + 20|0);
   HEAP32[$6>>2] = (1);
  } else {
   $7 = (($cinfo) + 224|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(1);
   $10 = (($cinfo) + 232|0);
   $11 = HEAP32[$10>>2]|0;
   if ($9) {
    $15 = (($11) + 72|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($1) + 20|0);
    $$c$i = $16;
    HEAP32[$17>>2] = $$c$i;
    break;
   } else {
    $12 = (($11) + 12|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($1) + 20|0);
    $$c1$i = $13;
    HEAP32[$14>>2] = $$c1$i;
    break;
   }
  }
 } while(0);
 $18 = (($1) + 12|0);
 HEAP32[$18>>2] = 0;
 $19 = (($1) + 16|0);
 HEAP32[$19>>2] = 0;
 if ((($pass_mode|0) == 3)) {
  $27 = (($1) + 64|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==(0|0);
  if ($29) {
   $30 = HEAP32[$cinfo>>2]|0;
   $31 = (($30) + 20|0);
   HEAP32[$31>>2] = 4;
   $32 = HEAP32[$30>>2]|0;
   FUNCTION_TABLE_vi[$32 & 63]($cinfo);
  }
  $33 = (($1) + 4|0);
  HEAP32[$33>>2] = 7;
  STACKTOP = sp;return;
 } else if ((($pass_mode|0) == 4)) {
  $41 = (($1) + 64|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0|0);
  if ($43) {
   $44 = HEAP32[$cinfo>>2]|0;
   $45 = (($44) + 20|0);
   HEAP32[$45>>2] = 4;
   $46 = HEAP32[$44>>2]|0;
   FUNCTION_TABLE_vi[$46 & 63]($cinfo);
  }
  $47 = (($1) + 4|0);
  HEAP32[$47>>2] = 9;
  STACKTOP = sp;return;
 } else if ((($pass_mode|0) == 0)) {
  $20 = (($1) + 64|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)==(0|0);
  if (!($22)) {
   $23 = HEAP32[$cinfo>>2]|0;
   $24 = (($23) + 20|0);
   HEAP32[$24>>2] = 4;
   $25 = HEAP32[$23>>2]|0;
   FUNCTION_TABLE_vi[$25 & 63]($cinfo);
  }
  $26 = (($1) + 4|0);
  HEAP32[$26>>2] = 6;
  STACKTOP = sp;return;
 } else if ((($pass_mode|0) == 2)) {
  $34 = (($1) + 64|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==(0|0);
  if ($36) {
   $37 = HEAP32[$cinfo>>2]|0;
   $38 = (($37) + 20|0);
   HEAP32[$38>>2] = 4;
   $39 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vi[$39 & 63]($cinfo);
  }
  $40 = (($1) + 4|0);
  HEAP32[$40>>2] = 8;
  STACKTOP = sp;return;
 } else {
  $48 = HEAP32[$cinfo>>2]|0;
  $49 = (($48) + 20|0);
  HEAP32[$49>>2] = 4;
  $50 = HEAP32[$48>>2]|0;
  FUNCTION_TABLE_vi[$50 & 63]($cinfo);
  STACKTOP = sp;return;
 }
}
function _compress_data($cinfo,$input_buf) {
 $cinfo = $cinfo|0;
 $input_buf = $input_buf|0;
 var $$0 = 0, $$c = 0, $$c$i = 0, $$c1$i = 0, $$pre = 0, $$pre$phi32Z2D = 0, $$pre$phi34Z2D = 0, $$pre$phiZ2D = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre30 = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $MCU_col_num$0$c = 0, $MCU_col_num$014 = 0, $bi$03 = 0, $bi$03$us = 0, $bi$11 = 0, $bi$11$us = 0, $blkn$010 = 0, $blkn$010$us = 0, $blkn$1$lcssa = 0, $blkn$1$lcssa$us = 0, $blkn$16 = 0, $blkn$16$us = 0;
 var $ci$09 = 0, $ci$09$us = 0, $yindex$05 = 0, $yindex$05$us = 0, $yoffset$0$c = 0, $yoffset$017 = 0, $ypos$07 = 0, $ypos$07$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 328|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 248|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 $5 = (($cinfo) + 224|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + -1)|0;
 $8 = (($1) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($1) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)<($11|0);
 do {
  if ($12) {
   $13 = (($1) + 12|0);
   $14 = (($cinfo) + 228|0);
   $15 = (($1) + 8|0);
   $16 = (($cinfo) + 344|0);
   $17 = (($1) + 24|0);
   $18 = (($cinfo) + 348|0);
   $$pre25 = HEAP32[$13>>2]|0;
   $19 = $$pre25;$191 = $11;$yoffset$017 = $9;
   L3: while(1) {
    $20 = ($19>>>0)>($4>>>0);
    if ($20) {
     $169 = $191;
    } else {
     $21 = $yoffset$017 << 3;
     $MCU_col_num$014 = $19;
     while(1) {
      $24 = HEAP32[$14>>2]|0;
      $25 = ($24|0)>(0);
      if ($25) {
       $26 = ($MCU_col_num$014>>>0)<($4>>>0);
       if ($26) {
        $192 = $24;$blkn$010$us = 0;$ci$09$us = 0;
        while(1) {
         $27 = ((($cinfo) + ($ci$09$us<<2)|0) + 232|0);
         $28 = HEAP32[$27>>2]|0;
         $29 = (($28) + 52|0);
         $30 = HEAP32[$29>>2]|0;
         $31 = (($28) + 64|0);
         $32 = HEAP32[$31>>2]|0;
         $33 = Math_imul($32, $MCU_col_num$014)|0;
         $34 = (($28) + 56|0);
         $35 = HEAP32[$34>>2]|0;
         $36 = ($35|0)>(0);
         if ($36) {
          $63 = (($28) + 4|0);
          $44 = (($28) + 72|0);
          $49 = $30;$blkn$16$us = $blkn$010$us;$yindex$05$us = 0;$ypos$07$us = $21;
          while(1) {
           $40 = HEAP32[$15>>2]|0;
           $41 = ($40>>>0)<($7>>>0);
           if ($41) {
            label = 15;
           } else {
            $42 = (($yindex$05$us) + ($yoffset$017))|0;
            $43 = HEAP32[$44>>2]|0;
            $45 = ($42|0)<($43|0);
            if ($45) {
             label = 15;
            } else {
             $46 = (($17) + ($blkn$16$us<<2)|0);
             $47 = HEAP32[$46>>2]|0;
             $48 = $49 << 7;
             _jzero_far($47,$48);
             $50 = HEAP32[$29>>2]|0;
             $51 = ($50|0)>(0);
             if ($51) {
              $92 = (($blkn$16$us) + -1)|0;
              $93 = (($17) + ($92<<2)|0);
              $53 = HEAP32[$93>>2]|0;
              $bi$11$us = 0;
              while(1) {
               $52 = HEAP16[$53>>1]|0;
               $54 = (($bi$11$us) + ($blkn$16$us))|0;
               $55 = (($17) + ($54<<2)|0);
               $56 = HEAP32[$55>>2]|0;
               HEAP16[$56>>1] = $52;
               $57 = (($bi$11$us) + 1)|0;
               $58 = ($57|0)<($50|0);
               if ($58) {
                $bi$11$us = $57;
               } else {
                break;
               }
              }
             }
            }
           }
           if ((label|0) == 15) {
            label = 0;
            $59 = HEAP32[$16>>2]|0;
            $60 = (($59) + 4|0);
            $61 = HEAP32[$60>>2]|0;
            $62 = HEAP32[$63>>2]|0;
            $64 = (($input_buf) + ($62<<2)|0);
            $65 = HEAP32[$64>>2]|0;
            $66 = (($17) + ($blkn$16$us<<2)|0);
            $67 = HEAP32[$66>>2]|0;
            FUNCTION_TABLE_viiiiiiii[$61 & 3]($cinfo,$28,$65,$67,$ypos$07$us,$33,$30,0);
            $68 = HEAP32[$29>>2]|0;
            $69 = ($30|0)<($68|0);
            if ($69) {
             $70 = (($blkn$16$us) + ($30))|0;
             $71 = (($17) + ($70<<2)|0);
             $72 = HEAP32[$71>>2]|0;
             $73 = (($68) - ($30))|0;
             $74 = $73 << 7;
             _jzero_far($72,$74);
             $75 = HEAP32[$29>>2]|0;
             $76 = ($30|0)<($75|0);
             if ($76) {
              $bi$03$us = $30;
              while(1) {
               $83 = (($bi$03$us) + ($blkn$16$us))|0;
               $84 = (($83) + -1)|0;
               $85 = (($17) + ($84<<2)|0);
               $86 = HEAP32[$85>>2]|0;
               $87 = HEAP16[$86>>1]|0;
               $88 = (($17) + ($83<<2)|0);
               $89 = HEAP32[$88>>2]|0;
               HEAP16[$89>>1] = $87;
               $90 = (($bi$03$us) + 1)|0;
               $91 = ($90|0)<($75|0);
               if ($91) {
                $bi$03$us = $90;
               } else {
                break;
               }
              }
             }
            }
           }
           $77 = HEAP32[$29>>2]|0;
           $78 = (($77) + ($blkn$16$us))|0;
           $79 = (($ypos$07$us) + 8)|0;
           $80 = (($yindex$05$us) + 1)|0;
           $81 = HEAP32[$34>>2]|0;
           $82 = ($80|0)<($81|0);
           if ($82) {
            $49 = $77;$blkn$16$us = $78;$yindex$05$us = $80;$ypos$07$us = $79;
           } else {
            break;
           }
          }
          $$pre27 = HEAP32[$14>>2]|0;
          $39 = $$pre27;$blkn$1$lcssa$us = $78;
         } else {
          $39 = $192;$blkn$1$lcssa$us = $blkn$010$us;
         }
         $37 = (($ci$09$us) + 1)|0;
         $38 = ($37|0)<($39|0);
         if ($38) {
          $192 = $39;$blkn$010$us = $blkn$1$lcssa$us;$ci$09$us = $37;
         } else {
          break;
         }
        }
       } else {
        $193 = $24;$blkn$010 = 0;$ci$09 = 0;
        while(1) {
         $94 = ((($cinfo) + ($ci$09<<2)|0) + 232|0);
         $95 = HEAP32[$94>>2]|0;
         $96 = (($95) + 52|0);
         $97 = (($95) + 68|0);
         $98 = HEAP32[$97>>2]|0;
         $99 = (($95) + 64|0);
         $100 = HEAP32[$99>>2]|0;
         $101 = Math_imul($100, $MCU_col_num$014)|0;
         $102 = (($95) + 56|0);
         $103 = HEAP32[$102>>2]|0;
         $104 = ($103|0)>(0);
         if ($104) {
          $105 = (($95) + 4|0);
          $106 = (($95) + 72|0);
          $blkn$16 = $blkn$010;$yindex$05 = 0;$ypos$07 = $21;
          while(1) {
           $107 = HEAP32[$15>>2]|0;
           $108 = ($107>>>0)<($7>>>0);
           if ($108) {
            label = 26;
           } else {
            $109 = (($yindex$05) + ($yoffset$017))|0;
            $110 = HEAP32[$106>>2]|0;
            $111 = ($109|0)<($110|0);
            if ($111) {
             label = 26;
            } else {
             $138 = (($17) + ($blkn$16<<2)|0);
             $139 = HEAP32[$138>>2]|0;
             $140 = HEAP32[$96>>2]|0;
             $141 = $140 << 7;
             _jzero_far($139,$141);
             $142 = HEAP32[$96>>2]|0;
             $143 = ($142|0)>(0);
             if ($143) {
              $144 = (($blkn$16) + -1)|0;
              $145 = (($17) + ($144<<2)|0);
              $146 = HEAP32[$145>>2]|0;
              $bi$11 = 0;
              while(1) {
               $147 = HEAP16[$146>>1]|0;
               $148 = (($bi$11) + ($blkn$16))|0;
               $149 = (($17) + ($148<<2)|0);
               $150 = HEAP32[$149>>2]|0;
               HEAP16[$150>>1] = $147;
               $151 = (($bi$11) + 1)|0;
               $152 = ($151|0)<($142|0);
               if ($152) {
                $bi$11 = $151;
               } else {
                $154 = $142;
                break;
               }
              }
             } else {
              $154 = $142;
             }
            }
           }
           if ((label|0) == 26) {
            label = 0;
            $112 = HEAP32[$16>>2]|0;
            $113 = (($112) + 4|0);
            $114 = HEAP32[$113>>2]|0;
            $115 = HEAP32[$105>>2]|0;
            $116 = (($input_buf) + ($115<<2)|0);
            $117 = HEAP32[$116>>2]|0;
            $118 = (($17) + ($blkn$16<<2)|0);
            $119 = HEAP32[$118>>2]|0;
            FUNCTION_TABLE_viiiiiiii[$114 & 3]($cinfo,$95,$117,$119,$ypos$07,$101,$98,0);
            $120 = HEAP32[$96>>2]|0;
            $121 = ($98|0)<($120|0);
            if ($121) {
             $122 = (($blkn$16) + ($98))|0;
             $123 = (($17) + ($122<<2)|0);
             $124 = HEAP32[$123>>2]|0;
             $125 = (($120) - ($98))|0;
             $126 = $125 << 7;
             _jzero_far($124,$126);
             $127 = HEAP32[$96>>2]|0;
             $128 = ($98|0)<($127|0);
             if ($128) {
              $bi$03 = $98;
              while(1) {
               $129 = (($bi$03) + ($blkn$16))|0;
               $130 = (($129) + -1)|0;
               $131 = (($17) + ($130<<2)|0);
               $132 = HEAP32[$131>>2]|0;
               $133 = HEAP16[$132>>1]|0;
               $134 = (($17) + ($129<<2)|0);
               $135 = HEAP32[$134>>2]|0;
               HEAP16[$135>>1] = $133;
               $136 = (($bi$03) + 1)|0;
               $137 = ($136|0)<($127|0);
               if ($137) {
                $bi$03 = $136;
               } else {
                $154 = $127;
                break;
               }
              }
             } else {
              $154 = $127;
             }
            } else {
             $154 = $120;
            }
           }
           $153 = (($154) + ($blkn$16))|0;
           $155 = (($ypos$07) + 8)|0;
           $156 = (($yindex$05) + 1)|0;
           $157 = HEAP32[$102>>2]|0;
           $158 = ($156|0)<($157|0);
           if ($158) {
            $blkn$16 = $153;$yindex$05 = $156;$ypos$07 = $155;
           } else {
            break;
           }
          }
          $$pre28 = HEAP32[$14>>2]|0;
          $161 = $$pre28;$blkn$1$lcssa = $153;
         } else {
          $161 = $193;$blkn$1$lcssa = $blkn$010;
         }
         $159 = (($ci$09) + 1)|0;
         $160 = ($159|0)<($161|0);
         if ($160) {
          $193 = $161;$blkn$010 = $blkn$1$lcssa;$ci$09 = $159;
         } else {
          break;
         }
        }
       }
      }
      $162 = HEAP32[$18>>2]|0;
      $163 = (($162) + 4|0);
      $164 = HEAP32[$163>>2]|0;
      $165 = (FUNCTION_TABLE_iii[$164 & 15]($cinfo,$17)|0);
      $166 = ($165<<24>>24)==(0);
      $22 = (($MCU_col_num$014) + 1)|0;
      if ($166) {
       break L3;
      }
      $23 = ($22>>>0)>($4>>>0);
      if ($23) {
       break;
      } else {
       $MCU_col_num$014 = $22;
      }
     }
     $$pre26 = HEAP32[$10>>2]|0;
     $169 = $$pre26;
    }
    HEAP32[$13>>2] = 0;
    $167 = (($yoffset$017) + 1)|0;
    $168 = ($167|0)<($169|0);
    if ($168) {
     $19 = 0;$191 = $169;$yoffset$017 = $167;
    } else {
     label = 39;
     break;
    }
   }
   if ((label|0) == 39) {
    $$pre = HEAP32[$0>>2]|0;
    $$pre$phi32Z2D = $15;$$pre$phi34Z2D = $14;$$pre$phiZ2D = $15;$175 = $$pre;
    break;
   }
   $yoffset$0$c = $yoffset$017;
   HEAP32[$8>>2] = $yoffset$0$c;
   $MCU_col_num$0$c = $MCU_col_num$014;
   HEAP32[$13>>2] = $MCU_col_num$0$c;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$pre30 = (($1) + 8|0);
   $$pre33 = (($cinfo) + 228|0);
   $$pre$phi32Z2D = $$pre30;$$pre$phi34Z2D = $$pre33;$$pre$phiZ2D = $$pre30;$175 = $1;
  }
 } while(0);
 $170 = HEAP32[$$pre$phi32Z2D>>2]|0;
 $171 = (($170) + 1)|0;
 $$c = $171;
 HEAP32[$$pre$phiZ2D>>2] = $$c;
 $172 = HEAP32[$$pre$phi34Z2D>>2]|0;
 $173 = ($172|0)>(1);
 do {
  if ($173) {
   $174 = (($175) + 20|0);
   HEAP32[$174>>2] = (1);
  } else {
   $176 = (($175) + 8|0);
   $177 = HEAP32[$176>>2]|0;
   $178 = HEAP32[$5>>2]|0;
   $179 = (($178) + -1)|0;
   $180 = ($177>>>0)<($179>>>0);
   $181 = (($cinfo) + 232|0);
   $182 = HEAP32[$181>>2]|0;
   if ($180) {
    $183 = (($182) + 12|0);
    $184 = HEAP32[$183>>2]|0;
    $185 = (($175) + 20|0);
    $$c1$i = $184;
    HEAP32[$185>>2] = $$c1$i;
    break;
   } else {
    $186 = (($182) + 72|0);
    $187 = HEAP32[$186>>2]|0;
    $188 = (($175) + 20|0);
    $$c$i = $187;
    HEAP32[$188>>2] = $$c$i;
    break;
   }
  }
 } while(0);
 $189 = (($175) + 12|0);
 HEAP32[$189>>2] = 0;
 $190 = (($175) + 16|0);
 HEAP32[$190>>2] = 0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _compress_first_pass($cinfo,$input_buf) {
 $cinfo = $cinfo|0;
 $input_buf = $input_buf|0;
 var $$ = 0, $$2 = 0, $$pre = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $MCUindex$010 = 0, $bi$03 = 0, $bi$16 = 0, $block_row$04 = 0, $block_row$118 = 0, $block_rows$0 = 0, $ci$021 = 0, $compptr$022 = 0, $exitcond = 0, $exitcond26 = 0, $exitcond27 = 0, $lastblockrow$013 = 0, $thisblockrow$011 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 328|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 224|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 $5 = (($cinfo) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)>(0);
 if (!($7)) {
  $98 = (_compress_output($cinfo,$input_buf)|0);
  STACKTOP = sp;return ($98|0);
 }
 $8 = (($cinfo) + 68|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($cinfo) + 4|0);
 $11 = (($1) + 64|0);
 $12 = (($1) + 8|0);
 $13 = (($1) + 104|0);
 $14 = (($cinfo) + 344|0);
 $ci$021 = 0;$compptr$022 = $9;
 while(1) {
  $15 = HEAP32[$10>>2]|0;
  $16 = (($15) + 32|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($11) + ($ci$021<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = HEAP32[$12>>2]|0;
  $21 = (($compptr$022) + 12|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $20)|0;
  $24 = (FUNCTION_TABLE_iiiiii[$17 & 3]($cinfo,$19,$23,$22,1)|0);
  $25 = HEAP32[$10>>2]|0;
  $26 = (($25) + 32|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($13) + ($ci$021<<2)|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = HEAP32[$12>>2]|0;
  $31 = HEAP32[$21>>2]|0;
  $32 = Math_imul($31, $30)|0;
  $33 = (FUNCTION_TABLE_iiiiii[$27 & 3]($cinfo,$29,$32,$31,1)|0);
  $34 = HEAP32[$12>>2]|0;
  $35 = ($34>>>0)<($4>>>0);
  if ($35) {
   $36 = HEAP32[$21>>2]|0;
   $block_rows$0 = $36;
  } else {
   $37 = (($compptr$022) + 32|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = HEAP32[$21>>2]|0;
   $40 = (($38>>>0) % ($39>>>0))&-1;
   $41 = ($40|0)==(0);
   $$ = $41 ? $39 : $40;
   $block_rows$0 = $$;
  }
  $42 = (($compptr$022) + 28|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($compptr$022) + 8|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($43>>>0) % ($45>>>0))&-1;
  $47 = ($46|0)>(0);
  $48 = (($45) - ($46))|0;
  $$2 = $47 ? $48 : $46;
  $49 = ($block_rows$0|0)>(0);
  if ($49) {
   $50 = (($input_buf) + ($ci$021<<2)|0);
   $51 = ($$2|0)>(0);
   $52 = $$2 << 7;
   $$sum = (($43) + -1)|0;
   $block_row$04 = 0;
   while(1) {
    $53 = (($24) + ($block_row$04<<2)|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = HEAP32[$14>>2]|0;
    $56 = (($55) + 4|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = HEAP32[$50>>2]|0;
    $59 = $block_row$04 << 3;
    $60 = (($33) + ($block_row$04<<2)|0);
    $61 = HEAP32[$60>>2]|0;
    FUNCTION_TABLE_viiiiiiii[$57 & 3]($cinfo,$compptr$022,$58,$54,$59,0,$43,$61);
    if ($51) {
     $62 = (($54) + ($43<<7)|0);
     _jzero_far($62,$52);
     $63 = (($54) + ($$sum<<7)|0);
     $64 = HEAP16[$63>>1]|0;
     $bi$03 = 0;
     while(1) {
      $$sum1 = (($bi$03) + ($43))|0;
      $65 = (($54) + ($$sum1<<7)|0);
      HEAP16[$65>>1] = $64;
      $66 = (($bi$03) + 1)|0;
      $exitcond = ($66|0)==($$2|0);
      if ($exitcond) {
       break;
      } else {
       $bi$03 = $66;
      }
     }
    }
    $67 = (($block_row$04) + 1)|0;
    $exitcond26 = ($67|0)==($block_rows$0|0);
    if ($exitcond26) {
     break;
    } else {
     $block_row$04 = $67;
    }
   }
   $$pre = HEAP32[$12>>2]|0;
   $68 = $$pre;
  } else {
   $68 = $34;
  }
  $69 = ($68|0)==($4|0);
  if ($69) {
   $70 = (($$2) + ($43))|0;
   $71 = (($70>>>0) / ($45>>>0))&-1;
   $72 = HEAP32[$21>>2]|0;
   $73 = ($block_rows$0|0)<($72|0);
   if ($73) {
    $74 = $70 << 7;
    $75 = ($71|0)==(0);
    $76 = (($45) + -1)|0;
    $77 = ($45|0)>(0);
    $block_row$118 = $block_rows$0;
    while(1) {
     $78 = (($24) + ($block_row$118<<2)|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = (($block_row$118) + -1)|0;
     $81 = (($24) + ($80<<2)|0);
     $82 = HEAP32[$81>>2]|0;
     _jzero_far($79,$74);
     if (!($75)) {
      $MCUindex$010 = 0;$lastblockrow$013 = $82;$thisblockrow$011 = $79;
      while(1) {
       $83 = (($lastblockrow$013) + ($76<<7)|0);
       $84 = HEAP16[$83>>1]|0;
       if ($77) {
        $bi$16 = 0;
        while(1) {
         $85 = (($thisblockrow$011) + ($bi$16<<7)|0);
         HEAP16[$85>>1] = $84;
         $86 = (($bi$16) + 1)|0;
         $exitcond27 = ($86|0)==($45|0);
         if ($exitcond27) {
          break;
         } else {
          $bi$16 = $86;
         }
        }
       }
       $87 = (($thisblockrow$011) + ($45<<7)|0);
       $88 = (($lastblockrow$013) + ($45<<7)|0);
       $89 = (($MCUindex$010) + 1)|0;
       $90 = ($89>>>0)<($71>>>0);
       if ($90) {
        $MCUindex$010 = $89;$lastblockrow$013 = $88;$thisblockrow$011 = $87;
       } else {
        break;
       }
      }
     }
     $91 = (($block_row$118) + 1)|0;
     $92 = HEAP32[$21>>2]|0;
     $93 = ($91|0)<($92|0);
     if ($93) {
      $block_row$118 = $91;
     } else {
      break;
     }
    }
   }
  }
  $94 = (($ci$021) + 1)|0;
  $95 = HEAP32[$5>>2]|0;
  $96 = ($94|0)<($95|0);
  if (!($96)) {
   break;
  }
  $97 = (($compptr$022) + 84|0);
  $ci$021 = $94;$compptr$022 = $97;
 }
 $98 = (_compress_output($cinfo,$input_buf)|0);
 STACKTOP = sp;return ($98|0);
}
function _compress_output($cinfo,$input_buf) {
 $cinfo = $cinfo|0;
 $input_buf = $input_buf|0;
 var $$0 = 0, $$c = 0, $$c$i = 0, $$c1$i = 0, $$pre = 0, $$pre31 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $MCU_col_num$0$c = 0, $MCU_col_num$015 = 0, $blkn$010 = 0, $blkn$1$lcssa = 0, $blkn$14 = 0, $blkn$2$lcssa = 0, $blkn$21 = 0, $buffer = 0, $buffer_ptr$03 = 0, $ci$024 = 0, $ci$111 = 0, $smax = 0, $xindex$02 = 0;
 var $yindex$05 = 0, $yoffset$0$c = 0, $yoffset$018 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $buffer = sp;
 $0 = (($cinfo) + 328|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 228|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(0);
 if ($4) {
  $5 = (($cinfo) + 4|0);
  $6 = (($1) + 64|0);
  $7 = (($1) + 8|0);
  $ci$024 = 0;
  while(1) {
   $8 = ((($cinfo) + ($ci$024<<2)|0) + 232|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[$5>>2]|0;
   $11 = (($10) + 32|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($9) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($6) + ($14<<2)|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$7>>2]|0;
   $18 = (($9) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = Math_imul($19, $17)|0;
   $21 = (FUNCTION_TABLE_iiiiii[$12 & 3]($cinfo,$16,$20,$19,0)|0);
   $22 = (($buffer) + ($ci$024<<2)|0);
   HEAP32[$22>>2] = $21;
   $23 = (($ci$024) + 1)|0;
   $24 = HEAP32[$2>>2]|0;
   $25 = ($23|0)<($24|0);
   if ($25) {
    $ci$024 = $23;
   } else {
    break;
   }
  }
 }
 $26 = (($1) + 16|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($1) + 20|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($27|0)<($29|0);
 L6: do {
  if ($30) {
   $31 = (($1) + 12|0);
   $32 = (($cinfo) + 248|0);
   $33 = (($cinfo) + 348|0);
   $34 = (($1) + 24|0);
   $$pre = HEAP32[$31>>2]|0;
   $100 = $29;$36 = $$pre;$yoffset$018 = $27;
   L8: while(1) {
    $35 = HEAP32[$32>>2]|0;
    $37 = ($36>>>0)<($35>>>0);
    if ($37) {
     $MCU_col_num$015 = $36;
     while(1) {
      $41 = HEAP32[$2>>2]|0;
      $42 = ($41|0)>(0);
      if ($42) {
       $blkn$010 = 0;$ci$111 = 0;
       while(1) {
        $43 = ((($cinfo) + ($ci$111<<2)|0) + 232|0);
        $44 = HEAP32[$43>>2]|0;
        $45 = (($44) + 52|0);
        $46 = HEAP32[$45>>2]|0;
        $47 = Math_imul($46, $MCU_col_num$015)|0;
        $48 = (($44) + 56|0);
        $49 = HEAP32[$48>>2]|0;
        $50 = ($49|0)>(0);
        if ($50) {
         $51 = (($buffer) + ($ci$111<<2)|0);
         $52 = HEAP32[$51>>2]|0;
         $53 = ($46|0)>(0);
         $blkn$14 = $blkn$010;$yindex$05 = 0;
         while(1) {
          if ($53) {
           $54 = (($yindex$05) + ($yoffset$018))|0;
           $55 = (($52) + ($54<<2)|0);
           $56 = HEAP32[$55>>2]|0;
           $57 = (($56) + ($47<<7)|0);
           $58 = ($46|0)>(1);
           $smax = $58 ? $46 : 1;
           $blkn$21 = $blkn$14;$buffer_ptr$03 = $57;$xindex$02 = 0;
           while(1) {
            $59 = (($buffer_ptr$03) + 128|0);
            $60 = (($blkn$21) + 1)|0;
            $61 = (($34) + ($blkn$21<<2)|0);
            HEAP32[$61>>2] = $buffer_ptr$03;
            $62 = (($xindex$02) + 1)|0;
            $63 = ($62|0)<($46|0);
            if ($63) {
             $blkn$21 = $60;$buffer_ptr$03 = $59;$xindex$02 = $62;
            } else {
             break;
            }
           }
           $64 = (($blkn$14) + ($smax))|0;
           $blkn$2$lcssa = $64;
          } else {
           $blkn$2$lcssa = $blkn$14;
          }
          $65 = (($yindex$05) + 1)|0;
          $66 = ($65|0)<($49|0);
          if ($66) {
           $blkn$14 = $blkn$2$lcssa;$yindex$05 = $65;
          } else {
           $blkn$1$lcssa = $blkn$2$lcssa;
           break;
          }
         }
        } else {
         $blkn$1$lcssa = $blkn$010;
        }
        $67 = (($ci$111) + 1)|0;
        $68 = ($67|0)<($41|0);
        if ($68) {
         $blkn$010 = $blkn$1$lcssa;$ci$111 = $67;
        } else {
         break;
        }
       }
      }
      $69 = HEAP32[$33>>2]|0;
      $70 = (($69) + 4|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = (FUNCTION_TABLE_iii[$71 & 15]($cinfo,$34)|0);
      $73 = ($72<<24>>24)==(0);
      $39 = (($MCU_col_num$015) + 1)|0;
      if ($73) {
       break L8;
      }
      $38 = HEAP32[$32>>2]|0;
      $40 = ($39>>>0)<($38>>>0);
      if ($40) {
       $MCU_col_num$015 = $39;
      } else {
       break;
      }
     }
     $$pre31 = HEAP32[$28>>2]|0;
     $76 = $$pre31;
    } else {
     $76 = $100;
    }
    HEAP32[$31>>2] = 0;
    $74 = (($yoffset$018) + 1)|0;
    $75 = ($74|0)<($76|0);
    if ($75) {
     $100 = $76;$36 = 0;$yoffset$018 = $74;
    } else {
     break L6;
    }
   }
   $yoffset$0$c = $yoffset$018;
   HEAP32[$26>>2] = $yoffset$0$c;
   $MCU_col_num$0$c = $MCU_col_num$015;
   HEAP32[$31>>2] = $MCU_col_num$0$c;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $77 = (($1) + 8|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($78) + 1)|0;
 $$c = $79;
 HEAP32[$77>>2] = $$c;
 $80 = HEAP32[$0>>2]|0;
 $81 = HEAP32[$2>>2]|0;
 $82 = ($81|0)>(1);
 do {
  if ($82) {
   $83 = (($80) + 20|0);
   HEAP32[$83>>2] = (1);
  } else {
   $84 = (($80) + 8|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = (($cinfo) + 224|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = (($87) + -1)|0;
   $89 = ($85>>>0)<($88>>>0);
   $90 = (($cinfo) + 232|0);
   $91 = HEAP32[$90>>2]|0;
   if ($89) {
    $92 = (($91) + 12|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = (($80) + 20|0);
    $$c1$i = $93;
    HEAP32[$94>>2] = $$c1$i;
    break;
   } else {
    $95 = (($91) + 72|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = (($80) + 20|0);
    $$c$i = $96;
    HEAP32[$97>>2] = $$c$i;
    break;
   }
  }
 } while(0);
 $98 = (($80) + 12|0);
 HEAP32[$98>>2] = 0;
 $99 = (($80) + 16|0);
 HEAP32[$99>>2] = 0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _compress_trellis_pass($cinfo,$input_buf) {
 $cinfo = $cinfo|0;
 $input_buf = $input_buf|0;
 var $$ = 0, $$2 = 0, $$pre = 0, $$pre29 = 0, $$pre30 = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $MCUindex$013 = 0, $actbl = 0, $actbl_data = 0, $arith_r_data = 0, $bi$03 = 0, $bi$16 = 0, $block_row$04 = 0, $block_row$118 = 0, $block_rows$0 = 0, $ci$021 = 0, $dctbl = 0, $dctbl_data = 0, $exitcond = 0, $exitcond25 = 0, $exitcond26 = 0, $lastDC = 0, $lastblockrow$012 = 0;
 var $thisblockrow$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 5152|0;
 $lastDC = sp + 5144|0;
 $dctbl_data = sp + 3864|0;
 $dctbl = sp + 3856|0;
 $actbl_data = sp + 2576|0;
 $actbl = sp + 2572|0;
 $arith_r_data = sp;
 $0 = (($cinfo) + 328|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 224|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 $5 = (($cinfo) + 228|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)>(0);
 if (!($7)) {
  $135 = (_compress_output($cinfo,$input_buf)|0);
  STACKTOP = sp;return ($135|0);
 }
 $8 = (($cinfo) + 177|0);
 $9 = (($cinfo) + 4|0);
 $10 = (($1) + 64|0);
 $11 = (($1) + 8|0);
 $12 = (($1) + 104|0);
 $13 = (($cinfo) + 316|0);
 $ci$021 = 0;
 while(1) {
  HEAP32[$dctbl>>2] = $dctbl_data;
  HEAP32[$actbl>>2] = $actbl_data;
  $14 = ((($cinfo) + ($ci$021<<2)|0) + 232|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = HEAP8[$8>>0]|0;
  $17 = ($16<<24>>24)==(0);
  $18 = (($15) + 20|0);
  $19 = HEAP32[$18>>2]|0;
  if ($17) {
   _jpeg_make_c_derived_tbl($cinfo,1,$19,$dctbl);
   $22 = (($15) + 24|0);
   $23 = HEAP32[$22>>2]|0;
   _jpeg_make_c_derived_tbl($cinfo,0,$23,$actbl);
  } else {
   $20 = (($15) + 24|0);
   $21 = HEAP32[$20>>2]|0;
   _jget_arith_rates($cinfo,$19,$21,$arith_r_data);
  }
  $24 = HEAP32[$9>>2]|0;
  $25 = (($24) + 32|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($15) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($10) + ($28<<2)|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$11>>2]|0;
  $32 = (($15) + 12|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = Math_imul($33, $31)|0;
  $35 = (FUNCTION_TABLE_iiiiii[$26 & 3]($cinfo,$30,$34,$33,1)|0);
  $36 = HEAP32[$9>>2]|0;
  $37 = (($36) + 32|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = HEAP32[$27>>2]|0;
  $40 = (($12) + ($39<<2)|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = HEAP32[$11>>2]|0;
  $43 = HEAP32[$32>>2]|0;
  $44 = Math_imul($43, $42)|0;
  $45 = (FUNCTION_TABLE_iiiiii[$38 & 3]($cinfo,$41,$44,$43,1)|0);
  $46 = HEAP32[$11>>2]|0;
  $47 = ($46>>>0)<($4>>>0);
  if ($47) {
   $48 = HEAP32[$32>>2]|0;
   $block_rows$0 = $48;
  } else {
   $49 = (($15) + 32|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = HEAP32[$32>>2]|0;
   $52 = (($50>>>0) % ($51>>>0))&-1;
   $53 = ($52|0)==(0);
   $$ = $53 ? $51 : $52;
   $block_rows$0 = $$;
  }
  $54 = (($15) + 28|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (($15) + 8|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = (($55>>>0) % ($57>>>0))&-1;
  $59 = ($58|0)>(0);
  $60 = (($57) - ($58))|0;
  $$2 = $59 ? $60 : $58;
  HEAP16[$lastDC>>1] = 0;
  $61 = ($block_rows$0|0)>(0);
  if ($61) {
   $62 = (($15) + 16|0);
   $63 = ($$2|0)>(0);
   $64 = $$2 << 7;
   $$sum = (($55) + -1)|0;
   $block_row$04 = 0;
   while(1) {
    $65 = (($35) + ($block_row$04<<2)|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = ($block_row$04|0)>(0);
    if ($67) {
     $68 = (($block_row$04) + -1)|0;
     $69 = (($35) + ($68<<2)|0);
     $70 = HEAP32[$69>>2]|0;
     $84 = $70;
    } else {
     $84 = 0;
    }
    $71 = HEAP8[$8>>0]|0;
    $72 = ($71<<24>>24)==(0);
    if ($72) {
     $85 = HEAP32[$dctbl>>2]|0;
     $86 = HEAP32[$actbl>>2]|0;
     $87 = (($45) + ($block_row$04<<2)|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = HEAP32[$62>>2]|0;
     $90 = ((($cinfo) + ($89<<2)|0) + 72|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = HEAP32[$13>>2]|0;
     $93 = ((($92) + ($89<<9)|0) + 24|0);
     $94 = ((($92) + ($89<<9)|0) + 2072|0);
     $95 = (($block_row$04) + -1)|0;
     $96 = (($45) + ($95<<2)|0);
     $97 = HEAP32[$96>>2]|0;
     _quantize_trellis($cinfo,$85,$86,$66,$88,$55,$91,$93,$94,$lastDC,$84,$97);
    } else {
     $73 = (($45) + ($block_row$04<<2)|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = HEAP32[$62>>2]|0;
     $76 = ((($cinfo) + ($75<<2)|0) + 72|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = HEAP32[$13>>2]|0;
     $79 = ((($78) + ($75<<9)|0) + 24|0);
     $80 = ((($78) + ($75<<9)|0) + 2072|0);
     $81 = (($block_row$04) + -1)|0;
     $82 = (($45) + ($81<<2)|0);
     $83 = HEAP32[$82>>2]|0;
     _quantize_trellis_arith($cinfo,$arith_r_data,$66,$74,$55,$77,$79,$80,$lastDC,$84,$83);
    }
    L25: do {
     if ($63) {
      $98 = (($66) + ($55<<7)|0);
      _jzero_far($98,$64);
      $99 = (($66) + ($$sum<<7)|0);
      $100 = HEAP16[$99>>1]|0;
      HEAP16[$lastDC>>1] = $100;
      $102 = $100;$bi$03 = 0;
      while(1) {
       $$sum1 = (($bi$03) + ($55))|0;
       $101 = (($66) + ($$sum1<<7)|0);
       HEAP16[$101>>1] = $102;
       $103 = (($bi$03) + 1)|0;
       $exitcond = ($103|0)==($$2|0);
       if ($exitcond) {
        break L25;
       }
       $$pre30 = HEAP16[$lastDC>>1]|0;
       $102 = $$pre30;$bi$03 = $103;
      }
     }
    } while(0);
    $104 = (($block_row$04) + 1)|0;
    $exitcond25 = ($104|0)==($block_rows$0|0);
    if ($exitcond25) {
     break;
    } else {
     $block_row$04 = $104;
    }
   }
   $$pre = HEAP32[$11>>2]|0;
   $105 = $$pre;
  } else {
   $105 = $46;
  }
  $106 = ($105|0)==($4|0);
  if ($106) {
   $107 = (($$2) + ($55))|0;
   $108 = (($107>>>0) / ($57>>>0))&-1;
   $109 = HEAP32[$32>>2]|0;
   $110 = ($block_rows$0|0)<($109|0);
   if ($110) {
    $111 = $107 << 7;
    $112 = ($108|0)==(0);
    $113 = (($57) + -1)|0;
    $114 = ($57|0)>(0);
    $block_row$118 = $block_rows$0;
    while(1) {
     $115 = (($35) + ($block_row$118<<2)|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = (($block_row$118) + -1)|0;
     $118 = (($35) + ($117<<2)|0);
     $119 = HEAP32[$118>>2]|0;
     _jzero_far($116,$111);
     if (!($112)) {
      $MCUindex$013 = 0;$lastblockrow$012 = $119;$thisblockrow$010 = $116;
      while(1) {
       $120 = (($lastblockrow$012) + ($113<<7)|0);
       $121 = HEAP16[$120>>1]|0;
       HEAP16[$lastDC>>1] = $121;
       L41: do {
        if ($114) {
         $123 = $121;$bi$16 = 0;
         while(1) {
          $122 = (($thisblockrow$010) + ($bi$16<<7)|0);
          HEAP16[$122>>1] = $123;
          $124 = (($bi$16) + 1)|0;
          $exitcond26 = ($124|0)==($57|0);
          if ($exitcond26) {
           break L41;
          }
          $$pre29 = HEAP16[$lastDC>>1]|0;
          $123 = $$pre29;$bi$16 = $124;
         }
        }
       } while(0);
       $125 = (($thisblockrow$010) + ($57<<7)|0);
       $126 = (($lastblockrow$012) + ($57<<7)|0);
       $127 = (($MCUindex$013) + 1)|0;
       $128 = ($127>>>0)<($108>>>0);
       if ($128) {
        $MCUindex$013 = $127;$lastblockrow$012 = $126;$thisblockrow$010 = $125;
       } else {
        break;
       }
      }
     }
     $129 = (($block_row$118) + 1)|0;
     $130 = HEAP32[$32>>2]|0;
     $131 = ($129|0)<($130|0);
     if ($131) {
      $block_row$118 = $129;
     } else {
      break;
     }
    }
   }
  }
  $132 = (($ci$021) + 1)|0;
  $133 = HEAP32[$5>>2]|0;
  $134 = ($132|0)<($133|0);
  if ($134) {
   $ci$021 = $132;
  } else {
   break;
  }
 }
 $135 = (_compress_output($cinfo,$input_buf)|0);
 STACKTOP = sp;return ($135|0);
}
function _jinit_color_converter($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 7]($cinfo,1,12)|0);
 $4 = (($cinfo) + 336|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$3>>2] = 2;
 $5 = (($cinfo) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 switch ($6|0) {
 case 5: case 4:  {
  $27 = (($cinfo) + 36|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==(4);
  if (!($29)) {
   $30 = HEAP32[$cinfo>>2]|0;
   $31 = (($30) + 20|0);
   HEAP32[$31>>2] = 9;
   $32 = HEAP32[$30>>2]|0;
   FUNCTION_TABLE_vi[$32 & 63]($cinfo);
  }
  break;
 }
 case 1:  {
  $7 = (($cinfo) + 36|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(1);
  if (!($9)) {
   $10 = HEAP32[$cinfo>>2]|0;
   $11 = (($10) + 20|0);
   HEAP32[$11>>2] = 9;
   $12 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vi[$12 & 63]($cinfo);
  }
  break;
 }
 case 3:  {
  $21 = (($cinfo) + 36|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(3);
  if (!($23)) {
   $24 = HEAP32[$cinfo>>2]|0;
   $25 = (($24) + 20|0);
   HEAP32[$25>>2] = 9;
   $26 = HEAP32[$24>>2]|0;
   FUNCTION_TABLE_vi[$26 & 63]($cinfo);
  }
  break;
 }
 case 15: case 14: case 13: case 12: case 11: case 10: case 9: case 8: case 7: case 6: case 2:  {
  $13 = (($cinfo) + 36|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (464 + ($6<<2)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14|0)==($16|0);
  if (!($17)) {
   $18 = HEAP32[$cinfo>>2]|0;
   $19 = (($18) + 20|0);
   HEAP32[$19>>2] = 9;
   $20 = HEAP32[$18>>2]|0;
   FUNCTION_TABLE_vi[$20 & 63]($cinfo);
  }
  break;
 }
 default: {
  $33 = (($cinfo) + 36|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)<(1);
  if ($35) {
   $36 = HEAP32[$cinfo>>2]|0;
   $37 = (($36) + 20|0);
   HEAP32[$37>>2] = 9;
   $38 = HEAP32[$36>>2]|0;
   FUNCTION_TABLE_vi[$38 & 63]($cinfo);
  }
 }
 }
 $39 = (($cinfo) + 64|0);
 $40 = HEAP32[$39>>2]|0;
 switch ($40|0) {
 case 1:  {
  $41 = (($cinfo) + 60|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(1);
  if (!($43)) {
   $44 = HEAP32[$cinfo>>2]|0;
   $45 = (($44) + 20|0);
   HEAP32[$45>>2] = 10;
   $46 = HEAP32[$44>>2]|0;
   FUNCTION_TABLE_vi[$46 & 63]($cinfo);
  }
  $47 = HEAP32[$5>>2]|0;
  switch ($47|0) {
  case 1:  {
   $48 = (($3) + 4|0);
   HEAP32[$48>>2] = 1;
   STACKTOP = sp;return;
   break;
  }
  case 15: case 14: case 13: case 12: case 11: case 10: case 9: case 8: case 7: case 6: case 2:  {
   $49 = (_jsimd_can_rgb_gray()|0);
   $50 = ($49|0)==(0);
   if ($50) {
    HEAP32[$3>>2] = 3;
    $52 = (($3) + 4|0);
    HEAP32[$52>>2] = 3;
    STACKTOP = sp;return;
   } else {
    $51 = (($3) + 4|0);
    HEAP32[$51>>2] = 2;
    STACKTOP = sp;return;
   }
   break;
  }
  case 3:  {
   $53 = (($3) + 4|0);
   HEAP32[$53>>2] = 1;
   STACKTOP = sp;return;
   break;
  }
  default: {
   $54 = HEAP32[$cinfo>>2]|0;
   $55 = (($54) + 20|0);
   HEAP32[$55>>2] = 27;
   $56 = HEAP32[$54>>2]|0;
   FUNCTION_TABLE_vi[$56 & 63]($cinfo);
   STACKTOP = sp;return;
  }
  }
  break;
 }
 case 4:  {
  $93 = (($cinfo) + 60|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = ($94|0)==(4);
  if (!($95)) {
   $96 = HEAP32[$cinfo>>2]|0;
   $97 = (($96) + 20|0);
   HEAP32[$97>>2] = 10;
   $98 = HEAP32[$96>>2]|0;
   FUNCTION_TABLE_vi[$98 & 63]($cinfo);
  }
  $99 = HEAP32[$5>>2]|0;
  $100 = ($99|0)==(4);
  if ($100) {
   $101 = (($3) + 4|0);
   HEAP32[$101>>2] = 4;
   STACKTOP = sp;return;
  } else {
   $102 = HEAP32[$cinfo>>2]|0;
   $103 = (($102) + 20|0);
   HEAP32[$103>>2] = 27;
   $104 = HEAP32[$102>>2]|0;
   FUNCTION_TABLE_vi[$104 & 63]($cinfo);
   STACKTOP = sp;return;
  }
  break;
 }
 case 2:  {
  $57 = (($cinfo) + 60|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)==(3);
  if (!($59)) {
   $60 = HEAP32[$cinfo>>2]|0;
   $61 = (($60) + 20|0);
   HEAP32[$61>>2] = 10;
   $62 = HEAP32[$60>>2]|0;
   FUNCTION_TABLE_vi[$62 & 63]($cinfo);
  }
  $63 = HEAP32[$5>>2]|0;
  $64 = 4292 >>> $63;
  $65 = $64 & 1;
  $66 = ($65|0)==(0);
  if (!($66)) {
   $67 = 13252 >>> $63;
   $68 = $67 & 1;
   $69 = ($68|0)==(0);
   if (!($69)) {
    $70 = 324 >>> $63;
    $71 = $70 & 1;
    $72 = ($71|0)==(0);
    if (!($72)) {
     $73 = (($3) + 4|0);
     HEAP32[$73>>2] = 4;
     STACKTOP = sp;return;
    }
   }
  }
  switch ($63|0) {
  case 15: case 14: case 13: case 12: case 11: case 10: case 9: case 8: case 7: case 6: case 2:  {
   $74 = (($3) + 4|0);
   HEAP32[$74>>2] = 5;
   STACKTOP = sp;return;
   break;
  }
  default: {
   $75 = HEAP32[$cinfo>>2]|0;
   $76 = (($75) + 20|0);
   HEAP32[$76>>2] = 27;
   $77 = HEAP32[$75>>2]|0;
   FUNCTION_TABLE_vi[$77 & 63]($cinfo);
   STACKTOP = sp;return;
  }
  }
  break;
 }
 case 5:  {
  $105 = (($cinfo) + 60|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = ($106|0)==(4);
  if (!($107)) {
   $108 = HEAP32[$cinfo>>2]|0;
   $109 = (($108) + 20|0);
   HEAP32[$109>>2] = 10;
   $110 = HEAP32[$108>>2]|0;
   FUNCTION_TABLE_vi[$110 & 63]($cinfo);
  }
  $111 = HEAP32[$5>>2]|0;
  if ((($111|0) == 4)) {
   HEAP32[$3>>2] = 3;
   $112 = (($3) + 4|0);
   HEAP32[$112>>2] = 8;
   STACKTOP = sp;return;
  } else if ((($111|0) == 5)) {
   $113 = (($3) + 4|0);
   HEAP32[$113>>2] = 4;
   STACKTOP = sp;return;
  } else {
   $114 = HEAP32[$cinfo>>2]|0;
   $115 = (($114) + 20|0);
   HEAP32[$115>>2] = 27;
   $116 = HEAP32[$114>>2]|0;
   FUNCTION_TABLE_vi[$116 & 63]($cinfo);
   STACKTOP = sp;return;
  }
  break;
 }
 case 3:  {
  $78 = (($cinfo) + 60|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = ($79|0)==(3);
  if (!($80)) {
   $81 = HEAP32[$cinfo>>2]|0;
   $82 = (($81) + 20|0);
   HEAP32[$82>>2] = 10;
   $83 = HEAP32[$81>>2]|0;
   FUNCTION_TABLE_vi[$83 & 63]($cinfo);
  }
  $84 = HEAP32[$5>>2]|0;
  switch ($84|0) {
  case 3:  {
   $89 = (($3) + 4|0);
   HEAP32[$89>>2] = 4;
   STACKTOP = sp;return;
   break;
  }
  case 15: case 14: case 13: case 12: case 11: case 10: case 9: case 8: case 7: case 6: case 2:  {
   $85 = (_jsimd_can_rgb_ycc()|0);
   $86 = ($85|0)==(0);
   if ($86) {
    HEAP32[$3>>2] = 3;
    $88 = (($3) + 4|0);
    HEAP32[$88>>2] = 7;
    STACKTOP = sp;return;
   } else {
    $87 = (($3) + 4|0);
    HEAP32[$87>>2] = 6;
    STACKTOP = sp;return;
   }
   break;
  }
  default: {
   $90 = HEAP32[$cinfo>>2]|0;
   $91 = (($90) + 20|0);
   HEAP32[$91>>2] = 27;
   $92 = HEAP32[$90>>2]|0;
   FUNCTION_TABLE_vi[$92 & 63]($cinfo);
   STACKTOP = sp;return;
  }
  }
  break;
 }
 default: {
  $117 = HEAP32[$5>>2]|0;
  $118 = ($40|0)==($117|0);
  if ($118) {
   $119 = (($cinfo) + 60|0);
   $120 = HEAP32[$119>>2]|0;
   $121 = (($cinfo) + 36|0);
   $122 = HEAP32[$121>>2]|0;
   $123 = ($120|0)==($122|0);
   if (!($123)) {
    label = 52;
   }
  } else {
   label = 52;
  }
  if ((label|0) == 52) {
   $124 = HEAP32[$cinfo>>2]|0;
   $125 = (($124) + 20|0);
   HEAP32[$125>>2] = 27;
   $126 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vi[$126 & 63]($cinfo);
  }
  $127 = (($3) + 4|0);
  HEAP32[$127>>2] = 4;
  STACKTOP = sp;return;
 }
 }
}
function _null_method($cinfo) {
 $cinfo = $cinfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _grayscale_convert($cinfo,$input_buf,$output_buf,$output_row,$num_rows) {
 $cinfo = $cinfo|0;
 $input_buf = $input_buf|0;
 $output_buf = $output_buf|0;
 $output_row = $output_row|0;
 $num_rows = $num_rows|0;
 var $$015$us = 0, $$06$us = 0, $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $col$04$us = 0, $exitcond = 0, $inptr$03$us = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($num_rows|0)<(1);
 $5 = ($1|0)==(0);
 $or$cond = $4 | $5;
 if ($or$cond) {
  STACKTOP = sp;return;
 } else {
  $$015$us = $output_row;$$06$us = $input_buf;$$in = $num_rows;
 }
 while(1) {
  $11 = (($$in) + -1)|0;
  $13 = (($$06$us) + 4|0);
  $14 = HEAP32[$output_buf>>2]|0;
  $15 = (($14) + ($$015$us<<2)|0);
  $8 = HEAP32[$15>>2]|0;
  $16 = (($$015$us) + 1)|0;
  $17 = HEAP32[$$06$us>>2]|0;
  $col$04$us = 0;$inptr$03$us = $17;
  while(1) {
   $6 = HEAP8[$inptr$03$us>>0]|0;
   $7 = (($8) + ($col$04$us)|0);
   HEAP8[$7>>0] = $6;
   $9 = (($inptr$03$us) + ($3)|0);
   $10 = (($col$04$us) + 1)|0;
   $exitcond = ($10|0)==($1|0);
   if ($exitcond) {
    break;
   } else {
    $col$04$us = $10;$inptr$03$us = $9;
   }
  }
  $12 = ($11|0)>(0);
  if ($12) {
   $$015$us = $16;$$06$us = $13;$$in = $11;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _rgb_ycc_start($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 336|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$4 & 7]($cinfo,1,8192)|0);
 $6 = (($1) + 8|0);
 HEAP32[$6>>2] = $5;
 $i$01 = 0;
 while(1) {
  $7 = ($i$01*19595)|0;
  $8 = (($5) + ($i$01<<2)|0);
  HEAP32[$8>>2] = $7;
  $9 = ($i$01*38470)|0;
  $10 = (($i$01) + 256)|0;
  $11 = (($5) + ($10<<2)|0);
  HEAP32[$11>>2] = $9;
  $12 = ($i$01*7471)|0;
  $13 = (($12) + 32768)|0;
  $14 = (($i$01) + 512)|0;
  $15 = (($5) + ($14<<2)|0);
  HEAP32[$15>>2] = $13;
  $16 = Math_imul($i$01, -11059)|0;
  $17 = (($i$01) + 768)|0;
  $18 = (($5) + ($17<<2)|0);
  HEAP32[$18>>2] = $16;
  $19 = Math_imul($i$01, -21709)|0;
  $20 = (($i$01) + 1024)|0;
  $21 = (($5) + ($20<<2)|0);
  HEAP32[$21>>2] = $19;
  $22 = $i$01 << 15;
  $23 = (($22) + 8421375)|0;
  $24 = (($i$01) + 1280)|0;
  $25 = (($5) + ($24<<2)|0);
  HEAP32[$25>>2] = $23;
  $26 = Math_imul($i$01, -27439)|0;
  $27 = (($i$01) + 1536)|0;
  $28 = (($5) + ($27<<2)|0);
  HEAP32[$28>>2] = $26;
  $29 = Math_imul($i$01, -5329)|0;
  $30 = (($i$01) + 1792)|0;
  $31 = (($5) + ($30<<2)|0);
  HEAP32[$31>>2] = $29;
  $32 = (($i$01) + 1)|0;
  $exitcond = ($32|0)==(256);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $32;
  }
 }
 STACKTOP = sp;return;
}
function _rgb_gray_convert($cinfo,$input_buf,$output_buf,$output_row,$num_rows) {
 $cinfo = $cinfo|0;
 $input_buf = $input_buf|0;
 $output_buf = $output_buf|0;
 $output_row = $output_row|0;
 $num_rows = $num_rows|0;
 var $$013$i = 0, $$013$i20 = 0, $$013$i30 = 0, $$013$i40 = 0, $$013$us$i = 0, $$013$us$i53 = 0, $$013$us$i62 = 0, $$04$i = 0, $$04$i19 = 0, $$04$i29 = 0, $$04$i39 = 0, $$04$us$i = 0, $$04$us$i52 = 0, $$04$us$i61 = 0, $$in$i = 0, $$in$i14 = 0, $$in$i18 = 0, $$in$i28 = 0, $$in$i38 = 0, $$in$i51 = 0;
 var $$in$i60 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cinfo$idx = 0, $cinfo$idx$val = 0, $cinfo$idx1 = 0, $cinfo$idx1$val = 0, $cinfo$idx10 = 0, $cinfo$idx10$val = 0, $cinfo$idx11 = 0, $cinfo$idx11$val = 0, $cinfo$idx12 = 0, $cinfo$idx12$val = 0;
 var $cinfo$idx13 = 0, $cinfo$idx13$val = 0, $cinfo$idx2 = 0, $cinfo$idx2$val = 0, $cinfo$idx3 = 0, $cinfo$idx3$val = 0, $cinfo$idx4 = 0, $cinfo$idx4$val = 0, $cinfo$idx5 = 0, $cinfo$idx5$val = 0, $cinfo$idx6 = 0, $cinfo$idx6$val = 0, $cinfo$idx7 = 0, $cinfo$idx7$val = 0, $cinfo$idx8 = 0, $cinfo$idx8$val = 0, $cinfo$idx9 = 0, $cinfo$idx9$val = 0, $col$02$i = 0, $col$02$i23 = 0;
 var $col$02$i33 = 0, $col$02$i43 = 0, $col$02$us$i = 0, $col$02$us$i47 = 0, $col$02$us$i56 = 0, $exitcond$i = 0, $exitcond$i15 = 0, $exitcond$i25 = 0, $exitcond$i35 = 0, $exitcond$i45 = 0, $exitcond$i49 = 0, $exitcond$i58 = 0, $inptr$01$i = 0, $inptr$01$i24 = 0, $inptr$01$i34 = 0, $inptr$01$i44 = 0, $inptr$01$us$i = 0, $inptr$01$us$i48 = 0, $inptr$01$us$i57 = 0, $or$cond$i = 0;
 var $or$cond$i46 = 0, $or$cond$i55 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 switch ($1|0) {
 case 12: case 7:  {
  $cinfo$idx2 = (($cinfo) + 28|0);
  $cinfo$idx2$val = HEAP32[$cinfo$idx2>>2]|0;
  $cinfo$idx3 = (($cinfo) + 336|0);
  $cinfo$idx3$val = HEAP32[$cinfo$idx3>>2]|0;
  $37 = (($cinfo$idx3$val) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($num_rows|0)<(1);
  $40 = ($cinfo$idx2$val|0)==(0);
  $or$cond$i55 = $39 | $40;
  if ($or$cond$i55) {
   STACKTOP = sp;return;
  } else {
   $$013$us$i62 = $output_row;$$04$us$i61 = $input_buf;$$in$i60 = $num_rows;
  }
  while(1) {
   $67 = (($$in$i60) + -1)|0;
   $69 = HEAP32[$output_buf>>2]|0;
   $70 = (($69) + ($$013$us$i62<<2)|0);
   $63 = HEAP32[$70>>2]|0;
   $71 = HEAP32[$$04$us$i61>>2]|0;
   $col$02$us$i56 = 0;$inptr$01$us$i57 = $71;
   while(1) {
    $41 = HEAP8[$inptr$01$us$i57>>0]|0;
    $42 = $41&255;
    $43 = (($inptr$01$us$i57) + 1|0);
    $44 = HEAP8[$43>>0]|0;
    $45 = $44&255;
    $46 = (($inptr$01$us$i57) + 2|0);
    $47 = HEAP8[$46>>0]|0;
    $48 = $47&255;
    $49 = (($inptr$01$us$i57) + 4|0);
    $50 = (($38) + ($42<<2)|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = $45 | 256;
    $53 = (($38) + ($52<<2)|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($54) + ($51))|0;
    $56 = $48 | 512;
    $57 = (($38) + ($56<<2)|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = (($55) + ($58))|0;
    $60 = $59 >>> 16;
    $61 = $60&255;
    $62 = (($63) + ($col$02$us$i56)|0);
    HEAP8[$62>>0] = $61;
    $64 = (($col$02$us$i56) + 1)|0;
    $exitcond$i58 = ($64|0)==($cinfo$idx2$val|0);
    if ($exitcond$i58) {
     break;
    } else {
     $col$02$us$i56 = $64;$inptr$01$us$i57 = $49;
    }
   }
   $65 = (($$04$us$i61) + 4|0);
   $66 = (($$013$us$i62) + 1)|0;
   $68 = ($67|0)>(0);
   if ($68) {
    $$013$us$i62 = $66;$$04$us$i61 = $65;$$in$i60 = $67;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 8:  {
  $cinfo$idx4 = (($cinfo) + 28|0);
  $cinfo$idx4$val = HEAP32[$cinfo$idx4>>2]|0;
  $cinfo$idx5 = (($cinfo) + 336|0);
  $cinfo$idx5$val = HEAP32[$cinfo$idx5>>2]|0;
  $72 = (($cinfo$idx5$val) + 8|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = ($num_rows|0)<(1);
  $75 = ($cinfo$idx4$val|0)==(0);
  $or$cond$i46 = $74 | $75;
  if ($or$cond$i46) {
   STACKTOP = sp;return;
  } else {
   $$013$us$i53 = $output_row;$$04$us$i52 = $input_buf;$$in$i51 = $num_rows;
  }
  while(1) {
   $102 = (($$in$i51) + -1)|0;
   $104 = HEAP32[$output_buf>>2]|0;
   $105 = (($104) + ($$013$us$i53<<2)|0);
   $98 = HEAP32[$105>>2]|0;
   $106 = HEAP32[$$04$us$i52>>2]|0;
   $col$02$us$i47 = 0;$inptr$01$us$i48 = $106;
   while(1) {
    $76 = (($inptr$01$us$i48) + 2|0);
    $77 = HEAP8[$76>>0]|0;
    $78 = $77&255;
    $79 = (($inptr$01$us$i48) + 1|0);
    $80 = HEAP8[$79>>0]|0;
    $81 = $80&255;
    $82 = HEAP8[$inptr$01$us$i48>>0]|0;
    $83 = $82&255;
    $84 = (($inptr$01$us$i48) + 3|0);
    $85 = (($73) + ($78<<2)|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = $81 | 256;
    $88 = (($73) + ($87<<2)|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = (($89) + ($86))|0;
    $91 = $83 | 512;
    $92 = (($73) + ($91<<2)|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = (($90) + ($93))|0;
    $95 = $94 >>> 16;
    $96 = $95&255;
    $97 = (($98) + ($col$02$us$i47)|0);
    HEAP8[$97>>0] = $96;
    $99 = (($col$02$us$i47) + 1)|0;
    $exitcond$i49 = ($99|0)==($cinfo$idx4$val|0);
    if ($exitcond$i49) {
     break;
    } else {
     $col$02$us$i47 = $99;$inptr$01$us$i48 = $84;
    }
   }
   $100 = (($$04$us$i52) + 4|0);
   $101 = (($$013$us$i53) + 1)|0;
   $103 = ($102|0)>(0);
   if ($103) {
    $$013$us$i53 = $101;$$04$us$i52 = $100;$$in$i51 = $102;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 15: case 11:  {
  $cinfo$idx10 = (($cinfo) + 28|0);
  $cinfo$idx10$val = HEAP32[$cinfo$idx10>>2]|0;
  $cinfo$idx11 = (($cinfo) + 336|0);
  $cinfo$idx11$val = HEAP32[$cinfo$idx11>>2]|0;
  $178 = (($cinfo$idx11$val) + 8|0);
  $179 = HEAP32[$178>>2]|0;
  $180 = ($num_rows|0)>(0);
  if (!($180)) {
   STACKTOP = sp;return;
  }
  $181 = ($cinfo$idx10$val|0)==(0);
  $$013$i20 = $output_row;$$04$i19 = $input_buf;$$in$i18 = $num_rows;
  while(1) {
   $182 = (($$in$i18) + -1)|0;
   $184 = (($$04$i19) + 4|0);
   $185 = HEAP32[$output_buf>>2]|0;
   $186 = (($185) + ($$013$i20<<2)|0);
   $187 = HEAP32[$186>>2]|0;
   $188 = (($$013$i20) + 1)|0;
   if (!($181)) {
    $189 = HEAP32[$$04$i19>>2]|0;
    $col$02$i23 = 0;$inptr$01$i24 = $189;
    while(1) {
     $190 = (($inptr$01$i24) + 1|0);
     $191 = HEAP8[$190>>0]|0;
     $192 = $191&255;
     $193 = (($inptr$01$i24) + 2|0);
     $194 = HEAP8[$193>>0]|0;
     $195 = $194&255;
     $196 = (($inptr$01$i24) + 3|0);
     $197 = HEAP8[$196>>0]|0;
     $198 = $197&255;
     $199 = (($inptr$01$i24) + 4|0);
     $200 = (($179) + ($192<<2)|0);
     $201 = HEAP32[$200>>2]|0;
     $202 = $195 | 256;
     $203 = (($179) + ($202<<2)|0);
     $204 = HEAP32[$203>>2]|0;
     $205 = (($204) + ($201))|0;
     $206 = $198 | 512;
     $207 = (($179) + ($206<<2)|0);
     $208 = HEAP32[$207>>2]|0;
     $209 = (($205) + ($208))|0;
     $210 = $209 >>> 16;
     $211 = $210&255;
     $212 = (($187) + ($col$02$i23)|0);
     HEAP8[$212>>0] = $211;
     $213 = (($col$02$i23) + 1)|0;
     $exitcond$i25 = ($213|0)==($cinfo$idx10$val|0);
     if ($exitcond$i25) {
      break;
     } else {
      $col$02$i23 = $213;$inptr$01$i24 = $199;
     }
    }
   }
   $183 = ($182|0)>(0);
   if ($183) {
    $$013$i20 = $188;$$04$i19 = $184;$$in$i18 = $182;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 6:  {
  $cinfo$idx = (($cinfo) + 28|0);
  $cinfo$idx$val = HEAP32[$cinfo$idx>>2]|0;
  $cinfo$idx1 = (($cinfo) + 336|0);
  $cinfo$idx1$val = HEAP32[$cinfo$idx1>>2]|0;
  $2 = (($cinfo$idx1$val) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($num_rows|0)<(1);
  $5 = ($cinfo$idx$val|0)==(0);
  $or$cond$i = $4 | $5;
  if ($or$cond$i) {
   STACKTOP = sp;return;
  } else {
   $$013$us$i = $output_row;$$04$us$i = $input_buf;$$in$i = $num_rows;
  }
  while(1) {
   $32 = (($$in$i) + -1)|0;
   $34 = HEAP32[$output_buf>>2]|0;
   $35 = (($34) + ($$013$us$i<<2)|0);
   $28 = HEAP32[$35>>2]|0;
   $36 = HEAP32[$$04$us$i>>2]|0;
   $col$02$us$i = 0;$inptr$01$us$i = $36;
   while(1) {
    $6 = HEAP8[$inptr$01$us$i>>0]|0;
    $7 = $6&255;
    $8 = (($inptr$01$us$i) + 1|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = $9&255;
    $11 = (($inptr$01$us$i) + 2|0);
    $12 = HEAP8[$11>>0]|0;
    $13 = $12&255;
    $14 = (($inptr$01$us$i) + 3|0);
    $15 = (($3) + ($7<<2)|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = $10 | 256;
    $18 = (($3) + ($17<<2)|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + ($16))|0;
    $21 = $13 | 512;
    $22 = (($3) + ($21<<2)|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($20) + ($23))|0;
    $25 = $24 >>> 16;
    $26 = $25&255;
    $27 = (($28) + ($col$02$us$i)|0);
    HEAP8[$27>>0] = $26;
    $29 = (($col$02$us$i) + 1)|0;
    $exitcond$i = ($29|0)==($cinfo$idx$val|0);
    if ($exitcond$i) {
     break;
    } else {
     $col$02$us$i = $29;$inptr$01$us$i = $14;
    }
   }
   $30 = (($$04$us$i) + 4|0);
   $31 = (($$013$us$i) + 1)|0;
   $33 = ($32|0)>(0);
   if ($33) {
    $$013$us$i = $31;$$04$us$i = $30;$$in$i = $32;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 14: case 10:  {
  $cinfo$idx8 = (($cinfo) + 28|0);
  $cinfo$idx8$val = HEAP32[$cinfo$idx8>>2]|0;
  $cinfo$idx9 = (($cinfo) + 336|0);
  $cinfo$idx9$val = HEAP32[$cinfo$idx9>>2]|0;
  $142 = (($cinfo$idx9$val) + 8|0);
  $143 = HEAP32[$142>>2]|0;
  $144 = ($num_rows|0)>(0);
  if (!($144)) {
   STACKTOP = sp;return;
  }
  $145 = ($cinfo$idx8$val|0)==(0);
  $$013$i30 = $output_row;$$04$i29 = $input_buf;$$in$i28 = $num_rows;
  while(1) {
   $146 = (($$in$i28) + -1)|0;
   $148 = (($$04$i29) + 4|0);
   $149 = HEAP32[$output_buf>>2]|0;
   $150 = (($149) + ($$013$i30<<2)|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = (($$013$i30) + 1)|0;
   if (!($145)) {
    $153 = HEAP32[$$04$i29>>2]|0;
    $col$02$i33 = 0;$inptr$01$i34 = $153;
    while(1) {
     $154 = (($inptr$01$i34) + 3|0);
     $155 = HEAP8[$154>>0]|0;
     $156 = $155&255;
     $157 = (($inptr$01$i34) + 2|0);
     $158 = HEAP8[$157>>0]|0;
     $159 = $158&255;
     $160 = (($inptr$01$i34) + 1|0);
     $161 = HEAP8[$160>>0]|0;
     $162 = $161&255;
     $163 = (($inptr$01$i34) + 4|0);
     $164 = (($143) + ($156<<2)|0);
     $165 = HEAP32[$164>>2]|0;
     $166 = $159 | 256;
     $167 = (($143) + ($166<<2)|0);
     $168 = HEAP32[$167>>2]|0;
     $169 = (($168) + ($165))|0;
     $170 = $162 | 512;
     $171 = (($143) + ($170<<2)|0);
     $172 = HEAP32[$171>>2]|0;
     $173 = (($169) + ($172))|0;
     $174 = $173 >>> 16;
     $175 = $174&255;
     $176 = (($151) + ($col$02$i33)|0);
     HEAP8[$176>>0] = $175;
     $177 = (($col$02$i33) + 1)|0;
     $exitcond$i35 = ($177|0)==($cinfo$idx8$val|0);
     if ($exitcond$i35) {
      break;
     } else {
      $col$02$i33 = $177;$inptr$01$i34 = $163;
     }
    }
   }
   $147 = ($146|0)>(0);
   if ($147) {
    $$013$i30 = $152;$$04$i29 = $148;$$in$i28 = $146;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 13: case 9:  {
  $cinfo$idx6 = (($cinfo) + 28|0);
  $cinfo$idx6$val = HEAP32[$cinfo$idx6>>2]|0;
  $cinfo$idx7 = (($cinfo) + 336|0);
  $cinfo$idx7$val = HEAP32[$cinfo$idx7>>2]|0;
  $107 = (($cinfo$idx7$val) + 8|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = ($num_rows|0)>(0);
  if (!($109)) {
   STACKTOP = sp;return;
  }
  $110 = ($cinfo$idx6$val|0)==(0);
  $$013$i40 = $output_row;$$04$i39 = $input_buf;$$in$i38 = $num_rows;
  while(1) {
   $111 = (($$in$i38) + -1)|0;
   $113 = (($$04$i39) + 4|0);
   $114 = HEAP32[$output_buf>>2]|0;
   $115 = (($114) + ($$013$i40<<2)|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = (($$013$i40) + 1)|0;
   if (!($110)) {
    $118 = HEAP32[$$04$i39>>2]|0;
    $col$02$i43 = 0;$inptr$01$i44 = $118;
    while(1) {
     $119 = (($inptr$01$i44) + 2|0);
     $120 = HEAP8[$119>>0]|0;
     $121 = $120&255;
     $122 = (($inptr$01$i44) + 1|0);
     $123 = HEAP8[$122>>0]|0;
     $124 = $123&255;
     $125 = HEAP8[$inptr$01$i44>>0]|0;
     $126 = $125&255;
     $127 = (($inptr$01$i44) + 4|0);
     $128 = (($108) + ($121<<2)|0);
     $129 = HEAP32[$128>>2]|0;
     $130 = $124 | 256;
     $131 = (($108) + ($130<<2)|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = (($132) + ($129))|0;
     $134 = $126 | 512;
     $135 = (($108) + ($134<<2)|0);
     $136 = HEAP32[$135>>2]|0;
     $137 = (($133) + ($136))|0;
     $138 = $137 >>> 16;
     $139 = $138&255;
     $140 = (($116) + ($col$02$i43)|0);
     HEAP8[$140>>0] = $139;
     $141 = (($col$02$i43) + 1)|0;
     $exitcond$i45 = ($141|0)==($cinfo$idx6$val|0);
     if ($exitcond$i45) {
      break;
     } else {
      $col$02$i43 = $141;$inptr$01$i44 = $127;
     }
    }
   }
   $112 = ($111|0)>(0);
   if ($112) {
    $$013$i40 = $117;$$04$i39 = $113;$$in$i38 = $111;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 default: {
  $cinfo$idx12 = (($cinfo) + 28|0);
  $cinfo$idx12$val = HEAP32[$cinfo$idx12>>2]|0;
  $cinfo$idx13 = (($cinfo) + 336|0);
  $cinfo$idx13$val = HEAP32[$cinfo$idx13>>2]|0;
  $214 = (($cinfo$idx13$val) + 8|0);
  $215 = HEAP32[$214>>2]|0;
  $216 = ($num_rows|0)>(0);
  if (!($216)) {
   STACKTOP = sp;return;
  }
  $217 = ($cinfo$idx12$val|0)==(0);
  $$013$i = $output_row;$$04$i = $input_buf;$$in$i14 = $num_rows;
  while(1) {
   $218 = (($$in$i14) + -1)|0;
   $220 = (($$04$i) + 4|0);
   $221 = HEAP32[$output_buf>>2]|0;
   $222 = (($221) + ($$013$i<<2)|0);
   $223 = HEAP32[$222>>2]|0;
   $224 = (($$013$i) + 1)|0;
   if (!($217)) {
    $225 = HEAP32[$$04$i>>2]|0;
    $col$02$i = 0;$inptr$01$i = $225;
    while(1) {
     $226 = HEAP8[$inptr$01$i>>0]|0;
     $227 = $226&255;
     $228 = (($inptr$01$i) + 1|0);
     $229 = HEAP8[$228>>0]|0;
     $230 = $229&255;
     $231 = (($inptr$01$i) + 2|0);
     $232 = HEAP8[$231>>0]|0;
     $233 = $232&255;
     $234 = (($inptr$01$i) + 3|0);
     $235 = (($215) + ($227<<2)|0);
     $236 = HEAP32[$235>>2]|0;
     $237 = $230 | 256;
     $238 = (($215) + ($237<<2)|0);
     $239 = HEAP32[$238>>2]|0;
     $240 = (($239) + ($236))|0;
     $241 = $233 | 512;
     $242 = (($215) + ($241<<2)|0);
     $243 = HEAP32[$242>>2]|0;
     $244 = (($240) + ($243))|0;
     $245 = $244 >>> 16;
     $246 = $245&255;
     $247 = (($223) + ($col$02$i)|0);
     HEAP8[$247>>0] = $246;
     $248 = (($col$02$i) + 1)|0;
     $exitcond$i15 = ($248|0)==($cinfo$idx12$val|0);
     if ($exitcond$i15) {
      break;
     } else {
      $col$02$i = $248;$inptr$01$i = $234;
     }
    }
   }
   $219 = ($218|0)>(0);
   if ($219) {
    $$013$i = $224;$$04$i = $220;$$in$i14 = $218;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 }
 }
}
function _null_convert($cinfo,$input_buf,$output_buf,$output_row,$num_rows) {
 $cinfo = $cinfo|0;
 $input_buf = $input_buf|0;
 $output_buf = $output_buf|0;
 $output_row = $output_row|0;
 $num_rows = $num_rows|0;
 var $$018 = 0, $$09 = 0, $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ci$05 = 0, $col$04 = 0, $exitcond = 0, $exitcond11 = 0, $inptr$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($num_rows|0)>(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = ($1|0)>(0);
 $6 = ($3|0)==(0);
 $$018 = $output_row;$$09 = $input_buf;$$in = $num_rows;
 while(1) {
  $7 = (($$in) + -1)|0;
  if ($5) {
   $ci$05 = 0;
   while(1) {
    $8 = (($output_buf) + ($ci$05<<2)|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($9) + ($$018<<2)|0);
    $11 = HEAP32[$10>>2]|0;
    if (!($6)) {
     $12 = HEAP32[$$09>>2]|0;
     $col$04 = 0;$inptr$03 = $12;
     while(1) {
      $13 = (($inptr$03) + ($ci$05)|0);
      $14 = HEAP8[$13>>0]|0;
      $15 = (($11) + ($col$04)|0);
      HEAP8[$15>>0] = $14;
      $16 = (($inptr$03) + ($1)|0);
      $17 = (($col$04) + 1)|0;
      $exitcond = ($17|0)==($3|0);
      if ($exitcond) {
       break;
      } else {
       $col$04 = $17;$inptr$03 = $16;
      }
     }
    }
    $18 = (($ci$05) + 1)|0;
    $exitcond11 = ($18|0)==($1|0);
    if ($exitcond11) {
     break;
    } else {
     $ci$05 = $18;
    }
   }
  }
  $19 = (($$09) + 4|0);
  $20 = (($$018) + 1)|0;
  $21 = ($7|0)>(0);
  if ($21) {
   $$018 = $20;$$09 = $19;$$in = $7;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _rgb_rgb_convert($cinfo,$input_buf,$output_buf,$output_row,$num_rows) {
 $cinfo = $cinfo|0;
 $input_buf = $input_buf|0;
 $output_buf = $output_buf|0;
 $output_row = $output_row|0;
 $num_rows = $num_rows|0;
 var $$013$i = 0, $$013$i11 = 0, $$013$i21 = 0, $$013$i31 = 0, $$013$i41 = 0, $$013$i51 = 0, $$013$i61 = 0, $$04$i = 0, $$04$i10 = 0, $$04$i20 = 0, $$04$i30 = 0, $$04$i40 = 0, $$04$i50 = 0, $$04$i60 = 0, $$in$i = 0, $$in$i19 = 0, $$in$i29 = 0, $$in$i39 = 0, $$in$i49 = 0, $$in$i59 = 0;
 var $$in$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $cinfo$idx = 0, $cinfo$idx$val = 0, $cinfo$idx1 = 0, $cinfo$idx1$val = 0, $cinfo$idx2 = 0, $cinfo$idx2$val = 0, $cinfo$idx3 = 0, $cinfo$idx3$val = 0, $cinfo$idx4 = 0, $cinfo$idx4$val = 0, $cinfo$idx5 = 0, $cinfo$idx5$val = 0, $cinfo$idx6 = 0, $cinfo$idx6$val = 0, $col$02$i = 0, $col$02$i14 = 0, $col$02$i24 = 0, $col$02$i34 = 0, $col$02$i44 = 0;
 var $col$02$i54 = 0, $col$02$i64 = 0, $exitcond$i = 0, $exitcond$i16 = 0, $exitcond$i26 = 0, $exitcond$i36 = 0, $exitcond$i46 = 0, $exitcond$i56 = 0, $exitcond$i66 = 0, $inptr$01$i = 0, $inptr$01$i15 = 0, $inptr$01$i25 = 0, $inptr$01$i35 = 0, $inptr$01$i45 = 0, $inptr$01$i55 = 0, $inptr$01$i65 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 switch ($1|0) {
 case 12: case 7:  {
  $cinfo$idx1 = (($cinfo) + 28|0);
  $cinfo$idx1$val = HEAP32[$cinfo$idx1>>2]|0;
  $30 = ($num_rows|0)>(0);
  if (!($30)) {
   STACKTOP = sp;return;
  }
  $31 = (($output_buf) + 4|0);
  $32 = (($output_buf) + 8|0);
  $33 = ($cinfo$idx1$val|0)==(0);
  $$013$i61 = $output_row;$$04$i60 = $input_buf;$$in$i59 = $num_rows;
  while(1) {
   $34 = (($$in$i59) + -1)|0;
   $36 = (($$04$i60) + 4|0);
   $37 = HEAP32[$output_buf>>2]|0;
   $38 = (($37) + ($$013$i61<<2)|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = HEAP32[$31>>2]|0;
   $41 = (($40) + ($$013$i61<<2)|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = HEAP32[$32>>2]|0;
   $44 = (($43) + ($$013$i61<<2)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($$013$i61) + 1)|0;
   if (!($33)) {
    $47 = HEAP32[$$04$i60>>2]|0;
    $col$02$i64 = 0;$inptr$01$i65 = $47;
    while(1) {
     $48 = HEAP8[$inptr$01$i65>>0]|0;
     $49 = (($39) + ($col$02$i64)|0);
     HEAP8[$49>>0] = $48;
     $50 = (($inptr$01$i65) + 1|0);
     $51 = HEAP8[$50>>0]|0;
     $52 = (($42) + ($col$02$i64)|0);
     HEAP8[$52>>0] = $51;
     $53 = (($inptr$01$i65) + 2|0);
     $54 = HEAP8[$53>>0]|0;
     $55 = (($45) + ($col$02$i64)|0);
     HEAP8[$55>>0] = $54;
     $56 = (($inptr$01$i65) + 4|0);
     $57 = (($col$02$i64) + 1)|0;
     $exitcond$i66 = ($57|0)==($cinfo$idx1$val|0);
     if ($exitcond$i66) {
      break;
     } else {
      $col$02$i64 = $57;$inptr$01$i65 = $56;
     }
    }
   }
   $35 = ($34|0)>(0);
   if ($35) {
    $$013$i61 = $46;$$04$i60 = $36;$$in$i59 = $34;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 13: case 9:  {
  $cinfo$idx3 = (($cinfo) + 28|0);
  $cinfo$idx3$val = HEAP32[$cinfo$idx3>>2]|0;
  $86 = ($num_rows|0)>(0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($output_buf) + 4|0);
  $88 = (($output_buf) + 8|0);
  $89 = ($cinfo$idx3$val|0)==(0);
  $$013$i41 = $output_row;$$04$i40 = $input_buf;$$in$i39 = $num_rows;
  while(1) {
   $90 = (($$in$i39) + -1)|0;
   $92 = (($$04$i40) + 4|0);
   $93 = HEAP32[$output_buf>>2]|0;
   $94 = (($93) + ($$013$i41<<2)|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = HEAP32[$87>>2]|0;
   $97 = (($96) + ($$013$i41<<2)|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = HEAP32[$88>>2]|0;
   $100 = (($99) + ($$013$i41<<2)|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = (($$013$i41) + 1)|0;
   if (!($89)) {
    $103 = HEAP32[$$04$i40>>2]|0;
    $col$02$i44 = 0;$inptr$01$i45 = $103;
    while(1) {
     $104 = (($inptr$01$i45) + 2|0);
     $105 = HEAP8[$104>>0]|0;
     $106 = (($95) + ($col$02$i44)|0);
     HEAP8[$106>>0] = $105;
     $107 = (($inptr$01$i45) + 1|0);
     $108 = HEAP8[$107>>0]|0;
     $109 = (($98) + ($col$02$i44)|0);
     HEAP8[$109>>0] = $108;
     $110 = HEAP8[$inptr$01$i45>>0]|0;
     $111 = (($101) + ($col$02$i44)|0);
     HEAP8[$111>>0] = $110;
     $112 = (($inptr$01$i45) + 4|0);
     $113 = (($col$02$i44) + 1)|0;
     $exitcond$i46 = ($113|0)==($cinfo$idx3$val|0);
     if ($exitcond$i46) {
      break;
     } else {
      $col$02$i44 = $113;$inptr$01$i45 = $112;
     }
    }
   }
   $91 = ($90|0)>(0);
   if ($91) {
    $$013$i41 = $102;$$04$i40 = $92;$$in$i39 = $90;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 8:  {
  $cinfo$idx2 = (($cinfo) + 28|0);
  $cinfo$idx2$val = HEAP32[$cinfo$idx2>>2]|0;
  $58 = ($num_rows|0)>(0);
  if (!($58)) {
   STACKTOP = sp;return;
  }
  $59 = (($output_buf) + 4|0);
  $60 = (($output_buf) + 8|0);
  $61 = ($cinfo$idx2$val|0)==(0);
  $$013$i51 = $output_row;$$04$i50 = $input_buf;$$in$i49 = $num_rows;
  while(1) {
   $62 = (($$in$i49) + -1)|0;
   $64 = (($$04$i50) + 4|0);
   $65 = HEAP32[$output_buf>>2]|0;
   $66 = (($65) + ($$013$i51<<2)|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = HEAP32[$59>>2]|0;
   $69 = (($68) + ($$013$i51<<2)|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = HEAP32[$60>>2]|0;
   $72 = (($71) + ($$013$i51<<2)|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = (($$013$i51) + 1)|0;
   if (!($61)) {
    $75 = HEAP32[$$04$i50>>2]|0;
    $col$02$i54 = 0;$inptr$01$i55 = $75;
    while(1) {
     $76 = (($inptr$01$i55) + 2|0);
     $77 = HEAP8[$76>>0]|0;
     $78 = (($67) + ($col$02$i54)|0);
     HEAP8[$78>>0] = $77;
     $79 = (($inptr$01$i55) + 1|0);
     $80 = HEAP8[$79>>0]|0;
     $81 = (($70) + ($col$02$i54)|0);
     HEAP8[$81>>0] = $80;
     $82 = HEAP8[$inptr$01$i55>>0]|0;
     $83 = (($73) + ($col$02$i54)|0);
     HEAP8[$83>>0] = $82;
     $84 = (($inptr$01$i55) + 3|0);
     $85 = (($col$02$i54) + 1)|0;
     $exitcond$i56 = ($85|0)==($cinfo$idx2$val|0);
     if ($exitcond$i56) {
      break;
     } else {
      $col$02$i54 = $85;$inptr$01$i55 = $84;
     }
    }
   }
   $63 = ($62|0)>(0);
   if ($63) {
    $$013$i51 = $74;$$04$i50 = $64;$$in$i49 = $62;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 6:  {
  $cinfo$idx = (($cinfo) + 28|0);
  $cinfo$idx$val = HEAP32[$cinfo$idx>>2]|0;
  $2 = ($num_rows|0)>(0);
  if (!($2)) {
   STACKTOP = sp;return;
  }
  $3 = (($output_buf) + 4|0);
  $4 = (($output_buf) + 8|0);
  $5 = ($cinfo$idx$val|0)==(0);
  $$013$i = $output_row;$$04$i = $input_buf;$$in$i = $num_rows;
  while(1) {
   $6 = (($$in$i) + -1)|0;
   $8 = (($$04$i) + 4|0);
   $9 = HEAP32[$output_buf>>2]|0;
   $10 = (($9) + ($$013$i<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$3>>2]|0;
   $13 = (($12) + ($$013$i<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = HEAP32[$4>>2]|0;
   $16 = (($15) + ($$013$i<<2)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($$013$i) + 1)|0;
   if (!($5)) {
    $19 = HEAP32[$$04$i>>2]|0;
    $col$02$i = 0;$inptr$01$i = $19;
    while(1) {
     $20 = HEAP8[$inptr$01$i>>0]|0;
     $21 = (($11) + ($col$02$i)|0);
     HEAP8[$21>>0] = $20;
     $22 = (($inptr$01$i) + 1|0);
     $23 = HEAP8[$22>>0]|0;
     $24 = (($14) + ($col$02$i)|0);
     HEAP8[$24>>0] = $23;
     $25 = (($inptr$01$i) + 2|0);
     $26 = HEAP8[$25>>0]|0;
     $27 = (($17) + ($col$02$i)|0);
     HEAP8[$27>>0] = $26;
     $28 = (($inptr$01$i) + 3|0);
     $29 = (($col$02$i) + 1)|0;
     $exitcond$i = ($29|0)==($cinfo$idx$val|0);
     if ($exitcond$i) {
      break;
     } else {
      $col$02$i = $29;$inptr$01$i = $28;
     }
    }
   }
   $7 = ($6|0)>(0);
   if ($7) {
    $$013$i = $18;$$04$i = $8;$$in$i = $6;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 14: case 10:  {
  $cinfo$idx4 = (($cinfo) + 28|0);
  $cinfo$idx4$val = HEAP32[$cinfo$idx4>>2]|0;
  $114 = ($num_rows|0)>(0);
  if (!($114)) {
   STACKTOP = sp;return;
  }
  $115 = (($output_buf) + 4|0);
  $116 = (($output_buf) + 8|0);
  $117 = ($cinfo$idx4$val|0)==(0);
  $$013$i31 = $output_row;$$04$i30 = $input_buf;$$in$i29 = $num_rows;
  while(1) {
   $118 = (($$in$i29) + -1)|0;
   $120 = (($$04$i30) + 4|0);
   $121 = HEAP32[$output_buf>>2]|0;
   $122 = (($121) + ($$013$i31<<2)|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = HEAP32[$115>>2]|0;
   $125 = (($124) + ($$013$i31<<2)|0);
   $126 = HEAP32[$125>>2]|0;
   $127 = HEAP32[$116>>2]|0;
   $128 = (($127) + ($$013$i31<<2)|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = (($$013$i31) + 1)|0;
   if (!($117)) {
    $131 = HEAP32[$$04$i30>>2]|0;
    $col$02$i34 = 0;$inptr$01$i35 = $131;
    while(1) {
     $132 = (($inptr$01$i35) + 3|0);
     $133 = HEAP8[$132>>0]|0;
     $134 = (($123) + ($col$02$i34)|0);
     HEAP8[$134>>0] = $133;
     $135 = (($inptr$01$i35) + 2|0);
     $136 = HEAP8[$135>>0]|0;
     $137 = (($126) + ($col$02$i34)|0);
     HEAP8[$137>>0] = $136;
     $138 = (($inptr$01$i35) + 1|0);
     $139 = HEAP8[$138>>0]|0;
     $140 = (($129) + ($col$02$i34)|0);
     HEAP8[$140>>0] = $139;
     $141 = (($inptr$01$i35) + 4|0);
     $142 = (($col$02$i34) + 1)|0;
     $exitcond$i36 = ($142|0)==($cinfo$idx4$val|0);
     if ($exitcond$i36) {
      break;
     } else {
      $col$02$i34 = $142;$inptr$01$i35 = $141;
     }
    }
   }
   $119 = ($118|0)>(0);
   if ($119) {
    $$013$i31 = $130;$$04$i30 = $120;$$in$i29 = $118;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 15: case 11:  {
  $cinfo$idx5 = (($cinfo) + 28|0);
  $cinfo$idx5$val = HEAP32[$cinfo$idx5>>2]|0;
  $143 = ($num_rows|0)>(0);
  if (!($143)) {
   STACKTOP = sp;return;
  }
  $144 = (($output_buf) + 4|0);
  $145 = (($output_buf) + 8|0);
  $146 = ($cinfo$idx5$val|0)==(0);
  $$013$i21 = $output_row;$$04$i20 = $input_buf;$$in$i19 = $num_rows;
  while(1) {
   $147 = (($$in$i19) + -1)|0;
   $149 = (($$04$i20) + 4|0);
   $150 = HEAP32[$output_buf>>2]|0;
   $151 = (($150) + ($$013$i21<<2)|0);
   $152 = HEAP32[$151>>2]|0;
   $153 = HEAP32[$144>>2]|0;
   $154 = (($153) + ($$013$i21<<2)|0);
   $155 = HEAP32[$154>>2]|0;
   $156 = HEAP32[$145>>2]|0;
   $157 = (($156) + ($$013$i21<<2)|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = (($$013$i21) + 1)|0;
   if (!($146)) {
    $160 = HEAP32[$$04$i20>>2]|0;
    $col$02$i24 = 0;$inptr$01$i25 = $160;
    while(1) {
     $161 = (($inptr$01$i25) + 1|0);
     $162 = HEAP8[$161>>0]|0;
     $163 = (($152) + ($col$02$i24)|0);
     HEAP8[$163>>0] = $162;
     $164 = (($inptr$01$i25) + 2|0);
     $165 = HEAP8[$164>>0]|0;
     $166 = (($155) + ($col$02$i24)|0);
     HEAP8[$166>>0] = $165;
     $167 = (($inptr$01$i25) + 3|0);
     $168 = HEAP8[$167>>0]|0;
     $169 = (($158) + ($col$02$i24)|0);
     HEAP8[$169>>0] = $168;
     $170 = (($inptr$01$i25) + 4|0);
     $171 = (($col$02$i24) + 1)|0;
     $exitcond$i26 = ($171|0)==($cinfo$idx5$val|0);
     if ($exitcond$i26) {
      break;
     } else {
      $col$02$i24 = $171;$inptr$01$i25 = $170;
     }
    }
   }
   $148 = ($147|0)>(0);
   if ($148) {
    $$013$i21 = $159;$$04$i20 = $149;$$in$i19 = $147;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 default: {
  $cinfo$idx6 = (($cinfo) + 28|0);
  $cinfo$idx6$val = HEAP32[$cinfo$idx6>>2]|0;
  $172 = ($num_rows|0)>(0);
  if (!($172)) {
   STACKTOP = sp;return;
  }
  $173 = (($output_buf) + 4|0);
  $174 = (($output_buf) + 8|0);
  $175 = ($cinfo$idx6$val|0)==(0);
  $$013$i11 = $output_row;$$04$i10 = $input_buf;$$in$i9 = $num_rows;
  while(1) {
   $176 = (($$in$i9) + -1)|0;
   $178 = (($$04$i10) + 4|0);
   $179 = HEAP32[$output_buf>>2]|0;
   $180 = (($179) + ($$013$i11<<2)|0);
   $181 = HEAP32[$180>>2]|0;
   $182 = HEAP32[$173>>2]|0;
   $183 = (($182) + ($$013$i11<<2)|0);
   $184 = HEAP32[$183>>2]|0;
   $185 = HEAP32[$174>>2]|0;
   $186 = (($185) + ($$013$i11<<2)|0);
   $187 = HEAP32[$186>>2]|0;
   $188 = (($$013$i11) + 1)|0;
   if (!($175)) {
    $189 = HEAP32[$$04$i10>>2]|0;
    $col$02$i14 = 0;$inptr$01$i15 = $189;
    while(1) {
     $190 = HEAP8[$inptr$01$i15>>0]|0;
     $191 = (($181) + ($col$02$i14)|0);
     HEAP8[$191>>0] = $190;
     $192 = (($inptr$01$i15) + 1|0);
     $193 = HEAP8[$192>>0]|0;
     $194 = (($184) + ($col$02$i14)|0);
     HEAP8[$194>>0] = $193;
     $195 = (($inptr$01$i15) + 2|0);
     $196 = HEAP8[$195>>0]|0;
     $197 = (($187) + ($col$02$i14)|0);
     HEAP8[$197>>0] = $196;
     $198 = (($inptr$01$i15) + 3|0);
     $199 = (($col$02$i14) + 1)|0;
     $exitcond$i16 = ($199|0)==($cinfo$idx6$val|0);
     if ($exitcond$i16) {
      break;
     } else {
      $col$02$i14 = $199;$inptr$01$i15 = $198;
     }
    }
   }
   $177 = ($176|0)>(0);
   if ($177) {
    $$013$i11 = $188;$$04$i10 = $178;$$in$i9 = $176;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 }
 }
}
function _rgb_ycc_convert($cinfo,$input_buf,$output_buf,$output_row,$num_rows) {
 $cinfo = $cinfo|0;
 $input_buf = $input_buf|0;
 $output_buf = $output_buf|0;
 $output_row = $output_row|0;
 $num_rows = $num_rows|0;
 var $$013$i = 0, $$013$i18 = 0, $$013$i28 = 0, $$013$i38 = 0, $$013$i48 = 0, $$013$i58 = 0, $$013$i68 = 0, $$04$i = 0, $$04$i17 = 0, $$04$i27 = 0, $$04$i37 = 0, $$04$i47 = 0, $$04$i57 = 0, $$04$i67 = 0, $$in$i = 0, $$in$i16 = 0, $$in$i26 = 0, $$in$i36 = 0, $$in$i46 = 0, $$in$i56 = 0;
 var $$in$i66 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0;
 var $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0;
 var $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $cinfo$idx = 0, $cinfo$idx$val = 0, $cinfo$idx1 = 0, $cinfo$idx1$val = 0, $cinfo$idx10 = 0, $cinfo$idx10$val = 0, $cinfo$idx11 = 0, $cinfo$idx11$val = 0, $cinfo$idx12 = 0, $cinfo$idx12$val = 0, $cinfo$idx13 = 0, $cinfo$idx13$val = 0, $cinfo$idx2 = 0, $cinfo$idx2$val = 0, $cinfo$idx3 = 0, $cinfo$idx3$val = 0, $cinfo$idx4 = 0, $cinfo$idx4$val = 0;
 var $cinfo$idx5 = 0, $cinfo$idx5$val = 0, $cinfo$idx6 = 0, $cinfo$idx6$val = 0, $cinfo$idx7 = 0, $cinfo$idx7$val = 0, $cinfo$idx8 = 0, $cinfo$idx8$val = 0, $cinfo$idx9 = 0, $cinfo$idx9$val = 0, $col$02$i = 0, $col$02$i21 = 0, $col$02$i31 = 0, $col$02$i41 = 0, $col$02$i51 = 0, $col$02$i61 = 0, $col$02$i71 = 0, $exitcond$i = 0, $exitcond$i23 = 0, $exitcond$i33 = 0;
 var $exitcond$i43 = 0, $exitcond$i53 = 0, $exitcond$i63 = 0, $exitcond$i73 = 0, $inptr$01$i = 0, $inptr$01$i22 = 0, $inptr$01$i32 = 0, $inptr$01$i42 = 0, $inptr$01$i52 = 0, $inptr$01$i62 = 0, $inptr$01$i72 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 switch ($1|0) {
 case 15: case 11:  {
  $cinfo$idx10 = (($cinfo) + 28|0);
  $cinfo$idx10$val = HEAP32[$cinfo$idx10>>2]|0;
  $cinfo$idx11 = (($cinfo) + 336|0);
  $cinfo$idx11$val = HEAP32[$cinfo$idx11>>2]|0;
  $358 = (($cinfo$idx11$val) + 8|0);
  $359 = HEAP32[$358>>2]|0;
  $360 = ($num_rows|0)>(0);
  if (!($360)) {
   STACKTOP = sp;return;
  }
  $361 = (($output_buf) + 4|0);
  $362 = (($output_buf) + 8|0);
  $363 = ($cinfo$idx10$val|0)==(0);
  $$013$i28 = $output_row;$$04$i27 = $input_buf;$$in$i26 = $num_rows;
  while(1) {
   $364 = (($$in$i26) + -1)|0;
   $366 = (($$04$i27) + 4|0);
   $367 = HEAP32[$output_buf>>2]|0;
   $368 = (($367) + ($$013$i28<<2)|0);
   $369 = HEAP32[$368>>2]|0;
   $370 = HEAP32[$361>>2]|0;
   $371 = (($370) + ($$013$i28<<2)|0);
   $372 = HEAP32[$371>>2]|0;
   $373 = HEAP32[$362>>2]|0;
   $374 = (($373) + ($$013$i28<<2)|0);
   $375 = HEAP32[$374>>2]|0;
   $376 = (($$013$i28) + 1)|0;
   if (!($363)) {
    $377 = HEAP32[$$04$i27>>2]|0;
    $col$02$i31 = 0;$inptr$01$i32 = $377;
    while(1) {
     $378 = (($inptr$01$i32) + 1|0);
     $379 = HEAP8[$378>>0]|0;
     $380 = $379&255;
     $381 = (($inptr$01$i32) + 2|0);
     $382 = HEAP8[$381>>0]|0;
     $383 = $382&255;
     $384 = (($inptr$01$i32) + 3|0);
     $385 = HEAP8[$384>>0]|0;
     $386 = $385&255;
     $387 = (($inptr$01$i32) + 4|0);
     $388 = (($359) + ($380<<2)|0);
     $389 = HEAP32[$388>>2]|0;
     $390 = $383 | 256;
     $391 = (($359) + ($390<<2)|0);
     $392 = HEAP32[$391>>2]|0;
     $393 = (($392) + ($389))|0;
     $394 = $386 | 512;
     $395 = (($359) + ($394<<2)|0);
     $396 = HEAP32[$395>>2]|0;
     $397 = (($393) + ($396))|0;
     $398 = $397 >>> 16;
     $399 = $398&255;
     $400 = (($369) + ($col$02$i31)|0);
     HEAP8[$400>>0] = $399;
     $401 = $380 | 768;
     $402 = (($359) + ($401<<2)|0);
     $403 = HEAP32[$402>>2]|0;
     $404 = $383 | 1024;
     $405 = (($359) + ($404<<2)|0);
     $406 = HEAP32[$405>>2]|0;
     $407 = (($406) + ($403))|0;
     $408 = $386 | 1280;
     $409 = (($359) + ($408<<2)|0);
     $410 = HEAP32[$409>>2]|0;
     $411 = (($407) + ($410))|0;
     $412 = $411 >>> 16;
     $413 = $412&255;
     $414 = (($372) + ($col$02$i31)|0);
     HEAP8[$414>>0] = $413;
     $415 = $380 | 1280;
     $416 = (($359) + ($415<<2)|0);
     $417 = HEAP32[$416>>2]|0;
     $418 = $383 | 1536;
     $419 = (($359) + ($418<<2)|0);
     $420 = HEAP32[$419>>2]|0;
     $421 = (($420) + ($417))|0;
     $422 = $386 | 1792;
     $423 = (($359) + ($422<<2)|0);
     $424 = HEAP32[$423>>2]|0;
     $425 = (($421) + ($424))|0;
     $426 = $425 >>> 16;
     $427 = $426&255;
     $428 = (($375) + ($col$02$i31)|0);
     HEAP8[$428>>0] = $427;
     $429 = (($col$02$i31) + 1)|0;
     $exitcond$i33 = ($429|0)==($cinfo$idx10$val|0);
     if ($exitcond$i33) {
      break;
     } else {
      $col$02$i31 = $429;$inptr$01$i32 = $387;
     }
    }
   }
   $365 = ($364|0)>(0);
   if ($365) {
    $$013$i28 = $376;$$04$i27 = $366;$$in$i26 = $364;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 6:  {
  $cinfo$idx = (($cinfo) + 28|0);
  $cinfo$idx$val = HEAP32[$cinfo$idx>>2]|0;
  $cinfo$idx1 = (($cinfo) + 336|0);
  $cinfo$idx1$val = HEAP32[$cinfo$idx1>>2]|0;
  $2 = (($cinfo$idx1$val) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($num_rows|0)>(0);
  if (!($4)) {
   STACKTOP = sp;return;
  }
  $5 = (($output_buf) + 4|0);
  $6 = (($output_buf) + 8|0);
  $7 = ($cinfo$idx$val|0)==(0);
  $$013$i = $output_row;$$04$i = $input_buf;$$in$i = $num_rows;
  while(1) {
   $8 = (($$in$i) + -1)|0;
   $10 = (($$04$i) + 4|0);
   $11 = HEAP32[$output_buf>>2]|0;
   $12 = (($11) + ($$013$i<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = HEAP32[$5>>2]|0;
   $15 = (($14) + ($$013$i<<2)|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$6>>2]|0;
   $18 = (($17) + ($$013$i<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($$013$i) + 1)|0;
   if (!($7)) {
    $21 = HEAP32[$$04$i>>2]|0;
    $col$02$i = 0;$inptr$01$i = $21;
    while(1) {
     $22 = HEAP8[$inptr$01$i>>0]|0;
     $23 = $22&255;
     $24 = (($inptr$01$i) + 1|0);
     $25 = HEAP8[$24>>0]|0;
     $26 = $25&255;
     $27 = (($inptr$01$i) + 2|0);
     $28 = HEAP8[$27>>0]|0;
     $29 = $28&255;
     $30 = (($inptr$01$i) + 3|0);
     $31 = (($3) + ($23<<2)|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = $26 | 256;
     $34 = (($3) + ($33<<2)|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (($35) + ($32))|0;
     $37 = $29 | 512;
     $38 = (($3) + ($37<<2)|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = (($36) + ($39))|0;
     $41 = $40 >>> 16;
     $42 = $41&255;
     $43 = (($13) + ($col$02$i)|0);
     HEAP8[$43>>0] = $42;
     $44 = $23 | 768;
     $45 = (($3) + ($44<<2)|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = $26 | 1024;
     $48 = (($3) + ($47<<2)|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = (($49) + ($46))|0;
     $51 = $29 | 1280;
     $52 = (($3) + ($51<<2)|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = (($50) + ($53))|0;
     $55 = $54 >>> 16;
     $56 = $55&255;
     $57 = (($16) + ($col$02$i)|0);
     HEAP8[$57>>0] = $56;
     $58 = $23 | 1280;
     $59 = (($3) + ($58<<2)|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = $26 | 1536;
     $62 = (($3) + ($61<<2)|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = (($63) + ($60))|0;
     $65 = $29 | 1792;
     $66 = (($3) + ($65<<2)|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = (($64) + ($67))|0;
     $69 = $68 >>> 16;
     $70 = $69&255;
     $71 = (($19) + ($col$02$i)|0);
     HEAP8[$71>>0] = $70;
     $72 = (($col$02$i) + 1)|0;
     $exitcond$i = ($72|0)==($cinfo$idx$val|0);
     if ($exitcond$i) {
      break;
     } else {
      $col$02$i = $72;$inptr$01$i = $30;
     }
    }
   }
   $9 = ($8|0)>(0);
   if ($9) {
    $$013$i = $20;$$04$i = $10;$$in$i = $8;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 12: case 7:  {
  $cinfo$idx2 = (($cinfo) + 28|0);
  $cinfo$idx2$val = HEAP32[$cinfo$idx2>>2]|0;
  $cinfo$idx3 = (($cinfo) + 336|0);
  $cinfo$idx3$val = HEAP32[$cinfo$idx3>>2]|0;
  $73 = (($cinfo$idx3$val) + 8|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = ($num_rows|0)>(0);
  if (!($75)) {
   STACKTOP = sp;return;
  }
  $76 = (($output_buf) + 4|0);
  $77 = (($output_buf) + 8|0);
  $78 = ($cinfo$idx2$val|0)==(0);
  $$013$i68 = $output_row;$$04$i67 = $input_buf;$$in$i66 = $num_rows;
  while(1) {
   $79 = (($$in$i66) + -1)|0;
   $81 = (($$04$i67) + 4|0);
   $82 = HEAP32[$output_buf>>2]|0;
   $83 = (($82) + ($$013$i68<<2)|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = HEAP32[$76>>2]|0;
   $86 = (($85) + ($$013$i68<<2)|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = HEAP32[$77>>2]|0;
   $89 = (($88) + ($$013$i68<<2)|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($$013$i68) + 1)|0;
   if (!($78)) {
    $92 = HEAP32[$$04$i67>>2]|0;
    $col$02$i71 = 0;$inptr$01$i72 = $92;
    while(1) {
     $93 = HEAP8[$inptr$01$i72>>0]|0;
     $94 = $93&255;
     $95 = (($inptr$01$i72) + 1|0);
     $96 = HEAP8[$95>>0]|0;
     $97 = $96&255;
     $98 = (($inptr$01$i72) + 2|0);
     $99 = HEAP8[$98>>0]|0;
     $100 = $99&255;
     $101 = (($inptr$01$i72) + 4|0);
     $102 = (($74) + ($94<<2)|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = $97 | 256;
     $105 = (($74) + ($104<<2)|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = (($106) + ($103))|0;
     $108 = $100 | 512;
     $109 = (($74) + ($108<<2)|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = (($107) + ($110))|0;
     $112 = $111 >>> 16;
     $113 = $112&255;
     $114 = (($84) + ($col$02$i71)|0);
     HEAP8[$114>>0] = $113;
     $115 = $94 | 768;
     $116 = (($74) + ($115<<2)|0);
     $117 = HEAP32[$116>>2]|0;
     $118 = $97 | 1024;
     $119 = (($74) + ($118<<2)|0);
     $120 = HEAP32[$119>>2]|0;
     $121 = (($120) + ($117))|0;
     $122 = $100 | 1280;
     $123 = (($74) + ($122<<2)|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = (($121) + ($124))|0;
     $126 = $125 >>> 16;
     $127 = $126&255;
     $128 = (($87) + ($col$02$i71)|0);
     HEAP8[$128>>0] = $127;
     $129 = $94 | 1280;
     $130 = (($74) + ($129<<2)|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = $97 | 1536;
     $133 = (($74) + ($132<<2)|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = (($134) + ($131))|0;
     $136 = $100 | 1792;
     $137 = (($74) + ($136<<2)|0);
     $138 = HEAP32[$137>>2]|0;
     $139 = (($135) + ($138))|0;
     $140 = $139 >>> 16;
     $141 = $140&255;
     $142 = (($90) + ($col$02$i71)|0);
     HEAP8[$142>>0] = $141;
     $143 = (($col$02$i71) + 1)|0;
     $exitcond$i73 = ($143|0)==($cinfo$idx2$val|0);
     if ($exitcond$i73) {
      break;
     } else {
      $col$02$i71 = $143;$inptr$01$i72 = $101;
     }
    }
   }
   $80 = ($79|0)>(0);
   if ($80) {
    $$013$i68 = $91;$$04$i67 = $81;$$in$i66 = $79;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 13: case 9:  {
  $cinfo$idx6 = (($cinfo) + 28|0);
  $cinfo$idx6$val = HEAP32[$cinfo$idx6>>2]|0;
  $cinfo$idx7 = (($cinfo) + 336|0);
  $cinfo$idx7$val = HEAP32[$cinfo$idx7>>2]|0;
  $215 = (($cinfo$idx7$val) + 8|0);
  $216 = HEAP32[$215>>2]|0;
  $217 = ($num_rows|0)>(0);
  if (!($217)) {
   STACKTOP = sp;return;
  }
  $218 = (($output_buf) + 4|0);
  $219 = (($output_buf) + 8|0);
  $220 = ($cinfo$idx6$val|0)==(0);
  $$013$i48 = $output_row;$$04$i47 = $input_buf;$$in$i46 = $num_rows;
  while(1) {
   $221 = (($$in$i46) + -1)|0;
   $223 = (($$04$i47) + 4|0);
   $224 = HEAP32[$output_buf>>2]|0;
   $225 = (($224) + ($$013$i48<<2)|0);
   $226 = HEAP32[$225>>2]|0;
   $227 = HEAP32[$218>>2]|0;
   $228 = (($227) + ($$013$i48<<2)|0);
   $229 = HEAP32[$228>>2]|0;
   $230 = HEAP32[$219>>2]|0;
   $231 = (($230) + ($$013$i48<<2)|0);
   $232 = HEAP32[$231>>2]|0;
   $233 = (($$013$i48) + 1)|0;
   if (!($220)) {
    $234 = HEAP32[$$04$i47>>2]|0;
    $col$02$i51 = 0;$inptr$01$i52 = $234;
    while(1) {
     $235 = (($inptr$01$i52) + 2|0);
     $236 = HEAP8[$235>>0]|0;
     $237 = $236&255;
     $238 = (($inptr$01$i52) + 1|0);
     $239 = HEAP8[$238>>0]|0;
     $240 = $239&255;
     $241 = HEAP8[$inptr$01$i52>>0]|0;
     $242 = $241&255;
     $243 = (($inptr$01$i52) + 4|0);
     $244 = (($216) + ($237<<2)|0);
     $245 = HEAP32[$244>>2]|0;
     $246 = $240 | 256;
     $247 = (($216) + ($246<<2)|0);
     $248 = HEAP32[$247>>2]|0;
     $249 = (($248) + ($245))|0;
     $250 = $242 | 512;
     $251 = (($216) + ($250<<2)|0);
     $252 = HEAP32[$251>>2]|0;
     $253 = (($249) + ($252))|0;
     $254 = $253 >>> 16;
     $255 = $254&255;
     $256 = (($226) + ($col$02$i51)|0);
     HEAP8[$256>>0] = $255;
     $257 = $237 | 768;
     $258 = (($216) + ($257<<2)|0);
     $259 = HEAP32[$258>>2]|0;
     $260 = $240 | 1024;
     $261 = (($216) + ($260<<2)|0);
     $262 = HEAP32[$261>>2]|0;
     $263 = (($262) + ($259))|0;
     $264 = $242 | 1280;
     $265 = (($216) + ($264<<2)|0);
     $266 = HEAP32[$265>>2]|0;
     $267 = (($263) + ($266))|0;
     $268 = $267 >>> 16;
     $269 = $268&255;
     $270 = (($229) + ($col$02$i51)|0);
     HEAP8[$270>>0] = $269;
     $271 = $237 | 1280;
     $272 = (($216) + ($271<<2)|0);
     $273 = HEAP32[$272>>2]|0;
     $274 = $240 | 1536;
     $275 = (($216) + ($274<<2)|0);
     $276 = HEAP32[$275>>2]|0;
     $277 = (($276) + ($273))|0;
     $278 = $242 | 1792;
     $279 = (($216) + ($278<<2)|0);
     $280 = HEAP32[$279>>2]|0;
     $281 = (($277) + ($280))|0;
     $282 = $281 >>> 16;
     $283 = $282&255;
     $284 = (($232) + ($col$02$i51)|0);
     HEAP8[$284>>0] = $283;
     $285 = (($col$02$i51) + 1)|0;
     $exitcond$i53 = ($285|0)==($cinfo$idx6$val|0);
     if ($exitcond$i53) {
      break;
     } else {
      $col$02$i51 = $285;$inptr$01$i52 = $243;
     }
    }
   }
   $222 = ($221|0)>(0);
   if ($222) {
    $$013$i48 = $233;$$04$i47 = $223;$$in$i46 = $221;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 8:  {
  $cinfo$idx4 = (($cinfo) + 28|0);
  $cinfo$idx4$val = HEAP32[$cinfo$idx4>>2]|0;
  $cinfo$idx5 = (($cinfo) + 336|0);
  $cinfo$idx5$val = HEAP32[$cinfo$idx5>>2]|0;
  $144 = (($cinfo$idx5$val) + 8|0);
  $145 = HEAP32[$144>>2]|0;
  $146 = ($num_rows|0)>(0);
  if (!($146)) {
   STACKTOP = sp;return;
  }
  $147 = (($output_buf) + 4|0);
  $148 = (($output_buf) + 8|0);
  $149 = ($cinfo$idx4$val|0)==(0);
  $$013$i58 = $output_row;$$04$i57 = $input_buf;$$in$i56 = $num_rows;
  while(1) {
   $150 = (($$in$i56) + -1)|0;
   $152 = (($$04$i57) + 4|0);
   $153 = HEAP32[$output_buf>>2]|0;
   $154 = (($153) + ($$013$i58<<2)|0);
   $155 = HEAP32[$154>>2]|0;
   $156 = HEAP32[$147>>2]|0;
   $157 = (($156) + ($$013$i58<<2)|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = HEAP32[$148>>2]|0;
   $160 = (($159) + ($$013$i58<<2)|0);
   $161 = HEAP32[$160>>2]|0;
   $162 = (($$013$i58) + 1)|0;
   if (!($149)) {
    $163 = HEAP32[$$04$i57>>2]|0;
    $col$02$i61 = 0;$inptr$01$i62 = $163;
    while(1) {
     $164 = (($inptr$01$i62) + 2|0);
     $165 = HEAP8[$164>>0]|0;
     $166 = $165&255;
     $167 = (($inptr$01$i62) + 1|0);
     $168 = HEAP8[$167>>0]|0;
     $169 = $168&255;
     $170 = HEAP8[$inptr$01$i62>>0]|0;
     $171 = $170&255;
     $172 = (($inptr$01$i62) + 3|0);
     $173 = (($145) + ($166<<2)|0);
     $174 = HEAP32[$173>>2]|0;
     $175 = $169 | 256;
     $176 = (($145) + ($175<<2)|0);
     $177 = HEAP32[$176>>2]|0;
     $178 = (($177) + ($174))|0;
     $179 = $171 | 512;
     $180 = (($145) + ($179<<2)|0);
     $181 = HEAP32[$180>>2]|0;
     $182 = (($178) + ($181))|0;
     $183 = $182 >>> 16;
     $184 = $183&255;
     $185 = (($155) + ($col$02$i61)|0);
     HEAP8[$185>>0] = $184;
     $186 = $166 | 768;
     $187 = (($145) + ($186<<2)|0);
     $188 = HEAP32[$187>>2]|0;
     $189 = $169 | 1024;
     $190 = (($145) + ($189<<2)|0);
     $191 = HEAP32[$190>>2]|0;
     $192 = (($191) + ($188))|0;
     $193 = $171 | 1280;
     $194 = (($145) + ($193<<2)|0);
     $195 = HEAP32[$194>>2]|0;
     $196 = (($192) + ($195))|0;
     $197 = $196 >>> 16;
     $198 = $197&255;
     $199 = (($158) + ($col$02$i61)|0);
     HEAP8[$199>>0] = $198;
     $200 = $166 | 1280;
     $201 = (($145) + ($200<<2)|0);
     $202 = HEAP32[$201>>2]|0;
     $203 = $169 | 1536;
     $204 = (($145) + ($203<<2)|0);
     $205 = HEAP32[$204>>2]|0;
     $206 = (($205) + ($202))|0;
     $207 = $171 | 1792;
     $208 = (($145) + ($207<<2)|0);
     $209 = HEAP32[$208>>2]|0;
     $210 = (($206) + ($209))|0;
     $211 = $210 >>> 16;
     $212 = $211&255;
     $213 = (($161) + ($col$02$i61)|0);
     HEAP8[$213>>0] = $212;
     $214 = (($col$02$i61) + 1)|0;
     $exitcond$i63 = ($214|0)==($cinfo$idx4$val|0);
     if ($exitcond$i63) {
      break;
     } else {
      $col$02$i61 = $214;$inptr$01$i62 = $172;
     }
    }
   }
   $151 = ($150|0)>(0);
   if ($151) {
    $$013$i58 = $162;$$04$i57 = $152;$$in$i56 = $150;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 14: case 10:  {
  $cinfo$idx8 = (($cinfo) + 28|0);
  $cinfo$idx8$val = HEAP32[$cinfo$idx8>>2]|0;
  $cinfo$idx9 = (($cinfo) + 336|0);
  $cinfo$idx9$val = HEAP32[$cinfo$idx9>>2]|0;
  $286 = (($cinfo$idx9$val) + 8|0);
  $287 = HEAP32[$286>>2]|0;
  $288 = ($num_rows|0)>(0);
  if (!($288)) {
   STACKTOP = sp;return;
  }
  $289 = (($output_buf) + 4|0);
  $290 = (($output_buf) + 8|0);
  $291 = ($cinfo$idx8$val|0)==(0);
  $$013$i38 = $output_row;$$04$i37 = $input_buf;$$in$i36 = $num_rows;
  while(1) {
   $292 = (($$in$i36) + -1)|0;
   $294 = (($$04$i37) + 4|0);
   $295 = HEAP32[$output_buf>>2]|0;
   $296 = (($295) + ($$013$i38<<2)|0);
   $297 = HEAP32[$296>>2]|0;
   $298 = HEAP32[$289>>2]|0;
   $299 = (($298) + ($$013$i38<<2)|0);
   $300 = HEAP32[$299>>2]|0;
   $301 = HEAP32[$290>>2]|0;
   $302 = (($301) + ($$013$i38<<2)|0);
   $303 = HEAP32[$302>>2]|0;
   $304 = (($$013$i38) + 1)|0;
   if (!($291)) {
    $305 = HEAP32[$$04$i37>>2]|0;
    $col$02$i41 = 0;$inptr$01$i42 = $305;
    while(1) {
     $306 = (($inptr$01$i42) + 3|0);
     $307 = HEAP8[$306>>0]|0;
     $308 = $307&255;
     $309 = (($inptr$01$i42) + 2|0);
     $310 = HEAP8[$309>>0]|0;
     $311 = $310&255;
     $312 = (($inptr$01$i42) + 1|0);
     $313 = HEAP8[$312>>0]|0;
     $314 = $313&255;
     $315 = (($inptr$01$i42) + 4|0);
     $316 = (($287) + ($308<<2)|0);
     $317 = HEAP32[$316>>2]|0;
     $318 = $311 | 256;
     $319 = (($287) + ($318<<2)|0);
     $320 = HEAP32[$319>>2]|0;
     $321 = (($320) + ($317))|0;
     $322 = $314 | 512;
     $323 = (($287) + ($322<<2)|0);
     $324 = HEAP32[$323>>2]|0;
     $325 = (($321) + ($324))|0;
     $326 = $325 >>> 16;
     $327 = $326&255;
     $328 = (($297) + ($col$02$i41)|0);
     HEAP8[$328>>0] = $327;
     $329 = $308 | 768;
     $330 = (($287) + ($329<<2)|0);
     $331 = HEAP32[$330>>2]|0;
     $332 = $311 | 1024;
     $333 = (($287) + ($332<<2)|0);
     $334 = HEAP32[$333>>2]|0;
     $335 = (($334) + ($331))|0;
     $336 = $314 | 1280;
     $337 = (($287) + ($336<<2)|0);
     $338 = HEAP32[$337>>2]|0;
     $339 = (($335) + ($338))|0;
     $340 = $339 >>> 16;
     $341 = $340&255;
     $342 = (($300) + ($col$02$i41)|0);
     HEAP8[$342>>0] = $341;
     $343 = $308 | 1280;
     $344 = (($287) + ($343<<2)|0);
     $345 = HEAP32[$344>>2]|0;
     $346 = $311 | 1536;
     $347 = (($287) + ($346<<2)|0);
     $348 = HEAP32[$347>>2]|0;
     $349 = (($348) + ($345))|0;
     $350 = $314 | 1792;
     $351 = (($287) + ($350<<2)|0);
     $352 = HEAP32[$351>>2]|0;
     $353 = (($349) + ($352))|0;
     $354 = $353 >>> 16;
     $355 = $354&255;
     $356 = (($303) + ($col$02$i41)|0);
     HEAP8[$356>>0] = $355;
     $357 = (($col$02$i41) + 1)|0;
     $exitcond$i43 = ($357|0)==($cinfo$idx8$val|0);
     if ($exitcond$i43) {
      break;
     } else {
      $col$02$i41 = $357;$inptr$01$i42 = $315;
     }
    }
   }
   $293 = ($292|0)>(0);
   if ($293) {
    $$013$i38 = $304;$$04$i37 = $294;$$in$i36 = $292;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 default: {
  $cinfo$idx12 = (($cinfo) + 28|0);
  $cinfo$idx12$val = HEAP32[$cinfo$idx12>>2]|0;
  $cinfo$idx13 = (($cinfo) + 336|0);
  $cinfo$idx13$val = HEAP32[$cinfo$idx13>>2]|0;
  $430 = (($cinfo$idx13$val) + 8|0);
  $431 = HEAP32[$430>>2]|0;
  $432 = ($num_rows|0)>(0);
  if (!($432)) {
   STACKTOP = sp;return;
  }
  $433 = (($output_buf) + 4|0);
  $434 = (($output_buf) + 8|0);
  $435 = ($cinfo$idx12$val|0)==(0);
  $$013$i18 = $output_row;$$04$i17 = $input_buf;$$in$i16 = $num_rows;
  while(1) {
   $436 = (($$in$i16) + -1)|0;
   $438 = (($$04$i17) + 4|0);
   $439 = HEAP32[$output_buf>>2]|0;
   $440 = (($439) + ($$013$i18<<2)|0);
   $441 = HEAP32[$440>>2]|0;
   $442 = HEAP32[$433>>2]|0;
   $443 = (($442) + ($$013$i18<<2)|0);
   $444 = HEAP32[$443>>2]|0;
   $445 = HEAP32[$434>>2]|0;
   $446 = (($445) + ($$013$i18<<2)|0);
   $447 = HEAP32[$446>>2]|0;
   $448 = (($$013$i18) + 1)|0;
   if (!($435)) {
    $449 = HEAP32[$$04$i17>>2]|0;
    $col$02$i21 = 0;$inptr$01$i22 = $449;
    while(1) {
     $450 = HEAP8[$inptr$01$i22>>0]|0;
     $451 = $450&255;
     $452 = (($inptr$01$i22) + 1|0);
     $453 = HEAP8[$452>>0]|0;
     $454 = $453&255;
     $455 = (($inptr$01$i22) + 2|0);
     $456 = HEAP8[$455>>0]|0;
     $457 = $456&255;
     $458 = (($inptr$01$i22) + 3|0);
     $459 = (($431) + ($451<<2)|0);
     $460 = HEAP32[$459>>2]|0;
     $461 = $454 | 256;
     $462 = (($431) + ($461<<2)|0);
     $463 = HEAP32[$462>>2]|0;
     $464 = (($463) + ($460))|0;
     $465 = $457 | 512;
     $466 = (($431) + ($465<<2)|0);
     $467 = HEAP32[$466>>2]|0;
     $468 = (($464) + ($467))|0;
     $469 = $468 >>> 16;
     $470 = $469&255;
     $471 = (($441) + ($col$02$i21)|0);
     HEAP8[$471>>0] = $470;
     $472 = $451 | 768;
     $473 = (($431) + ($472<<2)|0);
     $474 = HEAP32[$473>>2]|0;
     $475 = $454 | 1024;
     $476 = (($431) + ($475<<2)|0);
     $477 = HEAP32[$476>>2]|0;
     $478 = (($477) + ($474))|0;
     $479 = $457 | 1280;
     $480 = (($431) + ($479<<2)|0);
     $481 = HEAP32[$480>>2]|0;
     $482 = (($478) + ($481))|0;
     $483 = $482 >>> 16;
     $484 = $483&255;
     $485 = (($444) + ($col$02$i21)|0);
     HEAP8[$485>>0] = $484;
     $486 = $451 | 1280;
     $487 = (($431) + ($486<<2)|0);
     $488 = HEAP32[$487>>2]|0;
     $489 = $454 | 1536;
     $490 = (($431) + ($489<<2)|0);
     $491 = HEAP32[$490>>2]|0;
     $492 = (($491) + ($488))|0;
     $493 = $457 | 1792;
     $494 = (($431) + ($493<<2)|0);
     $495 = HEAP32[$494>>2]|0;
     $496 = (($492) + ($495))|0;
     $497 = $496 >>> 16;
     $498 = $497&255;
     $499 = (($447) + ($col$02$i21)|0);
     HEAP8[$499>>0] = $498;
     $500 = (($col$02$i21) + 1)|0;
     $exitcond$i23 = ($500|0)==($cinfo$idx12$val|0);
     if ($exitcond$i23) {
      break;
     } else {
      $col$02$i21 = $500;$inptr$01$i22 = $458;
     }
    }
   }
   $437 = ($436|0)>(0);
   if ($437) {
    $$013$i18 = $448;$$04$i17 = $438;$$in$i16 = $436;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 }
 }
}
function _cmyk_ycck_convert($cinfo,$input_buf,$output_buf,$output_row,$num_rows) {
 $cinfo = $cinfo|0;
 $input_buf = $input_buf|0;
 $output_buf = $output_buf|0;
 $output_row = $output_row|0;
 $num_rows = $num_rows|0;
 var $$015 = 0, $$06 = 0, $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $col$04 = 0, $exitcond = 0, $inptr$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 336|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($cinfo) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($num_rows|0)>(0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = (($output_buf) + 4|0);
 $8 = (($output_buf) + 8|0);
 $9 = (($output_buf) + 12|0);
 $10 = ($5|0)==(0);
 $$015 = $output_row;$$06 = $input_buf;$$in = $num_rows;
 while(1) {
  $11 = (($$in) + -1)|0;
  $13 = (($$06) + 4|0);
  $14 = HEAP32[$output_buf>>2]|0;
  $15 = (($14) + ($$015<<2)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$7>>2]|0;
  $18 = (($17) + ($$015<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = HEAP32[$8>>2]|0;
  $21 = (($20) + ($$015<<2)|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$9>>2]|0;
  $24 = (($23) + ($$015<<2)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($$015) + 1)|0;
  if (!($10)) {
   $27 = HEAP32[$$06>>2]|0;
   $col$04 = 0;$inptr$03 = $27;
   while(1) {
    $28 = HEAP8[$inptr$03>>0]|0;
    $29 = $28&255;
    $30 = $29 ^ 255;
    $31 = (($inptr$03) + 1|0);
    $32 = HEAP8[$31>>0]|0;
    $33 = $32&255;
    $34 = $33 ^ 255;
    $35 = (($inptr$03) + 2|0);
    $36 = HEAP8[$35>>0]|0;
    $37 = $36&255;
    $38 = $37 ^ 255;
    $39 = (($inptr$03) + 3|0);
    $40 = HEAP8[$39>>0]|0;
    $41 = (($25) + ($col$04)|0);
    HEAP8[$41>>0] = $40;
    $42 = (($inptr$03) + 4|0);
    $43 = (($3) + ($30<<2)|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = $34 | 256;
    $46 = (($3) + ($45<<2)|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($47) + ($44))|0;
    $49 = $38 | 512;
    $50 = (($3) + ($49<<2)|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($48) + ($51))|0;
    $53 = $52 >>> 16;
    $54 = $53&255;
    $55 = (($16) + ($col$04)|0);
    HEAP8[$55>>0] = $54;
    $56 = $30 | 768;
    $57 = (($3) + ($56<<2)|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = $34 | 1024;
    $60 = (($3) + ($59<<2)|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = (($61) + ($58))|0;
    $63 = $38 | 1280;
    $64 = (($3) + ($63<<2)|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = (($62) + ($65))|0;
    $67 = $66 >>> 16;
    $68 = $67&255;
    $69 = (($19) + ($col$04)|0);
    HEAP8[$69>>0] = $68;
    $70 = $30 | 1280;
    $71 = (($3) + ($70<<2)|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = $34 | 1536;
    $74 = (($3) + ($73<<2)|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = (($75) + ($72))|0;
    $77 = $38 | 1792;
    $78 = (($3) + ($77<<2)|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = (($76) + ($79))|0;
    $81 = $80 >>> 16;
    $82 = $81&255;
    $83 = (($22) + ($col$04)|0);
    HEAP8[$83>>0] = $82;
    $84 = (($col$04) + 1)|0;
    $exitcond = ($84|0)==($5|0);
    if ($exitcond) {
     break;
    } else {
     $col$04 = $84;$inptr$03 = $42;
    }
   }
  }
  $12 = ($11|0)>(0);
  if ($12) {
   $$015 = $26;$$06 = $13;$$in = $11;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _quantize_trellis($cinfo,$dctbl,$actbl,$coef_blocks,$src,$num_blocks,$qtbl,$norm_src,$norm_coef,$last_dc_val,$coef_blocks_above,$src_above) {
 $cinfo = $cinfo|0;
 $dctbl = $dctbl|0;
 $actbl = $actbl|0;
 $coef_blocks = $coef_blocks|0;
 $src = $src|0;
 $num_blocks = $num_blocks|0;
 $qtbl = $qtbl|0;
 $norm_src = $norm_src|0;
 $norm_coef = $norm_coef|0;
 $last_dc_val = $last_dc_val|0;
 $coef_blocks_above = $coef_blocks_above|0;
 $src_above = $src_above|0;
 var $$ = 0, $$$i = 0, $$13 = 0, $$op = 0, $$op$op = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre$pre = 0, $$pre138 = 0, $$pre146 = 0, $$pre147 = 0, $$pre148 = 0, $$pre150 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0.0, $123 = 0.0, $124 = 0, $125 = 0, $126 = 0, $127 = 0.0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0.0, $163 = 0.0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0.0, $185 = 0.0, $186 = 0, $187 = 0, $188 = 0, $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0, $192 = 0, $193 = 0.0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0.0, $215 = 0.0, $216 = 0, $217 = 0.0, $218 = 0.0, $219 = 0, $22 = 0, $220 = 0, $221 = 0.0, $222 = 0.0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0.0, $247 = 0.0;
 var $248 = 0.0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0.0, $283 = 0;
 var $284 = 0.0, $285 = 0.0, $286 = 0.0, $287 = 0.0, $288 = 0.0, $289 = 0.0, $29 = 0, $290 = 0.0, $291 = 0.0, $292 = 0, $293 = 0.0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0.0, $306 = 0, $307 = 0.0, $308 = 0.0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0.0, $316 = 0.0, $317 = 0, $318 = 0.0, $319 = 0.0;
 var $32 = 0, $320 = 0, $321 = 0.0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0;
 var $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0.0, $345 = 0, $346 = 0, $347 = 0.0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0.0;
 var $356 = 0.0, $357 = 0, $358 = 0.0, $359 = 0.0, $36 = 0, $360 = 0, $361 = 0.0, $362 = 0.0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0.0;
 var $374 = 0.0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0.0, $385 = 0.0, $386 = 0, $387 = 0.0, $388 = 0.0, $389 = 0, $39 = 0, $390 = 0, $391 = 0;
 var $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0.0, $4 = 0, $40 = 0, $400 = 0.0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0;
 var $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0.0, $426 = 0, $427 = 0.0;
 var $428 = 0.0, $429 = 0, $43 = 0, $430 = 0, $431 = 0.0, $432 = 0, $433 = 0.0, $434 = 0.0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0;
 var $446 = 0.0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0.0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0;
 var $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0.0, $477 = 0.0, $478 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0.0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0.0, $76 = 0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0;
 var $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $accumulated_block_cost$0 = 0, $accumulated_cost = 0, $accumulated_dc_cost = 0, $accumulated_zero_block_cost$0 = 0, $accumulated_zero_dist = 0, $best_cost$098 = 0.0, $best_cost$1 = 0.0;
 var $best_cost$2115 = 0.0, $best_cost$3 = 0.0, $best_cost$453 = 0.0, $best_cost$5 = 0.0, $best_cost_skip$096 = 0.0, $best_cost_skip$1 = 0.0, $bi$0119 = 0, $bi$1 = 0, $bi$139 = 0, $bi$141 = 0, $bi$2$lcssa = 0, $bi$233 = 0, $bi$327 = 0, $bi$416 = 0, $bits$0$lcssa = 0, $bits$069 = 0, $bits$1$lcssa = 0, $bits$160 = 0, $block_run_start$0 = 0, $brmerge = 0;
 var $candidate = 0, $candidate_bits = 0, $candidate_dist = 0, $cost7$0 = 0.0, $dc_candidate = 0, $dc_candidate_dist$0 = 0.0, $dc_cost_backtrack = 0, $dc_delta$068 = 0, $dc_delta$159 = 0, $exitcond = 0, $exitcond127 = 0, $exitcond128 = 0, $exitcond129 = 0, $exitcond133 = 0, $exitcond134 = 0, $exitcond135 = 0, $exp2 = 0.0, $exp27 = 0.0, $exp28 = 0.0, $i$0126 = 0;
 var $i$1024 = 0, $i$1120 = 0, $i$1215 = 0, $i$2123 = 0, $i$358 = 0, $i$491 = 0, $i$599 = 0, $i$6111 = 0, $i$7$lcssa = 0, $i$7106 = 0, $i$8116 = 0, $i$955 = 0, $indvars$iv = 0, $indvars$iv$next = 0, $ispos = 0, $ispos1 = 0, $ispos3 = 0, $ispos5 = 0, $j$085 = 0, $j$129 = 0;
 var $j$2$lcssa = 0, $j$219 = 0, $j$3 = 0, $j$417 = 0, $k$075 = 0, $k$176 = 0, $k$281 = 0, $l$067 = 0, $lambda$0 = 0.0, $lambda$0$in = 0.0, $lambda_table = 0, $last_block$054 = 0, $last_block$1 = 0, $last_block$240 = 0, $last_block$240$in = 0, $last_coeff_idx$097 = 0, $last_coeff_idx$1 = 0, $last_coeff_idx$2110 = 0, $neg = 0, $neg2 = 0;
 var $neg4 = 0, $neg6 = 0, $norm$157 = 0.0, $or$cond = 0, $or$cond10 = 0, $or$cond11 = 0, $or$cond12 = 0, $or$cond9 = 0, $phitmp155 = 0, $requires_eob$0 = 0, $run_start = 0, $sext = 0, $sext151 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1328|0;
 $accumulated_zero_dist = sp + 1072|0;
 $accumulated_cost = sp + 816|0;
 $run_start = sp + 560|0;
 $accumulated_dc_cost = sp + 520|0;
 $dc_cost_backtrack = sp + 484|0;
 $dc_candidate = sp + 448|0;
 $lambda_table = sp + 192|0;
 $candidate = sp + 128|0;
 $candidate_bits = sp + 64|0;
 $candidate_dist = sp;
 $0 = (($cinfo) + 316|0);
 $1 = HEAP16[$qtbl>>1]|0;
 $2 = $1&65535;
 $3 = (60 / ($2>>>0))&-1;
 $4 = (($3) + 2)|0;
 $5 = $4 | 1;
 $6 = ($5>>>0)>(9);
 $$$i = $6 ? 9 : $5;
 $7 = (($cinfo) + 300|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($cinfo) + 304|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==(0);
 $$ = $11 ? 1 : $8;
 $12 = ($10|0)<($$|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = HEAP32[$0>>2]|0;
 $14 = (($13) + 17|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  $31 = $13;$accumulated_block_cost$0 = 0;$accumulated_zero_block_cost$0 = 0;$block_run_start$0 = 0;$requires_eob$0 = 0;
 } else {
  $17 = $num_blocks << 2;
  $18 = (($17) + 4)|0;
  $19 = (_malloc($18)|0);
  $20 = (_malloc($18)|0);
  $21 = (_malloc($17)|0);
  $22 = (_malloc($18)|0);
  $23 = ($19|0)==(0|0);
  $24 = ($20|0)==(0|0);
  $or$cond = $23 | $24;
  $25 = ($21|0)==(0|0);
  $or$cond9 = $or$cond | $25;
  $26 = ($22|0)==(0|0);
  $or$cond10 = $or$cond9 | $26;
  if ($or$cond10) {
   $27 = HEAP32[$cinfo>>2]|0;
   $28 = (($27) + 20|0);
   HEAP32[$28>>2] = 54;
   $29 = HEAP32[$27>>2]|0;
   FUNCTION_TABLE_vi[$29 & 63]($cinfo);
   $$pre$pre = HEAP32[$0>>2]|0;
   $$pre = $$pre$pre;
  } else {
   $$pre = $13;
  }
  HEAPF32[$19>>2] = 0.0;
  HEAPF32[$20>>2] = 0.0;
  HEAP32[$22>>2] = 0;
  $31 = $$pre;$accumulated_block_cost$0 = $20;$accumulated_zero_block_cost$0 = $19;$block_run_start$0 = $21;$requires_eob$0 = $22;
 }
 $30 = (($31) + 16|0);
 $32 = HEAP8[$30>>0]|0;
 $33 = ($32<<24>>24)==(0);
 if ($33) {
  $i$2123 = 0;
 } else {
  $34 = $num_blocks << 2;
  $35 = $num_blocks << 1;
  $i$0126 = 0;
  while(1) {
   $36 = (_malloc($34)|0);
   $37 = (($accumulated_dc_cost) + ($i$0126<<2)|0);
   HEAP32[$37>>2] = $36;
   $38 = (_malloc($34)|0);
   $39 = (($dc_cost_backtrack) + ($i$0126<<2)|0);
   HEAP32[$39>>2] = $38;
   $40 = (_malloc($35)|0);
   $41 = (($dc_candidate) + ($i$0126<<2)|0);
   HEAP32[$41>>2] = $40;
   $42 = ($36|0)==(0|0);
   if ($42) {
    label = 10;
   } else {
    $43 = ($38|0)==(0|0);
    $44 = ($40|0)==(0|0);
    $or$cond11 = $43 | $44;
    if ($or$cond11) {
     label = 10;
    }
   }
   if ((label|0) == 10) {
    label = 0;
    $45 = HEAP32[$cinfo>>2]|0;
    $46 = (($45) + 20|0);
    HEAP32[$46>>2] = 54;
    $47 = HEAP32[$45>>2]|0;
    FUNCTION_TABLE_vi[$47 & 63]($cinfo);
   }
   $48 = (($i$0126) + 1)|0;
   $49 = ($48|0)<($$$i|0);
   if ($49) {
    $i$0126 = $48;
   } else {
    $i$2123 = 0;
    break;
   }
  }
 }
 while(1) {
  $61 = (($qtbl) + ($i$2123<<1)|0);
  $62 = HEAP16[$61>>1]|0;
  $63 = $62&65535;
  $64 = Math_imul($63, $63)|0;
  $65 = (+($64|0));
  $66 = 1.0 / $65;
  $67 = $66;
  $68 = (($lambda_table) + ($i$2123<<2)|0);
  HEAPF32[$68>>2] = $67;
  $69 = (($i$2123) + 1)|0;
  $exitcond135 = ($69|0)==(64);
  if ($exitcond135) {
   break;
  } else {
   $i$2123 = $69;
  }
 }
 $50 = ($num_blocks|0)==(0);
 if ($50) {
  $$pre146 = HEAP32[$0>>2]|0;
  $$phi$trans$insert = (($$pre146) + 17|0);
  $$pre147 = HEAP8[$$phi$trans$insert>>0]|0;
  $377 = $$pre147;$475 = $$pre146;
 } else {
  $51 = +HEAPF32[$lambda_table>>2];
  $52 = (($$) + -1)|0;
  $53 = (($accumulated_zero_dist) + ($52<<2)|0);
  $54 = (($accumulated_cost) + ($52<<2)|0);
  $55 = $$$i >>> 1;
  $56 = ($coef_blocks_above|0)==(0|0);
  $57 = ($src_above|0)==(0|0);
  $or$cond12 = $56 | $57;
  $58 = (($accumulated_zero_dist) + ($10<<2)|0);
  $59 = (($actbl) + 1024|0);
  $60 = (($actbl) + 1264|0);
  $bi$0119 = 0;$indvars$iv = 1;
  while(1) {
   $i$358 = 1;$norm$157 = 0.0;
   while(1) {
    $70 = ((($src) + ($bi$0119<<7)|0) + ($i$358<<1)|0);
    $71 = HEAP16[$70>>1]|0;
    $72 = $71 << 16 >> 16;
    $73 = Math_imul($72, $72)|0;
    $74 = (+($73|0));
    $75 = $norm$157 + $74;
    $76 = (($i$358) + 1)|0;
    $exitcond129 = ($76|0)==(64);
    if ($exitcond129) {
     break;
    } else {
     $i$358 = $76;$norm$157 = $75;
    }
   }
   $77 = HEAP32[$0>>2]|0;
   $78 = (($77) + 4168|0);
   $79 = +HEAPF32[$78>>2];
   $80 = $79 > 0.0;
   $81 = (($77) + 4164|0);
   $82 = +HEAPF32[$81>>2];
   $83 = $82;
   if ($80) {
    $84 = $79;
    $85 = $75 / 63.0;
    $exp27 = (+_exp2((+$83)));
    $exp28 = (+_exp2((+$84)));
    $86 = $85;
    $87 = $86 + $exp28;
    $88 = $exp27 / $87;
    $lambda$0$in = $88;
   } else {
    $89 = $83 + -12.0;
    $exp2 = (+_exp2((+$89)));
    $lambda$0$in = $exp2;
   }
   $lambda$0 = $lambda$0$in;
   $90 = $lambda$0 * $51;
   HEAPF32[$53>>2] = 0.0;
   HEAPF32[$54>>2] = 0.0;
   $91 = (($77) + 16|0);
   $92 = HEAP8[$91>>0]|0;
   $93 = ($92<<24>>24)==(0);
   if ($93) {
    $222 = 0.0;$i$491 = $$;
   } else {
    $94 = (($src) + ($bi$0119<<7)|0);
    $95 = HEAP16[$94>>1]|0;
    $96 = $95 << 16 >> 16;
    $ispos1 = ($95<<16>>16)>(-1);
    $neg2 = (0 - ($96))|0;
    $97 = $ispos1 ? $96 : $neg2;
    $98 = HEAP16[$qtbl>>1]|0;
    $99 = $98&65535;
    $100 = $99 << 3;
    $101 = $99 << 2;
    $102 = (($101) + ($97))|0;
    $103 = (($102|0) / ($100|0))&-1;
    $104 = (($103) - ($55))|0;
    $105 = $96 >> 30;
    $106 = $105 | 1;
    $107 = ($bi$0119|0)==(0);
    $108 = (($bi$0119) + -1)|0;
    $109 = (($src_above) + ($bi$0119<<7)|0);
    $110 = (($coef_blocks_above) + ($bi$0119<<7)|0);
    $k$075 = 0;
    while(1) {
     $111 = (($104) + ($k$075))|0;
     $112 = $111&65535;
     $113 = (($dc_candidate) + ($k$075<<2)|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = (($114) + ($bi$0119<<1)|0);
     $116 = ($112<<16>>16)>(1023);
     if ($116) {
      $119 = 1023;
     } else {
      $117 = ($112<<16>>16)<(-1023);
      $$op = $111 << 16;
      $$op$op = $$op >> 16;
      $phitmp155 = $117 ? -1023 : $$op$op;
      $119 = $phitmp155;
     }
     $118 = Math_imul($119, $100)|0;
     $120 = (($118) - ($97))|0;
     $121 = Math_imul($120, $120)|0;
     $122 = (+($121|0));
     $123 = $90 * $122;
     $124 = Math_imul($119, $106)|0;
     $125 = $124&65535;
     HEAP16[$115>>1] = $125;
     if ($or$cond12) {
      $dc_candidate_dist$0 = $123;
     } else {
      $126 = (($77) + 4172|0);
      $127 = +HEAPF32[$126>>2];
      $128 = $127 > 0.0;
      if ($128) {
       $129 = HEAP16[$109>>1]|0;
       $130 = $129 << 16 >> 16;
       $131 = HEAP16[$110>>1]|0;
       $132 = $131 << 16 >> 16;
       $133 = HEAP16[$94>>1]|0;
       $134 = $133 << 16 >> 16;
       $sext151 = $124 << 16;
       $135 = $sext151 >> 16;
       $136 = (($130) - ($134))|0;
       $137 = (($132) - ($135))|0;
       $138 = Math_imul($137, $100)|0;
       $139 = (($136) - ($138))|0;
       $140 = Math_imul($139, $139)|0;
       $141 = (+($140|0));
       $142 = $90 * $141;
       $143 = $142 - $123;
       $144 = $127 * $143;
       $145 = $123 + $144;
       $dc_candidate_dist$0 = $145;
      } else {
       $dc_candidate_dist$0 = $123;
      }
     }
     if ($107) {
      $148 = HEAP16[$114>>1]|0;
      $149 = $148 << 16 >> 16;
      $150 = HEAP16[$last_dc_val>>1]|0;
      $151 = $150 << 16 >> 16;
      $152 = (($149) - ($151))|0;
      $ispos5 = ($152|0)>(-1);
      $neg6 = (0 - ($152))|0;
      $153 = $ispos5 ? $152 : $neg6;
      $154 = ($153|0)==(0);
      if ($154) {
       $bits$0$lcssa = 0;
      } else {
       $bits$069 = 0;$dc_delta$068 = $153;
       while(1) {
        $155 = $dc_delta$068 >> 1;
        $156 = (($bits$069) + 1)|0;
        $157 = ($155|0)==(0);
        if ($157) {
         $bits$0$lcssa = $156;
         break;
        } else {
         $bits$069 = $156;$dc_delta$068 = $155;
        }
       }
      }
      $158 = ((($dctbl) + ($bits$0$lcssa)|0) + 1024|0);
      $159 = HEAP8[$158>>0]|0;
      $160 = $159 << 24 >> 24;
      $161 = (($160) + ($bits$0$lcssa))|0;
      $162 = (+($161|0));
      $163 = $dc_candidate_dist$0 + $162;
      $164 = (($accumulated_dc_cost) + ($k$075<<2)|0);
      $165 = HEAP32[$164>>2]|0;
      HEAPF32[$165>>2] = $163;
      $166 = (($dc_cost_backtrack) + ($k$075<<2)|0);
      $167 = HEAP32[$166>>2]|0;
      HEAP32[$167>>2] = -1;
     } else {
      $146 = (($accumulated_dc_cost) + ($k$075<<2)|0);
      $147 = (($dc_cost_backtrack) + ($k$075<<2)|0);
      $l$067 = 0;
      while(1) {
       $sext = $124 << 16;
       $168 = $sext >> 16;
       $169 = (($dc_candidate) + ($l$067<<2)|0);
       $170 = HEAP32[$169>>2]|0;
       $171 = (($170) + ($108<<1)|0);
       $172 = HEAP16[$171>>1]|0;
       $173 = $172 << 16 >> 16;
       $174 = (($168) - ($173))|0;
       $ispos3 = ($174|0)>(-1);
       $neg4 = (0 - ($174))|0;
       $175 = $ispos3 ? $174 : $neg4;
       $176 = ($175|0)==(0);
       if ($176) {
        $bits$1$lcssa = 0;
       } else {
        $bits$160 = 0;$dc_delta$159 = $175;
        while(1) {
         $177 = $dc_delta$159 >> 1;
         $178 = (($bits$160) + 1)|0;
         $179 = ($177|0)==(0);
         if ($179) {
          $bits$1$lcssa = $178;
          break;
         } else {
          $bits$160 = $178;$dc_delta$159 = $177;
         }
        }
       }
       $180 = ((($dctbl) + ($bits$1$lcssa)|0) + 1024|0);
       $181 = HEAP8[$180>>0]|0;
       $182 = $181 << 24 >> 24;
       $183 = (($182) + ($bits$1$lcssa))|0;
       $184 = (+($183|0));
       $185 = $dc_candidate_dist$0 + $184;
       $186 = (($accumulated_dc_cost) + ($l$067<<2)|0);
       $187 = HEAP32[$186>>2]|0;
       $188 = (($187) + ($108<<2)|0);
       $189 = +HEAPF32[$188>>2];
       $190 = $189 + $185;
       $191 = ($l$067|0)==(0);
       $$pre148 = HEAP32[$146>>2]|0;
       if ($191) {
        label = 37;
       } else {
        $192 = (($$pre148) + ($bi$0119<<2)|0);
        $193 = +HEAPF32[$192>>2];
        $194 = $190 < $193;
        if ($194) {
         label = 37;
        }
       }
       if ((label|0) == 37) {
        label = 0;
        $195 = (($$pre148) + ($bi$0119<<2)|0);
        HEAPF32[$195>>2] = $190;
        $196 = HEAP32[$147>>2]|0;
        $197 = (($196) + ($bi$0119<<2)|0);
        HEAP32[$197>>2] = $l$067;
       }
       $198 = (($l$067) + 1)|0;
       $199 = ($198|0)<($$$i|0);
       if ($199) {
        $l$067 = $198;
       } else {
        break;
       }
      }
     }
     $200 = (($k$075) + 1)|0;
     $201 = ($200|0)<($$$i|0);
     if ($201) {
      $k$075 = $200;
     } else {
      $222 = 0.0;$i$491 = $$;
      break;
     }
    }
   }
   while(1) {
    $202 = (142704 + ($i$491<<2)|0);
    $203 = HEAP32[$202>>2]|0;
    $204 = ((($src) + ($bi$0119<<7)|0) + ($203<<1)|0);
    $205 = HEAP16[$204>>1]|0;
    $206 = $205 << 16 >> 16;
    $207 = $206 >> 31;
    $ispos = ($205<<16>>16)>(-1);
    $neg = (0 - ($206))|0;
    $208 = $ispos ? $206 : $neg;
    $209 = (($qtbl) + ($203<<1)|0);
    $210 = HEAP16[$209>>1]|0;
    $211 = $210&65535;
    $212 = $211 << 3;
    $213 = Math_imul($208, $208)|0;
    $214 = (+($213|0));
    $215 = $lambda$0 * $214;
    $216 = (($lambda_table) + ($203<<2)|0);
    $217 = +HEAPF32[$216>>2];
    $218 = $215 * $217;
    $219 = (($i$491) + -1)|0;
    $220 = (($accumulated_zero_dist) + ($219<<2)|0);
    $221 = $218 + $222;
    $223 = (($accumulated_zero_dist) + ($i$491<<2)|0);
    HEAPF32[$223>>2] = $221;
    $224 = $211 << 2;
    $225 = (($224) + ($208))|0;
    $226 = (($225|0) / ($212|0))&-1;
    $227 = ($226|0)==(0);
    if ($227) {
     $228 = ((($coef_blocks) + ($bi$0119<<7)|0) + ($203<<1)|0);
     HEAP16[$228>>1] = 0;
     $229 = (($accumulated_cost) + ($i$491<<2)|0);
     HEAPF32[$229>>2] = 9.9999996802856924E+37;
    } else {
     $230 = ($226|0)>(1023);
     $$13 = $230 ? 1023 : $226;
     $231 = (536 + ($$13)|0);
     $232 = HEAP8[$231>>0]|0;
     $233 = $232&255;
     $234 = ($232<<24>>24)==(0);
     if (!($234)) {
      $235 = (($233) + -1)|0;
      $k$176 = 0;
      while(1) {
       $236 = ($k$176|0)<($235|0);
       if ($236) {
        $237 = 2 << $k$176;
        $238 = (($237) + -1)|0;
        $240 = $238;
       } else {
        $240 = $$13;
       }
       $239 = (($candidate) + ($k$176<<2)|0);
       HEAP32[$239>>2] = $240;
       $241 = Math_imul($240, $212)|0;
       $242 = (($241) - ($208))|0;
       $243 = (($k$176) + 1)|0;
       $244 = (($candidate_bits) + ($k$176<<2)|0);
       HEAP32[$244>>2] = $243;
       $245 = Math_imul($242, $242)|0;
       $246 = (+($245|0));
       $247 = $lambda$0 * $246;
       $248 = $217 * $247;
       $249 = (($candidate_dist) + ($k$176<<2)|0);
       HEAPF32[$249>>2] = $248;
       $250 = ($243|0)<($233|0);
       if ($250) {
        $k$176 = $243;
       } else {
        break;
       }
      }
     }
     $251 = (($accumulated_cost) + ($i$491<<2)|0);
     HEAPF32[$251>>2] = 9.9999996802856924E+37;
     $252 = ($$|0)>($i$491|0);
     if (!($252)) {
      $253 = ((($coef_blocks) + ($bi$0119<<7)|0) + ($203<<1)|0);
      $254 = (($run_start) + ($i$491<<2)|0);
      $476 = 9.9999996802856924E+37;$j$085 = $52;
      while(1) {
       $255 = ($j$085|0)==($52|0);
       if ($255) {
        label = 51;
       } else {
        $256 = (142704 + ($j$085<<2)|0);
        $257 = HEAP32[$256>>2]|0;
        $258 = ((($coef_blocks) + ($bi$0119<<7)|0) + ($257<<1)|0);
        $259 = HEAP16[$258>>1]|0;
        $260 = ($259<<16>>16)==(0);
        if ($260) {
         $477 = $476;
        } else {
         label = 51;
        }
       }
       do {
        if ((label|0) == 51) {
         label = 0;
         $261 = (($219) - ($j$085))|0;
         $262 = $261 >> 4;
         $263 = ($262|0)==(0);
         if (!($263)) {
          $264 = HEAP8[$60>>0]|0;
          $265 = ($264<<24>>24)==(0);
          if ($265) {
           $477 = $476;
           break;
          }
         }
         $266 = HEAP8[$60>>0]|0;
         $267 = $266 << 24 >> 24;
         $268 = Math_imul($267, $262)|0;
         if ($234) {
          $477 = $476;
         } else {
          $269 = $261 << 4;
          $270 = $269 & 240;
          $271 = (($accumulated_zero_dist) + ($j$085<<2)|0);
          $272 = (($accumulated_cost) + ($j$085<<2)|0);
          $293 = $476;$k$281 = 0;
          while(1) {
           $273 = (($candidate_bits) + ($k$281<<2)|0);
           $274 = HEAP32[$273>>2]|0;
           $275 = (($274) + ($270))|0;
           $276 = ((($actbl) + ($275)|0) + 1024|0);
           $277 = HEAP8[$276>>0]|0;
           $278 = ($277<<24>>24)==(0);
           do {
            if ($278) {
             $478 = $293;
            } else {
             $279 = $277 << 24 >> 24;
             $280 = (($274) + ($268))|0;
             $281 = (($280) + ($279))|0;
             $282 = (+($281|0));
             $283 = (($candidate_dist) + ($k$281<<2)|0);
             $284 = +HEAPF32[$283>>2];
             $285 = $282 + $284;
             $286 = +HEAPF32[$220>>2];
             $287 = +HEAPF32[$271>>2];
             $288 = $286 - $287;
             $289 = +HEAPF32[$272>>2];
             $290 = $288 + $289;
             $291 = $285 + $290;
             $292 = $291 < $293;
             if (!($292)) {
              $478 = $293;
              break;
             }
             $294 = (($candidate) + ($k$281<<2)|0);
             $295 = HEAP32[$294>>2]|0;
             $296 = $295 ^ $207;
             $297 = (($296) - ($207))|0;
             $298 = $297&65535;
             HEAP16[$253>>1] = $298;
             HEAPF32[$251>>2] = $291;
             HEAP32[$254>>2] = $j$085;
             $478 = $291;
            }
           } while(0);
           $299 = (($k$281) + 1)|0;
           $300 = ($299|0)<($233|0);
           if ($300) {
            $293 = $478;$k$281 = $299;
           } else {
            $477 = $478;
            break;
           }
          }
         }
        }
       } while(0);
       $301 = (($j$085) + 1)|0;
       $302 = ($301|0)<($i$491|0);
       if ($302) {
        $476 = $477;$j$085 = $301;
       } else {
        break;
       }
      }
     }
    }
    $303 = (($i$491) + 1)|0;
    $304 = ($i$491|0)<($10|0);
    if ($304) {
     $222 = $221;$i$491 = $303;
    } else {
     break;
    }
   }
   $305 = +HEAPF32[$58>>2];
   $306 = HEAP8[$59>>0]|0;
   $307 = (+($306<<24>>24));
   $308 = $305 + $307;
   $best_cost$098 = $308;$best_cost_skip$096 = $305;$i$599 = $$;$last_coeff_idx$097 = $52;
   while(1) {
    $309 = (142704 + ($i$599<<2)|0);
    $310 = HEAP32[$309>>2]|0;
    $311 = ((($coef_blocks) + ($bi$0119<<7)|0) + ($310<<1)|0);
    $312 = HEAP16[$311>>1]|0;
    $313 = ($312<<16>>16)==(0);
    if ($313) {
     $best_cost$1 = $best_cost$098;$best_cost_skip$1 = $best_cost_skip$096;$last_coeff_idx$1 = $last_coeff_idx$097;
    } else {
     $314 = (($accumulated_cost) + ($i$599<<2)|0);
     $315 = +HEAPF32[$314>>2];
     $316 = $315 + $305;
     $317 = (($accumulated_zero_dist) + ($i$599<<2)|0);
     $318 = +HEAPF32[$317>>2];
     $319 = $316 - $318;
     $320 = ($i$599|0)<($10|0);
     if ($320) {
      $321 = $319 + $307;
      $cost7$0 = $321;
     } else {
      $cost7$0 = $319;
     }
     $322 = $cost7$0 < $best_cost$098;
     if ($322) {
      $best_cost$1 = $cost7$0;$best_cost_skip$1 = $319;$last_coeff_idx$1 = $i$599;
     } else {
      $best_cost$1 = $best_cost$098;$best_cost_skip$1 = $best_cost_skip$096;$last_coeff_idx$1 = $last_coeff_idx$097;
     }
    }
    $323 = (($i$599) + 1)|0;
    $324 = ($i$599|0)<($10|0);
    if ($324) {
     $best_cost$098 = $best_cost$1;$best_cost_skip$096 = $best_cost_skip$1;$i$599 = $323;$last_coeff_idx$097 = $last_coeff_idx$1;
    } else {
     break;
    }
   }
   $325 = ($last_coeff_idx$1|0)<($10|0);
   $326 = $325&1;
   $327 = ($last_coeff_idx$1|0)==($52|0);
   $328 = $327&1;
   $329 = (($326) + ($328))|0;
   $i$6111 = $10;$last_coeff_idx$2110 = $last_coeff_idx$1;
   while(1) {
    $330 = ($i$6111|0)>($last_coeff_idx$2110|0);
    if ($330) {
     $i$7106 = $i$6111;
     while(1) {
      $331 = (142704 + ($i$7106<<2)|0);
      $332 = HEAP32[$331>>2]|0;
      $333 = ((($coef_blocks) + ($bi$0119<<7)|0) + ($332<<1)|0);
      HEAP16[$333>>1] = 0;
      $334 = (($i$7106) + -1)|0;
      $335 = ($334|0)>($last_coeff_idx$2110|0);
      if ($335) {
       $i$7106 = $334;
      } else {
       $i$7$lcssa = $last_coeff_idx$2110;
       break;
      }
     }
    } else {
     $i$7$lcssa = $i$6111;
    }
    $336 = (($run_start) + ($i$7$lcssa<<2)|0);
    $337 = HEAP32[$336>>2]|0;
    $338 = (($i$7$lcssa) + -1)|0;
    $339 = ($i$7$lcssa|0)>($$|0);
    if ($339) {
     $i$6111 = $338;$last_coeff_idx$2110 = $337;
    } else {
     break;
    }
   }
   $340 = (($77) + 17|0);
   $341 = HEAP8[$340>>0]|0;
   $342 = ($341<<24>>24)==(0);
   if ($342) {
    $$pre150 = (($bi$0119) + 1)|0;
    $$pre$phiZ2D = $$pre150;
   } else {
    $343 = (($accumulated_zero_block_cost$0) + ($bi$0119<<2)|0);
    $344 = +HEAPF32[$343>>2];
    $345 = (($bi$0119) + 1)|0;
    $346 = (($accumulated_zero_block_cost$0) + ($345<<2)|0);
    $347 = $305 + $344;
    HEAPF32[$346>>2] = $347;
    $348 = (($requires_eob$0) + ($345<<2)|0);
    HEAP32[$348>>2] = $329;
    $349 = ($329|0)==(2);
    if ($349) {
     $$pre$phiZ2D = $345;
    } else {
     $350 = (($block_run_start$0) + ($bi$0119<<2)|0);
     $351 = (($accumulated_block_cost$0) + ($345<<2)|0);
     $best_cost$2115 = 9.9999996802856924E+37;$i$8116 = 0;
     while(1) {
      $352 = (($requires_eob$0) + ($i$8116<<2)|0);
      $353 = HEAP32[$352>>2]|0;
      $354 = ($353|0)==(2);
      if ($354) {
       $best_cost$3 = $best_cost$2115;
      } else {
       $355 = +HEAPF32[$343>>2];
       $356 = $best_cost_skip$1 + $355;
       $357 = (($accumulated_zero_block_cost$0) + ($i$8116<<2)|0);
       $358 = +HEAPF32[$357>>2];
       $359 = $356 - $358;
       $360 = (($accumulated_block_cost$0) + ($i$8116<<2)|0);
       $361 = +HEAPF32[$360>>2];
       $362 = $359 + $361;
       $363 = (($bi$0119) - ($i$8116))|0;
       $364 = (($363) + ($353))|0;
       $365 = (536 + ($364)|0);
       $366 = HEAP8[$365>>0]|0;
       $367 = $366&255;
       $368 = $367 << 4;
       $369 = ((($actbl) + ($368)|0) + 1024|0);
       $370 = HEAP8[$369>>0]|0;
       $371 = $370 << 24 >> 24;
       $372 = (($371) + ($367))|0;
       $373 = (+($372|0));
       $374 = $362 + $373;
       $375 = $374 < $best_cost$2115;
       if ($375) {
        HEAP32[$350>>2] = $i$8116;
        HEAPF32[$351>>2] = $374;
        $best_cost$3 = $374;
       } else {
        $best_cost$3 = $best_cost$2115;
       }
      }
      $376 = (($i$8116) + 1)|0;
      $exitcond133 = ($376|0)==($indvars$iv|0);
      if ($exitcond133) {
       $$pre$phiZ2D = $345;
       break;
      } else {
       $best_cost$2115 = $best_cost$3;$i$8116 = $376;
      }
     }
    }
   }
   $indvars$iv$next = (($indvars$iv) + 1)|0;
   $exitcond134 = ($$pre$phiZ2D|0)==($num_blocks|0);
   if ($exitcond134) {
    $377 = $341;$475 = $77;
    break;
   } else {
    $bi$0119 = $$pre$phiZ2D;$indvars$iv = $indvars$iv$next;
   }
  }
 }
 $378 = ($377<<24>>24)==(0);
 if ($378) {
  $415 = $475;
 } else {
  $379 = (($accumulated_zero_block_cost$0) + ($num_blocks<<2)|0);
  $best_cost$453 = 9.9999996802856924E+37;$i$955 = 0;$last_block$054 = $num_blocks;
  while(1) {
   $381 = (($requires_eob$0) + ($i$955<<2)|0);
   $382 = HEAP32[$381>>2]|0;
   $383 = ($382|0)==(2);
   if ($383) {
    $best_cost$5 = $best_cost$453;$last_block$1 = $last_block$054;
   } else {
    $384 = +HEAPF32[$379>>2];
    $385 = $384 + 0.0;
    $386 = (($accumulated_zero_block_cost$0) + ($i$955<<2)|0);
    $387 = +HEAPF32[$386>>2];
    $388 = $385 - $387;
    $389 = (($num_blocks) - ($i$955))|0;
    $390 = (($389) + ($382))|0;
    $391 = (536 + ($390)|0);
    $392 = HEAP8[$391>>0]|0;
    $393 = $392&255;
    $394 = $393 << 4;
    $395 = ((($actbl) + ($394)|0) + 1024|0);
    $396 = HEAP8[$395>>0]|0;
    $397 = $396 << 24 >> 24;
    $398 = (($397) + ($393))|0;
    $399 = (+($398|0));
    $400 = $388 + $399;
    $401 = $400 < $best_cost$453;
    if ($401) {
     $best_cost$5 = $400;$last_block$1 = $i$955;
    } else {
     $best_cost$5 = $best_cost$453;$last_block$1 = $last_block$054;
    }
   }
   $exitcond128 = ($i$955|0)==($num_blocks|0);
   if ($exitcond128) {
    break;
   }
   $402 = (($i$955) + 1)|0;
   $best_cost$453 = $best_cost$5;$i$955 = $402;$last_block$054 = $last_block$1;
  }
  $bi$139 = (($num_blocks) + -1)|0;
  $380 = ($bi$139|0)>(-1);
  if ($380) {
   $bi$141 = $bi$139;$last_block$240$in = $last_block$1;
   while(1) {
    $last_block$240 = (($last_block$240$in) + -1)|0;
    $403 = ($bi$141|0)>($last_block$240|0);
    if ($403) {
     $bi$233 = $bi$141;
     while(1) {
      $j$129 = $$;
      while(1) {
       $404 = (142704 + ($j$129<<2)|0);
       $405 = HEAP32[$404>>2]|0;
       $406 = ((($coef_blocks) + ($bi$233<<7)|0) + ($405<<1)|0);
       HEAP16[$406>>1] = 0;
       $407 = (($j$129) + 1)|0;
       $408 = ($j$129|0)<($10|0);
       if ($408) {
        $j$129 = $407;
       } else {
        break;
       }
      }
      $409 = (($bi$233) + -1)|0;
      $410 = ($409|0)>($last_block$240|0);
      if ($410) {
       $bi$233 = $409;
      } else {
       $bi$2$lcssa = $last_block$240;
       break;
      }
     }
    } else {
     $bi$2$lcssa = $bi$141;
    }
    $411 = (($block_run_start$0) + ($bi$2$lcssa<<2)|0);
    $412 = HEAP32[$411>>2]|0;
    $bi$1 = (($bi$2$lcssa) + -1)|0;
    $413 = ($bi$1|0)>(-1);
    if ($413) {
     $bi$141 = $bi$1;$last_block$240$in = $412;
    } else {
     break;
    }
   }
  }
  _free($accumulated_zero_block_cost$0);
  _free($accumulated_block_cost$0);
  _free($block_run_start$0);
  _free($requires_eob$0);
  $$pre138 = HEAP32[$0>>2]|0;
  $415 = $$pre138;
 }
 $414 = (($415) + 21|0);
 $416 = HEAP8[$414>>0]|0;
 $417 = ($416<<24>>24)==(0);
 $brmerge = $417 | $50;
 if (!($brmerge)) {
  $bi$327 = 0;
  while(1) {
   $i$1024 = 1;
   while(1) {
    $418 = ((($src) + ($bi$327<<7)|0) + ($i$1024<<1)|0);
    $419 = HEAP16[$418>>1]|0;
    $420 = $419 << 16 >> 16;
    $421 = ((($coef_blocks) + ($bi$327<<7)|0) + ($i$1024<<1)|0);
    $422 = HEAP16[$421>>1]|0;
    $423 = $422 << 16 >> 16;
    $424 = Math_imul($423, $420)|0;
    $425 = (+($424|0));
    $426 = (($norm_src) + ($i$1024<<3)|0);
    $427 = +HEAPF64[$426>>3];
    $428 = $427 + $425;
    HEAPF64[$426>>3] = $428;
    $429 = $423 << 3;
    $430 = Math_imul($429, $423)|0;
    $431 = (+($430|0));
    $432 = (($norm_coef) + ($i$1024<<3)|0);
    $433 = +HEAPF64[$432>>3];
    $434 = $433 + $431;
    HEAPF64[$432>>3] = $434;
    $435 = (($i$1024) + 1)|0;
    $exitcond = ($435|0)==(64);
    if ($exitcond) {
     break;
    } else {
     $i$1024 = $435;
    }
   }
   $436 = (($bi$327) + 1)|0;
   $exitcond127 = ($436|0)==($num_blocks|0);
   if ($exitcond127) {
    break;
   } else {
    $bi$327 = $436;
   }
  }
 }
 $437 = (($415) + 16|0);
 $438 = HEAP8[$437>>0]|0;
 $439 = ($438<<24>>24)==(0);
 if ($439) {
  STACKTOP = sp;return;
 }
 $440 = ($$$i|0)==(1);
 $441 = (($num_blocks) + -1)|0;
 if ($440) {
  $j$2$lcssa = 0;
 } else {
  $i$1120 = 1;$j$219 = 0;
  while(1) {
   $443 = (($accumulated_dc_cost) + ($i$1120<<2)|0);
   $444 = HEAP32[$443>>2]|0;
   $445 = (($444) + ($441<<2)|0);
   $446 = +HEAPF32[$445>>2];
   $447 = (($accumulated_dc_cost) + ($j$219<<2)|0);
   $448 = HEAP32[$447>>2]|0;
   $449 = (($448) + ($441<<2)|0);
   $450 = +HEAPF32[$449>>2];
   $451 = $446 < $450;
   $j$3 = $451 ? $i$1120 : $j$219;
   $452 = (($i$1120) + 1)|0;
   $453 = ($452|0)<($$$i|0);
   if ($453) {
    $i$1120 = $452;$j$219 = $j$3;
   } else {
    $j$2$lcssa = $j$3;
    break;
   }
  }
 }
 $442 = ($441|0)>(-1);
 if ($442) {
  $bi$416 = $441;$j$417 = $j$2$lcssa;
  while(1) {
   $454 = (($dc_candidate) + ($j$417<<2)|0);
   $455 = HEAP32[$454>>2]|0;
   $456 = (($455) + ($bi$416<<1)|0);
   $457 = HEAP16[$456>>1]|0;
   $458 = (($coef_blocks) + ($bi$416<<7)|0);
   HEAP16[$458>>1] = $457;
   $459 = (($dc_cost_backtrack) + ($j$417<<2)|0);
   $460 = HEAP32[$459>>2]|0;
   $461 = (($460) + ($bi$416<<2)|0);
   $462 = HEAP32[$461>>2]|0;
   $463 = (($bi$416) + -1)|0;
   $464 = ($bi$416|0)>(0);
   if ($464) {
    $bi$416 = $463;$j$417 = $462;
   } else {
    break;
   }
  }
 }
 $465 = (($coef_blocks) + ($441<<7)|0);
 $466 = HEAP16[$465>>1]|0;
 HEAP16[$last_dc_val>>1] = $466;
 $i$1215 = 0;
 while(1) {
  $467 = (($accumulated_dc_cost) + ($i$1215<<2)|0);
  $468 = HEAP32[$467>>2]|0;
  _free($468);
  $469 = (($dc_cost_backtrack) + ($i$1215<<2)|0);
  $470 = HEAP32[$469>>2]|0;
  _free($470);
  $471 = (($dc_candidate) + ($i$1215<<2)|0);
  $472 = HEAP32[$471>>2]|0;
  _free($472);
  $473 = (($i$1215) + 1)|0;
  $474 = ($473|0)<($$$i|0);
  if ($474) {
   $i$1215 = $473;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _quantize_trellis_arith($cinfo,$r,$coef_blocks,$src,$num_blocks,$qtbl,$norm_src,$norm_coef,$last_dc_val,$coef_blocks_above,$src_above) {
 $cinfo = $cinfo|0;
 $r = $r|0;
 $coef_blocks = $coef_blocks|0;
 $src = $src|0;
 $num_blocks = $num_blocks|0;
 $qtbl = $qtbl|0;
 $norm_src = $norm_src|0;
 $norm_coef = $norm_coef|0;
 $last_dc_val = $last_dc_val|0;
 $coef_blocks_above = $coef_blocks_above|0;
 $src_above = $src_above|0;
 var $$ = 0, $$$i = 0, $$8 = 0, $$8$v = 0, $$lobit = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre128 = 0, $$pre131 = 0, $$sink = 0, $$sink10 = 0, $$sink9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0.0, $113 = 0, $114 = 0, $115 = 0, $116 = 0.0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0.0, $155 = 0, $156 = 0, $157 = 0.0, $158 = 0.0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0.0, $168 = 0.0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0.0, $173 = 0.0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0.0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0.0, $203 = 0, $204 = 0, $205 = 0, $206 = 0.0, $207 = 0.0, $208 = 0, $209 = 0, $21 = 0, $210 = 0.0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0.0, $235 = 0.0, $236 = 0, $237 = 0.0, $238 = 0.0, $239 = 0, $24 = 0, $240 = 0, $241 = 0.0, $242 = 0.0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0.0, $254 = 0.0, $255 = 0.0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0.0, $262 = 0.0, $263 = 0.0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0.0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0.0, $287 = 0.0, $288 = 0.0, $289 = 0.0, $29 = 0, $290 = 0, $291 = 0.0, $292 = 0.0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0.0, $299 = 0.0, $3 = 0, $30 = 0, $300 = 0, $301 = 0.0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0.0, $309 = 0.0, $31 = 0, $310 = 0, $311 = 0, $312 = 0.0, $313 = 0.0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0.0;
 var $321 = 0.0, $322 = 0, $323 = 0.0, $324 = 0.0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0.0, $335 = 0.0, $336 = 0, $337 = 0, $338 = 0.0, $339 = 0;
 var $34 = 0, $340 = 0.0, $341 = 0, $342 = 0.0, $343 = 0.0, $344 = 0.0, $345 = 0.0, $346 = 0.0, $347 = 0, $348 = 0.0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0.0, $357 = 0.0;
 var $358 = 0.0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0.0, $366 = 0.0, $367 = 0, $368 = 0.0, $369 = 0.0, $37 = 0.0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0.0, $375 = 0.0;
 var $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0;
 var $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0.0, $402 = 0, $403 = 0.0, $404 = 0.0, $405 = 0, $406 = 0, $407 = 0.0, $408 = 0, $409 = 0.0, $41 = 0, $410 = 0.0;
 var $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0.0, $423 = 0, $424 = 0, $425 = 0, $426 = 0.0, $427 = 0, $428 = 0, $429 = 0;
 var $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0;
 var $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0.0, $454 = 0.0, $455 = 0, $456 = 0.0, $457 = 0.0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0;
 var $72 = 0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $accumulated_cost = 0, $accumulated_dc_cost = 0, $accumulated_zero_dist = 0, $best_cost$082 = 0.0, $best_cost$1 = 0.0, $bi$096 = 0, $bi$124 = 0, $bi$213 = 0, $bits$029 = 0.0, $bits$1 = 0.0;
 var $bits$238 = 0.0, $bits$3 = 0.0, $brmerge = 0, $candidate = 0, $candidate_dist = 0, $coef_bits$054 = 0.0, $coef_bits$1$ph = 0.0, $coef_bits$2$lcssa = 0.0, $coef_bits$262 = 0.0, $cost$0 = 0.0, $cost10$0 = 0.0, $dc_candidate = 0, $dc_candidate_dist$0 = 0.0, $dc_context = 0, $dc_cost_backtrack = 0, $exitcond = 0, $exitcond105 = 0, $exitcond106 = 0, $exitcond112 = 0, $exitcond118 = 0;
 var $exitcond119 = 0, $exp2 = 0.0, $exp25 = 0.0, $exp26 = 0.0, $i$0104 = 0, $i$1012 = 0, $i$2101 = 0, $i$327 = 0, $i$583 = 0, $i$693 = 0, $i$7$lcssa = 0, $i$788 = 0, $i$821 = 0, $i$917 = 0, $indvars$iv = 0, $indvars$iv$next = 0, $ispos = 0, $ispos1 = 0, $ispos3 = 0, $j$070 = 0;
 var $j$1$lcssa = 0, $j$116 = 0, $j$2 = 0, $j$314 = 0, $k$044 = 0, $k$1 = 0, $k$2 = 0, $k$2$in47 = 0, $k$2$in47$phi = 0, $k$245 = 0, $k$248 = 0, $k$368 = 0, $l$042 = 0, $lambda$0 = 0.0, $lambda$0$in = 0.0, $lambda_table = 0, $last_coeff_idx$081 = 0, $last_coeff_idx$1 = 0, $last_coeff_idx$292 = 0, $m$030 = 0;
 var $m$1 = 0, $m7$055 = 0, $neg = 0, $neg2 = 0, $neg4 = 0, $norm$126 = 0.0, $or$cond = 0, $or$cond135 = 0, $or$cond7 = 0, $run_bits$0$lcssa = 0.0, $run_bits$046 = 0.0, $run_start = 0, $sext = 0, $sext132 = 0, $sext133 = 0, $st$031 = 0, $st$1 = 0, $st8$056 = 0, $umax = 0, $updated_dc_context$0 = 0;
 var $updated_dc_context$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1296|0;
 $accumulated_zero_dist = sp + 1040|0;
 $accumulated_cost = sp + 784|0;
 $run_start = sp + 528|0;
 $accumulated_dc_cost = sp + 492|0;
 $dc_cost_backtrack = sp + 456|0;
 $dc_candidate = sp + 420|0;
 $dc_context = sp + 384|0;
 $lambda_table = sp + 128|0;
 $candidate = sp + 64|0;
 $candidate_dist = sp;
 $0 = (($cinfo) + 316|0);
 $1 = HEAP16[$qtbl>>1]|0;
 $2 = $1&65535;
 $3 = (60 / ($2>>>0))&-1;
 $4 = (($3) + 2)|0;
 $5 = $4 | 1;
 $6 = ($5>>>0)>(9);
 $$$i = $6 ? 9 : $5;
 $7 = (($cinfo) + 300|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($cinfo) + 304|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==(0);
 $$ = $11 ? 1 : $8;
 $12 = ($10|0)<($$|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = HEAP32[$0>>2]|0;
 $14 = (($13) + 16|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  $i$2101 = 0;
 } else {
  $17 = $num_blocks << 2;
  $18 = $num_blocks << 1;
  $i$0104 = 0;
  while(1) {
   $19 = (_malloc($17)|0);
   $20 = (($accumulated_dc_cost) + ($i$0104<<2)|0);
   HEAP32[$20>>2] = $19;
   $21 = (_malloc($17)|0);
   $22 = (($dc_cost_backtrack) + ($i$0104<<2)|0);
   HEAP32[$22>>2] = $21;
   $23 = (_malloc($18)|0);
   $24 = (($dc_candidate) + ($i$0104<<2)|0);
   HEAP32[$24>>2] = $23;
   $25 = (_malloc($17)|0);
   $26 = (($dc_context) + ($i$0104<<2)|0);
   HEAP32[$26>>2] = $25;
   $27 = ($19|0)==(0|0);
   $28 = ($21|0)==(0|0);
   $or$cond135 = $27 | $28;
   if ($or$cond135) {
    label = 6;
   } else {
    $29 = ($23|0)==(0|0);
    $30 = ($25|0)==(0|0);
    $or$cond = $29 | $30;
    if ($or$cond) {
     label = 6;
    }
   }
   if ((label|0) == 6) {
    label = 0;
    $31 = HEAP32[$cinfo>>2]|0;
    $32 = (($31) + 20|0);
    HEAP32[$32>>2] = 54;
    $33 = HEAP32[$31>>2]|0;
    FUNCTION_TABLE_vi[$33 & 63]($cinfo);
   }
   $34 = (($i$0104) + 1)|0;
   $35 = ($34|0)<($$$i|0);
   if ($35) {
    $i$0104 = $34;
   } else {
    $i$2101 = 0;
    break;
   }
  }
 }
 while(1) {
  $52 = (($qtbl) + ($i$2101<<1)|0);
  $53 = HEAP16[$52>>1]|0;
  $54 = $53&65535;
  $55 = Math_imul($54, $54)|0;
  $56 = (+($55|0));
  $57 = 1.0 / $56;
  $58 = $57;
  $59 = (($lambda_table) + ($i$2101<<2)|0);
  HEAPF32[$59>>2] = $58;
  $60 = (($i$2101) + 1)|0;
  $exitcond119 = ($60|0)==(64);
  if ($exitcond119) {
   break;
  } else {
   $i$2101 = $60;
  }
 }
 $36 = ($num_blocks|0)==(0);
 if ($36) {
  $$pre = HEAP32[$0>>2]|0;
  $391 = $$pre;
 } else {
  $37 = +HEAPF32[$lambda_table>>2];
  $38 = (($$) + -1)|0;
  $39 = (($accumulated_zero_dist) + ($38<<2)|0);
  $40 = (($accumulated_cost) + ($38<<2)|0);
  $41 = $$$i >>> 1;
  $42 = ($coef_blocks_above|0)==(0|0);
  $43 = ($src_above|0)==(0|0);
  $or$cond7 = $42 | $43;
  $44 = (($r) + 2560|0);
  $45 = (($r) + 2564|0);
  $46 = (($accumulated_zero_dist) + ($10<<2)|0);
  $47 = (($r) + 516|0);
  $48 = (($candidate) + 4|0);
  $49 = (($candidate_dist) + 4|0);
  $50 = (($r) + 2568|0);
  $51 = ($8>>>0)>(1);
  $umax = $51 ? $8 : 1;
  $bi$096 = 0;
  while(1) {
   $i$327 = 1;$norm$126 = 0.0;
   while(1) {
    $61 = ((($src) + ($bi$096<<7)|0) + ($i$327<<1)|0);
    $62 = HEAP16[$61>>1]|0;
    $63 = $62 << 16 >> 16;
    $64 = Math_imul($63, $63)|0;
    $65 = (+($64|0));
    $66 = $norm$126 + $65;
    $67 = (($i$327) + 1)|0;
    $exitcond106 = ($67|0)==(64);
    if ($exitcond106) {
     break;
    } else {
     $i$327 = $67;$norm$126 = $66;
    }
   }
   $68 = HEAP32[$0>>2]|0;
   $69 = (($68) + 4168|0);
   $70 = +HEAPF32[$69>>2];
   $71 = $70 > 0.0;
   $72 = (($68) + 4164|0);
   $73 = +HEAPF32[$72>>2];
   $74 = $73;
   if ($71) {
    $75 = $70;
    $76 = $66 / 63.0;
    $exp25 = (+_exp2((+$74)));
    $exp26 = (+_exp2((+$75)));
    $77 = $76;
    $78 = $77 + $exp26;
    $79 = $exp25 / $78;
    $lambda$0$in = $79;
   } else {
    $80 = $74 + -12.0;
    $exp2 = (+_exp2((+$80)));
    $lambda$0$in = $exp2;
   }
   $lambda$0 = $lambda$0$in;
   $81 = $lambda$0 * $37;
   HEAPF32[$39>>2] = 0.0;
   HEAPF32[$40>>2] = 0.0;
   $82 = (($68) + 16|0);
   $83 = HEAP8[$82>>0]|0;
   $84 = ($83<<24>>24)==(0);
   if ($84) {
    $indvars$iv = $umax;
   } else {
    $85 = (($src) + ($bi$096<<7)|0);
    $86 = HEAP16[$85>>1]|0;
    $87 = $86 << 16 >> 16;
    $ispos1 = ($86<<16>>16)>(-1);
    $neg2 = (0 - ($87))|0;
    $88 = $ispos1 ? $87 : $neg2;
    $89 = HEAP16[$qtbl>>1]|0;
    $90 = $89&65535;
    $91 = $90 << 3;
    $92 = $90 << 2;
    $93 = (($92) + ($88))|0;
    $94 = (($93|0) / ($91|0))&-1;
    $95 = (($94) - ($41))|0;
    $96 = $87 >> 30;
    $97 = $96 | 1;
    $98 = ($bi$096|0)==(0);
    $99 = $98 ? 1 : $$$i;
    $100 = (($bi$096) + -1)|0;
    $101 = (($src_above) + ($bi$096<<7)|0);
    $102 = (($coef_blocks_above) + ($bi$096<<7)|0);
    $k$044 = 0;
    while(1) {
     $103 = (($95) + ($k$044))|0;
     $104 = (($dc_candidate) + ($k$044<<2)|0);
     $105 = HEAP32[$104>>2]|0;
     $106 = (($105) + ($bi$096<<1)|0);
     $sext = $103 << 16;
     $107 = $sext >> 16;
     $108 = Math_imul($107, $91)|0;
     $109 = (($108) - ($88))|0;
     $110 = Math_imul($109, $109)|0;
     $111 = (+($110|0));
     $112 = $81 * $111;
     $113 = Math_imul($107, $97)|0;
     $114 = $113&65535;
     HEAP16[$106>>1] = $114;
     if ($or$cond7) {
      $dc_candidate_dist$0 = $112;
     } else {
      $115 = (($68) + 4172|0);
      $116 = +HEAPF32[$115>>2];
      $117 = $116 > 0.0;
      if ($117) {
       $118 = HEAP16[$101>>1]|0;
       $119 = $118 << 16 >> 16;
       $120 = HEAP16[$102>>1]|0;
       $121 = $120 << 16 >> 16;
       $122 = HEAP16[$85>>1]|0;
       $123 = $122 << 16 >> 16;
       $sext133 = $113 << 16;
       $124 = $sext133 >> 16;
       $125 = (($119) - ($123))|0;
       $126 = (($121) - ($124))|0;
       $127 = Math_imul($126, $91)|0;
       $128 = (($125) - ($127))|0;
       $129 = Math_imul($128, $128)|0;
       $130 = (+($129|0));
       $131 = $81 * $130;
       $132 = $131 - $112;
       $133 = $116 * $132;
       $134 = $112 + $133;
       $dc_candidate_dist$0 = $134;
      } else {
       $dc_candidate_dist$0 = $112;
      }
     }
     $135 = (($accumulated_dc_cost) + ($k$044<<2)|0);
     $136 = (($dc_cost_backtrack) + ($k$044<<2)|0);
     $137 = (($dc_context) + ($k$044<<2)|0);
     $l$042 = 0;
     while(1) {
      if ($98) {
       $$sink9 = HEAP16[$last_dc_val>>1]|0;
       $138 = $$sink9 << 16 >> 16;
       $$sink10 = $$sink9;$149 = $138;$153 = 0;
      } else {
       $139 = (($dc_candidate) + ($l$042<<2)|0);
       $140 = HEAP32[$139>>2]|0;
       $141 = (($140) + ($100<<1)|0);
       $$sink = HEAP16[$141>>1]|0;
       $142 = $$sink << 16 >> 16;
       $143 = (($dc_context) + ($l$042<<2)|0);
       $144 = HEAP32[$143>>2]|0;
       $145 = (($144) + ($100<<2)|0);
       $146 = HEAP32[$145>>2]|0;
       $$sink10 = $$sink;$149 = $142;$153 = $146;
      }
      $sext132 = $113 << 16;
      $147 = $sext132 >> 16;
      $148 = (($147) - ($149))|0;
      $150 = ($114<<16>>16)!=($$sink10<<16>>16);
      $151 = $150&1;
      $152 = ((($r) + ($153<<3)|0) + ($151<<2)|0);
      $154 = +HEAPF32[$152>>2];
      if ($150) {
       $$lobit = $148 >>> 31;
       $155 = (($153) + 1)|0;
       $156 = ((($r) + ($155<<3)|0) + ($$lobit<<2)|0);
       $157 = +HEAPF32[$156>>2];
       $158 = $154 + $157;
       $159 = $$lobit | 2;
       $160 = (($159) + ($153))|0;
       $161 = $148 >> 31;
       $162 = $161 & 4;
       $ispos3 = ($148|0)>(-1);
       $neg4 = (0 - ($148))|0;
       $163 = $ispos3 ? $148 : $neg4;
       $164 = (($163) + -1)|0;
       $165 = ($164|0)==(0);
       if ($165) {
        $bits$1 = $158;$m$1 = 0;$st$1 = $160;
       } else {
        $166 = ((($r) + ($160<<3)|0) + 4|0);
        $167 = +HEAPF32[$166>>2];
        $168 = $158 + $167;
        $169 = $164 >> 1;
        $170 = ($169|0)==(0);
        if ($170) {
         $bits$1 = $168;$m$1 = 1;$st$1 = 20;
        } else {
         $177 = $169;$bits$029 = $168;$m$030 = 1;$st$031 = 20;
         while(1) {
          $171 = ((($r) + ($st$031<<3)|0) + 4|0);
          $172 = +HEAPF32[$171>>2];
          $173 = $bits$029 + $172;
          $174 = $m$030 << 1;
          $175 = (($st$031) + 1)|0;
          $176 = $177 >> 1;
          $178 = ($176|0)==(0);
          if ($178) {
           $bits$1 = $173;$m$1 = $174;$st$1 = $175;
           break;
          } else {
           $177 = $176;$bits$029 = $173;$m$030 = $174;$st$031 = $175;
          }
         }
        }
       }
       $179 = (($r) + ($st$1<<3)|0);
       $180 = +HEAPF32[$179>>2];
       $181 = $bits$1 + $180;
       $182 = HEAP32[$44>>2]|0;
       $183 = 1 << $182;
       $184 = $183 >> 1;
       $185 = ($m$1|0)<($184|0);
       if ($185) {
        $updated_dc_context$0 = 0;
       } else {
        $186 = HEAP32[$45>>2]|0;
        $187 = 1 << $186;
        $188 = $187 >> 1;
        $189 = ($m$1|0)>($188|0);
        $$8$v = $189 ? 12 : 4;
        $$8 = (($$8$v) + ($162))|0;
        $updated_dc_context$0 = $$8;
       }
       $190 = (($st$1) + 14)|0;
       $191 = $m$1 >> 1;
       $192 = ($191|0)==(0);
       if ($192) {
        $bits$3 = $181;$updated_dc_context$1 = $updated_dc_context$0;
       } else {
        $194 = $191;$bits$238 = $181;
        while(1) {
         $193 = $194 & $164;
         $195 = ($193|0)!=(0);
         $196 = $195&1;
         $197 = ((($r) + ($190<<3)|0) + ($196<<2)|0);
         $198 = +HEAPF32[$197>>2];
         $199 = $bits$238 + $198;
         $200 = $194 >> 1;
         $201 = ($200|0)==(0);
         if ($201) {
          $bits$3 = $199;$updated_dc_context$1 = $updated_dc_context$0;
          break;
         } else {
          $194 = $200;$bits$238 = $199;
         }
        }
       }
      } else {
       $bits$3 = $154;$updated_dc_context$1 = 0;
      }
      $202 = $dc_candidate_dist$0 + $bits$3;
      if ($98) {
       $cost$0 = $202;
      } else {
       $203 = (($accumulated_dc_cost) + ($l$042<<2)|0);
       $204 = HEAP32[$203>>2]|0;
       $205 = (($204) + ($100<<2)|0);
       $206 = +HEAPF32[$205>>2];
       $207 = $202 + $206;
       $cost$0 = $207;
      }
      $208 = ($l$042|0)==(0);
      $$pre128 = HEAP32[$135>>2]|0;
      if ($208) {
       label = 38;
      } else {
       $209 = (($$pre128) + ($bi$096<<2)|0);
       $210 = +HEAPF32[$209>>2];
       $211 = $cost$0 < $210;
       if ($211) {
        label = 38;
       }
      }
      if ((label|0) == 38) {
       label = 0;
       $212 = (($$pre128) + ($bi$096<<2)|0);
       HEAPF32[$212>>2] = $cost$0;
       $213 = $98 ? -1 : $l$042;
       $214 = HEAP32[$136>>2]|0;
       $215 = (($214) + ($bi$096<<2)|0);
       HEAP32[$215>>2] = $213;
       $216 = HEAP32[$137>>2]|0;
       $217 = (($216) + ($bi$096<<2)|0);
       HEAP32[$217>>2] = $updated_dc_context$1;
      }
      $218 = (($l$042) + 1)|0;
      $219 = ($218|0)<($99|0);
      if ($219) {
       $l$042 = $218;
      } else {
       break;
      }
     }
     $220 = (($k$044) + 1)|0;
     $221 = ($220|0)<($$$i|0);
     if ($221) {
      $k$044 = $220;
     } else {
      $indvars$iv = $umax;
      break;
     }
    }
   }
   while(1) {
    $222 = (142704 + ($indvars$iv<<2)|0);
    $223 = HEAP32[$222>>2]|0;
    $224 = ((($src) + ($bi$096<<7)|0) + ($223<<1)|0);
    $225 = HEAP16[$224>>1]|0;
    $226 = $225 << 16 >> 16;
    $227 = $226 >> 31;
    $ispos = ($225<<16>>16)>(-1);
    $neg = (0 - ($226))|0;
    $228 = $ispos ? $226 : $neg;
    $229 = (($qtbl) + ($223<<1)|0);
    $230 = HEAP16[$229>>1]|0;
    $231 = $230&65535;
    $232 = $231 << 3;
    $233 = Math_imul($228, $228)|0;
    $234 = (+($233|0));
    $235 = $lambda$0 * $234;
    $236 = (($lambda_table) + ($223<<2)|0);
    $237 = +HEAPF32[$236>>2];
    $238 = $237 * $235;
    $239 = (($indvars$iv) + -1)|0;
    $240 = (($accumulated_zero_dist) + ($239<<2)|0);
    $241 = +HEAPF32[$240>>2];
    $242 = $241 + $238;
    $243 = (($accumulated_zero_dist) + ($indvars$iv<<2)|0);
    HEAPF32[$243>>2] = $242;
    $244 = $231 << 2;
    $245 = (($244) + ($228))|0;
    $246 = (($245|0) / ($232|0))&-1;
    $247 = ($246|0)==(0);
    if ($247) {
     $248 = ((($coef_blocks) + ($bi$096<<7)|0) + ($223<<1)|0);
     HEAP16[$248>>1] = 0;
     $249 = (($accumulated_cost) + ($indvars$iv<<2)|0);
     HEAPF32[$249>>2] = 9.9999996802856924E+37;
    } else {
     HEAP32[$candidate>>2] = $246;
     $250 = Math_imul($246, $232)|0;
     $251 = (($250) - ($228))|0;
     $252 = Math_imul($251, $251)|0;
     $253 = (+($252|0));
     $254 = $lambda$0 * $253;
     $255 = $254 * $237;
     HEAPF32[$candidate_dist>>2] = $255;
     $256 = ($246|0)>(1);
     if ($256) {
      $257 = (($246) + -1)|0;
      HEAP32[$48>>2] = $257;
      $258 = Math_imul($257, $232)|0;
      $259 = (($258) - ($228))|0;
      $260 = Math_imul($259, $259)|0;
      $261 = (+($260|0));
      $262 = $lambda$0 * $261;
      $263 = $262 * $237;
      HEAPF32[$49>>2] = $263;
      $k$1 = 2;
     } else {
      $k$1 = 1;
     }
     $264 = (($accumulated_cost) + ($indvars$iv<<2)|0);
     HEAPF32[$264>>2] = 9.9999996802856924E+37;
     $265 = ($$|0)>($indvars$iv|0);
     if (!($265)) {
      $266 = ($239*3)|0;
      $267 = (($266) + 1)|0;
      $268 = ((($r) + ($267<<3)|0) + 516|0);
      $269 = (($266) + 2)|0;
      $270 = ((($coef_blocks) + ($bi$096<<7)|0) + ($223<<1)|0);
      $271 = (($run_start) + ($indvars$iv<<2)|0);
      $272 = ((($r) + ($269<<3)|0) + 516|0);
      $453 = 9.9999996802856924E+37;$j$070 = $38;
      while(1) {
       $273 = ($j$070|0)==($38|0);
       if ($273) {
        label = 50;
       } else {
        $274 = (142704 + ($j$070<<2)|0);
        $275 = HEAP32[$274>>2]|0;
        $276 = ((($coef_blocks) + ($bi$096<<7)|0) + ($275<<1)|0);
        $277 = HEAP16[$276>>1]|0;
        $278 = ($277<<16>>16)==(0);
        if ($278) {
         $$pre131 = (($j$070) + 1)|0;
         $$pre$phiZ2D = $$pre131;$454 = $453;
        } else {
         label = 50;
        }
       }
       if ((label|0) == 50) {
        label = 0;
        $279 = ($j$070*3)|0;
        $280 = ((($r) + ($279<<3)|0) + 512|0);
        $281 = +HEAPF32[$280>>2];
        $k$245 = (($j$070) + 1)|0;
        $282 = ($k$245|0)<($indvars$iv|0);
        if ($282) {
         $k$2$in47 = $j$070;$k$248 = $k$245;$run_bits$046 = $281;
         while(1) {
          $283 = ($k$2$in47*3)|0;
          $284 = (($283) + 1)|0;
          $285 = ((($r) + ($284<<3)|0) + 512|0);
          $286 = +HEAPF32[$285>>2];
          $287 = $run_bits$046 + $286;
          $k$2 = (($k$248) + 1)|0;
          $exitcond112 = ($k$2|0)==($indvars$iv|0);
          if ($exitcond112) {
           $run_bits$0$lcssa = $287;
           break;
          } else {
           $k$2$in47$phi = $k$248;$k$248 = $k$2;$run_bits$046 = $287;$k$2$in47 = $k$2$in47$phi;
          }
         }
        } else {
         $run_bits$0$lcssa = $281;
        }
        $288 = +HEAPF32[$268>>2];
        $289 = $run_bits$0$lcssa + $288;
        $290 = (($accumulated_zero_dist) + ($j$070<<2)|0);
        $291 = +HEAPF32[$290>>2];
        $292 = $241 - $291;
        $293 = (($accumulated_cost) + ($j$070<<2)|0);
        $348 = $453;$k$368 = 0;
        while(1) {
         $294 = (($candidate) + ($k$368<<2)|0);
         $295 = HEAP32[$294>>2]|0;
         $296 = (($295) + -1)|0;
         $297 = ($296|0)==(0);
         do {
          if ($297) {
           $coef_bits$1$ph = 1.0;
           label = 58;
          } else {
           $298 = +HEAPF32[$272>>2];
           $299 = $298 + 1.0;
           $300 = ($296>>>0)<(2);
           if ($300) {
            $coef_bits$1$ph = $299;
            label = 58;
           } else {
            $301 = $298 + $299;
            $302 = HEAP32[$50>>2]|0;
            $303 = ($indvars$iv|0)<=($302|0);
            $304 = $303 ? 189 : 217;
            $305 = $296 >> 2;
            $306 = ($305|0)==(0);
            if ($306) {
             $307 = ((($r) + ($304<<3)|0) + 512|0);
             $308 = +HEAPF32[$307>>2];
             $309 = $301 + $308;
             $310 = (($304) + 14)|0;
             $333 = $310;$455 = 1;$456 = $309;
            } else {
             $317 = $305;$coef_bits$054 = $301;$m7$055 = 2;$st8$056 = $304;
             while(1) {
              $311 = ((($r) + ($st8$056<<3)|0) + 516|0);
              $312 = +HEAPF32[$311>>2];
              $313 = $coef_bits$054 + $312;
              $314 = $m7$055 << 1;
              $315 = (($st8$056) + 1)|0;
              $316 = $317 >> 1;
              $318 = ($316|0)==(0);
              if ($318) {
               break;
              } else {
               $317 = $316;$coef_bits$054 = $313;$m7$055 = $314;$st8$056 = $315;
              }
             }
             $322 = ((($r) + ($315<<3)|0) + 512|0);
             $323 = +HEAPF32[$322>>2];
             $324 = $313 + $323;
             $325 = (($st8$056) + 15)|0;
             $326 = $314 >> 1;
             $327 = ($326|0)==(0);
             if ($327) {
              $coef_bits$2$lcssa = $324;
              break;
             } else {
              $333 = $325;$455 = $326;$456 = $324;
             }
            }
            $329 = $455;$coef_bits$262 = $456;
            while(1) {
             $328 = $329 & $296;
             $330 = ($328|0)!=(0);
             $331 = $330&1;
             $332 = (((($r) + ($333<<3)|0) + ($331<<2)|0) + 512|0);
             $334 = +HEAPF32[$332>>2];
             $335 = $coef_bits$262 + $334;
             $336 = $329 >> 1;
             $337 = ($336|0)==(0);
             if ($337) {
              $coef_bits$2$lcssa = $335;
              break;
             } else {
              $329 = $336;$coef_bits$262 = $335;
             }
            }
           }
          }
         } while(0);
         if ((label|0) == 58) {
          label = 0;
          $319 = ((($r) + ($269<<3)|0) + 512|0);
          $320 = +HEAPF32[$319>>2];
          $321 = $coef_bits$1$ph + $320;
          $coef_bits$2$lcssa = $321;
         }
         $338 = $289 + $coef_bits$2$lcssa;
         $339 = (~~(($338)));
         $340 = (+($339|0));
         $341 = (($candidate_dist) + ($k$368<<2)|0);
         $342 = +HEAPF32[$341>>2];
         $343 = $340 + $342;
         $344 = +HEAPF32[$293>>2];
         $345 = $292 + $344;
         $346 = $343 + $345;
         $347 = $346 < $348;
         if ($347) {
          $349 = $295 ^ $227;
          $350 = (($349) - ($227))|0;
          $351 = $350&65535;
          HEAP16[$270>>1] = $351;
          HEAPF32[$264>>2] = $346;
          HEAP32[$271>>2] = $j$070;
          $457 = $346;
         } else {
          $457 = $348;
         }
         $352 = (($k$368) + 1)|0;
         $353 = ($352|0)<($k$1|0);
         if ($353) {
          $348 = $457;$k$368 = $352;
         } else {
          $$pre$phiZ2D = $k$245;$454 = $457;
          break;
         }
        }
       }
       $354 = ($$pre$phiZ2D|0)<($indvars$iv|0);
       if ($354) {
        $453 = $454;$j$070 = $$pre$phiZ2D;
       } else {
        break;
       }
      }
     }
    }
    $indvars$iv$next = (($indvars$iv) + 1)|0;
    $355 = ($indvars$iv|0)<($10|0);
    if ($355) {
     $indvars$iv = $indvars$iv$next;
    } else {
     break;
    }
   }
   $356 = +HEAPF32[$47>>2];
   $357 = +HEAPF32[$46>>2];
   $358 = $357 + $356;
   $best_cost$082 = $358;$i$583 = $$;$last_coeff_idx$081 = $38;
   while(1) {
    $359 = (142704 + ($i$583<<2)|0);
    $360 = HEAP32[$359>>2]|0;
    $361 = ((($coef_blocks) + ($bi$096<<7)|0) + ($360<<1)|0);
    $362 = HEAP16[$361>>1]|0;
    $363 = ($362<<16>>16)==(0);
    if ($363) {
     $best_cost$1 = $best_cost$082;$last_coeff_idx$1 = $last_coeff_idx$081;
    } else {
     $364 = (($accumulated_cost) + ($i$583<<2)|0);
     $365 = +HEAPF32[$364>>2];
     $366 = $365 + $357;
     $367 = (($accumulated_zero_dist) + ($i$583<<2)|0);
     $368 = +HEAPF32[$367>>2];
     $369 = $366 - $368;
     $370 = ($i$583|0)<($10|0);
     if ($370) {
      $371 = ($i$583*3)|0;
      $372 = (($371) + -3)|0;
      $373 = ((($r) + ($372<<3)|0) + 516|0);
      $374 = +HEAPF32[$373>>2];
      $375 = $369 + $374;
      $cost10$0 = $375;
     } else {
      $cost10$0 = $369;
     }
     $376 = $cost10$0 < $best_cost$082;
     if ($376) {
      $best_cost$1 = $cost10$0;$last_coeff_idx$1 = $i$583;
     } else {
      $best_cost$1 = $best_cost$082;$last_coeff_idx$1 = $last_coeff_idx$081;
     }
    }
    $377 = (($i$583) + 1)|0;
    $378 = ($i$583|0)<($10|0);
    if ($378) {
     $best_cost$082 = $best_cost$1;$i$583 = $377;$last_coeff_idx$081 = $last_coeff_idx$1;
    } else {
     $i$693 = $10;$last_coeff_idx$292 = $last_coeff_idx$1;
     break;
    }
   }
   while(1) {
    $379 = ($i$693|0)>($last_coeff_idx$292|0);
    if ($379) {
     $i$788 = $i$693;
     while(1) {
      $380 = (142704 + ($i$788<<2)|0);
      $381 = HEAP32[$380>>2]|0;
      $382 = ((($coef_blocks) + ($bi$096<<7)|0) + ($381<<1)|0);
      HEAP16[$382>>1] = 0;
      $383 = (($i$788) + -1)|0;
      $384 = ($383|0)>($last_coeff_idx$292|0);
      if ($384) {
       $i$788 = $383;
      } else {
       $i$7$lcssa = $last_coeff_idx$292;
       break;
      }
     }
    } else {
     $i$7$lcssa = $i$693;
    }
    $385 = (($run_start) + ($i$7$lcssa<<2)|0);
    $386 = HEAP32[$385>>2]|0;
    $387 = (($i$7$lcssa) + -1)|0;
    $388 = ($i$7$lcssa|0)>($$|0);
    if ($388) {
     $i$693 = $387;$last_coeff_idx$292 = $386;
    } else {
     break;
    }
   }
   $389 = (($bi$096) + 1)|0;
   $exitcond118 = ($389|0)==($num_blocks|0);
   if ($exitcond118) {
    $391 = $68;
    break;
   } else {
    $bi$096 = $389;
   }
  }
 }
 $390 = (($391) + 21|0);
 $392 = HEAP8[$390>>0]|0;
 $393 = ($392<<24>>24)==(0);
 $brmerge = $393 | $36;
 if (!($brmerge)) {
  $bi$124 = 0;
  while(1) {
   $i$821 = 1;
   while(1) {
    $394 = ((($src) + ($bi$124<<7)|0) + ($i$821<<1)|0);
    $395 = HEAP16[$394>>1]|0;
    $396 = $395 << 16 >> 16;
    $397 = ((($coef_blocks) + ($bi$124<<7)|0) + ($i$821<<1)|0);
    $398 = HEAP16[$397>>1]|0;
    $399 = $398 << 16 >> 16;
    $400 = Math_imul($399, $396)|0;
    $401 = (+($400|0));
    $402 = (($norm_src) + ($i$821<<3)|0);
    $403 = +HEAPF64[$402>>3];
    $404 = $403 + $401;
    HEAPF64[$402>>3] = $404;
    $405 = $399 << 3;
    $406 = Math_imul($405, $399)|0;
    $407 = (+($406|0));
    $408 = (($norm_coef) + ($i$821<<3)|0);
    $409 = +HEAPF64[$408>>3];
    $410 = $409 + $407;
    HEAPF64[$408>>3] = $410;
    $411 = (($i$821) + 1)|0;
    $exitcond = ($411|0)==(64);
    if ($exitcond) {
     break;
    } else {
     $i$821 = $411;
    }
   }
   $412 = (($bi$124) + 1)|0;
   $exitcond105 = ($412|0)==($num_blocks|0);
   if ($exitcond105) {
    break;
   } else {
    $bi$124 = $412;
   }
  }
 }
 $413 = (($391) + 16|0);
 $414 = HEAP8[$413>>0]|0;
 $415 = ($414<<24>>24)==(0);
 if ($415) {
  STACKTOP = sp;return;
 }
 $416 = ($$$i|0)==(1);
 $417 = (($num_blocks) + -1)|0;
 if ($416) {
  $j$1$lcssa = 0;
 } else {
  $i$917 = 1;$j$116 = 0;
  while(1) {
   $419 = (($accumulated_dc_cost) + ($i$917<<2)|0);
   $420 = HEAP32[$419>>2]|0;
   $421 = (($420) + ($417<<2)|0);
   $422 = +HEAPF32[$421>>2];
   $423 = (($accumulated_dc_cost) + ($j$116<<2)|0);
   $424 = HEAP32[$423>>2]|0;
   $425 = (($424) + ($417<<2)|0);
   $426 = +HEAPF32[$425>>2];
   $427 = $422 < $426;
   $j$2 = $427 ? $i$917 : $j$116;
   $428 = (($i$917) + 1)|0;
   $429 = ($428|0)<($$$i|0);
   if ($429) {
    $i$917 = $428;$j$116 = $j$2;
   } else {
    $j$1$lcssa = $j$2;
    break;
   }
  }
 }
 $418 = ($417|0)>(-1);
 if ($418) {
  $bi$213 = $417;$j$314 = $j$1$lcssa;
  while(1) {
   $430 = (($dc_candidate) + ($j$314<<2)|0);
   $431 = HEAP32[$430>>2]|0;
   $432 = (($431) + ($bi$213<<1)|0);
   $433 = HEAP16[$432>>1]|0;
   $434 = (($coef_blocks) + ($bi$213<<7)|0);
   HEAP16[$434>>1] = $433;
   $435 = (($dc_cost_backtrack) + ($j$314<<2)|0);
   $436 = HEAP32[$435>>2]|0;
   $437 = (($436) + ($bi$213<<2)|0);
   $438 = HEAP32[$437>>2]|0;
   $439 = (($bi$213) + -1)|0;
   $440 = ($bi$213|0)>(0);
   if ($440) {
    $bi$213 = $439;$j$314 = $438;
   } else {
    break;
   }
  }
 }
 $441 = (($coef_blocks) + ($417<<7)|0);
 $442 = HEAP16[$441>>1]|0;
 HEAP16[$last_dc_val>>1] = $442;
 $i$1012 = 0;
 while(1) {
  $443 = (($accumulated_dc_cost) + ($i$1012<<2)|0);
  $444 = HEAP32[$443>>2]|0;
  _free($444);
  $445 = (($dc_cost_backtrack) + ($i$1012<<2)|0);
  $446 = HEAP32[$445>>2]|0;
  _free($446);
  $447 = (($dc_candidate) + ($i$1012<<2)|0);
  $448 = HEAP32[$447>>2]|0;
  _free($448);
  $449 = (($dc_context) + ($i$1012<<2)|0);
  $450 = HEAP32[$449>>2]|0;
  _free($450);
  $451 = (($i$1012) + 1)|0;
  $452 = ($451|0)<($$$i|0);
  if ($452) {
   $i$1012 = $451;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _jinit_forward_dct($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $convsamp$jsimd_convsamp = 0, $convsamp_float$jsimd_convsamp_float = 0, $storemerge1 = 0, $storemerge3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 7]($cinfo,1,80)|0);
 $4 = (($cinfo) + 344|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$3>>2] = 4;
 $5 = (($cinfo) + 184|0);
 $6 = HEAP32[$5>>2]|0;
 do {
  if ((($6|0) == 2)) {
   $15 = (($3) + 4|0);
   HEAP32[$15>>2] = 2;
   $16 = (_jsimd_can_fdct_float()|0);
   $17 = ($16|0)==(0);
   $18 = (($3) + 44|0);
   if ($17) {
    HEAP32[$18>>2] = 10;
    break;
   } else {
    HEAP32[$18>>2] = 9;
    break;
   }
  } else if ((($6|0) == 1)) {
   $11 = (($3) + 4|0);
   HEAP32[$11>>2] = 1;
   $12 = (_jsimd_can_fdct_ifast()|0);
   $13 = ($12|0)==(0);
   $14 = (($3) + 8|0);
   if ($13) {
    HEAP32[$14>>2] = 8;
    break;
   } else {
    HEAP32[$14>>2] = 7;
    break;
   }
  } else if ((($6|0) == 0)) {
   $7 = (($3) + 4|0);
   HEAP32[$7>>2] = 1;
   $8 = (_jsimd_can_fdct_islow()|0);
   $9 = ($8|0)==(0);
   $10 = (($3) + 8|0);
   if ($9) {
    HEAP32[$10>>2] = 6;
    break;
   } else {
    HEAP32[$10>>2] = 5;
    break;
   }
  } else {
   $19 = HEAP32[$cinfo>>2]|0;
   $20 = (($19) + 20|0);
   HEAP32[$20>>2] = 48;
   $21 = HEAP32[$19>>2]|0;
   FUNCTION_TABLE_vi[$21 & 63]($cinfo);
  }
 } while(0);
 $22 = HEAP32[$5>>2]|0;
 do {
  if ((($22|0) == 1) | (($22|0) == 0)) {
   $23 = (_jsimd_can_convsamp()|0);
   $24 = ($23|0)==(0);
   $25 = (($3) + 12|0);
   $convsamp$jsimd_convsamp = $24 ? 2 : 1;
   HEAP32[$25>>2] = $convsamp$jsimd_convsamp;
   $26 = (($cinfo) + 316|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($27) + 22|0);
   $29 = HEAP8[$28>>0]|0;
   $30 = ($29<<24>>24)==(0);
   $31 = (($3) + 16|0);
   $storemerge3 = $30 ? 0 : 3;
   HEAP32[$31>>2] = $storemerge3;
   $32 = (_jsimd_can_quantize()|0);
   $33 = ($32|0)==(0);
   $34 = (($3) + 20|0);
   if ($33) {
    HEAP32[$34>>2] = 4;
    break;
   } else {
    HEAP32[$34>>2] = 3;
    break;
   }
  } else if ((($22|0) == 2)) {
   $35 = (_jsimd_can_convsamp_float()|0);
   $36 = ($35|0)==(0);
   $37 = (($3) + 48|0);
   $convsamp_float$jsimd_convsamp_float = $36 ? 6 : 5;
   HEAP32[$37>>2] = $convsamp_float$jsimd_convsamp_float;
   $38 = (($cinfo) + 316|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($39) + 22|0);
   $41 = HEAP8[$40>>0]|0;
   $42 = ($41<<24>>24)==(0);
   $43 = (($3) + 52|0);
   $storemerge1 = $42 ? 0 : 4;
   HEAP32[$43>>2] = $storemerge1;
   $44 = (_jsimd_can_quantize_float()|0);
   $45 = ($44|0)==(0);
   $46 = (($3) + 56|0);
   if ($45) {
    HEAP32[$46>>2] = 8;
    break;
   } else {
    HEAP32[$46>>2] = 7;
    break;
   }
  } else {
   $47 = HEAP32[$cinfo>>2]|0;
   $48 = (($47) + 20|0);
   HEAP32[$48>>2] = 48;
   $49 = HEAP32[$47>>2]|0;
   FUNCTION_TABLE_vi[$49 & 63]($cinfo);
  }
 } while(0);
 $50 = HEAP32[$5>>2]|0;
 $51 = ($50|0)==(2);
 $52 = HEAP32[$0>>2]|0;
 $53 = HEAP32[$52>>2]|0;
 $54 = (FUNCTION_TABLE_iiii[$53 & 7]($cinfo,1,256)|0);
 if ($51) {
  $55 = (($3) + 76|0);
  HEAP32[$55>>2] = $54;
  $57 = (($3) + 24|0);
  $58 = (($3) + 60|0);
  HEAP32[$57>>2] = 0;
  HEAP32[$58>>2] = 0;
  $59 = (($3) + 28|0);
  HEAP32[$59>>2] = 0;
  $60 = (($3) + 64|0);
  HEAP32[$60>>2] = 0;
  $61 = (($3) + 32|0);
  HEAP32[$61>>2] = 0;
  $62 = (($3) + 68|0);
  HEAP32[$62>>2] = 0;
  $63 = (($3) + 36|0);
  HEAP32[$63>>2] = 0;
  $64 = (($3) + 72|0);
  HEAP32[$64>>2] = 0;
  STACKTOP = sp;return;
 } else {
  $56 = (($3) + 40|0);
  HEAP32[$56>>2] = $54;
  $57 = (($3) + 24|0);
  $58 = (($3) + 60|0);
  HEAP32[$57>>2] = 0;
  HEAP32[$58>>2] = 0;
  $59 = (($3) + 28|0);
  HEAP32[$59>>2] = 0;
  $60 = (($3) + 64|0);
  HEAP32[$60>>2] = 0;
  $61 = (($3) + 32|0);
  HEAP32[$61>>2] = 0;
  $62 = (($3) + 68|0);
  HEAP32[$62>>2] = 0;
  $63 = (($3) + 36|0);
  HEAP32[$63>>2] = 0;
  $64 = (($3) + 72|0);
  HEAP32[$64>>2] = 0;
  STACKTOP = sp;return;
 }
}
function _start_pass_fdctmgr($cinfo) {
 $cinfo = $cinfo|0;
 var $$phi$trans$insert$pre = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0;
 var $99 = 0.0, $ci$011 = 0, $compptr$010 = 0, $exitcond = 0, $exitcond12 = 0, $exitcond13 = 0, $i$09 = 0, $i$17 = 0, $i$24 = 0, $row$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 344|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 60|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = (($cinfo) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($cinfo) + 184|0);
 $8 = (($1) + 24|0);
 $9 = (($cinfo) + 4|0);
 $10 = (($1) + 20|0);
 $11 = (($1) + 60|0);
 $ci$011 = 0;$compptr$010 = $6;
 while(1) {
  $12 = (($compptr$010) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13>>>0)>(3);
  $$phi$trans$insert$pre = ((($cinfo) + ($13<<2)|0) + 72|0);
  if ($14) {
   label = 5;
  } else {
   $15 = HEAP32[$$phi$trans$insert$pre>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    label = 5;
   } else {
    $29 = $15;
   }
  }
  if ((label|0) == 5) {
   label = 0;
   $17 = HEAP32[$cinfo>>2]|0;
   $18 = (($17) + 20|0);
   HEAP32[$18>>2] = 52;
   $19 = (($17) + 24|0);
   HEAP32[$19>>2] = $13;
   $20 = HEAP32[$17>>2]|0;
   FUNCTION_TABLE_vi[$20 & 63]($cinfo);
   $$pre = HEAP32[$$phi$trans$insert$pre>>2]|0;
   $29 = $$pre;
  }
  $21 = HEAP32[$7>>2]|0;
  if ((($21|0) == 1)) {
   $41 = (($8) + ($13<<2)|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    $44 = HEAP32[$9>>2]|0;
    $45 = HEAP32[$44>>2]|0;
    $46 = (FUNCTION_TABLE_iiii[$45 & 7]($cinfo,1,1024)|0);
    HEAP32[$41>>2] = $46;
    $58 = $46;
   } else {
    $58 = $42;
   }
   $i$17 = 0;
   while(1) {
    $47 = (($29) + ($i$17<<1)|0);
    $48 = HEAP16[$47>>1]|0;
    $49 = $48&65535;
    $50 = (66072 + ($i$17<<1)|0);
    $51 = HEAP16[$50>>1]|0;
    $52 = $51 << 16 >> 16;
    $53 = Math_imul($52, $49)|0;
    $54 = (($53) + 1024)|0;
    $55 = $54 >>> 11;
    $56 = $55&65535;
    $57 = (($58) + ($i$17<<2)|0);
    $59 = (_compute_reciprocal($56,$57)|0);
    $60 = ($59|0)==(0);
    if ($60) {
     $61 = HEAP32[$10>>2]|0;
     $62 = ($61|0)==(3|0);
     if ($62) {
      HEAP32[$10>>2] = 4;
     }
    }
    $63 = (($i$17) + 1)|0;
    $exitcond12 = ($63|0)==(64);
    if ($exitcond12) {
     break;
    } else {
     $i$17 = $63;
    }
   }
  } else if ((($21|0) == 2)) {
   $64 = (($11) + ($13<<2)|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = ($65|0)==(0|0);
   if ($66) {
    $67 = HEAP32[$9>>2]|0;
    $68 = HEAP32[$67>>2]|0;
    $69 = (FUNCTION_TABLE_iiii[$68 & 7]($cinfo,1,256)|0);
    HEAP32[$64>>2] = $69;
    $80 = $69;
   } else {
    $80 = $65;
   }
   $i$24 = 0;$row$05 = 0;
   while(1) {
    $70 = (66200 + ($row$05<<3)|0);
    $71 = +HEAPF64[$70>>3];
    $72 = (($29) + ($i$24<<1)|0);
    $73 = HEAP16[$72>>1]|0;
    $74 = (+($73&65535));
    $75 = $74 * $71;
    $76 = $75 * 8.0;
    $77 = 1.0 / $76;
    $78 = $77;
    $79 = (($80) + ($i$24<<2)|0);
    HEAPF32[$79>>2] = $78;
    $81 = $i$24 | 1;
    $82 = (($29) + ($81<<1)|0);
    $83 = HEAP16[$82>>1]|0;
    $84 = (+($83&65535));
    $85 = $84 * $71;
    $86 = $85 * 1.3870398450000001;
    $87 = $86 * 8.0;
    $88 = 1.0 / $87;
    $89 = $88;
    $90 = (($80) + ($81<<2)|0);
    HEAPF32[$90>>2] = $89;
    $91 = (($81) + 1)|0;
    $92 = (($29) + ($91<<1)|0);
    $93 = HEAP16[$92>>1]|0;
    $94 = (+($93&65535));
    $95 = $94 * $71;
    $96 = $95 * 1.3065629649999999;
    $97 = $96 * 8.0;
    $98 = 1.0 / $97;
    $99 = $98;
    $100 = (($80) + ($91<<2)|0);
    HEAPF32[$100>>2] = $99;
    $101 = $i$24 | 3;
    $102 = (($29) + ($101<<1)|0);
    $103 = HEAP16[$102>>1]|0;
    $104 = (+($103&65535));
    $105 = $104 * $71;
    $106 = $105 * 1.1758756020000001;
    $107 = $106 * 8.0;
    $108 = 1.0 / $107;
    $109 = $108;
    $110 = (($80) + ($101<<2)|0);
    HEAPF32[$110>>2] = $109;
    $111 = (($101) + 1)|0;
    $112 = (($29) + ($111<<1)|0);
    $113 = HEAP16[$112>>1]|0;
    $114 = (+($113&65535));
    $115 = $114 * $71;
    $116 = $115 * 8.0;
    $117 = 1.0 / $116;
    $118 = $117;
    $119 = (($80) + ($111<<2)|0);
    HEAPF32[$119>>2] = $118;
    $120 = (($101) + 2)|0;
    $121 = (($29) + ($120<<1)|0);
    $122 = HEAP16[$121>>1]|0;
    $123 = (+($122&65535));
    $124 = $123 * $71;
    $125 = $124 * 0.785694958;
    $126 = $125 * 8.0;
    $127 = 1.0 / $126;
    $128 = $127;
    $129 = (($80) + ($120<<2)|0);
    HEAPF32[$129>>2] = $128;
    $130 = (($101) + 3)|0;
    $131 = (($29) + ($130<<1)|0);
    $132 = HEAP16[$131>>1]|0;
    $133 = (+($132&65535));
    $134 = $133 * $71;
    $135 = $134 * 0.54119609999999996;
    $136 = $135 * 8.0;
    $137 = 1.0 / $136;
    $138 = $137;
    $139 = (($80) + ($130<<2)|0);
    HEAPF32[$139>>2] = $138;
    $140 = $i$24 | 7;
    $141 = (($29) + ($140<<1)|0);
    $142 = HEAP16[$141>>1]|0;
    $143 = (+($142&65535));
    $144 = $143 * $71;
    $145 = $144 * 0.275899379;
    $146 = $145 * 8.0;
    $147 = 1.0 / $146;
    $148 = $147;
    $149 = (($80) + ($140<<2)|0);
    HEAPF32[$149>>2] = $148;
    $150 = (($i$24) + 8)|0;
    $151 = (($row$05) + 1)|0;
    $exitcond = ($151|0)==(8);
    if ($exitcond) {
     break;
    } else {
     $i$24 = $150;$row$05 = $151;
    }
   }
  } else if ((($21|0) == 0)) {
   $22 = (($8) + ($13<<2)|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0|0);
   if ($24) {
    $25 = HEAP32[$9>>2]|0;
    $26 = HEAP32[$25>>2]|0;
    $27 = (FUNCTION_TABLE_iiii[$26 & 7]($cinfo,1,1024)|0);
    HEAP32[$22>>2] = $27;
    $35 = $27;
   } else {
    $35 = $23;
   }
   $i$09 = 0;
   while(1) {
    $28 = (($29) + ($i$09<<1)|0);
    $30 = HEAP16[$28>>1]|0;
    $31 = $30&65535;
    $32 = $31 << 3;
    $33 = $32&65535;
    $34 = (($35) + ($i$09<<2)|0);
    $36 = (_compute_reciprocal($33,$34)|0);
    $37 = ($36|0)==(0);
    if ($37) {
     $38 = HEAP32[$10>>2]|0;
     $39 = ($38|0)==(3|0);
     if ($39) {
      HEAP32[$10>>2] = 4;
     }
    }
    $40 = (($i$09) + 1)|0;
    $exitcond13 = ($40|0)==(64);
    if ($exitcond13) {
     break;
    } else {
     $i$09 = $40;
    }
   }
  } else {
   $152 = HEAP32[$cinfo>>2]|0;
   $153 = (($152) + 20|0);
   HEAP32[$153>>2] = 48;
   $154 = HEAP32[$152>>2]|0;
   FUNCTION_TABLE_vi[$154 & 63]($cinfo);
  }
  $155 = (($ci$011) + 1)|0;
  $156 = (($compptr$010) + 84|0);
  $157 = HEAP32[$2>>2]|0;
  $158 = ($155|0)<($157|0);
  if ($158) {
   $ci$011 = $155;$compptr$010 = $156;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _forward_DCT($cinfo,$compptr,$sample_data,$coef_blocks,$start_row,$start_col,$num_blocks,$dst) {
 $cinfo = $cinfo|0;
 $compptr = $compptr|0;
 $sample_data = $sample_data|0;
 $coef_blocks = $coef_blocks|0;
 $start_row = $start_row|0;
 $start_col = $start_col|0;
 $num_blocks = $num_blocks|0;
 $dst = $dst|0;
 var $$010 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bi$08 = 0, $exitcond = 0, $exitcond11 = 0;
 var $exitcond12 = 0, $exitcond13 = 0, $i$04 = 0, $i$11 = 0, $i1$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 344|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($compptr) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 24|0);
 $5 = (($4) + ($3<<2)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($cinfo) + ($3<<2)|0) + 72|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($1) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($1) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($1) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($1) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($1) + 40|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($sample_data) + ($start_row<<2)|0);
 $20 = ($num_blocks|0)==(0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = ($14|0)!=(0|0);
 $22 = ($dst|0)==(0|0);
 $23 = (($cinfo) + 184|0);
 $$010 = $start_col;$bi$08 = 0;
 while(1) {
  FUNCTION_TABLE_viii[$12 & 15]($19,$$010,$18);
  if ($21) {
   FUNCTION_TABLE_vii[$14 & 15]($18,$8);
  }
  FUNCTION_TABLE_vi[$10 & 63]($18);
  L9: do {
   if (!($22)) {
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==(1);
    if ($25) {
     $i$04 = 0;
    } else {
     $i$11 = 0;
     while(1) {
      $43 = (($18) + ($i$11<<2)|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = $44&65535;
      $46 = ((($dst) + ($bi$08<<7)|0) + ($i$11<<1)|0);
      HEAP16[$46>>1] = $45;
      $47 = (($i$11) + 1)|0;
      $exitcond = ($47|0)==(64);
      if ($exitcond) {
       break L9;
      } else {
       $i$11 = $47;
      }
     }
    }
    while(1) {
     $26 = (($18) + ($i$04<<2)|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (66072 + ($i$04<<1)|0);
     $29 = HEAP16[$28>>1]|0;
     $30 = $29 << 16 >> 16;
     $31 = ($27|0)>(-1);
     $32 = $27 << 15;
     if ($31) {
      $33 = (($30) + ($32))|0;
      $34 = $30 << 1;
      $35 = (($33|0) / ($34|0))&-1;
      $40 = $35;
     } else {
      $36 = (($32) - ($30))|0;
      $37 = $30 << 1;
      $38 = (($36|0) / ($37|0))&-1;
      $40 = $38;
     }
     $39 = $40&65535;
     $41 = ((($dst) + ($bi$08<<7)|0) + ($i$04<<1)|0);
     HEAP16[$41>>1] = $39;
     $42 = (($i$04) + 1)|0;
     $exitcond11 = ($42|0)==(64);
     if ($exitcond11) {
      break;
     } else {
      $i$04 = $42;
     }
    }
   }
  } while(0);
  $48 = (($coef_blocks) + ($bi$08<<7)|0);
  FUNCTION_TABLE_viii[$16 & 15]($48,$6,$18);
  if ($21) {
   $i1$07 = 0;
   while(1) {
    $49 = ((($coef_blocks) + ($bi$08<<7)|0) + ($i1$07<<1)|0);
    $50 = HEAP16[$49>>1]|0;
    $51 = ($50<<16>>16)<(-1023);
    if ($51) {
     HEAP16[$49>>1] = -1023;
    } else {
     $52 = ($50<<16>>16)>(1023);
     if ($52) {
      HEAP16[$49>>1] = 1023;
     }
    }
    $53 = (($i1$07) + 1)|0;
    $exitcond12 = ($53|0)==(64);
    if ($exitcond12) {
     break;
    } else {
     $i1$07 = $53;
    }
   }
  }
  $54 = (($bi$08) + 1)|0;
  $55 = (($$010) + 8)|0;
  $exitcond13 = ($54|0)==($num_blocks|0);
  if ($exitcond13) {
   break;
  } else {
   $$010 = $55;$bi$08 = $54;
  }
 }
 STACKTOP = sp;return;
}
function _forward_DCT_float($cinfo,$compptr,$sample_data,$coef_blocks,$start_row,$start_col,$num_blocks,$dst) {
 $cinfo = $cinfo|0;
 $compptr = $compptr|0;
 $sample_data = $sample_data|0;
 $coef_blocks = $coef_blocks|0;
 $start_row = $start_row|0;
 $start_col = $start_col|0;
 $num_blocks = $num_blocks|0;
 $dst = $dst|0;
 var $$07 = 0, $$sink = 0.0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0;
 var $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bi$05 = 0, $exitcond = 0, $exitcond8 = 0, $exitcond9 = 0, $i$01 = 0;
 var $i1$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 344|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($compptr) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 60|0);
 $5 = (($4) + ($3<<2)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($cinfo) + ($3<<2)|0) + 72|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($1) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($1) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($1) + 52|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($1) + 56|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($1) + 76|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($sample_data) + ($start_row<<2)|0);
 $20 = ($num_blocks|0)==(0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = ($14|0)!=(0|0);
 $22 = ($dst|0)==(0|0);
 $$07 = $start_col;$bi$05 = 0;
 while(1) {
  FUNCTION_TABLE_viii[$12 & 15]($19,$$07,$18);
  if ($21) {
   FUNCTION_TABLE_vii[$14 & 15]($18,$8);
  }
  FUNCTION_TABLE_vi[$10 & 63]($18);
  if (!($22)) {
   $i$01 = 0;
   while(1) {
    $23 = (($18) + ($i$01<<2)|0);
    $24 = +HEAPF32[$23>>2];
    $25 = (($i$01|0) % 8)&-1;
    $26 = (66200 + ($25<<3)|0);
    $27 = +HEAPF64[$26>>3];
    $28 = $24;
    $29 = $28 / $27;
    $30 = $29;
    $31 = (($i$01|0) / 8)&-1;
    $32 = (66200 + ($31<<3)|0);
    $33 = +HEAPF64[$32>>3];
    $34 = $30;
    $35 = $34 / $33;
    $36 = $35;
    $37 = $36;
    $38 = !($36 >= 0.0);
    if ($38) {
     $40 = $37 + -0.5;
     $$sink = $40;
    } else {
     $39 = $37 + 0.5;
     $$sink = $39;
    }
    $41 = (~~(($$sink)));
    $42 = $41&65535;
    $43 = ((($dst) + ($bi$05<<7)|0) + ($i$01<<1)|0);
    HEAP16[$43>>1] = $42;
    $44 = (($i$01) + 1)|0;
    $exitcond = ($44|0)==(64);
    if ($exitcond) {
     break;
    } else {
     $i$01 = $44;
    }
   }
  }
  $45 = (($coef_blocks) + ($bi$05<<7)|0);
  FUNCTION_TABLE_viii[$16 & 15]($45,$6,$18);
  if ($21) {
   $i1$04 = 0;
   while(1) {
    $46 = ((($coef_blocks) + ($bi$05<<7)|0) + ($i1$04<<1)|0);
    $47 = HEAP16[$46>>1]|0;
    $48 = ($47<<16>>16)<(-1023);
    if ($48) {
     HEAP16[$46>>1] = -1023;
    } else {
     $49 = ($47<<16>>16)>(1023);
     if ($49) {
      HEAP16[$46>>1] = 1023;
     }
    }
    $50 = (($i1$04) + 1)|0;
    $exitcond8 = ($50|0)==(64);
    if ($exitcond8) {
     break;
    } else {
     $i1$04 = $50;
    }
   }
  }
  $51 = (($bi$05) + 1)|0;
  $52 = (($$07) + 8)|0;
  $exitcond9 = ($51|0)==($num_blocks|0);
  if ($exitcond9) {
   break;
  } else {
   $$07 = $52;$bi$05 = $51;
  }
 }
 STACKTOP = sp;return;
}
function _convsamp($sample_data,$start_col,$workspace) {
 $sample_data = $sample_data|0;
 $start_col = $start_col|0;
 $workspace = $workspace|0;
 var $$sum = 0, $$sum1 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $elemr$08 = 0, $exitcond = 0, $workspaceptr$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$sum = (($start_col) + 1)|0;
 $$sum1 = (($start_col) + 2)|0;
 $$sum2 = (($start_col) + 3)|0;
 $$sum3 = (($start_col) + 4)|0;
 $$sum4 = (($start_col) + 5)|0;
 $$sum5 = (($start_col) + 6)|0;
 $$sum6 = (($start_col) + 7)|0;
 $elemr$08 = 0;$workspaceptr$07 = $workspace;
 while(1) {
  $0 = (($sample_data) + ($elemr$08<<2)|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = (($1) + ($start_col)|0);
  $3 = (($1) + ($$sum)|0);
  $4 = HEAP8[$2>>0]|0;
  $5 = $4&255;
  $6 = (($5) + -128)|0;
  $7 = (($workspaceptr$07) + 4|0);
  HEAP32[$workspaceptr$07>>2] = $6;
  $8 = (($1) + ($$sum1)|0);
  $9 = HEAP8[$3>>0]|0;
  $10 = $9&255;
  $11 = (($10) + -128)|0;
  $12 = (($workspaceptr$07) + 8|0);
  HEAP32[$7>>2] = $11;
  $13 = (($1) + ($$sum2)|0);
  $14 = HEAP8[$8>>0]|0;
  $15 = $14&255;
  $16 = (($15) + -128)|0;
  $17 = (($workspaceptr$07) + 12|0);
  HEAP32[$12>>2] = $16;
  $18 = (($1) + ($$sum3)|0);
  $19 = HEAP8[$13>>0]|0;
  $20 = $19&255;
  $21 = (($20) + -128)|0;
  $22 = (($workspaceptr$07) + 16|0);
  HEAP32[$17>>2] = $21;
  $23 = (($1) + ($$sum4)|0);
  $24 = HEAP8[$18>>0]|0;
  $25 = $24&255;
  $26 = (($25) + -128)|0;
  $27 = (($workspaceptr$07) + 20|0);
  HEAP32[$22>>2] = $26;
  $28 = (($1) + ($$sum5)|0);
  $29 = HEAP8[$23>>0]|0;
  $30 = $29&255;
  $31 = (($30) + -128)|0;
  $32 = (($workspaceptr$07) + 24|0);
  HEAP32[$27>>2] = $31;
  $33 = (($1) + ($$sum6)|0);
  $34 = HEAP8[$28>>0]|0;
  $35 = $34&255;
  $36 = (($35) + -128)|0;
  $37 = (($workspaceptr$07) + 28|0);
  HEAP32[$32>>2] = $36;
  $38 = HEAP8[$33>>0]|0;
  $39 = $38&255;
  $40 = (($39) + -128)|0;
  $41 = (($workspaceptr$07) + 32|0);
  HEAP32[$37>>2] = $40;
  $42 = (($elemr$08) + 1)|0;
  $exitcond = ($42|0)==(8);
  if ($exitcond) {
   break;
  } else {
   $elemr$08 = $42;$workspaceptr$07 = $41;
  }
 }
 STACKTOP = sp;return;
}
function _preprocess_deringing($data,$quantization_table) {
 $data = $data|0;
 $quantization_table = $quantization_table|0;
 var $$ = 0, $$$ = 0, $$3 = 0, $$4 = 0, $$5 = 0, $$maxsample_count$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0;
 var $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0, $exitcond = 0, $exitcond13 = 0, $fslope$0 = 0, $fslope$0$$5 = 0, $fslope$0$$5$neg = 0, $i$09 = 0, $i$16 = 0, $maxsample_count$010 = 0, $n$0 = 0, $n$1 = 0, $n$2 = 0, $position$07 = 0.0;
 var $sum$011 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $i$09 = 0;$maxsample_count$010 = 0;$sum$011 = 0;
 while(1) {
  $0 = (($data) + ($i$09<<2)|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = (($1) + ($sum$011))|0;
  $3 = ($1|0)>(126);
  $4 = $3&1;
  $$maxsample_count$0 = (($4) + ($maxsample_count$010))|0;
  $5 = (($i$09) + 1)|0;
  $exitcond13 = ($5|0)==(64);
  if ($exitcond13) {
   break;
  } else {
   $i$09 = $5;$maxsample_count$010 = $$maxsample_count$0;$sum$011 = $2;
  }
 }
 $6 = $$maxsample_count$0 & -65;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP16[$quantization_table>>1]|0;
 $9 = $8&65535;
 $10 = $9 << 1;
 $11 = ($10>>>0)>(31);
 $$ = $11 ? 31 : $10;
 $12 = (8128 - ($2))|0;
 $13 = (($12|0) / ($$maxsample_count$0|0))&-1;
 $14 = ($$|0)<($13|0);
 $$$ = $14 ? $$ : $13;
 $15 = (($$$) + 127)|0;
 $n$0 = 0;
 while(1) {
  $16 = (142704 + ($n$0<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($data) + ($17<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)<(127);
  L9: do {
   if ($20) {
    $21 = (($n$0) + 1)|0;
    $n$2 = $21;
   } else {
    $n$1 = $n$0;
    while(1) {
     $22 = (($n$1) + 1)|0;
     $23 = ($22|0)<(64);
     if (!($23)) {
      break;
     }
     $24 = (142704 + ($22<<2)|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($data) + ($25<<2)|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27|0)>(126);
     if ($28) {
      $n$1 = $22;
     } else {
      break;
     }
    }
    $29 = ($n$0|0)>(0);
    $30 = (($n$0) + -1)|0;
    $$3 = $29 ? $30 : 0;
    $31 = (142704 + ($$3<<2)|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($data) + ($32<<2)|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($n$0|0)>(1);
    $36 = (($n$0) + -2)|0;
    $37 = $35 ? $36 : 0;
    $38 = (142704 + ($37<<2)|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($data) + ($39<<2)|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($22|0)<(63);
    $43 = $42 ? $22 : 63;
    $44 = (142704 + ($43<<2)|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($data) + ($45<<2)|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ($22|0)<(62);
    $49 = (($n$1) + 2)|0;
    $$4 = $48 ? $49 : 63;
    $50 = (142704 + ($$4<<2)|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($data) + ($51<<2)|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($34) - ($41))|0;
    $55 = (127 - ($34))|0;
    $56 = ($54|0)>($55|0);
    $57 = $56 ? $54 : $55;
    $58 = (($47) - ($53))|0;
    $59 = (127 - ($47))|0;
    $60 = ($58|0)>($59|0);
    $$5 = $60 ? $58 : $59;
    $61 = ($n$0|0)==(0);
    $fslope$0 = $61 ? $$5 : $57;
    $62 = (($22) - ($n$0))|0;
    $63 = (($62) + 1)|0;
    $64 = (+($63|0));
    $65 = 1.0 / $64;
    $66 = ($n$0|0)<($22|0);
    if ($66) {
     $67 = ($22|0)==(64);
     $fslope$0$$5 = $67 ? $fslope$0 : $$5;
     $fslope$0$$5$neg = (0 - ($fslope$0$$5))|0;
     $68 = Math_imul($fslope$0, $62)|0;
     $69 = Math_imul($62, $fslope$0$$5$neg)|0;
     $70 = (+($68|0));
     $71 = (+($69|0));
     $96 = $17;$i$16 = $n$0;$position$07 = $65;
     while(1) {
      $72 = $position$07 * $position$07;
      $73 = $position$07 * $72;
      $74 = $73 * 2.0;
      $75 = $72 * 3.0;
      $76 = $74 - $75;
      $77 = $76 + 1.0;
      $78 = $73 * -2.0;
      $79 = $75 + $78;
      $80 = $72 * 2.0;
      $81 = $73 - $80;
      $82 = $position$07 + $81;
      $83 = $73 - $72;
      $84 = $77 * 127.0;
      $85 = $70 * $82;
      $86 = $85 + $84;
      $87 = $79 * 127.0;
      $88 = $87 + $86;
      $89 = $71 * $83;
      $90 = $89 + $88;
      $91 = (+Math_ceil((+$90)));
      $92 = (~~(($91)));
      $93 = ($92|0)<($15|0);
      $94 = $93 ? $92 : $15;
      $95 = (($data) + ($96<<2)|0);
      HEAP32[$95>>2] = $94;
      $97 = (($i$16) + 1)|0;
      $exitcond = ($97|0)==($22|0);
      if ($exitcond) {
       $n$2 = $49;
       break L9;
      }
      $98 = $65 + $position$07;
      $$phi$trans$insert = (142704 + ($97<<2)|0);
      $$pre = HEAP32[$$phi$trans$insert>>2]|0;
      $96 = $$pre;$i$16 = $97;$position$07 = $98;
     }
    } else {
     $n$2 = $49;
    }
   }
  } while(0);
  $99 = ($n$2|0)<(64);
  if ($99) {
   $n$0 = $n$2;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _quantize($coef_block,$divisors,$workspace) {
 $coef_block = $coef_block|0;
 $divisors = $divisors|0;
 $workspace = $workspace|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $temp$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $i$01 = 0;
 while(1) {
  $0 = (($workspace) + ($i$01<<2)|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = (($divisors) + ($i$01<<2)|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($i$01) + 64)|0;
  $5 = (($divisors) + ($4<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($i$01) + 192)|0;
  $8 = (($divisors) + ($7<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($1|0)<(0);
  if ($10) {
   $11 = (($6) - ($1))|0;
   $12 = (___muldi3(($11|0),0,($3|0),0)|0);
   $13 = tempRet0;
   $14 = (($9) + 32)|0;
   $15 = (_bitshift64Lshr(($12|0),($13|0),($14|0))|0);
   $16 = tempRet0;
   $17 = (0 - ($15))|0;
   $temp$0 = $17;
  } else {
   $18 = (($6) + ($1))|0;
   $19 = (___muldi3(($18|0),0,($3|0),0)|0);
   $20 = tempRet0;
   $21 = (($9) + 32)|0;
   $22 = (_bitshift64Lshr(($19|0),($20|0),($21|0))|0);
   $23 = tempRet0;
   $temp$0 = $22;
  }
  $24 = $temp$0&65535;
  $25 = (($coef_block) + ($i$01<<1)|0);
  HEAP16[$25>>1] = $24;
  $26 = (($i$01) + 1)|0;
  $exitcond = ($26|0)==(64);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $26;
  }
 }
 STACKTOP = sp;return;
}
function _convsamp_float($sample_data,$start_col,$workspace) {
 $sample_data = $sample_data|0;
 $start_col = $start_col|0;
 $workspace = $workspace|0;
 var $$sum = 0, $$sum1 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, $elemr$08 = 0, $exitcond = 0;
 var $workspaceptr$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$sum = (($start_col) + 1)|0;
 $$sum1 = (($start_col) + 2)|0;
 $$sum2 = (($start_col) + 3)|0;
 $$sum3 = (($start_col) + 4)|0;
 $$sum4 = (($start_col) + 5)|0;
 $$sum5 = (($start_col) + 6)|0;
 $$sum6 = (($start_col) + 7)|0;
 $elemr$08 = 0;$workspaceptr$07 = $workspace;
 while(1) {
  $0 = (($sample_data) + ($elemr$08<<2)|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = (($1) + ($start_col)|0);
  $3 = (($1) + ($$sum)|0);
  $4 = HEAP8[$2>>0]|0;
  $5 = $4&255;
  $6 = (($5) + -128)|0;
  $7 = (+($6|0));
  $8 = (($workspaceptr$07) + 4|0);
  HEAPF32[$workspaceptr$07>>2] = $7;
  $9 = (($1) + ($$sum1)|0);
  $10 = HEAP8[$3>>0]|0;
  $11 = $10&255;
  $12 = (($11) + -128)|0;
  $13 = (+($12|0));
  $14 = (($workspaceptr$07) + 8|0);
  HEAPF32[$8>>2] = $13;
  $15 = (($1) + ($$sum2)|0);
  $16 = HEAP8[$9>>0]|0;
  $17 = $16&255;
  $18 = (($17) + -128)|0;
  $19 = (+($18|0));
  $20 = (($workspaceptr$07) + 12|0);
  HEAPF32[$14>>2] = $19;
  $21 = (($1) + ($$sum3)|0);
  $22 = HEAP8[$15>>0]|0;
  $23 = $22&255;
  $24 = (($23) + -128)|0;
  $25 = (+($24|0));
  $26 = (($workspaceptr$07) + 16|0);
  HEAPF32[$20>>2] = $25;
  $27 = (($1) + ($$sum4)|0);
  $28 = HEAP8[$21>>0]|0;
  $29 = $28&255;
  $30 = (($29) + -128)|0;
  $31 = (+($30|0));
  $32 = (($workspaceptr$07) + 20|0);
  HEAPF32[$26>>2] = $31;
  $33 = (($1) + ($$sum5)|0);
  $34 = HEAP8[$27>>0]|0;
  $35 = $34&255;
  $36 = (($35) + -128)|0;
  $37 = (+($36|0));
  $38 = (($workspaceptr$07) + 24|0);
  HEAPF32[$32>>2] = $37;
  $39 = (($1) + ($$sum6)|0);
  $40 = HEAP8[$33>>0]|0;
  $41 = $40&255;
  $42 = (($41) + -128)|0;
  $43 = (+($42|0));
  $44 = (($workspaceptr$07) + 28|0);
  HEAPF32[$38>>2] = $43;
  $45 = HEAP8[$39>>0]|0;
  $46 = $45&255;
  $47 = (($46) + -128)|0;
  $48 = (+($47|0));
  $49 = (($workspaceptr$07) + 32|0);
  HEAPF32[$44>>2] = $48;
  $50 = (($elemr$08) + 1)|0;
  $exitcond = ($50|0)==(8);
  if ($exitcond) {
   break;
  } else {
   $elemr$08 = $50;$workspaceptr$07 = $49;
  }
 }
 STACKTOP = sp;return;
}
function _float_preprocess_deringing($data,$quantization_table) {
 $data = $data|0;
 $quantization_table = $quantization_table|0;
 var $$ = 0, $$3 = 0, $$4 = 0.0, $$mux = 0.0, $$not = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0.0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0.0, $104 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0;
 var $16 = 0.0, $17 = 0, $18 = 0, $19 = 0, $2 = 0.0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0;
 var $70 = 0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0;
 var $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0, $99 = 0.0, $brmerge = 0, $exitcond = 0, $exitcond12 = 0, $fslope$0 = 0.0, $fslope$0$$4 = 0.0, $i$08 = 0, $i$15 = 0, $maxsample_count$09 = 0;
 var $maxsample_count$1 = 0, $n$0 = 0, $n$1 = 0, $n$2 = 0, $not$ = 0, $phitmp = 0.0, $phitmp2 = 0.0, $position$06 = 0.0, $sum$010 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $i$08 = 0;$maxsample_count$09 = 0;$sum$010 = 0.0;
 while(1) {
  $0 = (($data) + ($i$08<<2)|0);
  $1 = +HEAPF32[$0>>2];
  $2 = $sum$010 + $1;
  $not$ = $1 >= 127.0;
  $3 = $not$&1;
  $maxsample_count$1 = (($3) + ($maxsample_count$09))|0;
  $4 = (($i$08) + 1)|0;
  $exitcond12 = ($4|0)==(64);
  if ($exitcond12) {
   break;
  } else {
   $i$08 = $4;$maxsample_count$09 = $maxsample_count$1;$sum$010 = $2;
  }
 }
 $5 = $maxsample_count$1 & -65;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP16[$quantization_table>>1]|0;
 $8 = $7&65535;
 $9 = $8 << 1;
 $10 = ($9>>>0)>(31);
 if ($10) {
  $14 = 31.0;
 } else {
  $phitmp = (+($9|0));
  $14 = $phitmp;
 }
 $11 = 8128.0 - $2;
 $12 = (+($maxsample_count$1|0));
 $13 = $11 / $12;
 $$not = !($14 < $13);
 $brmerge = $$not | $10;
 $$mux = $$not ? $13 : 31.0;
 if ($brmerge) {
  $16 = $$mux;
 } else {
  $phitmp2 = (+($9|0));
  $16 = $phitmp2;
 }
 $15 = $16 + 127.0;
 $n$0 = 0;
 while(1) {
  $17 = (142704 + ($n$0<<2)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($data) + ($18<<2)|0);
  $20 = +HEAPF32[$19>>2];
  $21 = $20 < 127.0;
  L15: do {
   if ($21) {
    $22 = (($n$0) + 1)|0;
    $n$2 = $22;
   } else {
    $n$1 = $n$0;
    while(1) {
     $23 = (($n$1) + 1)|0;
     $24 = ($23|0)<(64);
     if (!($24)) {
      break;
     }
     $25 = (142704 + ($23<<2)|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = (($data) + ($26<<2)|0);
     $28 = +HEAPF32[$27>>2];
     $29 = !($28 >= 127.0);
     if ($29) {
      break;
     } else {
      $n$1 = $23;
     }
    }
    $30 = ($n$0|0)>(0);
    $31 = (($n$0) + -1)|0;
    $$ = $30 ? $31 : 0;
    $32 = (142704 + ($$<<2)|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($data) + ($33<<2)|0);
    $35 = +HEAPF32[$34>>2];
    $36 = ($n$0|0)>(1);
    $37 = (($n$0) + -2)|0;
    $38 = $36 ? $37 : 0;
    $39 = (142704 + ($38<<2)|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($data) + ($40<<2)|0);
    $42 = +HEAPF32[$41>>2];
    $43 = ($23|0)<(63);
    $44 = $43 ? $23 : 63;
    $45 = (142704 + ($44<<2)|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (($data) + ($46<<2)|0);
    $48 = +HEAPF32[$47>>2];
    $49 = ($23|0)<(62);
    $50 = (($n$1) + 2)|0;
    $$3 = $49 ? $50 : 63;
    $51 = (142704 + ($$3<<2)|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (($data) + ($52<<2)|0);
    $54 = +HEAPF32[$53>>2];
    $55 = $35 - $42;
    $56 = 127.0 - $35;
    $57 = $55 > $56;
    $58 = $57 ? $55 : $56;
    $59 = $48 - $54;
    $60 = 127.0 - $48;
    $61 = $59 > $60;
    $$4 = $61 ? $59 : $60;
    $62 = ($n$0|0)==(0);
    $fslope$0 = $62 ? $$4 : $58;
    $63 = (($23) - ($n$0))|0;
    $64 = (($63) + 1)|0;
    $65 = (+($64|0));
    $66 = 1.0 / $65;
    $67 = ($n$0|0)<($23|0);
    if ($67) {
     $68 = ($23|0)==(64);
     $fslope$0$$4 = $68 ? $fslope$0 : $$4;
     $69 = 127.0 - $fslope$0;
     $70 = (~~(($69)));
     $71 = 127.0 - $fslope$0$$4;
     $72 = (~~(($71)));
     $73 = (127 - ($70))|0;
     $74 = Math_imul($73, $63)|0;
     $75 = (($72) + -127)|0;
     $76 = Math_imul($75, $63)|0;
     $77 = (+($74|0));
     $78 = (+($76|0));
     $101 = $18;$i$15 = $n$0;$position$06 = $66;
     while(1) {
      $79 = $position$06 * $position$06;
      $80 = $position$06 * $79;
      $81 = $80 * 2.0;
      $82 = $79 * 3.0;
      $83 = $81 - $82;
      $84 = $83 + 1.0;
      $85 = $80 * -2.0;
      $86 = $82 + $85;
      $87 = $79 * 2.0;
      $88 = $80 - $87;
      $89 = $position$06 + $88;
      $90 = $80 - $79;
      $91 = $84 * 127.0;
      $92 = $77 * $89;
      $93 = $92 + $91;
      $94 = $86 * 127.0;
      $95 = $94 + $93;
      $96 = $78 * $90;
      $97 = $96 + $95;
      $98 = $97 < $15;
      $99 = $98 ? $97 : $15;
      $100 = (($data) + ($101<<2)|0);
      HEAPF32[$100>>2] = $99;
      $102 = (($i$15) + 1)|0;
      $exitcond = ($102|0)==($23|0);
      if ($exitcond) {
       $n$2 = $50;
       break L15;
      }
      $103 = $66 + $position$06;
      $$phi$trans$insert = (142704 + ($102<<2)|0);
      $$pre = HEAP32[$$phi$trans$insert>>2]|0;
      $101 = $$pre;$i$15 = $102;$position$06 = $103;
     }
    } else {
     $n$2 = $50;
    }
   }
  } while(0);
  $104 = ($n$2|0)<(64);
  if ($104) {
   $n$0 = $n$2;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _quantize_float($coef_block,$divisors,$workspace) {
 $coef_block = $coef_block|0;
 $divisors = $divisors|0;
 $workspace = $workspace|0;
 var $0 = 0, $1 = 0.0, $10 = 0, $2 = 0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $i$01 = 0;
 while(1) {
  $0 = (($workspace) + ($i$01<<2)|0);
  $1 = +HEAPF32[$0>>2];
  $2 = (($divisors) + ($i$01<<2)|0);
  $3 = +HEAPF32[$2>>2];
  $4 = $1 * $3;
  $5 = $4 + 16384.5;
  $6 = (~~(($5)));
  $7 = (($6) + 49152)|0;
  $8 = $7&65535;
  $9 = (($coef_block) + ($i$01<<1)|0);
  HEAP16[$9>>1] = $8;
  $10 = (($i$01) + 1)|0;
  $exitcond = ($10|0)==(64);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $10;
  }
 }
 STACKTOP = sp;return;
}
function _compute_reciprocal($divisor,$dtbl) {
 $divisor = $divisor|0;
 $dtbl = $dtbl|0;
 var $$ = 0, $$0$i = 0, $$01$i = 0, $$1$i = 0, $$2$i = 0, $$2$lobit$i = 0, $$not$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bit$0$i = 0, $bit$1$i = 0, $bit$2$$i = 0, $bit$2$i = 0, $c$0 = 0;
 var $fq$0$off0 = 0, $not$ = 0, $r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($divisor<<16>>16)==(0);
 $$pre = $divisor&65535;
 if ($0) {
  $$01$i = 0;
 } else {
  $1 = $$pre & 65280;
  $2 = ($1|0)==(0);
  if ($2) {
   $3 = $$pre << 8;
   $4 = $3&65535;
   $$0$i = $4;$bit$0$i = 8;
  } else {
   $$0$i = $divisor;$bit$0$i = 16;
  }
  $5 = $$0$i&65535;
  $6 = $5 & 61440;
  $7 = ($6|0)==(0);
  if ($7) {
   $8 = (($bit$0$i) + -4)|0;
   $9 = $5 << 4;
   $10 = $9&65535;
   $$1$i = $10;$bit$1$i = $8;
  } else {
   $$1$i = $$0$i;$bit$1$i = $bit$0$i;
  }
  $11 = $$1$i&65535;
  $12 = $11 & 49152;
  $13 = ($12|0)==(0);
  if ($13) {
   $14 = (($bit$1$i) + -2)|0;
   $15 = $11 << 2;
   $16 = $15&65535;
   $$2$i = $16;$bit$2$i = $14;
  } else {
   $$2$i = $$1$i;$bit$2$i = $bit$1$i;
  }
  $$2$lobit$i = ($$2$i<<16>>16) >> 15;
  $17 = $$2$lobit$i << 16 >> 16;
  $$not$i = $17 ^ -1;
  $bit$2$$i = (($bit$2$i) + ($$not$i))|0;
  $$01$i = $bit$2$$i;
 }
 $18 = (($$01$i) + 31)|0;
 $19 = (_bitshift64Shl(1,0,($18|0))|0);
 $20 = tempRet0;
 $21 = $divisor&65535;
 $22 = (___udivdi3(($19|0),($20|0),($21|0),0)|0);
 $23 = tempRet0;
 $24 = (___uremdi3(($19|0),($20|0),($21|0),0)|0);
 $25 = tempRet0;
 $26 = $$pre >>> 1;
 $27 = ($24|0)==(0);
 $28 = ($25|0)==(0);
 $29 = $27 & $28;
 do {
  if ($29) {
   $30 = (_bitshift64Lshr(($22|0),($23|0),1)|0);
   $31 = tempRet0;
   $32 = (($$01$i) + 30)|0;
   $c$0 = $26;$fq$0$off0 = $30;$r$0 = $32;
  } else {
   $33 = ($25>>>0)>(0);
   $34 = ($25|0)==(0);
   $35 = ($24>>>0)>($26>>>0);
   $36 = $34 & $35;
   $37 = $33 | $36;
   if ($37) {
    $39 = (_i64Add(($22|0),($23|0),1,0)|0);
    $40 = tempRet0;
    $c$0 = $26;$fq$0$off0 = $39;$r$0 = $18;
    break;
   } else {
    $38 = (($26) + 1)|0;
    $c$0 = $38;$fq$0$off0 = $22;$r$0 = $18;
    break;
   }
  }
 } while(0);
 HEAP32[$dtbl>>2] = $fq$0$off0;
 $41 = (($dtbl) + 256|0);
 HEAP32[$41>>2] = $c$0;
 $42 = (64 - ($r$0))|0;
 $43 = 1 << $42;
 $44 = (($dtbl) + 512|0);
 HEAP32[$44>>2] = $43;
 $45 = (($r$0) + -32)|0;
 $46 = (($dtbl) + 768|0);
 HEAP32[$46>>2] = $45;
 $not$ = ($r$0|0)>(16);
 $$ = $not$&1;
 STACKTOP = sp;return ($$|0);
}
function _jpeg_make_c_derived_tbl($cinfo,$isDC,$tblno,$pdtbl) {
 $cinfo = $cinfo|0;
 $isDC = $isDC|0;
 $tblno = $tblno|0;
 $pdtbl = $pdtbl|0;
 var $$in = 0, $$pre$phi27Z2D = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $code$010 = 0, $code$1$lcssa = 0, $code$14 = 0, $exitcond = 0;
 var $exitcond22 = 0, $huffcode = 0, $huffsize = 0, $l$018 = 0, $p$019 = 0, $p$1$lcssa = 0, $p$29 = 0, $p$3$lcssa = 0, $p$33 = 0, $p$42 = 0, $scevgep = 0, $si$08 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1296|0;
 $huffsize = sp + 1028|0;
 $huffcode = sp;
 $0 = ($tblno>>>0)>(3);
 if ($0) {
  $1 = HEAP32[$cinfo>>2]|0;
  $2 = (($1) + 20|0);
  HEAP32[$2>>2] = 50;
  $3 = (($1) + 24|0);
  HEAP32[$3>>2] = $tblno;
  $4 = HEAP32[$1>>2]|0;
  FUNCTION_TABLE_vi[$4 & 63]($cinfo);
 }
 $5 = ($isDC<<24>>24)!=(0);
 if ($5) {
  $6 = ((($cinfo) + ($tblno<<2)|0) + 88|0);
  $$in = $6;
 } else {
  $7 = ((($cinfo) + ($tblno<<2)|0) + 104|0);
  $$in = $7;
 }
 $8 = HEAP32[$$in>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $10 = HEAP32[$cinfo>>2]|0;
  $11 = (($10) + 20|0);
  HEAP32[$11>>2] = 50;
  $12 = (($10) + 24|0);
  HEAP32[$12>>2] = $tblno;
  $13 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$13 & 63]($cinfo);
 }
 $14 = HEAP32[$pdtbl>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  $16 = (($cinfo) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = HEAP32[$17>>2]|0;
  $19 = (FUNCTION_TABLE_iiii[$18 & 7]($cinfo,1,1280)|0);
  HEAP32[$pdtbl>>2] = $19;
  $$pre$phi27Z2D = $cinfo;$55 = $19;
 } else {
  $$pre$phi27Z2D = $cinfo;$55 = $14;
 }
 $l$018 = 1;$p$019 = 0;
 while(1) {
  $20 = (($8) + ($l$018)|0);
  $21 = HEAP8[$20>>0]|0;
  $22 = $21&255;
  $23 = (($22) + ($p$019))|0;
  $24 = ($23|0)>(256);
  if ($24) {
   $25 = HEAP32[$cinfo>>2]|0;
   $26 = (($25) + 20|0);
   HEAP32[$26>>2] = 8;
   $27 = HEAP32[$25>>2]|0;
   FUNCTION_TABLE_vi[$27 & 63]($$pre$phi27Z2D);
  }
  $28 = ($21<<24>>24)==(0);
  if ($28) {
   $p$1$lcssa = $p$019;
  } else {
   $29 = $l$018&255;
   $scevgep = (($huffsize) + ($p$019)|0);
   _memset(($scevgep|0),($29|0),($22|0))|0;
   $p$1$lcssa = $23;
  }
  $30 = (($l$018) + 1)|0;
  $exitcond22 = ($30|0)==(17);
  if ($exitcond22) {
   break;
  } else {
   $l$018 = $30;$p$019 = $p$1$lcssa;
  }
 }
 $31 = (($huffsize) + ($p$1$lcssa)|0);
 HEAP8[$31>>0] = 0;
 $32 = HEAP8[$huffsize>>0]|0;
 $33 = ($32<<24>>24)==(0);
 if (!($33)) {
  $34 = $32 << 24 >> 24;
  $36 = $32;$code$010 = 0;$p$29 = 0;$si$08 = $34;
  while(1) {
   $35 = $36 << 24 >> 24;
   $37 = ($35|0)==($si$08|0);
   if ($37) {
    $code$14 = $code$010;$p$33 = $p$29;
    while(1) {
     $38 = (($p$33) + 1)|0;
     $39 = (($huffcode) + ($p$33<<2)|0);
     HEAP32[$39>>2] = $code$14;
     $40 = (($code$14) + 1)|0;
     $41 = (($huffsize) + ($38)|0);
     $42 = HEAP8[$41>>0]|0;
     $43 = $42 << 24 >> 24;
     $44 = ($43|0)==($si$08|0);
     if ($44) {
      $code$14 = $40;$p$33 = $38;
     } else {
      $52 = $42;$code$1$lcssa = $40;$p$3$lcssa = $38;
      break;
     }
    }
   } else {
    $52 = $36;$code$1$lcssa = $code$010;$p$3$lcssa = $p$29;
   }
   $45 = 1 << $si$08;
   $46 = ($code$1$lcssa|0)<($45|0);
   if (!($46)) {
    $47 = HEAP32[$cinfo>>2]|0;
    $48 = (($47) + 20|0);
    HEAP32[$48>>2] = 8;
    $49 = HEAP32[$47>>2]|0;
    FUNCTION_TABLE_vi[$49 & 63]($$pre$phi27Z2D);
   }
   $50 = $code$1$lcssa << 1;
   $51 = (($si$08) + 1)|0;
   $53 = ($52<<24>>24)==(0);
   if ($53) {
    break;
   } else {
    $36 = $52;$code$010 = $50;$p$29 = $p$3$lcssa;$si$08 = $51;
   }
  }
 }
 $54 = (($55) + 1024|0);
 _memset(($54|0),0,256)|0;
 $56 = $5 ? 15 : 255;
 $57 = ($p$1$lcssa|0)>(0);
 if ($57) {
  $p$42 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $58 = ((($8) + ($p$42)|0) + 17|0);
  $59 = HEAP8[$58>>0]|0;
  $60 = $59&255;
  $61 = ($60>>>0)>($56>>>0);
  $$pre$pre = ((($55) + ($60)|0) + 1024|0);
  if ($61) {
   label = 27;
  } else {
   $62 = HEAP8[$$pre$pre>>0]|0;
   $63 = ($62<<24>>24)==(0);
   if (!($63)) {
    label = 27;
   }
  }
  if ((label|0) == 27) {
   label = 0;
   $64 = HEAP32[$cinfo>>2]|0;
   $65 = (($64) + 20|0);
   HEAP32[$65>>2] = 8;
   $66 = HEAP32[$64>>2]|0;
   FUNCTION_TABLE_vi[$66 & 63]($$pre$phi27Z2D);
  }
  $67 = (($huffcode) + ($p$42<<2)|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = (($55) + ($60<<2)|0);
  HEAP32[$69>>2] = $68;
  $70 = (($huffsize) + ($p$42)|0);
  $71 = HEAP8[$70>>0]|0;
  HEAP8[$$pre$pre>>0] = $71;
  $72 = (($p$42) + 1)|0;
  $exitcond = ($72|0)==($p$1$lcssa|0);
  if ($exitcond) {
   break;
  } else {
   $p$42 = $72;
  }
 }
 STACKTOP = sp;return;
}
function _jpeg_gen_optimal_table($cinfo,$htbl,$freq) {
 $cinfo = $cinfo|0;
 $htbl = $htbl|0;
 $freq = $freq|0;
 var $$lcssa19 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $bits = 0, $c1$0 = 0, $c1$1 = 0, $c2$016 = 0, $c2$1 = 0, $codesize = 0, $exitcond = 0, $exitcond26 = 0, $exitcond30 = 0, $exitcond31 = 0, $i$1 = 0, $i$217 = 0, $i$314 = 0, $i$412 = 0, $i$5 = 0, $i$66 = 0, $j$0 = 0, $j$14 = 0, $or$cond = 0, $or$cond1 = 0;
 var $or$cond2 = 0, $others = 0, $p$05 = 0, $p$13 = 0, $p$2 = 0, $v$0 = 0, $v$1 = 0, $v$218 = 0, $v$3 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2096|0;
 $bits = sp + 2056|0;
 $codesize = sp + 1028|0;
 $others = sp;
 dest=$bits+0|0; stop=dest+33|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 _memset(($codesize|0),0,1028)|0;
 _memset(($others|0),-1,1028)|0;
 $0 = (($freq) + 1024|0);
 HEAP32[$0>>2] = 1;
 $c1$0 = -1;$i$1 = 0;$v$0 = 1000000000;
 L1: while(1) {
  $1 = ($i$1|0)<(257);
  if ($1) {
   $2 = (($freq) + ($i$1<<2)|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0);
   $5 = ($3|0)>($v$0|0);
   $or$cond = $4 | $5;
   $c1$1 = $or$cond ? $c1$0 : $i$1;
   $v$1 = $or$cond ? $v$0 : $3;
   $6 = (($i$1) + 1)|0;
   $c1$0 = $c1$1;$i$1 = $6;$v$0 = $v$1;
   continue;
  } else {
   $c2$016 = -1;$i$217 = 0;$v$218 = 1000000000;
  }
  while(1) {
   $7 = (($freq) + ($i$217<<2)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0);
   $10 = ($8|0)>($v$218|0);
   $or$cond1 = $9 | $10;
   $11 = ($i$217|0)==($c1$0|0);
   $or$cond2 = $or$cond1 | $11;
   $c2$1 = $or$cond2 ? $c2$016 : $i$217;
   $v$3 = $or$cond2 ? $v$218 : $8;
   $12 = (($i$217) + 1)|0;
   $exitcond31 = ($12|0)==(257);
   if ($exitcond31) {
    break;
   } else {
    $c2$016 = $c2$1;$i$217 = $12;$v$218 = $v$3;
   }
  }
  $13 = ($c2$1|0)<(0);
  if ($13) {
   break;
  }
  $14 = (($freq) + ($c2$1<<2)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($freq) + ($c1$0<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + ($15))|0;
  HEAP32[$16>>2] = $18;
  HEAP32[$14>>2] = 0;
  $19 = (($codesize) + ($c1$0<<2)|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + 1)|0;
  HEAP32[$19>>2] = $21;
  $22 = (($others) + ($c1$0<<2)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)>(-1);
  if ($24) {
   $26 = $23;
   while(1) {
    $25 = (($codesize) + ($26<<2)|0);
    $27 = HEAP32[$25>>2]|0;
    $28 = (($27) + 1)|0;
    HEAP32[$25>>2] = $28;
    $29 = (($others) + ($26<<2)|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)>(-1);
    if ($31) {
     $26 = $30;
    } else {
     $$lcssa19 = $29;
     break;
    }
   }
  } else {
   $$lcssa19 = $22;
  }
  HEAP32[$$lcssa19>>2] = $c2$1;
  $32 = (($codesize) + ($c2$1<<2)|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 1)|0;
  HEAP32[$32>>2] = $34;
  $35 = (($others) + ($c2$1<<2)|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)>(-1);
  if ($37) {
   $39 = $36;
  } else {
   $c1$0 = -1;$i$1 = 0;$v$0 = 1000000000;
   continue;
  }
  while(1) {
   $38 = (($codesize) + ($39<<2)|0);
   $40 = HEAP32[$38>>2]|0;
   $41 = (($40) + 1)|0;
   HEAP32[$38>>2] = $41;
   $42 = (($others) + ($39<<2)|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)>(-1);
   if ($44) {
    $39 = $43;
   } else {
    $c1$0 = -1;$i$1 = 0;$v$0 = 1000000000;
    continue L1;
   }
  }
 }
 $i$314 = 0;
 while(1) {
  $45 = (($codesize) + ($i$314<<2)|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==(0);
  if (!($47)) {
   $48 = ($46|0)>(32);
   if ($48) {
    $49 = HEAP32[$cinfo>>2]|0;
    $50 = (($49) + 20|0);
    HEAP32[$50>>2] = 39;
    $51 = HEAP32[$49>>2]|0;
    FUNCTION_TABLE_vi[$51 & 63]($cinfo);
   }
   $52 = (($bits) + ($46)|0);
   $53 = HEAP8[$52>>0]|0;
   $54 = (($53) + 1)<<24>>24;
   HEAP8[$52>>0] = $54;
  }
  $55 = (($i$314) + 1)|0;
  $exitcond30 = ($55|0)==(257);
  if ($exitcond30) {
   $i$412 = 32;
   break;
  } else {
   $i$314 = $55;
  }
 }
 while(1) {
  $56 = (($bits) + ($i$412)|0);
  $57 = HEAP8[$56>>0]|0;
  $58 = ($57<<24>>24)==(0);
  if ($58) {
   $$pre = (($i$412) + -1)|0;
   $$pre$phiZ2D = $$pre;
  } else {
   $59 = (($i$412) + -2)|0;
   $60 = (($i$412) + -1)|0;
   $61 = (($bits) + ($60)|0);
   $67 = $57;
   while(1) {
    $j$0 = $59;
    while(1) {
     $62 = (($bits) + ($j$0)|0);
     $63 = HEAP8[$62>>0]|0;
     $64 = ($63<<24>>24)==(0);
     $65 = (($j$0) + -1)|0;
     if ($64) {
      $j$0 = $65;
     } else {
      break;
     }
    }
    $66 = $67&255;
    $68 = (($66) + 254)|0;
    $69 = $68&255;
    HEAP8[$56>>0] = $69;
    $70 = HEAP8[$61>>0]|0;
    $71 = (($70) + 1)<<24>>24;
    HEAP8[$61>>0] = $71;
    $72 = (($j$0) + 1)|0;
    $73 = (($bits) + ($72)|0);
    $74 = HEAP8[$73>>0]|0;
    $75 = $74&255;
    $76 = (($75) + 2)|0;
    $77 = $76&255;
    HEAP8[$73>>0] = $77;
    $78 = HEAP8[$62>>0]|0;
    $79 = (($78) + -1)<<24>>24;
    HEAP8[$62>>0] = $79;
    $80 = HEAP8[$56>>0]|0;
    $81 = ($80<<24>>24)==(0);
    if ($81) {
     $$pre$phiZ2D = $60;
     break;
    } else {
     $67 = $80;
    }
   }
  }
  $82 = ($$pre$phiZ2D|0)>(16);
  if ($82) {
   $i$412 = $$pre$phiZ2D;
  } else {
   $i$5 = 16;
   break;
  }
 }
 while(1) {
  $83 = (($bits) + ($i$5)|0);
  $84 = HEAP8[$83>>0]|0;
  $85 = ($84<<24>>24)==(0);
  $86 = (($i$5) + -1)|0;
  if ($85) {
   $i$5 = $86;
  } else {
   break;
  }
 }
 $87 = (($84) + -1)<<24>>24;
 HEAP8[$83>>0] = $87;
 dest=$htbl+0|0; src=$bits+0|0; stop=dest+17|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $i$66 = 1;$p$05 = 0;
 while(1) {
  $j$14 = 0;$p$13 = $p$05;
  while(1) {
   $88 = (($codesize) + ($j$14<<2)|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = ($89|0)==($i$66|0);
   if ($90) {
    $91 = $j$14&255;
    $92 = ((($htbl) + ($p$13)|0) + 17|0);
    HEAP8[$92>>0] = $91;
    $93 = (($p$13) + 1)|0;
    $p$2 = $93;
   } else {
    $p$2 = $p$13;
   }
   $94 = (($j$14) + 1)|0;
   $exitcond = ($94|0)==(256);
   if ($exitcond) {
    break;
   } else {
    $j$14 = $94;$p$13 = $p$2;
   }
  }
  $95 = (($i$66) + 1)|0;
  $exitcond26 = ($95|0)==(33);
  if ($exitcond26) {
   break;
  } else {
   $i$66 = $95;$p$05 = $p$2;
  }
 }
 $96 = (($htbl) + 273|0);
 HEAP8[$96>>0] = 0;
 STACKTOP = sp;return;
}
function _jinit_huff_encoder($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 7]($cinfo,1,108)|0);
 $4 = (($cinfo) + 348|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$3>>2] = 5;
 $5 = (($3) + 60|0);
 $6 = (($3) + 44|0);
 $7 = (($3) + 92|0);
 $8 = (($3) + 76|0);
 HEAP32[$5>>2] = 0;
 HEAP32[$6>>2] = 0;
 HEAP32[$7>>2] = 0;
 HEAP32[$8>>2] = 0;
 $9 = (($3) + 64|0);
 HEAP32[$9>>2] = 0;
 $10 = (($3) + 48|0);
 HEAP32[$10>>2] = 0;
 $11 = (($3) + 96|0);
 HEAP32[$11>>2] = 0;
 $12 = (($3) + 80|0);
 HEAP32[$12>>2] = 0;
 $13 = (($3) + 68|0);
 HEAP32[$13>>2] = 0;
 $14 = (($3) + 52|0);
 HEAP32[$14>>2] = 0;
 $15 = (($3) + 100|0);
 HEAP32[$15>>2] = 0;
 $16 = (($3) + 84|0);
 HEAP32[$16>>2] = 0;
 $17 = (($3) + 72|0);
 HEAP32[$17>>2] = 0;
 $18 = (($3) + 56|0);
 HEAP32[$18>>2] = 0;
 $19 = (($3) + 104|0);
 HEAP32[$19>>2] = 0;
 $20 = (($3) + 88|0);
 HEAP32[$20>>2] = 0;
 STACKTOP = sp;return;
}
function _start_pass_huff($cinfo,$gather_statistics) {
 $cinfo = $cinfo|0;
 $gather_statistics = $gather_statistics|0;
 var $$c = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $ci$04 = 0, $ci$04$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($gather_statistics<<24>>24)!=(0);
 $3 = (($1) + 4|0);
 if ($2) {
  HEAP32[$3>>2] = 10;
  $4 = (($1) + 8|0);
  HEAP32[$4>>2] = 11;
 } else {
  HEAP32[$3>>2] = 11;
  $5 = (($1) + 8|0);
  HEAP32[$5>>2] = 12;
 }
 $6 = (($cinfo) + 228|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(0);
 L5: do {
  if ($8) {
   $9 = (($1) + 76|0);
   $10 = (($cinfo) + 4|0);
   $11 = (($1) + 92|0);
   $12 = (($1) + 20|0);
   $13 = (($1) + 44|0);
   $14 = (($1) + 60|0);
   if ($2) {
    $ci$04$us = 0;
   } else {
    $ci$04 = 0;
    while(1) {
     $49 = ((($cinfo) + ($ci$04<<2)|0) + 232|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = (($50) + 20|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = (($50) + 24|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = (($13) + ($52<<2)|0);
     _jpeg_make_c_derived_tbl($cinfo,1,$52,$55);
     $56 = (($14) + ($54<<2)|0);
     _jpeg_make_c_derived_tbl($cinfo,0,$54,$56);
     $57 = (($12) + ($ci$04<<2)|0);
     HEAP32[$57>>2] = 0;
     $58 = (($ci$04) + 1)|0;
     $59 = HEAP32[$6>>2]|0;
     $60 = ($58|0)<($59|0);
     if ($60) {
      $ci$04 = $58;
     } else {
      break L5;
     }
    }
   }
   while(1) {
    $15 = ((($cinfo) + ($ci$04$us<<2)|0) + 232|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($16) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($16) + 24|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($18>>>0)>(3);
    if ($21) {
     $22 = HEAP32[$cinfo>>2]|0;
     $23 = (($22) + 20|0);
     HEAP32[$23>>2] = 50;
     $24 = (($22) + 24|0);
     HEAP32[$24>>2] = $18;
     $25 = HEAP32[$22>>2]|0;
     FUNCTION_TABLE_vi[$25 & 63]($cinfo);
    }
    $26 = ($20>>>0)>(3);
    if ($26) {
     $27 = HEAP32[$cinfo>>2]|0;
     $28 = (($27) + 20|0);
     HEAP32[$28>>2] = 50;
     $29 = (($27) + 24|0);
     HEAP32[$29>>2] = $20;
     $30 = HEAP32[$27>>2]|0;
     FUNCTION_TABLE_vi[$30 & 63]($cinfo);
    }
    $31 = (($9) + ($18<<2)|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==(0|0);
    if ($33) {
     $34 = HEAP32[$10>>2]|0;
     $35 = HEAP32[$34>>2]|0;
     $36 = (FUNCTION_TABLE_iiii[$35 & 7]($cinfo,1,1028)|0);
     HEAP32[$31>>2] = $36;
     $37 = $36;
    } else {
     $37 = $32;
    }
    _memset(($37|0),0,1028)|0;
    $38 = (($11) + ($20<<2)|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==(0|0);
    if ($40) {
     $41 = HEAP32[$10>>2]|0;
     $42 = HEAP32[$41>>2]|0;
     $43 = (FUNCTION_TABLE_iiii[$42 & 7]($cinfo,1,1028)|0);
     HEAP32[$38>>2] = $43;
     $44 = $43;
    } else {
     $44 = $39;
    }
    _memset(($44|0),0,1028)|0;
    $45 = (($12) + ($ci$04$us<<2)|0);
    HEAP32[$45>>2] = 0;
    $46 = (($ci$04$us) + 1)|0;
    $47 = HEAP32[$6>>2]|0;
    $48 = ($46|0)<($47|0);
    if ($48) {
     $ci$04$us = $46;
    } else {
     break;
    }
   }
  }
 } while(0);
 $61 = (($1) + 12|0);
 HEAP32[$61>>2] = 0;
 $62 = (($1) + 16|0);
 HEAP32[$62>>2] = 0;
 $63 = (($cinfo) + 188|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($1) + 36|0);
 $$c = $64;
 HEAP32[$65>>2] = $$c;
 $66 = (($1) + 40|0);
 HEAP32[$66>>2] = 0;
 STACKTOP = sp;return;
}
function _encode_mcu_gather($cinfo,$MCU_data) {
 $cinfo = $cinfo|0;
 $MCU_data = $MCU_data|0;
 var $$$i = 0, $$1$i = 0, $$c = 0, $$c1 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$promoted$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $blkn$02 = 0, $ci$04 = 0, $exitcond$i = 0, $k$03$i = 0, $nbits$0$lcssa14$i = 0, $nbits$06$i = 0, $nbits$1$i = 0, $r$04$i = 0, $r$1$lcssa$i = 0, $r$2$i = 0, $temp$15$i = 0, $temp$3$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 188|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = (($1) + 36|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $8 = (($cinfo) + 228|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)>(0);
   if ($10) {
    $11 = (($1) + 20|0);
    $ci$04 = 0;
    while(1) {
     $12 = (($11) + ($ci$04<<2)|0);
     HEAP32[$12>>2] = 0;
     $13 = (($ci$04) + 1)|0;
     $14 = HEAP32[$8>>2]|0;
     $15 = ($13|0)<($14|0);
     if ($15) {
      $ci$04 = $13;
     } else {
      break;
     }
    }
    $$pre = HEAP32[$2>>2]|0;
    $16 = $$pre;
   } else {
    $16 = $3;
   }
   $$c1 = $16;
   HEAP32[$5>>2] = $$c1;
   $$pre$phiZ2D = $5;$18 = $16;
  } else {
   $$pre$phiZ2D = $5;$18 = $6;
  }
  $17 = (($18) + -1)|0;
  $$c = $17;
  HEAP32[$$pre$phiZ2D>>2] = $$c;
 }
 $19 = (($cinfo) + 256|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)>(0);
 if (!($21)) {
  STACKTOP = sp;return 1;
 }
 $22 = (($1) + 20|0);
 $23 = (($1) + 76|0);
 $24 = (($1) + 92|0);
 $blkn$02 = 0;
 while(1) {
  $25 = ((($cinfo) + ($blkn$02<<2)|0) + 260|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ((($cinfo) + ($26<<2)|0) + 232|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($MCU_data) + ($blkn$02<<2)|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($22) + ($26<<2)|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($28) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($23) + ($34<<2)|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($28) + 24|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($24) + ($38<<2)|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = HEAP16[$30>>1]|0;
  $42 = $41 << 16 >> 16;
  $43 = (($42) - ($32))|0;
  $44 = ($43|0)<(0);
  $45 = (0 - ($43))|0;
  $$$i = $44 ? $45 : $43;
  $46 = ($$$i|0)==(0);
  if ($46) {
   $nbits$0$lcssa14$i = 0;
  } else {
   $nbits$06$i = 0;$temp$15$i = $$$i;
   while(1) {
    $47 = (($nbits$06$i) + 1)|0;
    $48 = $temp$15$i >> 1;
    $49 = ($48|0)==(0);
    if ($49) {
     break;
    } else {
     $nbits$06$i = $47;$temp$15$i = $48;
    }
   }
   $50 = ($nbits$06$i|0)>(10);
   if ($50) {
    $51 = HEAP32[$cinfo>>2]|0;
    $52 = (($51) + 20|0);
    HEAP32[$52>>2] = 6;
    $53 = HEAP32[$51>>2]|0;
    FUNCTION_TABLE_vi[$53 & 63]($cinfo);
    $nbits$0$lcssa14$i = $47;
   } else {
    $nbits$0$lcssa14$i = $47;
   }
  }
  $54 = (($36) + ($nbits$0$lcssa14$i<<2)|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (($55) + 1)|0;
  HEAP32[$54>>2] = $56;
  $57 = (($40) + 960|0);
  $k$03$i = 1;$r$04$i = 0;
  while(1) {
   $58 = (142704 + ($k$03$i<<2)|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = (($30) + ($59<<1)|0);
   $61 = HEAP16[$60>>1]|0;
   $62 = $61 << 16 >> 16;
   $63 = ($61<<16>>16)==(0);
   if ($63) {
    $71 = (($r$04$i) + 1)|0;
    $r$2$i = $71;
   } else {
    $64 = ($r$04$i|0)>(15);
    if ($64) {
     $$promoted$i = HEAP32[$57>>2]|0;
     $65 = (($r$04$i) + -16)|0;
     $66 = $65 >>> 4;
     $67 = $66 << 4;
     $68 = (($65) - ($67))|0;
     $69 = (($66) + 1)|0;
     $70 = (($69) + ($$promoted$i))|0;
     HEAP32[$57>>2] = $70;
     $r$1$lcssa$i = $68;
    } else {
     $r$1$lcssa$i = $r$04$i;
    }
    $72 = ($61<<16>>16)<(0);
    $73 = (0 - ($62))|0;
    $$1$i = $72 ? $73 : $62;
    $nbits$1$i = 1;$temp$3$i = $$1$i;
    while(1) {
     $74 = $temp$3$i >> 1;
     $75 = ($74|0)==(0);
     $76 = (($nbits$1$i) + 1)|0;
     if ($75) {
      break;
     } else {
      $nbits$1$i = $76;$temp$3$i = $74;
     }
    }
    $77 = ($nbits$1$i|0)>(10);
    if ($77) {
     $78 = HEAP32[$cinfo>>2]|0;
     $79 = (($78) + 20|0);
     HEAP32[$79>>2] = 6;
     $80 = HEAP32[$78>>2]|0;
     FUNCTION_TABLE_vi[$80 & 63]($cinfo);
    }
    $81 = $r$1$lcssa$i << 4;
    $82 = (($nbits$1$i) + ($81))|0;
    $83 = (($40) + ($82<<2)|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = (($84) + 1)|0;
    HEAP32[$83>>2] = $85;
    $r$2$i = 0;
   }
   $86 = (($k$03$i) + 1)|0;
   $exitcond$i = ($86|0)==(64);
   if ($exitcond$i) {
    break;
   } else {
    $k$03$i = $86;$r$04$i = $r$2$i;
   }
  }
  $87 = ($r$2$i|0)>(0);
  if ($87) {
   $88 = HEAP32[$40>>2]|0;
   $89 = (($88) + 1)|0;
   HEAP32[$40>>2] = $89;
  }
  $90 = HEAP32[$29>>2]|0;
  $91 = HEAP16[$90>>1]|0;
  $92 = $91 << 16 >> 16;
  HEAP32[$31>>2] = $92;
  $93 = (($blkn$02) + 1)|0;
  $94 = HEAP32[$19>>2]|0;
  $95 = ($93|0)<($94|0);
  if ($95) {
   $blkn$02 = $93;
  } else {
   break;
  }
 }
 STACKTOP = sp;return 1;
}
function _finish_pass_gather($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ci$02 = 0, $did_ac = 0, $did_dc = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $did_dc = sp + 4|0;
 $did_ac = sp;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$did_dc>>2] = 0;
 HEAP32[$did_ac>>2] = 0;
 $2 = (($cinfo) + 228|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = (($1) + 76|0);
 $6 = (($1) + 92|0);
 $ci$02 = 0;
 while(1) {
  $7 = ((($cinfo) + ($ci$02<<2)|0) + 232|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 20|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 24|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($did_dc) + ($10)|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   $16 = ((($cinfo) + ($10<<2)|0) + 88|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0|0);
   if ($18) {
    $19 = (_jpeg_alloc_huff_table($cinfo)|0);
    HEAP32[$16>>2] = $19;
    $22 = $19;
   } else {
    $22 = $17;
   }
   $20 = (($5) + ($10<<2)|0);
   $21 = HEAP32[$20>>2]|0;
   _jpeg_gen_optimal_table($cinfo,$22,$21);
   HEAP8[$13>>0] = 1;
  }
  $23 = (($did_ac) + ($12)|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = ($24<<24>>24)==(0);
  if ($25) {
   $26 = ((($cinfo) + ($12<<2)|0) + 104|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0|0);
   if ($28) {
    $29 = (_jpeg_alloc_huff_table($cinfo)|0);
    HEAP32[$26>>2] = $29;
    $32 = $29;
   } else {
    $32 = $27;
   }
   $30 = (($6) + ($12<<2)|0);
   $31 = HEAP32[$30>>2]|0;
   _jpeg_gen_optimal_table($cinfo,$32,$31);
   HEAP8[$23>>0] = 1;
  }
  $33 = (($ci$02) + 1)|0;
  $34 = HEAP32[$2>>2]|0;
  $35 = ($33|0)<($34|0);
  if ($35) {
   $ci$02 = $33;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _encode_mcu_huff($cinfo,$MCU_data) {
 $cinfo = $cinfo|0;
 $MCU_data = $MCU_data|0;
 var $$0 = 0, $$c = 0, $$c1 = 0, $$c2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $blkn$05 = 0, $ci$03$i = 0, $state = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $state = sp;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$state>>2] = $4;
 $5 = (($3) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($state) + 4|0);
 HEAP32[$7>>2] = $6;
 $8 = (($state) + 8|0);
 $9 = (($1) + 12|0);
 ;HEAP32[$8+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$9+12>>2]|0;HEAP32[$8+16>>2]=HEAP32[$9+16>>2]|0;HEAP32[$8+20>>2]=HEAP32[$9+20>>2]|0;
 $10 = (($state) + 32|0);
 HEAP32[$10>>2] = $cinfo;
 $11 = (($cinfo) + 188|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 if (!($13)) {
  $14 = (($1) + 36|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0);
  if ($16) {
   $17 = (($1) + 40|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (_flush_bits($state)|0);
   $20 = ($19<<24>>24)==(0);
   if ($20) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $21 = HEAP32[$state>>2]|0;
   $22 = (($21) + 1|0);
   HEAP32[$state>>2] = $22;
   HEAP8[$21>>0] = -1;
   $23 = HEAP32[$7>>2]|0;
   $24 = (($23) + -1)|0;
   HEAP32[$7>>2] = $24;
   $25 = ($24|0)==(0);
   do {
    if ($25) {
     $26 = HEAP32[$10>>2]|0;
     $27 = (($26) + 24|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = (($28) + 12|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = (FUNCTION_TABLE_ii[$30 & 7]($26)|0);
     $32 = ($31<<24>>24)==(0);
     if ($32) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     } else {
      $33 = HEAP32[$28>>2]|0;
      HEAP32[$state>>2] = $33;
      $34 = (($28) + 4|0);
      $35 = HEAP32[$34>>2]|0;
      HEAP32[$7>>2] = $35;
      $39 = $33;$41 = $35;
      break;
     }
    } else {
     $39 = $22;$41 = $24;
    }
   } while(0);
   $36 = (($18) + 208)|0;
   $37 = $36&255;
   $38 = (($39) + 1|0);
   HEAP32[$state>>2] = $38;
   HEAP8[$39>>0] = $37;
   $40 = (($41) + -1)|0;
   HEAP32[$7>>2] = $40;
   $42 = ($40|0)==(0);
   $43 = HEAP32[$10>>2]|0;
   do {
    if ($42) {
     $44 = (($43) + 24|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = (($45) + 12|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = (FUNCTION_TABLE_ii[$47 & 7]($43)|0);
     $49 = ($48<<24>>24)==(0);
     if ($49) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     } else {
      $50 = HEAP32[$45>>2]|0;
      HEAP32[$state>>2] = $50;
      $51 = (($45) + 4|0);
      $52 = HEAP32[$51>>2]|0;
      HEAP32[$7>>2] = $52;
      break;
     }
    }
   } while(0);
   $53 = (($43) + 228|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)>(0);
   if ($55) {
    $ci$03$i = 0;
    while(1) {
     $56 = ((($state) + ($ci$03$i<<2)|0) + 16|0);
     HEAP32[$56>>2] = 0;
     $57 = (($ci$03$i) + 1)|0;
     $58 = HEAP32[$10>>2]|0;
     $59 = (($58) + 228|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ($57|0)<($60|0);
     if ($61) {
      $ci$03$i = $57;
     } else {
      break;
     }
    }
   }
  }
 }
 $62 = (($cinfo) + 256|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($63|0)>(0);
 L22: do {
  if ($64) {
   $65 = (($1) + 44|0);
   $66 = (($1) + 60|0);
   $blkn$05 = 0;
   while(1) {
    $67 = ((($cinfo) + ($blkn$05<<2)|0) + 260|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = ((($cinfo) + ($68<<2)|0) + 232|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = (($MCU_data) + ($blkn$05<<2)|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ((($state) + ($68<<2)|0) + 16|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = (($70) + 20|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = (($65) + ($76<<2)|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = (($70) + 24|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = (($66) + ($80<<2)|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (_encode_one_block($state,$72,$74,$78,$82)|0);
    $84 = ($83<<24>>24)==(0);
    if ($84) {
     $$0 = 0;
     break;
    }
    $85 = HEAP32[$71>>2]|0;
    $86 = HEAP16[$85>>1]|0;
    $87 = $86 << 16 >> 16;
    HEAP32[$73>>2] = $87;
    $88 = (($blkn$05) + 1)|0;
    $89 = HEAP32[$62>>2]|0;
    $90 = ($88|0)<($89|0);
    if ($90) {
     $blkn$05 = $88;
    } else {
     break L22;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $91 = HEAP32[$state>>2]|0;
 $92 = HEAP32[$2>>2]|0;
 HEAP32[$92>>2] = $91;
 $93 = HEAP32[$7>>2]|0;
 $94 = HEAP32[$2>>2]|0;
 $95 = (($94) + 4|0);
 HEAP32[$95>>2] = $93;
 ;HEAP32[$9+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$8+12>>2]|0;HEAP32[$9+16>>2]=HEAP32[$8+16>>2]|0;HEAP32[$9+20>>2]=HEAP32[$8+20>>2]|0;
 $96 = HEAP32[$11>>2]|0;
 $97 = ($96|0)==(0);
 if ($97) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $98 = (($1) + 36|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = ($99|0)==(0);
 if ($100) {
  $$c1 = $96;
  HEAP32[$98>>2] = $$c1;
  $101 = (($1) + 40|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = (($102) + 1)|0;
  $104 = $103 & 7;
  $$c2 = $104;
  HEAP32[$101>>2] = $$c2;
  $106 = $96;
 } else {
  $106 = $99;
 }
 $105 = (($106) + -1)|0;
 $$c = $105;
 HEAP32[$98>>2] = $$c;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _finish_pass_huff($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $state = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $state = sp;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$state>>2] = $4;
 $5 = (($3) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($state) + 4|0);
 HEAP32[$7>>2] = $6;
 $8 = (($state) + 8|0);
 $9 = (($1) + 12|0);
 ;HEAP32[$8+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$9+12>>2]|0;HEAP32[$8+16>>2]=HEAP32[$9+16>>2]|0;HEAP32[$8+20>>2]=HEAP32[$9+20>>2]|0;
 $10 = (($state) + 32|0);
 HEAP32[$10>>2] = $cinfo;
 $11 = (_flush_bits($state)|0);
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  $13 = HEAP32[$cinfo>>2]|0;
  $14 = (($13) + 20|0);
  HEAP32[$14>>2] = 24;
  $15 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_vi[$15 & 63]($cinfo);
 }
 $16 = HEAP32[$state>>2]|0;
 $17 = HEAP32[$2>>2]|0;
 HEAP32[$17>>2] = $16;
 $18 = HEAP32[$7>>2]|0;
 $19 = HEAP32[$2>>2]|0;
 $20 = (($19) + 4|0);
 HEAP32[$20>>2] = $18;
 ;HEAP32[$9+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$8+12>>2]|0;HEAP32[$9+16>>2]=HEAP32[$8+16>>2]|0;HEAP32[$9+20>>2]=HEAP32[$8+20>>2]|0;
 STACKTOP = sp;return;
}
function _flush_bits($state) {
 $state = $state|0;
 var $$0 = 0, $$pre = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_buffer = 0, $buffer$0 = 0;
 var $buffer$1$be = 0, $buffer$1$lcssa = 0, $buffer$14 = 0, $buffer$22 = 0, $bytes$0$ = 0, $bytes$01 = 0, $localbuf$0 = 0, $put_bits$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $_buffer = sp;
 $0 = (($state) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($state) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($state) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5>>>0)<(256);
 if ($6) {
  $buffer$0 = $_buffer;$localbuf$0 = 1;
 } else {
  $7 = HEAP32[$state>>2]|0;
  $buffer$0 = $7;$localbuf$0 = 0;
 }
 $8 = $1 << 7;
 $9 = $8 | 127;
 $10 = ($3|0)>(0);
 if ($10) {
  $11 = (($3) + 7)|0;
  $buffer$14 = $buffer$0;$put_bits$03 = $11;
  while(1) {
   $12 = (($put_bits$03) + -8)|0;
   $13 = $9 >>> $12;
   $14 = $13&255;
   $15 = (($buffer$14) + 1|0);
   HEAP8[$buffer$14>>0] = $14;
   $16 = $13 & 255;
   $17 = ($16|0)==(255);
   if ($17) {
    $18 = (($buffer$14) + 2|0);
    HEAP8[$15>>0] = 0;
    $buffer$1$be = $18;
   } else {
    $buffer$1$be = $15;
   }
   $19 = ($12|0)>(7);
   if ($19) {
    $buffer$14 = $buffer$1$be;$put_bits$03 = $12;
   } else {
    $buffer$1$lcssa = $buffer$1$be;
    break;
   }
  }
 } else {
  $buffer$1$lcssa = $buffer$0;
 }
 HEAP32[$0>>2] = 0;
 HEAP32[$2>>2] = 0;
 $20 = ($localbuf$0|0)==(0);
 if ($20) {
  $47 = HEAP32[$state>>2]|0;
  $48 = $buffer$1$lcssa;
  $49 = $47;
  $50 = HEAP32[$4>>2]|0;
  $51 = (($49) - ($48))|0;
  $52 = (($51) + ($50))|0;
  HEAP32[$4>>2] = $52;
  HEAP32[$state>>2] = $buffer$1$lcssa;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = (($state) + 32|0);
 $22 = ($buffer$1$lcssa|0)==($_buffer|0);
 if ($22) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $23 = $buffer$1$lcssa;
 $24 = $_buffer;
 $25 = (($23) - ($24))|0;
 $$pre = HEAP32[$4>>2]|0;
 $$pre7 = HEAP32[$state>>2]|0;
 $27 = $$pre;$28 = $$pre7;$buffer$22 = $_buffer;$bytes$01 = $25;
 while(1) {
  $26 = ($bytes$01>>>0)<($27>>>0);
  $bytes$0$ = $26 ? $bytes$01 : $27;
  _memcpy(($28|0),($buffer$22|0),($bytes$0$|0))|0;
  $29 = HEAP32[$state>>2]|0;
  $30 = (($29) + ($bytes$0$)|0);
  HEAP32[$state>>2] = $30;
  $31 = (($buffer$22) + ($bytes$0$)|0);
  $32 = HEAP32[$4>>2]|0;
  $33 = (($32) - ($bytes$0$))|0;
  HEAP32[$4>>2] = $33;
  $34 = ($32|0)==($bytes$0$|0);
  if ($34) {
   $35 = HEAP32[$21>>2]|0;
   $36 = (($35) + 24|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($37) + 12|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (FUNCTION_TABLE_ii[$39 & 7]($35)|0);
   $41 = ($40<<24>>24)==(0);
   if ($41) {
    $$0 = 0;
    label = 16;
    break;
   }
   $42 = HEAP32[$37>>2]|0;
   HEAP32[$state>>2] = $42;
   $43 = (($37) + 4|0);
   $44 = HEAP32[$43>>2]|0;
   HEAP32[$4>>2] = $44;
   $53 = $42;$54 = $44;
  } else {
   $53 = $30;$54 = $33;
  }
  $45 = (($bytes$01) - ($bytes$0$))|0;
  $46 = ($bytes$01|0)==($bytes$0$|0);
  if ($46) {
   $$0 = 1;
   label = 16;
   break;
  } else {
   $27 = $54;$28 = $53;$buffer$22 = $31;$bytes$01 = $45;
  }
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _encode_one_block($state,$block,$last_dc_val,$dctbl,$actbl) {
 $state = $state|0;
 $block = $block|0;
 $last_dc_val = $last_dc_val|0;
 $dctbl = $dctbl|0;
 $actbl = $actbl|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0;
 var $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0;
 var $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0;
 var $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0;
 var $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0;
 var $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0;
 var $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0;
 var $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0;
 var $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0;
 var $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0;
 var $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0;
 var $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0;
 var $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0;
 var $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0;
 var $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0;
 var $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0;
 var $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0;
 var $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0;
 var $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0;
 var $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0;
 var $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0;
 var $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0;
 var $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0;
 var $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0;
 var $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0;
 var $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0;
 var $1465 = 0, $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0;
 var $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0;
 var $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0;
 var $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0;
 var $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0;
 var $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0;
 var $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0;
 var $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0;
 var $1609 = 0, $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0;
 var $1627 = 0, $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0;
 var $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0;
 var $1663 = 0, $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0;
 var $1681 = 0, $1682 = 0, $1683 = 0, $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0;
 var $17 = 0, $170 = 0, $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0;
 var $1717 = 0, $1718 = 0, $1719 = 0, $172 = 0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0, $1730 = 0, $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0;
 var $1735 = 0, $1736 = 0, $1737 = 0, $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0, $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0;
 var $1753 = 0, $1754 = 0, $1755 = 0, $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0, $1765 = 0, $1766 = 0, $1767 = 0, $1768 = 0, $1769 = 0, $177 = 0, $1770 = 0;
 var $1771 = 0, $1772 = 0, $1773 = 0, $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0, $1779 = 0, $178 = 0, $1780 = 0, $1781 = 0, $1782 = 0, $1783 = 0, $1784 = 0, $1785 = 0, $1786 = 0, $1787 = 0, $1788 = 0, $1789 = 0;
 var $179 = 0, $1790 = 0, $1791 = 0, $1792 = 0, $1793 = 0, $1794 = 0, $1795 = 0, $1796 = 0, $1797 = 0, $1798 = 0, $1799 = 0, $18 = 0, $180 = 0, $1800 = 0, $1801 = 0, $1802 = 0, $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0;
 var $1807 = 0, $1808 = 0, $1809 = 0, $181 = 0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0, $1814 = 0, $1815 = 0, $1816 = 0, $1817 = 0, $1818 = 0, $1819 = 0, $182 = 0, $1820 = 0, $1821 = 0, $1822 = 0, $1823 = 0, $1824 = 0;
 var $1825 = 0, $1826 = 0, $1827 = 0, $1828 = 0, $1829 = 0, $183 = 0, $1830 = 0, $1831 = 0, $1832 = 0, $1833 = 0, $1834 = 0, $1835 = 0, $1836 = 0, $1837 = 0, $1838 = 0, $1839 = 0, $184 = 0, $1840 = 0, $1841 = 0, $1842 = 0;
 var $1843 = 0, $1844 = 0, $1845 = 0, $1846 = 0, $1847 = 0, $1848 = 0, $1849 = 0, $185 = 0, $1850 = 0, $1851 = 0, $1852 = 0, $1853 = 0, $1854 = 0, $1855 = 0, $1856 = 0, $1857 = 0, $1858 = 0, $1859 = 0, $186 = 0, $1860 = 0;
 var $1861 = 0, $1862 = 0, $1863 = 0, $1864 = 0, $1865 = 0, $1866 = 0, $1867 = 0, $1868 = 0, $1869 = 0, $187 = 0, $1870 = 0, $1871 = 0, $1872 = 0, $1873 = 0, $1874 = 0, $1875 = 0, $1876 = 0, $1877 = 0, $1878 = 0, $1879 = 0;
 var $188 = 0, $1880 = 0, $1881 = 0, $1882 = 0, $1883 = 0, $1884 = 0, $1885 = 0, $1886 = 0, $1887 = 0, $1888 = 0, $1889 = 0, $189 = 0, $1890 = 0, $1891 = 0, $1892 = 0, $1893 = 0, $1894 = 0, $1895 = 0, $1896 = 0, $1897 = 0;
 var $1898 = 0, $1899 = 0, $19 = 0, $190 = 0, $1900 = 0, $1901 = 0, $1902 = 0, $1903 = 0, $1904 = 0, $1905 = 0, $1906 = 0, $1907 = 0, $1908 = 0, $1909 = 0, $191 = 0, $1910 = 0, $1911 = 0, $1912 = 0, $1913 = 0, $1914 = 0;
 var $1915 = 0, $1916 = 0, $1917 = 0, $1918 = 0, $1919 = 0, $192 = 0, $1920 = 0, $1921 = 0, $1922 = 0, $1923 = 0, $1924 = 0, $1925 = 0, $1926 = 0, $1927 = 0, $1928 = 0, $1929 = 0, $193 = 0, $1930 = 0, $1931 = 0, $1932 = 0;
 var $1933 = 0, $1934 = 0, $1935 = 0, $1936 = 0, $1937 = 0, $1938 = 0, $1939 = 0, $194 = 0, $1940 = 0, $1941 = 0, $1942 = 0, $1943 = 0, $1944 = 0, $1945 = 0, $1946 = 0, $1947 = 0, $1948 = 0, $1949 = 0, $195 = 0, $1950 = 0;
 var $1951 = 0, $1952 = 0, $1953 = 0, $1954 = 0, $1955 = 0, $1956 = 0, $1957 = 0, $1958 = 0, $1959 = 0, $196 = 0, $1960 = 0, $1961 = 0, $1962 = 0, $1963 = 0, $1964 = 0, $1965 = 0, $1966 = 0, $1967 = 0, $1968 = 0, $1969 = 0;
 var $197 = 0, $1970 = 0, $1971 = 0, $1972 = 0, $1973 = 0, $1974 = 0, $1975 = 0, $1976 = 0, $1977 = 0, $1978 = 0, $1979 = 0, $198 = 0, $1980 = 0, $1981 = 0, $1982 = 0, $1983 = 0, $1984 = 0, $1985 = 0, $1986 = 0, $1987 = 0;
 var $1988 = 0, $1989 = 0, $199 = 0, $1990 = 0, $1991 = 0, $1992 = 0, $1993 = 0, $1994 = 0, $1995 = 0, $1996 = 0, $1997 = 0, $1998 = 0, $1999 = 0, $2 = 0, $20 = 0, $200 = 0, $2000 = 0, $2001 = 0, $2002 = 0, $2003 = 0;
 var $2004 = 0, $2005 = 0, $2006 = 0, $2007 = 0, $2008 = 0, $2009 = 0, $201 = 0, $2010 = 0, $2011 = 0, $2012 = 0, $2013 = 0, $2014 = 0, $2015 = 0, $2016 = 0, $2017 = 0, $2018 = 0, $2019 = 0, $202 = 0, $2020 = 0, $2021 = 0;
 var $2022 = 0, $2023 = 0, $2024 = 0, $2025 = 0, $2026 = 0, $2027 = 0, $2028 = 0, $2029 = 0, $203 = 0, $2030 = 0, $2031 = 0, $2032 = 0, $2033 = 0, $2034 = 0, $2035 = 0, $2036 = 0, $2037 = 0, $2038 = 0, $2039 = 0, $204 = 0;
 var $2040 = 0, $2041 = 0, $2042 = 0, $2043 = 0, $2044 = 0, $2045 = 0, $2046 = 0, $2047 = 0, $2048 = 0, $2049 = 0, $205 = 0, $2050 = 0, $2051 = 0, $2052 = 0, $2053 = 0, $2054 = 0, $2055 = 0, $2056 = 0, $2057 = 0, $2058 = 0;
 var $2059 = 0, $206 = 0, $2060 = 0, $2061 = 0, $2062 = 0, $2063 = 0, $2064 = 0, $2065 = 0, $2066 = 0, $2067 = 0, $2068 = 0, $2069 = 0, $207 = 0, $2070 = 0, $2071 = 0, $2072 = 0, $2073 = 0, $2074 = 0, $2075 = 0, $2076 = 0;
 var $2077 = 0, $2078 = 0, $2079 = 0, $208 = 0, $2080 = 0, $2081 = 0, $2082 = 0, $2083 = 0, $2084 = 0, $2085 = 0, $2086 = 0, $2087 = 0, $2088 = 0, $2089 = 0, $209 = 0, $2090 = 0, $2091 = 0, $2092 = 0, $2093 = 0, $2094 = 0;
 var $2095 = 0, $2096 = 0, $2097 = 0, $2098 = 0, $2099 = 0, $21 = 0, $210 = 0, $2100 = 0, $2101 = 0, $2102 = 0, $2103 = 0, $2104 = 0, $2105 = 0, $2106 = 0, $2107 = 0, $2108 = 0, $2109 = 0, $211 = 0, $2110 = 0, $2111 = 0;
 var $2112 = 0, $2113 = 0, $2114 = 0, $2115 = 0, $2116 = 0, $2117 = 0, $2118 = 0, $2119 = 0, $212 = 0, $2120 = 0, $2121 = 0, $2122 = 0, $2123 = 0, $2124 = 0, $2125 = 0, $2126 = 0, $2127 = 0, $2128 = 0, $2129 = 0, $213 = 0;
 var $2130 = 0, $2131 = 0, $2132 = 0, $2133 = 0, $2134 = 0, $2135 = 0, $2136 = 0, $2137 = 0, $2138 = 0, $2139 = 0, $214 = 0, $2140 = 0, $2141 = 0, $2142 = 0, $2143 = 0, $2144 = 0, $2145 = 0, $2146 = 0, $2147 = 0, $2148 = 0;
 var $2149 = 0, $215 = 0, $2150 = 0, $2151 = 0, $2152 = 0, $2153 = 0, $2154 = 0, $2155 = 0, $2156 = 0, $2157 = 0, $2158 = 0, $2159 = 0, $216 = 0, $2160 = 0, $2161 = 0, $2162 = 0, $2163 = 0, $2164 = 0, $2165 = 0, $2166 = 0;
 var $2167 = 0, $2168 = 0, $2169 = 0, $217 = 0, $2170 = 0, $2171 = 0, $2172 = 0, $2173 = 0, $2174 = 0, $2175 = 0, $2176 = 0, $2177 = 0, $2178 = 0, $2179 = 0, $218 = 0, $2180 = 0, $2181 = 0, $2182 = 0, $2183 = 0, $2184 = 0;
 var $2185 = 0, $2186 = 0, $2187 = 0, $2188 = 0, $2189 = 0, $219 = 0, $2190 = 0, $2191 = 0, $2192 = 0, $2193 = 0, $2194 = 0, $2195 = 0, $2196 = 0, $2197 = 0, $2198 = 0, $2199 = 0, $22 = 0, $220 = 0, $2200 = 0, $2201 = 0;
 var $2202 = 0, $2203 = 0, $2204 = 0, $2205 = 0, $2206 = 0, $2207 = 0, $2208 = 0, $2209 = 0, $221 = 0, $2210 = 0, $2211 = 0, $2212 = 0, $2213 = 0, $2214 = 0, $2215 = 0, $2216 = 0, $2217 = 0, $2218 = 0, $2219 = 0, $222 = 0;
 var $2220 = 0, $2221 = 0, $2222 = 0, $2223 = 0, $2224 = 0, $2225 = 0, $2226 = 0, $2227 = 0, $2228 = 0, $2229 = 0, $223 = 0, $2230 = 0, $2231 = 0, $2232 = 0, $2233 = 0, $2234 = 0, $2235 = 0, $2236 = 0, $2237 = 0, $2238 = 0;
 var $2239 = 0, $224 = 0, $2240 = 0, $2241 = 0, $2242 = 0, $2243 = 0, $2244 = 0, $2245 = 0, $2246 = 0, $2247 = 0, $2248 = 0, $2249 = 0, $225 = 0, $2250 = 0, $2251 = 0, $2252 = 0, $2253 = 0, $2254 = 0, $2255 = 0, $2256 = 0;
 var $2257 = 0, $2258 = 0, $2259 = 0, $226 = 0, $2260 = 0, $2261 = 0, $2262 = 0, $2263 = 0, $2264 = 0, $2265 = 0, $2266 = 0, $2267 = 0, $2268 = 0, $2269 = 0, $227 = 0, $2270 = 0, $2271 = 0, $2272 = 0, $2273 = 0, $2274 = 0;
 var $2275 = 0, $2276 = 0, $2277 = 0, $2278 = 0, $2279 = 0, $228 = 0, $2280 = 0, $2281 = 0, $2282 = 0, $2283 = 0, $2284 = 0, $2285 = 0, $2286 = 0, $2287 = 0, $2288 = 0, $2289 = 0, $229 = 0, $2290 = 0, $2291 = 0, $2292 = 0;
 var $2293 = 0, $2294 = 0, $2295 = 0, $2296 = 0, $2297 = 0, $2298 = 0, $2299 = 0, $23 = 0, $230 = 0, $2300 = 0, $2301 = 0, $2302 = 0, $2303 = 0, $2304 = 0, $2305 = 0, $2306 = 0, $2307 = 0, $2308 = 0, $2309 = 0, $231 = 0;
 var $2310 = 0, $2311 = 0, $2312 = 0, $2313 = 0, $2314 = 0, $2315 = 0, $2316 = 0, $2317 = 0, $2318 = 0, $2319 = 0, $232 = 0, $2320 = 0, $2321 = 0, $2322 = 0, $2323 = 0, $2324 = 0, $2325 = 0, $2326 = 0, $2327 = 0, $2328 = 0;
 var $2329 = 0, $233 = 0, $2330 = 0, $2331 = 0, $2332 = 0, $2333 = 0, $2334 = 0, $2335 = 0, $2336 = 0, $2337 = 0, $2338 = 0, $2339 = 0, $234 = 0, $2340 = 0, $2341 = 0, $2342 = 0, $2343 = 0, $2344 = 0, $2345 = 0, $2346 = 0;
 var $2347 = 0, $2348 = 0, $2349 = 0, $235 = 0, $2350 = 0, $2351 = 0, $2352 = 0, $2353 = 0, $2354 = 0, $2355 = 0, $2356 = 0, $2357 = 0, $2358 = 0, $2359 = 0, $236 = 0, $2360 = 0, $2361 = 0, $2362 = 0, $2363 = 0, $2364 = 0;
 var $2365 = 0, $2366 = 0, $2367 = 0, $2368 = 0, $2369 = 0, $237 = 0, $2370 = 0, $2371 = 0, $2372 = 0, $2373 = 0, $2374 = 0, $2375 = 0, $2376 = 0, $2377 = 0, $2378 = 0, $2379 = 0, $238 = 0, $2380 = 0, $2381 = 0, $2382 = 0;
 var $2383 = 0, $2384 = 0, $2385 = 0, $2386 = 0, $2387 = 0, $2388 = 0, $2389 = 0, $239 = 0, $2390 = 0, $2391 = 0, $2392 = 0, $2393 = 0, $2394 = 0, $2395 = 0, $2396 = 0, $2397 = 0, $2398 = 0, $2399 = 0, $24 = 0, $240 = 0;
 var $2400 = 0, $2401 = 0, $2402 = 0, $2403 = 0, $2404 = 0, $2405 = 0, $2406 = 0, $2407 = 0, $2408 = 0, $2409 = 0, $241 = 0, $2410 = 0, $2411 = 0, $2412 = 0, $2413 = 0, $2414 = 0, $2415 = 0, $2416 = 0, $2417 = 0, $2418 = 0;
 var $2419 = 0, $242 = 0, $2420 = 0, $2421 = 0, $2422 = 0, $2423 = 0, $2424 = 0, $2425 = 0, $2426 = 0, $2427 = 0, $2428 = 0, $2429 = 0, $243 = 0, $2430 = 0, $2431 = 0, $2432 = 0, $2433 = 0, $2434 = 0, $2435 = 0, $2436 = 0;
 var $2437 = 0, $2438 = 0, $2439 = 0, $244 = 0, $2440 = 0, $2441 = 0, $2442 = 0, $2443 = 0, $2444 = 0, $2445 = 0, $2446 = 0, $2447 = 0, $2448 = 0, $2449 = 0, $245 = 0, $2450 = 0, $2451 = 0, $2452 = 0, $2453 = 0, $2454 = 0;
 var $2455 = 0, $2456 = 0, $2457 = 0, $2458 = 0, $2459 = 0, $246 = 0, $2460 = 0, $2461 = 0, $2462 = 0, $2463 = 0, $2464 = 0, $2465 = 0, $2466 = 0, $2467 = 0, $2468 = 0, $2469 = 0, $247 = 0, $2470 = 0, $2471 = 0, $2472 = 0;
 var $2473 = 0, $2474 = 0, $2475 = 0, $2476 = 0, $2477 = 0, $2478 = 0, $2479 = 0, $248 = 0, $2480 = 0, $2481 = 0, $2482 = 0, $2483 = 0, $2484 = 0, $2485 = 0, $2486 = 0, $2487 = 0, $2488 = 0, $2489 = 0, $249 = 0, $2490 = 0;
 var $2491 = 0, $2492 = 0, $2493 = 0, $2494 = 0, $2495 = 0, $2496 = 0, $2497 = 0, $2498 = 0, $2499 = 0, $25 = 0, $250 = 0, $2500 = 0, $2501 = 0, $2502 = 0, $2503 = 0, $2504 = 0, $2505 = 0, $2506 = 0, $2507 = 0, $2508 = 0;
 var $2509 = 0, $251 = 0, $2510 = 0, $2511 = 0, $2512 = 0, $2513 = 0, $2514 = 0, $2515 = 0, $2516 = 0, $2517 = 0, $2518 = 0, $2519 = 0, $252 = 0, $2520 = 0, $2521 = 0, $2522 = 0, $2523 = 0, $2524 = 0, $2525 = 0, $2526 = 0;
 var $2527 = 0, $2528 = 0, $2529 = 0, $253 = 0, $2530 = 0, $2531 = 0, $2532 = 0, $2533 = 0, $2534 = 0, $2535 = 0, $2536 = 0, $2537 = 0, $2538 = 0, $2539 = 0, $254 = 0, $2540 = 0, $2541 = 0, $2542 = 0, $2543 = 0, $2544 = 0;
 var $2545 = 0, $2546 = 0, $2547 = 0, $2548 = 0, $2549 = 0, $255 = 0, $2550 = 0, $2551 = 0, $2552 = 0, $2553 = 0, $2554 = 0, $2555 = 0, $2556 = 0, $2557 = 0, $2558 = 0, $2559 = 0, $256 = 0, $2560 = 0, $2561 = 0, $2562 = 0;
 var $2563 = 0, $2564 = 0, $2565 = 0, $2566 = 0, $2567 = 0, $2568 = 0, $2569 = 0, $257 = 0, $2570 = 0, $2571 = 0, $2572 = 0, $2573 = 0, $2574 = 0, $2575 = 0, $2576 = 0, $2577 = 0, $2578 = 0, $2579 = 0, $258 = 0, $2580 = 0;
 var $2581 = 0, $2582 = 0, $2583 = 0, $2584 = 0, $2585 = 0, $2586 = 0, $2587 = 0, $2588 = 0, $2589 = 0, $259 = 0, $2590 = 0, $2591 = 0, $2592 = 0, $2593 = 0, $2594 = 0, $2595 = 0, $2596 = 0, $2597 = 0, $2598 = 0, $2599 = 0;
 var $26 = 0, $260 = 0, $2600 = 0, $2601 = 0, $2602 = 0, $2603 = 0, $2604 = 0, $2605 = 0, $2606 = 0, $2607 = 0, $2608 = 0, $2609 = 0, $261 = 0, $2610 = 0, $2611 = 0, $2612 = 0, $2613 = 0, $2614 = 0, $2615 = 0, $2616 = 0;
 var $2617 = 0, $2618 = 0, $2619 = 0, $262 = 0, $2620 = 0, $2621 = 0, $2622 = 0, $2623 = 0, $2624 = 0, $2625 = 0, $2626 = 0, $2627 = 0, $2628 = 0, $2629 = 0, $263 = 0, $2630 = 0, $2631 = 0, $2632 = 0, $2633 = 0, $2634 = 0;
 var $2635 = 0, $2636 = 0, $2637 = 0, $2638 = 0, $2639 = 0, $264 = 0, $2640 = 0, $2641 = 0, $2642 = 0, $2643 = 0, $2644 = 0, $2645 = 0, $2646 = 0, $2647 = 0, $2648 = 0, $2649 = 0, $265 = 0, $2650 = 0, $2651 = 0, $2652 = 0;
 var $2653 = 0, $2654 = 0, $2655 = 0, $2656 = 0, $2657 = 0, $2658 = 0, $2659 = 0, $266 = 0, $2660 = 0, $2661 = 0, $2662 = 0, $2663 = 0, $2664 = 0, $2665 = 0, $2666 = 0, $2667 = 0, $2668 = 0, $2669 = 0, $267 = 0, $2670 = 0;
 var $2671 = 0, $2672 = 0, $2673 = 0, $2674 = 0, $2675 = 0, $2676 = 0, $2677 = 0, $2678 = 0, $2679 = 0, $268 = 0, $2680 = 0, $2681 = 0, $2682 = 0, $2683 = 0, $2684 = 0, $2685 = 0, $2686 = 0, $2687 = 0, $2688 = 0, $2689 = 0;
 var $269 = 0, $2690 = 0, $2691 = 0, $2692 = 0, $2693 = 0, $2694 = 0, $2695 = 0, $2696 = 0, $2697 = 0, $2698 = 0, $2699 = 0, $27 = 0, $270 = 0, $2700 = 0, $2701 = 0, $2702 = 0, $2703 = 0, $2704 = 0, $2705 = 0, $2706 = 0;
 var $2707 = 0, $2708 = 0, $2709 = 0, $271 = 0, $2710 = 0, $2711 = 0, $2712 = 0, $2713 = 0, $2714 = 0, $2715 = 0, $2716 = 0, $2717 = 0, $2718 = 0, $2719 = 0, $272 = 0, $2720 = 0, $2721 = 0, $2722 = 0, $2723 = 0, $2724 = 0;
 var $2725 = 0, $2726 = 0, $2727 = 0, $2728 = 0, $2729 = 0, $273 = 0, $2730 = 0, $2731 = 0, $2732 = 0, $2733 = 0, $2734 = 0, $2735 = 0, $2736 = 0, $2737 = 0, $2738 = 0, $2739 = 0, $274 = 0, $2740 = 0, $2741 = 0, $2742 = 0;
 var $2743 = 0, $2744 = 0, $2745 = 0, $2746 = 0, $2747 = 0, $2748 = 0, $2749 = 0, $275 = 0, $2750 = 0, $2751 = 0, $2752 = 0, $2753 = 0, $2754 = 0, $2755 = 0, $2756 = 0, $2757 = 0, $2758 = 0, $2759 = 0, $276 = 0, $2760 = 0;
 var $2761 = 0, $2762 = 0, $2763 = 0, $2764 = 0, $2765 = 0, $2766 = 0, $2767 = 0, $2768 = 0, $2769 = 0, $277 = 0, $2770 = 0, $2771 = 0, $2772 = 0, $2773 = 0, $2774 = 0, $2775 = 0, $2776 = 0, $2777 = 0, $2778 = 0, $2779 = 0;
 var $278 = 0, $2780 = 0, $2781 = 0, $2782 = 0, $2783 = 0, $2784 = 0, $2785 = 0, $2786 = 0, $2787 = 0, $2788 = 0, $2789 = 0, $279 = 0, $2790 = 0, $2791 = 0, $2792 = 0, $2793 = 0, $2794 = 0, $2795 = 0, $2796 = 0, $2797 = 0;
 var $2798 = 0, $2799 = 0, $28 = 0, $280 = 0, $2800 = 0, $2801 = 0, $2802 = 0, $2803 = 0, $2804 = 0, $2805 = 0, $2806 = 0, $2807 = 0, $2808 = 0, $2809 = 0, $281 = 0, $2810 = 0, $2811 = 0, $2812 = 0, $2813 = 0, $2814 = 0;
 var $2815 = 0, $2816 = 0, $2817 = 0, $2818 = 0, $2819 = 0, $282 = 0, $2820 = 0, $2821 = 0, $2822 = 0, $2823 = 0, $2824 = 0, $2825 = 0, $2826 = 0, $2827 = 0, $2828 = 0, $2829 = 0, $283 = 0, $2830 = 0, $2831 = 0, $2832 = 0;
 var $2833 = 0, $2834 = 0, $2835 = 0, $2836 = 0, $2837 = 0, $2838 = 0, $2839 = 0, $284 = 0, $2840 = 0, $2841 = 0, $2842 = 0, $2843 = 0, $2844 = 0, $2845 = 0, $2846 = 0, $2847 = 0, $2848 = 0, $2849 = 0, $285 = 0, $2850 = 0;
 var $2851 = 0, $2852 = 0, $2853 = 0, $2854 = 0, $2855 = 0, $2856 = 0, $2857 = 0, $2858 = 0, $2859 = 0, $286 = 0, $2860 = 0, $2861 = 0, $2862 = 0, $2863 = 0, $2864 = 0, $2865 = 0, $2866 = 0, $2867 = 0, $2868 = 0, $2869 = 0;
 var $287 = 0, $2870 = 0, $2871 = 0, $2872 = 0, $2873 = 0, $2874 = 0, $2875 = 0, $2876 = 0, $2877 = 0, $2878 = 0, $2879 = 0, $288 = 0, $2880 = 0, $2881 = 0, $2882 = 0, $2883 = 0, $2884 = 0, $2885 = 0, $2886 = 0, $2887 = 0;
 var $2888 = 0, $2889 = 0, $289 = 0, $2890 = 0, $2891 = 0, $2892 = 0, $2893 = 0, $2894 = 0, $2895 = 0, $2896 = 0, $2897 = 0, $2898 = 0, $2899 = 0, $29 = 0, $290 = 0, $2900 = 0, $2901 = 0, $2902 = 0, $2903 = 0, $2904 = 0;
 var $2905 = 0, $2906 = 0, $2907 = 0, $2908 = 0, $2909 = 0, $291 = 0, $2910 = 0, $2911 = 0, $2912 = 0, $2913 = 0, $2914 = 0, $2915 = 0, $2916 = 0, $2917 = 0, $2918 = 0, $2919 = 0, $292 = 0, $2920 = 0, $2921 = 0, $2922 = 0;
 var $2923 = 0, $2924 = 0, $2925 = 0, $2926 = 0, $2927 = 0, $2928 = 0, $2929 = 0, $293 = 0, $2930 = 0, $2931 = 0, $2932 = 0, $2933 = 0, $2934 = 0, $2935 = 0, $2936 = 0, $2937 = 0, $2938 = 0, $2939 = 0, $294 = 0, $2940 = 0;
 var $2941 = 0, $2942 = 0, $2943 = 0, $2944 = 0, $2945 = 0, $2946 = 0, $2947 = 0, $2948 = 0, $2949 = 0, $295 = 0, $2950 = 0, $2951 = 0, $2952 = 0, $2953 = 0, $2954 = 0, $2955 = 0, $2956 = 0, $2957 = 0, $2958 = 0, $2959 = 0;
 var $296 = 0, $2960 = 0, $2961 = 0, $2962 = 0, $2963 = 0, $2964 = 0, $2965 = 0, $2966 = 0, $2967 = 0, $2968 = 0, $2969 = 0, $297 = 0, $2970 = 0, $2971 = 0, $2972 = 0, $2973 = 0, $2974 = 0, $2975 = 0, $2976 = 0, $2977 = 0;
 var $2978 = 0, $2979 = 0, $298 = 0, $2980 = 0, $2981 = 0, $2982 = 0, $2983 = 0, $2984 = 0, $2985 = 0, $2986 = 0, $2987 = 0, $2988 = 0, $2989 = 0, $299 = 0, $2990 = 0, $2991 = 0, $2992 = 0, $2993 = 0, $2994 = 0, $2995 = 0;
 var $2996 = 0, $2997 = 0, $2998 = 0, $2999 = 0, $3 = 0, $30 = 0, $300 = 0, $3000 = 0, $3001 = 0, $3002 = 0, $3003 = 0, $3004 = 0, $3005 = 0, $3006 = 0, $3007 = 0, $3008 = 0, $3009 = 0, $301 = 0, $3010 = 0, $3011 = 0;
 var $3012 = 0, $3013 = 0, $3014 = 0, $3015 = 0, $3016 = 0, $3017 = 0, $3018 = 0, $3019 = 0, $302 = 0, $3020 = 0, $3021 = 0, $3022 = 0, $3023 = 0, $3024 = 0, $3025 = 0, $3026 = 0, $3027 = 0, $3028 = 0, $3029 = 0, $303 = 0;
 var $3030 = 0, $3031 = 0, $3032 = 0, $3033 = 0, $3034 = 0, $3035 = 0, $3036 = 0, $3037 = 0, $3038 = 0, $3039 = 0, $304 = 0, $3040 = 0, $3041 = 0, $3042 = 0, $3043 = 0, $3044 = 0, $3045 = 0, $3046 = 0, $3047 = 0, $3048 = 0;
 var $3049 = 0, $305 = 0, $3050 = 0, $3051 = 0, $3052 = 0, $3053 = 0, $3054 = 0, $3055 = 0, $3056 = 0, $3057 = 0, $3058 = 0, $3059 = 0, $306 = 0, $3060 = 0, $3061 = 0, $3062 = 0, $3063 = 0, $3064 = 0, $3065 = 0, $3066 = 0;
 var $3067 = 0, $3068 = 0, $3069 = 0, $307 = 0, $3070 = 0, $3071 = 0, $3072 = 0, $3073 = 0, $3074 = 0, $3075 = 0, $3076 = 0, $3077 = 0, $3078 = 0, $3079 = 0, $308 = 0, $3080 = 0, $3081 = 0, $3082 = 0, $3083 = 0, $3084 = 0;
 var $3085 = 0, $3086 = 0, $3087 = 0, $3088 = 0, $3089 = 0, $309 = 0, $3090 = 0, $3091 = 0, $3092 = 0, $3093 = 0, $3094 = 0, $3095 = 0, $3096 = 0, $3097 = 0, $3098 = 0, $3099 = 0, $31 = 0, $310 = 0, $3100 = 0, $3101 = 0;
 var $3102 = 0, $3103 = 0, $3104 = 0, $3105 = 0, $3106 = 0, $3107 = 0, $3108 = 0, $3109 = 0, $311 = 0, $3110 = 0, $3111 = 0, $3112 = 0, $3113 = 0, $3114 = 0, $3115 = 0, $3116 = 0, $3117 = 0, $3118 = 0, $3119 = 0, $312 = 0;
 var $3120 = 0, $3121 = 0, $3122 = 0, $3123 = 0, $3124 = 0, $3125 = 0, $3126 = 0, $3127 = 0, $3128 = 0, $3129 = 0, $313 = 0, $3130 = 0, $3131 = 0, $3132 = 0, $3133 = 0, $3134 = 0, $3135 = 0, $3136 = 0, $3137 = 0, $3138 = 0;
 var $3139 = 0, $314 = 0, $3140 = 0, $3141 = 0, $3142 = 0, $3143 = 0, $3144 = 0, $3145 = 0, $3146 = 0, $3147 = 0, $3148 = 0, $3149 = 0, $315 = 0, $3150 = 0, $3151 = 0, $3152 = 0, $3153 = 0, $3154 = 0, $3155 = 0, $3156 = 0;
 var $3157 = 0, $3158 = 0, $3159 = 0, $316 = 0, $3160 = 0, $3161 = 0, $3162 = 0, $3163 = 0, $3164 = 0, $3165 = 0, $3166 = 0, $3167 = 0, $3168 = 0, $3169 = 0, $317 = 0, $3170 = 0, $3171 = 0, $3172 = 0, $3173 = 0, $3174 = 0;
 var $3175 = 0, $3176 = 0, $3177 = 0, $3178 = 0, $3179 = 0, $318 = 0, $3180 = 0, $3181 = 0, $3182 = 0, $3183 = 0, $3184 = 0, $3185 = 0, $3186 = 0, $3187 = 0, $3188 = 0, $3189 = 0, $319 = 0, $3190 = 0, $3191 = 0, $3192 = 0;
 var $3193 = 0, $3194 = 0, $3195 = 0, $3196 = 0, $3197 = 0, $3198 = 0, $3199 = 0, $32 = 0, $320 = 0, $3200 = 0, $3201 = 0, $3202 = 0, $3203 = 0, $3204 = 0, $3205 = 0, $3206 = 0, $3207 = 0, $3208 = 0, $3209 = 0, $321 = 0;
 var $3210 = 0, $3211 = 0, $3212 = 0, $3213 = 0, $3214 = 0, $3215 = 0, $3216 = 0, $3217 = 0, $3218 = 0, $3219 = 0, $322 = 0, $3220 = 0, $3221 = 0, $3222 = 0, $3223 = 0, $3224 = 0, $3225 = 0, $3226 = 0, $3227 = 0, $3228 = 0;
 var $3229 = 0, $323 = 0, $3230 = 0, $3231 = 0, $3232 = 0, $3233 = 0, $3234 = 0, $3235 = 0, $3236 = 0, $3237 = 0, $3238 = 0, $3239 = 0, $324 = 0, $3240 = 0, $3241 = 0, $3242 = 0, $3243 = 0, $3244 = 0, $3245 = 0, $3246 = 0;
 var $3247 = 0, $3248 = 0, $3249 = 0, $325 = 0, $3250 = 0, $3251 = 0, $3252 = 0, $3253 = 0, $3254 = 0, $3255 = 0, $3256 = 0, $3257 = 0, $3258 = 0, $3259 = 0, $326 = 0, $3260 = 0, $3261 = 0, $3262 = 0, $3263 = 0, $3264 = 0;
 var $3265 = 0, $3266 = 0, $3267 = 0, $3268 = 0, $3269 = 0, $327 = 0, $3270 = 0, $3271 = 0, $3272 = 0, $3273 = 0, $3274 = 0, $3275 = 0, $3276 = 0, $3277 = 0, $3278 = 0, $3279 = 0, $328 = 0, $3280 = 0, $3281 = 0, $3282 = 0;
 var $3283 = 0, $3284 = 0, $3285 = 0, $3286 = 0, $3287 = 0, $3288 = 0, $3289 = 0, $329 = 0, $3290 = 0, $3291 = 0, $3292 = 0, $3293 = 0, $3294 = 0, $3295 = 0, $3296 = 0, $3297 = 0, $3298 = 0, $3299 = 0, $33 = 0, $330 = 0;
 var $3300 = 0, $3301 = 0, $3302 = 0, $3303 = 0, $3304 = 0, $3305 = 0, $3306 = 0, $3307 = 0, $3308 = 0, $3309 = 0, $331 = 0, $3310 = 0, $3311 = 0, $3312 = 0, $3313 = 0, $3314 = 0, $3315 = 0, $3316 = 0, $3317 = 0, $3318 = 0;
 var $3319 = 0, $332 = 0, $3320 = 0, $3321 = 0, $3322 = 0, $3323 = 0, $3324 = 0, $3325 = 0, $3326 = 0, $3327 = 0, $3328 = 0, $3329 = 0, $333 = 0, $3330 = 0, $3331 = 0, $3332 = 0, $3333 = 0, $3334 = 0, $3335 = 0, $3336 = 0;
 var $3337 = 0, $3338 = 0, $3339 = 0, $334 = 0, $3340 = 0, $3341 = 0, $3342 = 0, $3343 = 0, $3344 = 0, $3345 = 0, $3346 = 0, $3347 = 0, $3348 = 0, $3349 = 0, $335 = 0, $3350 = 0, $3351 = 0, $3352 = 0, $3353 = 0, $3354 = 0;
 var $3355 = 0, $3356 = 0, $3357 = 0, $3358 = 0, $3359 = 0, $336 = 0, $3360 = 0, $3361 = 0, $3362 = 0, $3363 = 0, $3364 = 0, $3365 = 0, $3366 = 0, $3367 = 0, $3368 = 0, $3369 = 0, $337 = 0, $3370 = 0, $3371 = 0, $3372 = 0;
 var $3373 = 0, $3374 = 0, $3375 = 0, $3376 = 0, $3377 = 0, $3378 = 0, $3379 = 0, $338 = 0, $3380 = 0, $3381 = 0, $3382 = 0, $3383 = 0, $3384 = 0, $3385 = 0, $3386 = 0, $3387 = 0, $3388 = 0, $3389 = 0, $339 = 0, $3390 = 0;
 var $3391 = 0, $3392 = 0, $3393 = 0, $3394 = 0, $3395 = 0, $3396 = 0, $3397 = 0, $3398 = 0, $3399 = 0, $34 = 0, $340 = 0, $3400 = 0, $3401 = 0, $3402 = 0, $3403 = 0, $3404 = 0, $3405 = 0, $3406 = 0, $3407 = 0, $3408 = 0;
 var $3409 = 0, $341 = 0, $3410 = 0, $3411 = 0, $3412 = 0, $3413 = 0, $3414 = 0, $3415 = 0, $3416 = 0, $3417 = 0, $3418 = 0, $3419 = 0, $342 = 0, $3420 = 0, $3421 = 0, $3422 = 0, $3423 = 0, $3424 = 0, $3425 = 0, $3426 = 0;
 var $3427 = 0, $3428 = 0, $3429 = 0, $343 = 0, $3430 = 0, $3431 = 0, $3432 = 0, $3433 = 0, $3434 = 0, $3435 = 0, $3436 = 0, $3437 = 0, $3438 = 0, $3439 = 0, $344 = 0, $3440 = 0, $3441 = 0, $3442 = 0, $3443 = 0, $3444 = 0;
 var $3445 = 0, $3446 = 0, $3447 = 0, $3448 = 0, $3449 = 0, $345 = 0, $3450 = 0, $3451 = 0, $3452 = 0, $3453 = 0, $3454 = 0, $3455 = 0, $3456 = 0, $3457 = 0, $3458 = 0, $3459 = 0, $346 = 0, $3460 = 0, $3461 = 0, $3462 = 0;
 var $3463 = 0, $3464 = 0, $3465 = 0, $3466 = 0, $3467 = 0, $3468 = 0, $3469 = 0, $347 = 0, $3470 = 0, $3471 = 0, $3472 = 0, $3473 = 0, $3474 = 0, $3475 = 0, $3476 = 0, $3477 = 0, $3478 = 0, $3479 = 0, $348 = 0, $3480 = 0;
 var $3481 = 0, $3482 = 0, $3483 = 0, $3484 = 0, $3485 = 0, $3486 = 0, $3487 = 0, $3488 = 0, $3489 = 0, $349 = 0, $3490 = 0, $3491 = 0, $3492 = 0, $3493 = 0, $3494 = 0, $3495 = 0, $3496 = 0, $3497 = 0, $3498 = 0, $3499 = 0;
 var $35 = 0, $350 = 0, $3500 = 0, $3501 = 0, $3502 = 0, $3503 = 0, $3504 = 0, $3505 = 0, $3506 = 0, $3507 = 0, $3508 = 0, $3509 = 0, $351 = 0, $3510 = 0, $3511 = 0, $3512 = 0, $3513 = 0, $3514 = 0, $3515 = 0, $3516 = 0;
 var $3517 = 0, $3518 = 0, $3519 = 0, $352 = 0, $3520 = 0, $3521 = 0, $3522 = 0, $3523 = 0, $3524 = 0, $3525 = 0, $3526 = 0, $3527 = 0, $3528 = 0, $3529 = 0, $353 = 0, $3530 = 0, $3531 = 0, $3532 = 0, $3533 = 0, $3534 = 0;
 var $3535 = 0, $3536 = 0, $3537 = 0, $3538 = 0, $3539 = 0, $354 = 0, $3540 = 0, $3541 = 0, $3542 = 0, $3543 = 0, $3544 = 0, $3545 = 0, $3546 = 0, $3547 = 0, $3548 = 0, $3549 = 0, $355 = 0, $3550 = 0, $3551 = 0, $3552 = 0;
 var $3553 = 0, $3554 = 0, $3555 = 0, $3556 = 0, $3557 = 0, $3558 = 0, $3559 = 0, $356 = 0, $3560 = 0, $3561 = 0, $3562 = 0, $3563 = 0, $3564 = 0, $3565 = 0, $3566 = 0, $3567 = 0, $3568 = 0, $3569 = 0, $357 = 0, $3570 = 0;
 var $3571 = 0, $3572 = 0, $3573 = 0, $3574 = 0, $3575 = 0, $3576 = 0, $3577 = 0, $3578 = 0, $3579 = 0, $358 = 0, $3580 = 0, $3581 = 0, $3582 = 0, $3583 = 0, $3584 = 0, $3585 = 0, $3586 = 0, $3587 = 0, $3588 = 0, $3589 = 0;
 var $359 = 0, $3590 = 0, $3591 = 0, $3592 = 0, $3593 = 0, $3594 = 0, $3595 = 0, $3596 = 0, $3597 = 0, $3598 = 0, $3599 = 0, $36 = 0, $360 = 0, $3600 = 0, $3601 = 0, $3602 = 0, $3603 = 0, $3604 = 0, $3605 = 0, $3606 = 0;
 var $3607 = 0, $3608 = 0, $3609 = 0, $361 = 0, $3610 = 0, $3611 = 0, $3612 = 0, $3613 = 0, $3614 = 0, $3615 = 0, $3616 = 0, $3617 = 0, $3618 = 0, $3619 = 0, $362 = 0, $3620 = 0, $3621 = 0, $3622 = 0, $3623 = 0, $3624 = 0;
 var $3625 = 0, $3626 = 0, $3627 = 0, $3628 = 0, $3629 = 0, $363 = 0, $3630 = 0, $3631 = 0, $3632 = 0, $3633 = 0, $3634 = 0, $3635 = 0, $3636 = 0, $3637 = 0, $3638 = 0, $3639 = 0, $364 = 0, $3640 = 0, $3641 = 0, $3642 = 0;
 var $3643 = 0, $3644 = 0, $3645 = 0, $3646 = 0, $3647 = 0, $3648 = 0, $3649 = 0, $365 = 0, $3650 = 0, $3651 = 0, $3652 = 0, $3653 = 0, $3654 = 0, $3655 = 0, $3656 = 0, $3657 = 0, $3658 = 0, $3659 = 0, $366 = 0, $3660 = 0;
 var $3661 = 0, $3662 = 0, $3663 = 0, $3664 = 0, $3665 = 0, $3666 = 0, $3667 = 0, $3668 = 0, $3669 = 0, $367 = 0, $3670 = 0, $3671 = 0, $3672 = 0, $3673 = 0, $3674 = 0, $3675 = 0, $3676 = 0, $3677 = 0, $3678 = 0, $3679 = 0;
 var $368 = 0, $3680 = 0, $3681 = 0, $3682 = 0, $3683 = 0, $3684 = 0, $3685 = 0, $3686 = 0, $3687 = 0, $3688 = 0, $3689 = 0, $369 = 0, $3690 = 0, $3691 = 0, $3692 = 0, $3693 = 0, $3694 = 0, $3695 = 0, $3696 = 0, $3697 = 0;
 var $3698 = 0, $3699 = 0, $37 = 0, $370 = 0, $3700 = 0, $3701 = 0, $3702 = 0, $3703 = 0, $3704 = 0, $3705 = 0, $3706 = 0, $3707 = 0, $3708 = 0, $3709 = 0, $371 = 0, $3710 = 0, $3711 = 0, $3712 = 0, $3713 = 0, $3714 = 0;
 var $3715 = 0, $3716 = 0, $3717 = 0, $3718 = 0, $3719 = 0, $372 = 0, $3720 = 0, $3721 = 0, $3722 = 0, $3723 = 0, $3724 = 0, $3725 = 0, $3726 = 0, $3727 = 0, $3728 = 0, $3729 = 0, $373 = 0, $3730 = 0, $3731 = 0, $3732 = 0;
 var $3733 = 0, $3734 = 0, $3735 = 0, $3736 = 0, $3737 = 0, $3738 = 0, $3739 = 0, $374 = 0, $3740 = 0, $3741 = 0, $3742 = 0, $3743 = 0, $3744 = 0, $3745 = 0, $3746 = 0, $3747 = 0, $3748 = 0, $3749 = 0, $375 = 0, $3750 = 0;
 var $3751 = 0, $3752 = 0, $3753 = 0, $3754 = 0, $3755 = 0, $3756 = 0, $3757 = 0, $3758 = 0, $3759 = 0, $376 = 0, $3760 = 0, $3761 = 0, $3762 = 0, $3763 = 0, $3764 = 0, $3765 = 0, $3766 = 0, $3767 = 0, $3768 = 0, $3769 = 0;
 var $377 = 0, $3770 = 0, $3771 = 0, $3772 = 0, $3773 = 0, $3774 = 0, $3775 = 0, $3776 = 0, $3777 = 0, $3778 = 0, $3779 = 0, $378 = 0, $3780 = 0, $3781 = 0, $3782 = 0, $3783 = 0, $3784 = 0, $3785 = 0, $3786 = 0, $3787 = 0;
 var $3788 = 0, $3789 = 0, $379 = 0, $3790 = 0, $3791 = 0, $3792 = 0, $3793 = 0, $3794 = 0, $3795 = 0, $3796 = 0, $3797 = 0, $3798 = 0, $3799 = 0, $38 = 0, $380 = 0, $3800 = 0, $3801 = 0, $3802 = 0, $3803 = 0, $3804 = 0;
 var $3805 = 0, $3806 = 0, $3807 = 0, $3808 = 0, $3809 = 0, $381 = 0, $3810 = 0, $3811 = 0, $3812 = 0, $3813 = 0, $3814 = 0, $3815 = 0, $3816 = 0, $3817 = 0, $3818 = 0, $3819 = 0, $382 = 0, $3820 = 0, $3821 = 0, $3822 = 0;
 var $3823 = 0, $3824 = 0, $3825 = 0, $3826 = 0, $3827 = 0, $3828 = 0, $3829 = 0, $383 = 0, $3830 = 0, $3831 = 0, $3832 = 0, $3833 = 0, $3834 = 0, $3835 = 0, $3836 = 0, $3837 = 0, $3838 = 0, $3839 = 0, $384 = 0, $3840 = 0;
 var $3841 = 0, $3842 = 0, $3843 = 0, $3844 = 0, $3845 = 0, $3846 = 0, $3847 = 0, $3848 = 0, $3849 = 0, $385 = 0, $3850 = 0, $3851 = 0, $3852 = 0, $3853 = 0, $3854 = 0, $3855 = 0, $3856 = 0, $3857 = 0, $3858 = 0, $3859 = 0;
 var $386 = 0, $3860 = 0, $3861 = 0, $3862 = 0, $3863 = 0, $3864 = 0, $3865 = 0, $3866 = 0, $3867 = 0, $3868 = 0, $3869 = 0, $387 = 0, $3870 = 0, $3871 = 0, $3872 = 0, $3873 = 0, $3874 = 0, $3875 = 0, $3876 = 0, $3877 = 0;
 var $3878 = 0, $3879 = 0, $388 = 0, $3880 = 0, $3881 = 0, $3882 = 0, $3883 = 0, $3884 = 0, $3885 = 0, $3886 = 0, $3887 = 0, $3888 = 0, $3889 = 0, $389 = 0, $3890 = 0, $3891 = 0, $3892 = 0, $3893 = 0, $3894 = 0, $3895 = 0;
 var $3896 = 0, $3897 = 0, $3898 = 0, $3899 = 0, $39 = 0, $390 = 0, $3900 = 0, $3901 = 0, $3902 = 0, $3903 = 0, $3904 = 0, $3905 = 0, $3906 = 0, $3907 = 0, $3908 = 0, $3909 = 0, $391 = 0, $3910 = 0, $3911 = 0, $3912 = 0;
 var $3913 = 0, $3914 = 0, $3915 = 0, $3916 = 0, $3917 = 0, $3918 = 0, $3919 = 0, $392 = 0, $3920 = 0, $3921 = 0, $3922 = 0, $3923 = 0, $3924 = 0, $3925 = 0, $3926 = 0, $3927 = 0, $3928 = 0, $3929 = 0, $393 = 0, $3930 = 0;
 var $3931 = 0, $3932 = 0, $3933 = 0, $3934 = 0, $3935 = 0, $3936 = 0, $3937 = 0, $3938 = 0, $3939 = 0, $394 = 0, $3940 = 0, $3941 = 0, $3942 = 0, $3943 = 0, $3944 = 0, $3945 = 0, $3946 = 0, $3947 = 0, $3948 = 0, $3949 = 0;
 var $395 = 0, $3950 = 0, $3951 = 0, $3952 = 0, $3953 = 0, $3954 = 0, $3955 = 0, $3956 = 0, $3957 = 0, $3958 = 0, $3959 = 0, $396 = 0, $3960 = 0, $3961 = 0, $3962 = 0, $3963 = 0, $3964 = 0, $3965 = 0, $3966 = 0, $3967 = 0;
 var $3968 = 0, $3969 = 0, $397 = 0, $3970 = 0, $3971 = 0, $3972 = 0, $3973 = 0, $3974 = 0, $3975 = 0, $3976 = 0, $3977 = 0, $3978 = 0, $3979 = 0, $398 = 0, $3980 = 0, $3981 = 0, $3982 = 0, $3983 = 0, $3984 = 0, $3985 = 0;
 var $3986 = 0, $3987 = 0, $3988 = 0, $3989 = 0, $399 = 0, $3990 = 0, $3991 = 0, $3992 = 0, $3993 = 0, $3994 = 0, $3995 = 0, $3996 = 0, $3997 = 0, $3998 = 0, $3999 = 0, $4 = 0, $40 = 0, $400 = 0, $4000 = 0, $4001 = 0;
 var $4002 = 0, $4003 = 0, $4004 = 0, $4005 = 0, $4006 = 0, $4007 = 0, $4008 = 0, $4009 = 0, $401 = 0, $4010 = 0, $4011 = 0, $4012 = 0, $4013 = 0, $4014 = 0, $4015 = 0, $4016 = 0, $4017 = 0, $4018 = 0, $4019 = 0, $402 = 0;
 var $4020 = 0, $4021 = 0, $4022 = 0, $4023 = 0, $4024 = 0, $4025 = 0, $4026 = 0, $4027 = 0, $4028 = 0, $4029 = 0, $403 = 0, $4030 = 0, $4031 = 0, $4032 = 0, $4033 = 0, $4034 = 0, $4035 = 0, $4036 = 0, $4037 = 0, $4038 = 0;
 var $4039 = 0, $404 = 0, $4040 = 0, $4041 = 0, $4042 = 0, $4043 = 0, $4044 = 0, $4045 = 0, $4046 = 0, $4047 = 0, $4048 = 0, $4049 = 0, $405 = 0, $4050 = 0, $4051 = 0, $4052 = 0, $4053 = 0, $4054 = 0, $4055 = 0, $4056 = 0;
 var $4057 = 0, $4058 = 0, $4059 = 0, $406 = 0, $4060 = 0, $4061 = 0, $4062 = 0, $4063 = 0, $4064 = 0, $4065 = 0, $4066 = 0, $4067 = 0, $4068 = 0, $4069 = 0, $407 = 0, $4070 = 0, $4071 = 0, $4072 = 0, $4073 = 0, $4074 = 0;
 var $4075 = 0, $4076 = 0, $4077 = 0, $4078 = 0, $4079 = 0, $408 = 0, $4080 = 0, $4081 = 0, $4082 = 0, $4083 = 0, $4084 = 0, $4085 = 0, $4086 = 0, $4087 = 0, $4088 = 0, $4089 = 0, $409 = 0, $4090 = 0, $4091 = 0, $4092 = 0;
 var $4093 = 0, $4094 = 0, $4095 = 0, $4096 = 0, $4097 = 0, $4098 = 0, $4099 = 0, $41 = 0, $410 = 0, $4100 = 0, $4101 = 0, $4102 = 0, $4103 = 0, $4104 = 0, $4105 = 0, $4106 = 0, $4107 = 0, $4108 = 0, $4109 = 0, $411 = 0;
 var $4110 = 0, $4111 = 0, $4112 = 0, $4113 = 0, $4114 = 0, $4115 = 0, $4116 = 0, $4117 = 0, $4118 = 0, $4119 = 0, $412 = 0, $4120 = 0, $4121 = 0, $4122 = 0, $4123 = 0, $4124 = 0, $4125 = 0, $4126 = 0, $4127 = 0, $4128 = 0;
 var $4129 = 0, $413 = 0, $4130 = 0, $4131 = 0, $4132 = 0, $4133 = 0, $4134 = 0, $4135 = 0, $4136 = 0, $4137 = 0, $4138 = 0, $4139 = 0, $414 = 0, $4140 = 0, $4141 = 0, $4142 = 0, $4143 = 0, $4144 = 0, $4145 = 0, $4146 = 0;
 var $4147 = 0, $4148 = 0, $4149 = 0, $415 = 0, $4150 = 0, $4151 = 0, $4152 = 0, $4153 = 0, $4154 = 0, $4155 = 0, $4156 = 0, $4157 = 0, $4158 = 0, $4159 = 0, $416 = 0, $4160 = 0, $4161 = 0, $4162 = 0, $4163 = 0, $4164 = 0;
 var $4165 = 0, $4166 = 0, $4167 = 0, $4168 = 0, $4169 = 0, $417 = 0, $4170 = 0, $4171 = 0, $4172 = 0, $4173 = 0, $4174 = 0, $4175 = 0, $4176 = 0, $4177 = 0, $4178 = 0, $4179 = 0, $418 = 0, $4180 = 0, $4181 = 0, $4182 = 0;
 var $4183 = 0, $4184 = 0, $4185 = 0, $4186 = 0, $4187 = 0, $4188 = 0, $4189 = 0, $419 = 0, $4190 = 0, $4191 = 0, $4192 = 0, $4193 = 0, $4194 = 0, $4195 = 0, $4196 = 0, $4197 = 0, $4198 = 0, $4199 = 0, $42 = 0, $420 = 0;
 var $4200 = 0, $4201 = 0, $4202 = 0, $4203 = 0, $4204 = 0, $4205 = 0, $4206 = 0, $4207 = 0, $4208 = 0, $4209 = 0, $421 = 0, $4210 = 0, $4211 = 0, $4212 = 0, $4213 = 0, $4214 = 0, $4215 = 0, $4216 = 0, $4217 = 0, $4218 = 0;
 var $4219 = 0, $422 = 0, $4220 = 0, $4221 = 0, $4222 = 0, $4223 = 0, $4224 = 0, $4225 = 0, $4226 = 0, $4227 = 0, $4228 = 0, $4229 = 0, $423 = 0, $4230 = 0, $4231 = 0, $4232 = 0, $4233 = 0, $4234 = 0, $4235 = 0, $4236 = 0;
 var $4237 = 0, $4238 = 0, $4239 = 0, $424 = 0, $4240 = 0, $4241 = 0, $4242 = 0, $4243 = 0, $4244 = 0, $4245 = 0, $4246 = 0, $4247 = 0, $4248 = 0, $4249 = 0, $425 = 0, $4250 = 0, $4251 = 0, $4252 = 0, $4253 = 0, $4254 = 0;
 var $4255 = 0, $4256 = 0, $4257 = 0, $4258 = 0, $4259 = 0, $426 = 0, $4260 = 0, $4261 = 0, $4262 = 0, $4263 = 0, $4264 = 0, $4265 = 0, $4266 = 0, $4267 = 0, $4268 = 0, $4269 = 0, $427 = 0, $4270 = 0, $4271 = 0, $4272 = 0;
 var $4273 = 0, $4274 = 0, $4275 = 0, $4276 = 0, $4277 = 0, $4278 = 0, $4279 = 0, $428 = 0, $4280 = 0, $4281 = 0, $4282 = 0, $4283 = 0, $4284 = 0, $4285 = 0, $4286 = 0, $4287 = 0, $4288 = 0, $4289 = 0, $429 = 0, $4290 = 0;
 var $4291 = 0, $4292 = 0, $4293 = 0, $4294 = 0, $4295 = 0, $4296 = 0, $4297 = 0, $4298 = 0, $4299 = 0, $43 = 0, $430 = 0, $4300 = 0, $4301 = 0, $4302 = 0, $4303 = 0, $4304 = 0, $4305 = 0, $4306 = 0, $4307 = 0, $4308 = 0;
 var $4309 = 0, $431 = 0, $4310 = 0, $4311 = 0, $4312 = 0, $4313 = 0, $4314 = 0, $4315 = 0, $4316 = 0, $4317 = 0, $4318 = 0, $4319 = 0, $432 = 0, $4320 = 0, $4321 = 0, $4322 = 0, $4323 = 0, $4324 = 0, $4325 = 0, $4326 = 0;
 var $4327 = 0, $4328 = 0, $4329 = 0, $433 = 0, $4330 = 0, $4331 = 0, $4332 = 0, $4333 = 0, $4334 = 0, $4335 = 0, $4336 = 0, $4337 = 0, $4338 = 0, $4339 = 0, $434 = 0, $4340 = 0, $4341 = 0, $4342 = 0, $4343 = 0, $4344 = 0;
 var $4345 = 0, $4346 = 0, $4347 = 0, $4348 = 0, $4349 = 0, $435 = 0, $4350 = 0, $4351 = 0, $4352 = 0, $4353 = 0, $4354 = 0, $4355 = 0, $4356 = 0, $4357 = 0, $4358 = 0, $4359 = 0, $436 = 0, $4360 = 0, $4361 = 0, $4362 = 0;
 var $4363 = 0, $4364 = 0, $4365 = 0, $4366 = 0, $4367 = 0, $4368 = 0, $4369 = 0, $437 = 0, $4370 = 0, $4371 = 0, $4372 = 0, $4373 = 0, $4374 = 0, $4375 = 0, $4376 = 0, $4377 = 0, $4378 = 0, $4379 = 0, $438 = 0, $4380 = 0;
 var $4381 = 0, $4382 = 0, $4383 = 0, $4384 = 0, $4385 = 0, $4386 = 0, $4387 = 0, $4388 = 0, $4389 = 0, $439 = 0, $4390 = 0, $4391 = 0, $4392 = 0, $4393 = 0, $4394 = 0, $4395 = 0, $4396 = 0, $4397 = 0, $4398 = 0, $4399 = 0;
 var $44 = 0, $440 = 0, $4400 = 0, $4401 = 0, $4402 = 0, $4403 = 0, $4404 = 0, $4405 = 0, $4406 = 0, $4407 = 0, $4408 = 0, $4409 = 0, $441 = 0, $4410 = 0, $4411 = 0, $4412 = 0, $4413 = 0, $4414 = 0, $4415 = 0, $4416 = 0;
 var $4417 = 0, $4418 = 0, $4419 = 0, $442 = 0, $4420 = 0, $4421 = 0, $4422 = 0, $4423 = 0, $4424 = 0, $4425 = 0, $4426 = 0, $4427 = 0, $4428 = 0, $4429 = 0, $443 = 0, $4430 = 0, $4431 = 0, $4432 = 0, $4433 = 0, $4434 = 0;
 var $4435 = 0, $4436 = 0, $4437 = 0, $4438 = 0, $4439 = 0, $444 = 0, $4440 = 0, $4441 = 0, $4442 = 0, $4443 = 0, $4444 = 0, $4445 = 0, $4446 = 0, $4447 = 0, $4448 = 0, $4449 = 0, $445 = 0, $4450 = 0, $4451 = 0, $4452 = 0;
 var $4453 = 0, $4454 = 0, $4455 = 0, $4456 = 0, $4457 = 0, $4458 = 0, $4459 = 0, $446 = 0, $4460 = 0, $4461 = 0, $4462 = 0, $4463 = 0, $4464 = 0, $4465 = 0, $4466 = 0, $4467 = 0, $4468 = 0, $4469 = 0, $447 = 0, $4470 = 0;
 var $4471 = 0, $4472 = 0, $4473 = 0, $4474 = 0, $4475 = 0, $4476 = 0, $4477 = 0, $4478 = 0, $4479 = 0, $448 = 0, $4480 = 0, $4481 = 0, $4482 = 0, $4483 = 0, $4484 = 0, $4485 = 0, $4486 = 0, $4487 = 0, $4488 = 0, $4489 = 0;
 var $449 = 0, $4490 = 0, $4491 = 0, $4492 = 0, $4493 = 0, $4494 = 0, $4495 = 0, $4496 = 0, $4497 = 0, $4498 = 0, $4499 = 0, $45 = 0, $450 = 0, $4500 = 0, $4501 = 0, $4502 = 0, $4503 = 0, $4504 = 0, $4505 = 0, $4506 = 0;
 var $4507 = 0, $4508 = 0, $4509 = 0, $451 = 0, $4510 = 0, $4511 = 0, $4512 = 0, $4513 = 0, $4514 = 0, $4515 = 0, $4516 = 0, $4517 = 0, $4518 = 0, $4519 = 0, $452 = 0, $4520 = 0, $4521 = 0, $4522 = 0, $4523 = 0, $4524 = 0;
 var $4525 = 0, $4526 = 0, $4527 = 0, $4528 = 0, $4529 = 0, $453 = 0, $4530 = 0, $4531 = 0, $4532 = 0, $4533 = 0, $4534 = 0, $4535 = 0, $4536 = 0, $4537 = 0, $4538 = 0, $4539 = 0, $454 = 0, $4540 = 0, $4541 = 0, $4542 = 0;
 var $4543 = 0, $4544 = 0, $4545 = 0, $4546 = 0, $4547 = 0, $4548 = 0, $4549 = 0, $455 = 0, $4550 = 0, $4551 = 0, $4552 = 0, $4553 = 0, $4554 = 0, $4555 = 0, $4556 = 0, $4557 = 0, $4558 = 0, $4559 = 0, $456 = 0, $4560 = 0;
 var $4561 = 0, $4562 = 0, $4563 = 0, $4564 = 0, $4565 = 0, $4566 = 0, $4567 = 0, $4568 = 0, $4569 = 0, $457 = 0, $4570 = 0, $4571 = 0, $4572 = 0, $4573 = 0, $4574 = 0, $4575 = 0, $4576 = 0, $4577 = 0, $4578 = 0, $4579 = 0;
 var $458 = 0, $4580 = 0, $4581 = 0, $4582 = 0, $4583 = 0, $4584 = 0, $4585 = 0, $4586 = 0, $4587 = 0, $4588 = 0, $4589 = 0, $459 = 0, $4590 = 0, $4591 = 0, $4592 = 0, $4593 = 0, $4594 = 0, $4595 = 0, $4596 = 0, $4597 = 0;
 var $4598 = 0, $4599 = 0, $46 = 0, $460 = 0, $4600 = 0, $4601 = 0, $4602 = 0, $4603 = 0, $4604 = 0, $4605 = 0, $4606 = 0, $4607 = 0, $4608 = 0, $4609 = 0, $461 = 0, $4610 = 0, $4611 = 0, $4612 = 0, $4613 = 0, $4614 = 0;
 var $4615 = 0, $4616 = 0, $4617 = 0, $4618 = 0, $4619 = 0, $462 = 0, $4620 = 0, $4621 = 0, $4622 = 0, $4623 = 0, $4624 = 0, $4625 = 0, $4626 = 0, $4627 = 0, $4628 = 0, $4629 = 0, $463 = 0, $4630 = 0, $4631 = 0, $4632 = 0;
 var $4633 = 0, $4634 = 0, $4635 = 0, $4636 = 0, $4637 = 0, $4638 = 0, $4639 = 0, $464 = 0, $4640 = 0, $4641 = 0, $4642 = 0, $4643 = 0, $4644 = 0, $4645 = 0, $4646 = 0, $4647 = 0, $4648 = 0, $4649 = 0, $465 = 0, $4650 = 0;
 var $4651 = 0, $4652 = 0, $4653 = 0, $4654 = 0, $4655 = 0, $4656 = 0, $4657 = 0, $4658 = 0, $4659 = 0, $466 = 0, $4660 = 0, $4661 = 0, $4662 = 0, $4663 = 0, $4664 = 0, $4665 = 0, $4666 = 0, $4667 = 0, $4668 = 0, $4669 = 0;
 var $467 = 0, $4670 = 0, $4671 = 0, $4672 = 0, $4673 = 0, $4674 = 0, $4675 = 0, $4676 = 0, $4677 = 0, $4678 = 0, $4679 = 0, $468 = 0, $4680 = 0, $4681 = 0, $4682 = 0, $4683 = 0, $4684 = 0, $4685 = 0, $4686 = 0, $4687 = 0;
 var $4688 = 0, $4689 = 0, $469 = 0, $4690 = 0, $4691 = 0, $4692 = 0, $4693 = 0, $4694 = 0, $4695 = 0, $4696 = 0, $4697 = 0, $4698 = 0, $4699 = 0, $47 = 0, $470 = 0, $4700 = 0, $4701 = 0, $4702 = 0, $4703 = 0, $4704 = 0;
 var $4705 = 0, $4706 = 0, $4707 = 0, $4708 = 0, $4709 = 0, $471 = 0, $4710 = 0, $4711 = 0, $4712 = 0, $4713 = 0, $4714 = 0, $4715 = 0, $4716 = 0, $4717 = 0, $4718 = 0, $4719 = 0, $472 = 0, $4720 = 0, $4721 = 0, $4722 = 0;
 var $4723 = 0, $4724 = 0, $4725 = 0, $4726 = 0, $4727 = 0, $4728 = 0, $4729 = 0, $473 = 0, $4730 = 0, $4731 = 0, $4732 = 0, $4733 = 0, $4734 = 0, $4735 = 0, $4736 = 0, $4737 = 0, $4738 = 0, $4739 = 0, $474 = 0, $4740 = 0;
 var $4741 = 0, $4742 = 0, $4743 = 0, $4744 = 0, $4745 = 0, $4746 = 0, $4747 = 0, $4748 = 0, $4749 = 0, $475 = 0, $4750 = 0, $4751 = 0, $4752 = 0, $4753 = 0, $4754 = 0, $4755 = 0, $4756 = 0, $4757 = 0, $4758 = 0, $4759 = 0;
 var $476 = 0, $4760 = 0, $4761 = 0, $4762 = 0, $4763 = 0, $4764 = 0, $4765 = 0, $4766 = 0, $4767 = 0, $4768 = 0, $4769 = 0, $477 = 0, $4770 = 0, $4771 = 0, $4772 = 0, $4773 = 0, $4774 = 0, $4775 = 0, $4776 = 0, $4777 = 0;
 var $4778 = 0, $4779 = 0, $478 = 0, $4780 = 0, $4781 = 0, $4782 = 0, $4783 = 0, $4784 = 0, $4785 = 0, $4786 = 0, $4787 = 0, $4788 = 0, $4789 = 0, $479 = 0, $4790 = 0, $4791 = 0, $4792 = 0, $4793 = 0, $4794 = 0, $4795 = 0;
 var $4796 = 0, $4797 = 0, $4798 = 0, $4799 = 0, $48 = 0, $480 = 0, $4800 = 0, $4801 = 0, $4802 = 0, $4803 = 0, $4804 = 0, $4805 = 0, $4806 = 0, $4807 = 0, $4808 = 0, $4809 = 0, $481 = 0, $4810 = 0, $4811 = 0, $4812 = 0;
 var $4813 = 0, $4814 = 0, $4815 = 0, $4816 = 0, $4817 = 0, $4818 = 0, $4819 = 0, $482 = 0, $4820 = 0, $4821 = 0, $4822 = 0, $4823 = 0, $4824 = 0, $4825 = 0, $4826 = 0, $4827 = 0, $4828 = 0, $4829 = 0, $483 = 0, $4830 = 0;
 var $4831 = 0, $4832 = 0, $4833 = 0, $4834 = 0, $4835 = 0, $4836 = 0, $4837 = 0, $4838 = 0, $4839 = 0, $484 = 0, $4840 = 0, $4841 = 0, $4842 = 0, $4843 = 0, $4844 = 0, $4845 = 0, $4846 = 0, $4847 = 0, $4848 = 0, $4849 = 0;
 var $485 = 0, $4850 = 0, $4851 = 0, $4852 = 0, $4853 = 0, $4854 = 0, $4855 = 0, $4856 = 0, $4857 = 0, $4858 = 0, $4859 = 0, $486 = 0, $4860 = 0, $4861 = 0, $4862 = 0, $4863 = 0, $4864 = 0, $4865 = 0, $4866 = 0, $4867 = 0;
 var $4868 = 0, $4869 = 0, $487 = 0, $4870 = 0, $4871 = 0, $4872 = 0, $4873 = 0, $4874 = 0, $4875 = 0, $4876 = 0, $4877 = 0, $4878 = 0, $4879 = 0, $488 = 0, $4880 = 0, $4881 = 0, $4882 = 0, $4883 = 0, $4884 = 0, $4885 = 0;
 var $4886 = 0, $4887 = 0, $4888 = 0, $4889 = 0, $489 = 0, $4890 = 0, $4891 = 0, $4892 = 0, $4893 = 0, $4894 = 0, $4895 = 0, $4896 = 0, $4897 = 0, $4898 = 0, $4899 = 0, $49 = 0, $490 = 0, $4900 = 0, $4901 = 0, $4902 = 0;
 var $4903 = 0, $4904 = 0, $4905 = 0, $4906 = 0, $4907 = 0, $4908 = 0, $4909 = 0, $491 = 0, $4910 = 0, $4911 = 0, $4912 = 0, $4913 = 0, $4914 = 0, $4915 = 0, $4916 = 0, $4917 = 0, $4918 = 0, $4919 = 0, $492 = 0, $4920 = 0;
 var $4921 = 0, $4922 = 0, $4923 = 0, $4924 = 0, $4925 = 0, $4926 = 0, $4927 = 0, $4928 = 0, $4929 = 0, $493 = 0, $4930 = 0, $4931 = 0, $4932 = 0, $4933 = 0, $4934 = 0, $4935 = 0, $4936 = 0, $4937 = 0, $4938 = 0, $4939 = 0;
 var $494 = 0, $4940 = 0, $4941 = 0, $4942 = 0, $4943 = 0, $4944 = 0, $4945 = 0, $4946 = 0, $4947 = 0, $4948 = 0, $4949 = 0, $495 = 0, $4950 = 0, $4951 = 0, $4952 = 0, $4953 = 0, $4954 = 0, $4955 = 0, $4956 = 0, $4957 = 0;
 var $4958 = 0, $4959 = 0, $496 = 0, $4960 = 0, $4961 = 0, $4962 = 0, $4963 = 0, $4964 = 0, $4965 = 0, $4966 = 0, $4967 = 0, $4968 = 0, $4969 = 0, $497 = 0, $4970 = 0, $4971 = 0, $4972 = 0, $4973 = 0, $4974 = 0, $4975 = 0;
 var $4976 = 0, $4977 = 0, $4978 = 0, $4979 = 0, $498 = 0, $4980 = 0, $4981 = 0, $4982 = 0, $4983 = 0, $4984 = 0, $4985 = 0, $4986 = 0, $4987 = 0, $4988 = 0, $4989 = 0, $499 = 0, $4990 = 0, $4991 = 0, $4992 = 0, $4993 = 0;
 var $4994 = 0, $4995 = 0, $4996 = 0, $4997 = 0, $4998 = 0, $4999 = 0, $5 = 0, $50 = 0, $500 = 0, $5000 = 0, $5001 = 0, $5002 = 0, $5003 = 0, $5004 = 0, $5005 = 0, $5006 = 0, $5007 = 0, $5008 = 0, $5009 = 0, $501 = 0;
 var $5010 = 0, $5011 = 0, $5012 = 0, $5013 = 0, $5014 = 0, $5015 = 0, $5016 = 0, $5017 = 0, $5018 = 0, $5019 = 0, $502 = 0, $5020 = 0, $5021 = 0, $5022 = 0, $5023 = 0, $5024 = 0, $5025 = 0, $5026 = 0, $5027 = 0, $5028 = 0;
 var $5029 = 0, $503 = 0, $5030 = 0, $5031 = 0, $5032 = 0, $5033 = 0, $5034 = 0, $5035 = 0, $5036 = 0, $5037 = 0, $5038 = 0, $5039 = 0, $504 = 0, $5040 = 0, $5041 = 0, $5042 = 0, $5043 = 0, $5044 = 0, $5045 = 0, $5046 = 0;
 var $5047 = 0, $5048 = 0, $5049 = 0, $505 = 0, $5050 = 0, $5051 = 0, $5052 = 0, $5053 = 0, $5054 = 0, $5055 = 0, $5056 = 0, $5057 = 0, $5058 = 0, $5059 = 0, $506 = 0, $5060 = 0, $5061 = 0, $5062 = 0, $5063 = 0, $5064 = 0;
 var $5065 = 0, $5066 = 0, $5067 = 0, $5068 = 0, $5069 = 0, $507 = 0, $5070 = 0, $5071 = 0, $5072 = 0, $5073 = 0, $5074 = 0, $5075 = 0, $5076 = 0, $5077 = 0, $5078 = 0, $5079 = 0, $508 = 0, $5080 = 0, $5081 = 0, $5082 = 0;
 var $5083 = 0, $5084 = 0, $5085 = 0, $5086 = 0, $5087 = 0, $5088 = 0, $5089 = 0, $509 = 0, $5090 = 0, $5091 = 0, $5092 = 0, $5093 = 0, $5094 = 0, $5095 = 0, $5096 = 0, $5097 = 0, $5098 = 0, $5099 = 0, $51 = 0, $510 = 0;
 var $5100 = 0, $5101 = 0, $5102 = 0, $5103 = 0, $5104 = 0, $5105 = 0, $5106 = 0, $5107 = 0, $5108 = 0, $5109 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0;
 var $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0;
 var $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0;
 var $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0;
 var $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0;
 var $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0;
 var $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0;
 var $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0;
 var $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0;
 var $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0;
 var $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0;
 var $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0;
 var $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0;
 var $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0;
 var $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0;
 var $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0;
 var $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0;
 var $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0;
 var $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0;
 var $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0;
 var $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0;
 var $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0;
 var $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0;
 var $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0;
 var $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0;
 var $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0;
 var $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0;
 var $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $_buffer = 0, $buffer$0 = 0, $buffer$1 = 0, $buffer$10 = 0, $buffer$100 = 0, $buffer$101$lcssa = 0, $buffer$101553 = 0, $buffer$102 = 0, $buffer$103 = 0;
 var $buffer$104 = 0, $buffer$105 = 0, $buffer$106 = 0, $buffer$108 = 0, $buffer$109$lcssa = 0, $buffer$109542 = 0, $buffer$110 = 0, $buffer$111 = 0, $buffer$112 = 0, $buffer$113 = 0, $buffer$114 = 0, $buffer$116 = 0, $buffer$117$lcssa = 0, $buffer$117531 = 0, $buffer$118 = 0, $buffer$119 = 0, $buffer$12 = 0, $buffer$120 = 0, $buffer$121 = 0, $buffer$122 = 0;
 var $buffer$124 = 0, $buffer$125$lcssa = 0, $buffer$125520 = 0, $buffer$126 = 0, $buffer$127 = 0, $buffer$128 = 0, $buffer$129 = 0, $buffer$130 = 0, $buffer$132 = 0, $buffer$133$lcssa = 0, $buffer$133509 = 0, $buffer$134 = 0, $buffer$135 = 0, $buffer$136 = 0, $buffer$137 = 0, $buffer$138 = 0, $buffer$140 = 0, $buffer$141$lcssa = 0, $buffer$141498 = 0, $buffer$142 = 0;
 var $buffer$143 = 0, $buffer$144 = 0, $buffer$145 = 0, $buffer$146 = 0, $buffer$148 = 0, $buffer$149$lcssa = 0, $buffer$149487 = 0, $buffer$150 = 0, $buffer$151 = 0, $buffer$152 = 0, $buffer$153 = 0, $buffer$154 = 0, $buffer$156 = 0, $buffer$157$lcssa = 0, $buffer$157476 = 0, $buffer$158 = 0, $buffer$159 = 0, $buffer$16 = 0, $buffer$160 = 0, $buffer$161 = 0;
 var $buffer$162 = 0, $buffer$164 = 0, $buffer$165$lcssa = 0, $buffer$165465 = 0, $buffer$166 = 0, $buffer$167 = 0, $buffer$168 = 0, $buffer$169 = 0, $buffer$17 = 0, $buffer$170 = 0, $buffer$172 = 0, $buffer$173$lcssa = 0, $buffer$173454 = 0, $buffer$174 = 0, $buffer$175 = 0, $buffer$176 = 0, $buffer$177 = 0, $buffer$178 = 0, $buffer$18 = 0, $buffer$180 = 0;
 var $buffer$181$lcssa = 0, $buffer$181443 = 0, $buffer$182 = 0, $buffer$183 = 0, $buffer$184 = 0, $buffer$185 = 0, $buffer$186 = 0, $buffer$188 = 0, $buffer$189$lcssa = 0, $buffer$189432 = 0, $buffer$190 = 0, $buffer$191 = 0, $buffer$192 = 0, $buffer$193 = 0, $buffer$194 = 0, $buffer$196 = 0, $buffer$197$lcssa = 0, $buffer$197421 = 0, $buffer$198 = 0, $buffer$199 = 0;
 var $buffer$2 = 0, $buffer$20 = 0, $buffer$200 = 0, $buffer$201 = 0, $buffer$202 = 0, $buffer$204 = 0, $buffer$205$lcssa = 0, $buffer$205410 = 0, $buffer$206 = 0, $buffer$207 = 0, $buffer$208 = 0, $buffer$209 = 0, $buffer$21$lcssa = 0, $buffer$210 = 0, $buffer$212 = 0, $buffer$213$lcssa = 0, $buffer$213399 = 0, $buffer$214 = 0, $buffer$215 = 0, $buffer$216 = 0;
 var $buffer$217 = 0, $buffer$218 = 0, $buffer$22 = 0, $buffer$220 = 0, $buffer$221$lcssa = 0, $buffer$221388 = 0, $buffer$222 = 0, $buffer$223 = 0, $buffer$224 = 0, $buffer$225 = 0, $buffer$226 = 0, $buffer$228 = 0, $buffer$229$lcssa = 0, $buffer$229377 = 0, $buffer$23 = 0, $buffer$230 = 0, $buffer$231 = 0, $buffer$232 = 0, $buffer$233 = 0, $buffer$234 = 0;
 var $buffer$236 = 0, $buffer$237$lcssa = 0, $buffer$237366 = 0, $buffer$238 = 0, $buffer$239 = 0, $buffer$24 = 0, $buffer$240 = 0, $buffer$241 = 0, $buffer$242 = 0, $buffer$244 = 0, $buffer$245$lcssa = 0, $buffer$245355 = 0, $buffer$246 = 0, $buffer$247 = 0, $buffer$248 = 0, $buffer$249 = 0, $buffer$25 = 0, $buffer$250 = 0, $buffer$252 = 0, $buffer$253$lcssa = 0;
 var $buffer$253344 = 0, $buffer$254 = 0, $buffer$255 = 0, $buffer$256 = 0, $buffer$257 = 0, $buffer$258 = 0, $buffer$26 = 0, $buffer$260 = 0, $buffer$261$lcssa = 0, $buffer$261333 = 0, $buffer$262 = 0, $buffer$263 = 0, $buffer$264 = 0, $buffer$265 = 0, $buffer$266 = 0, $buffer$268 = 0, $buffer$269$lcssa = 0, $buffer$269322 = 0, $buffer$270 = 0, $buffer$271 = 0;
 var $buffer$272 = 0, $buffer$273 = 0, $buffer$274 = 0, $buffer$276 = 0, $buffer$277$lcssa = 0, $buffer$277311 = 0, $buffer$278 = 0, $buffer$279 = 0, $buffer$28 = 0, $buffer$280 = 0, $buffer$281 = 0, $buffer$282 = 0, $buffer$284 = 0, $buffer$285$lcssa = 0, $buffer$285300 = 0, $buffer$286 = 0, $buffer$287 = 0, $buffer$288 = 0, $buffer$289 = 0, $buffer$29$lcssa = 0;
 var $buffer$290 = 0, $buffer$292 = 0, $buffer$293$lcssa = 0, $buffer$293289 = 0, $buffer$294 = 0, $buffer$295 = 0, $buffer$296 = 0, $buffer$297 = 0, $buffer$298 = 0, $buffer$3 = 0, $buffer$30 = 0, $buffer$300 = 0, $buffer$301$lcssa = 0, $buffer$301278 = 0, $buffer$302 = 0, $buffer$303 = 0, $buffer$304 = 0, $buffer$305 = 0, $buffer$306 = 0, $buffer$308 = 0;
 var $buffer$309$lcssa = 0, $buffer$309267 = 0, $buffer$31 = 0, $buffer$310 = 0, $buffer$311 = 0, $buffer$312 = 0, $buffer$313 = 0, $buffer$314 = 0, $buffer$316 = 0, $buffer$317$lcssa = 0, $buffer$317256 = 0, $buffer$318 = 0, $buffer$319 = 0, $buffer$32 = 0, $buffer$320 = 0, $buffer$321 = 0, $buffer$322 = 0, $buffer$324 = 0, $buffer$325$lcssa = 0, $buffer$325245 = 0;
 var $buffer$326 = 0, $buffer$327 = 0, $buffer$328 = 0, $buffer$329 = 0, $buffer$33 = 0, $buffer$330 = 0, $buffer$332 = 0, $buffer$333$lcssa = 0, $buffer$333234 = 0, $buffer$334 = 0, $buffer$335 = 0, $buffer$336 = 0, $buffer$337 = 0, $buffer$338 = 0, $buffer$34 = 0, $buffer$340 = 0, $buffer$341$lcssa = 0, $buffer$341223 = 0, $buffer$342 = 0, $buffer$343 = 0;
 var $buffer$344 = 0, $buffer$345 = 0, $buffer$346 = 0, $buffer$348 = 0, $buffer$349$lcssa = 0, $buffer$349212 = 0, $buffer$350 = 0, $buffer$351 = 0, $buffer$352 = 0, $buffer$353 = 0, $buffer$354 = 0, $buffer$356 = 0, $buffer$357$lcssa = 0, $buffer$357201 = 0, $buffer$358 = 0, $buffer$359 = 0, $buffer$36 = 0, $buffer$360 = 0, $buffer$361 = 0, $buffer$362 = 0;
 var $buffer$364 = 0, $buffer$365$lcssa = 0, $buffer$365190 = 0, $buffer$366 = 0, $buffer$367 = 0, $buffer$368 = 0, $buffer$369 = 0, $buffer$37$lcssa = 0, $buffer$370 = 0, $buffer$372 = 0, $buffer$373$lcssa = 0, $buffer$373179 = 0, $buffer$374 = 0, $buffer$375 = 0, $buffer$376 = 0, $buffer$37641 = 0, $buffer$377 = 0, $buffer$378 = 0, $buffer$38 = 0, $buffer$380 = 0;
 var $buffer$381$lcssa = 0, $buffer$381168 = 0, $buffer$382 = 0, $buffer$383 = 0, $buffer$384 = 0, $buffer$385 = 0, $buffer$386 = 0, $buffer$388 = 0, $buffer$389$lcssa = 0, $buffer$389157 = 0, $buffer$39 = 0, $buffer$390 = 0, $buffer$391 = 0, $buffer$392 = 0, $buffer$393 = 0, $buffer$394 = 0, $buffer$396 = 0, $buffer$397$lcssa = 0, $buffer$397146 = 0, $buffer$398 = 0;
 var $buffer$399 = 0, $buffer$4 = 0, $buffer$40 = 0, $buffer$400 = 0, $buffer$401 = 0, $buffer$402 = 0, $buffer$404 = 0, $buffer$405$lcssa = 0, $buffer$405135 = 0, $buffer$406 = 0, $buffer$407 = 0, $buffer$408 = 0, $buffer$409 = 0, $buffer$41 = 0, $buffer$410 = 0, $buffer$412 = 0, $buffer$413$lcssa = 0, $buffer$413124 = 0, $buffer$414 = 0, $buffer$415 = 0;
 var $buffer$416 = 0, $buffer$417 = 0, $buffer$418 = 0, $buffer$42 = 0, $buffer$420 = 0, $buffer$421$lcssa = 0, $buffer$421113 = 0, $buffer$422 = 0, $buffer$423 = 0, $buffer$424 = 0, $buffer$425 = 0, $buffer$426 = 0, $buffer$428 = 0, $buffer$429$lcssa = 0, $buffer$429102 = 0, $buffer$430 = 0, $buffer$431 = 0, $buffer$432 = 0, $buffer$433 = 0, $buffer$434 = 0;
 var $buffer$436 = 0, $buffer$437$lcssa = 0, $buffer$43791 = 0, $buffer$438 = 0, $buffer$439 = 0, $buffer$44 = 0, $buffer$440 = 0, $buffer$441 = 0, $buffer$442 = 0, $buffer$444 = 0, $buffer$445$lcssa = 0, $buffer$44580 = 0, $buffer$446 = 0, $buffer$447 = 0, $buffer$448 = 0, $buffer$449 = 0, $buffer$45$lcssa = 0, $buffer$450 = 0, $buffer$452 = 0, $buffer$453$lcssa = 0;
 var $buffer$45369 = 0, $buffer$454 = 0, $buffer$455 = 0, $buffer$456 = 0, $buffer$45630 = 0, $buffer$457 = 0, $buffer$458 = 0, $buffer$46 = 0, $buffer$460 = 0, $buffer$461$lcssa = 0, $buffer$46158 = 0, $buffer$462 = 0, $buffer$463 = 0, $buffer$464 = 0, $buffer$465 = 0, $buffer$466 = 0, $buffer$468 = 0, $buffer$469$lcssa = 0, $buffer$46947 = 0, $buffer$47 = 0;
 var $buffer$470 = 0, $buffer$471 = 0, $buffer$472 = 0, $buffer$473 = 0, $buffer$474 = 0, $buffer$476 = 0, $buffer$477$lcssa = 0, $buffer$47736 = 0, $buffer$478 = 0, $buffer$479 = 0, $buffer$48 = 0, $buffer$480 = 0, $buffer$481 = 0, $buffer$482 = 0, $buffer$484 = 0, $buffer$485$lcssa = 0, $buffer$48525 = 0, $buffer$486 = 0, $buffer$487 = 0, $buffer$488 = 0;
 var $buffer$489 = 0, $buffer$49 = 0, $buffer$490 = 0, $buffer$492 = 0, $buffer$493$lcssa = 0, $buffer$49314 = 0, $buffer$494 = 0, $buffer$495 = 0, $buffer$496 = 0, $buffer$497 = 0, $buffer$498 = 0, $buffer$50 = 0, $buffer$500 = 0, $buffer$501$lcssa = 0, $buffer$5015 = 0, $buffer$502 = 0, $buffer$503 = 0, $buffer$504 = 0, $buffer$505 = 0, $buffer$506 = 0;
 var $buffer$509 = 0, $buffer$510 = 0, $buffer$5112 = 0, $buffer$52 = 0, $buffer$53$lcssa = 0, $buffer$53619 = 0, $buffer$54 = 0, $buffer$55 = 0, $buffer$56 = 0, $buffer$57 = 0, $buffer$58 = 0, $buffer$60 = 0, $buffer$61$lcssa = 0, $buffer$61608 = 0, $buffer$62 = 0, $buffer$63 = 0, $buffer$64 = 0, $buffer$65 = 0, $buffer$66 = 0, $buffer$68 = 0;
 var $buffer$69$lcssa = 0, $buffer$69597 = 0, $buffer$70 = 0, $buffer$71 = 0, $buffer$72 = 0, $buffer$73 = 0, $buffer$74 = 0, $buffer$76 = 0, $buffer$77$lcssa = 0, $buffer$77586 = 0, $buffer$78 = 0, $buffer$79 = 0, $buffer$8 = 0, $buffer$80 = 0, $buffer$81 = 0, $buffer$82 = 0, $buffer$84 = 0, $buffer$85$lcssa = 0, $buffer$85575 = 0, $buffer$86 = 0;
 var $buffer$87 = 0, $buffer$88 = 0, $buffer$89 = 0, $buffer$9 = 0, $buffer$90 = 0, $buffer$92 = 0, $buffer$93$lcssa = 0, $buffer$93564 = 0, $buffer$94 = 0, $buffer$95 = 0, $buffer$96 = 0, $buffer$97 = 0, $buffer$98 = 0, $bytes$0$ = 0, $bytes$01 = 0, $localbuf$0 = 0, $phitmp = 0, $put_bits$0 = 0, $put_bits$1 = 0, $put_bits$101 = 0;
 var $put_bits$102$lcssa = 0, $put_bits$102463 = 0, $put_bits$103 = 0, $put_bits$104 = 0, $put_bits$106 = 0, $put_bits$107$lcssa = 0, $put_bits$107452 = 0, $put_bits$108 = 0, $put_bits$109 = 0, $put_bits$11 = 0, $put_bits$111 = 0, $put_bits$112$lcssa = 0, $put_bits$112441 = 0, $put_bits$113 = 0, $put_bits$114 = 0, $put_bits$116 = 0, $put_bits$117$lcssa = 0, $put_bits$117430 = 0, $put_bits$118 = 0, $put_bits$119 = 0;
 var $put_bits$12$lcssa = 0, $put_bits$121 = 0, $put_bits$122$lcssa = 0, $put_bits$122419 = 0, $put_bits$123 = 0, $put_bits$124 = 0, $put_bits$126 = 0, $put_bits$127$lcssa = 0, $put_bits$127408 = 0, $put_bits$128 = 0, $put_bits$129 = 0, $put_bits$13 = 0, $put_bits$131 = 0, $put_bits$132$lcssa = 0, $put_bits$132397 = 0, $put_bits$133 = 0, $put_bits$134 = 0, $put_bits$136 = 0, $put_bits$137$lcssa = 0, $put_bits$137386 = 0;
 var $put_bits$138 = 0, $put_bits$139 = 0, $put_bits$14 = 0, $put_bits$141 = 0, $put_bits$142$lcssa = 0, $put_bits$142375 = 0, $put_bits$143 = 0, $put_bits$144 = 0, $put_bits$146 = 0, $put_bits$147$lcssa = 0, $put_bits$147364 = 0, $put_bits$148 = 0, $put_bits$149 = 0, $put_bits$151 = 0, $put_bits$152$lcssa = 0, $put_bits$152353 = 0, $put_bits$153 = 0, $put_bits$154 = 0, $put_bits$156 = 0, $put_bits$157$lcssa = 0;
 var $put_bits$157342 = 0, $put_bits$158 = 0, $put_bits$159 = 0, $put_bits$16 = 0, $put_bits$161 = 0, $put_bits$162$lcssa = 0, $put_bits$162331 = 0, $put_bits$163 = 0, $put_bits$164 = 0, $put_bits$166 = 0, $put_bits$167$lcssa = 0, $put_bits$167320 = 0, $put_bits$168 = 0, $put_bits$169 = 0, $put_bits$17$lcssa = 0, $put_bits$171 = 0, $put_bits$172$lcssa = 0, $put_bits$172309 = 0, $put_bits$173 = 0, $put_bits$174 = 0;
 var $put_bits$176 = 0, $put_bits$177$lcssa = 0, $put_bits$177298 = 0, $put_bits$178 = 0, $put_bits$179 = 0, $put_bits$18 = 0, $put_bits$181 = 0, $put_bits$182$lcssa = 0, $put_bits$182287 = 0, $put_bits$183 = 0, $put_bits$184 = 0, $put_bits$186 = 0, $put_bits$187$lcssa = 0, $put_bits$187276 = 0, $put_bits$188 = 0, $put_bits$189 = 0, $put_bits$19 = 0, $put_bits$191 = 0, $put_bits$192$lcssa = 0, $put_bits$192265 = 0;
 var $put_bits$193 = 0, $put_bits$194 = 0, $put_bits$196 = 0, $put_bits$197$lcssa = 0, $put_bits$197254 = 0, $put_bits$198 = 0, $put_bits$199 = 0, $put_bits$201 = 0, $put_bits$202$lcssa = 0, $put_bits$202243 = 0, $put_bits$203 = 0, $put_bits$204 = 0, $put_bits$206 = 0, $put_bits$207$lcssa = 0, $put_bits$207232 = 0, $put_bits$208 = 0, $put_bits$209 = 0, $put_bits$21 = 0, $put_bits$211 = 0, $put_bits$212$lcssa = 0;
 var $put_bits$212221 = 0, $put_bits$213 = 0, $put_bits$214 = 0, $put_bits$216 = 0, $put_bits$217$lcssa = 0, $put_bits$217210 = 0, $put_bits$218 = 0, $put_bits$219 = 0, $put_bits$22$lcssa = 0, $put_bits$221 = 0, $put_bits$222$lcssa = 0, $put_bits$222199 = 0, $put_bits$223 = 0, $put_bits$224 = 0, $put_bits$226 = 0, $put_bits$22639 = 0, $put_bits$227$lcssa = 0, $put_bits$227188 = 0, $put_bits$228 = 0, $put_bits$229 = 0;
 var $put_bits$23 = 0, $put_bits$231 = 0, $put_bits$232$lcssa = 0, $put_bits$232177 = 0, $put_bits$233 = 0, $put_bits$234 = 0, $put_bits$236 = 0, $put_bits$237$lcssa = 0, $put_bits$237166 = 0, $put_bits$238 = 0, $put_bits$239 = 0, $put_bits$24 = 0, $put_bits$241 = 0, $put_bits$242$lcssa = 0, $put_bits$242155 = 0, $put_bits$243 = 0, $put_bits$244 = 0, $put_bits$246 = 0, $put_bits$247$lcssa = 0, $put_bits$247144 = 0;
 var $put_bits$248 = 0, $put_bits$249 = 0, $put_bits$251 = 0, $put_bits$252$lcssa = 0, $put_bits$252133 = 0, $put_bits$253 = 0, $put_bits$254 = 0, $put_bits$256 = 0, $put_bits$257$lcssa = 0, $put_bits$257122 = 0, $put_bits$258 = 0, $put_bits$259 = 0, $put_bits$26 = 0, $put_bits$261 = 0, $put_bits$262$lcssa = 0, $put_bits$262111 = 0, $put_bits$263 = 0, $put_bits$264 = 0, $put_bits$266 = 0, $put_bits$267$lcssa = 0;
 var $put_bits$267100 = 0, $put_bits$268 = 0, $put_bits$269 = 0, $put_bits$27$lcssa = 0, $put_bits$271 = 0, $put_bits$272$lcssa = 0, $put_bits$27289 = 0, $put_bits$273 = 0, $put_bits$274 = 0, $put_bits$276 = 0, $put_bits$27628 = 0, $put_bits$277$lcssa = 0, $put_bits$27778 = 0, $put_bits$278 = 0, $put_bits$279 = 0, $put_bits$28 = 0, $put_bits$281 = 0, $put_bits$282$lcssa = 0, $put_bits$28267 = 0, $put_bits$283 = 0;
 var $put_bits$284 = 0, $put_bits$286 = 0, $put_bits$287$lcssa = 0, $put_bits$28756 = 0, $put_bits$288 = 0, $put_bits$289 = 0, $put_bits$29 = 0, $put_bits$291 = 0, $put_bits$292$lcssa = 0, $put_bits$29245 = 0, $put_bits$293 = 0, $put_bits$294 = 0, $put_bits$296 = 0, $put_bits$297$lcssa = 0, $put_bits$29734 = 0, $put_bits$298 = 0, $put_bits$299 = 0, $put_bits$301 = 0, $put_bits$302$lcssa = 0, $put_bits$30223 = 0;
 var $put_bits$303 = 0, $put_bits$304 = 0, $put_bits$306 = 0, $put_bits$307$lcssa = 0, $put_bits$30712 = 0, $put_bits$308 = 0, $put_bits$309 = 0, $put_bits$31 = 0, $put_bits$311 = 0, $put_bits$312$lcssa = 0, $put_bits$3123 = 0, $put_bits$313 = 0, $put_bits$314 = 0, $put_bits$317 = 0, $put_bits$32$lcssa = 0, $put_bits$32617 = 0, $put_bits$33 = 0, $put_bits$34 = 0, $put_bits$36 = 0, $put_bits$37$lcssa = 0;
 var $put_bits$37606 = 0, $put_bits$38 = 0, $put_bits$39 = 0, $put_bits$4 = 0, $put_bits$41 = 0, $put_bits$42$lcssa = 0, $put_bits$42595 = 0, $put_bits$43 = 0, $put_bits$44 = 0, $put_bits$46 = 0, $put_bits$47$lcssa = 0, $put_bits$47584 = 0, $put_bits$48 = 0, $put_bits$49 = 0, $put_bits$51 = 0, $put_bits$52$lcssa = 0, $put_bits$52573 = 0, $put_bits$53 = 0, $put_bits$54 = 0, $put_bits$56 = 0;
 var $put_bits$57$lcssa = 0, $put_bits$57562 = 0, $put_bits$58 = 0, $put_bits$59 = 0, $put_bits$6 = 0, $put_bits$61 = 0, $put_bits$62$lcssa = 0, $put_bits$62551 = 0, $put_bits$63 = 0, $put_bits$64 = 0, $put_bits$66 = 0, $put_bits$67$lcssa = 0, $put_bits$67540 = 0, $put_bits$68 = 0, $put_bits$69 = 0, $put_bits$71 = 0, $put_bits$72$lcssa = 0, $put_bits$72529 = 0, $put_bits$73 = 0, $put_bits$74 = 0;
 var $put_bits$76 = 0, $put_bits$77$lcssa = 0, $put_bits$77518 = 0, $put_bits$78 = 0, $put_bits$79 = 0, $put_bits$81 = 0, $put_bits$82$lcssa = 0, $put_bits$82507 = 0, $put_bits$83 = 0, $put_bits$84 = 0, $put_bits$86 = 0, $put_bits$87$lcssa = 0, $put_bits$87496 = 0, $put_bits$88 = 0, $put_bits$89 = 0, $put_bits$9 = 0, $put_bits$91 = 0, $put_bits$92$lcssa = 0, $put_bits$92485 = 0, $put_bits$93 = 0;
 var $put_bits$94 = 0, $put_bits$96 = 0, $put_bits$97$lcssa = 0, $put_bits$97474 = 0, $put_bits$98 = 0, $put_bits$99 = 0, $put_buffer$1 = 0, $put_buffer$10$lcssa = 0, $put_buffer$100$lcssa = 0, $put_buffer$100134 = 0, $put_buffer$101 = 0, $put_buffer$102$lcssa = 0, $put_buffer$102123 = 0, $put_buffer$103 = 0, $put_buffer$104$lcssa = 0, $put_buffer$104112 = 0, $put_buffer$105 = 0, $put_buffer$106$lcssa = 0, $put_buffer$106101 = 0, $put_buffer$10629 = 0;
 var $put_buffer$107 = 0, $put_buffer$108$lcssa = 0, $put_buffer$10890 = 0, $put_buffer$109 = 0, $put_buffer$11 = 0, $put_buffer$110$lcssa = 0, $put_buffer$11079 = 0, $put_buffer$111 = 0, $put_buffer$112$lcssa = 0, $put_buffer$11268 = 0, $put_buffer$113 = 0, $put_buffer$114$lcssa = 0, $put_buffer$11457 = 0, $put_buffer$115 = 0, $put_buffer$116$lcssa = 0, $put_buffer$11646 = 0, $put_buffer$117 = 0, $put_buffer$118$lcssa = 0, $put_buffer$11835 = 0, $put_buffer$119 = 0;
 var $put_buffer$12$lcssa = 0, $put_buffer$120$lcssa = 0, $put_buffer$12024 = 0, $put_buffer$121 = 0, $put_buffer$122$lcssa = 0, $put_buffer$12213 = 0, $put_buffer$123 = 0, $put_buffer$124$lcssa = 0, $put_buffer$1244 = 0, $put_buffer$126 = 0, $put_buffer$12618 = 0, $put_buffer$13 = 0, $put_buffer$14$lcssa = 0, $put_buffer$14607 = 0, $put_buffer$15 = 0, $put_buffer$16$lcssa = 0, $put_buffer$16596 = 0, $put_buffer$17 = 0, $put_buffer$18$lcssa = 0, $put_buffer$18585 = 0;
 var $put_buffer$19 = 0, $put_buffer$20$lcssa = 0, $put_buffer$20574 = 0, $put_buffer$21 = 0, $put_buffer$22$lcssa = 0, $put_buffer$22563 = 0, $put_buffer$23 = 0, $put_buffer$24$lcssa = 0, $put_buffer$24552 = 0, $put_buffer$25 = 0, $put_buffer$26$lcssa = 0, $put_buffer$26541 = 0, $put_buffer$27 = 0, $put_buffer$28$lcssa = 0, $put_buffer$28530 = 0, $put_buffer$29 = 0, $put_buffer$3 = 0, $put_buffer$30$lcssa = 0, $put_buffer$30519 = 0, $put_buffer$31 = 0;
 var $put_buffer$32$lcssa = 0, $put_buffer$32508 = 0, $put_buffer$33 = 0, $put_buffer$34$lcssa = 0, $put_buffer$34497 = 0, $put_buffer$35 = 0, $put_buffer$36$lcssa = 0, $put_buffer$36486 = 0, $put_buffer$37 = 0, $put_buffer$38$lcssa = 0, $put_buffer$38475 = 0, $put_buffer$39 = 0, $put_buffer$4$lcssa = 0, $put_buffer$40$lcssa = 0, $put_buffer$40464 = 0, $put_buffer$41 = 0, $put_buffer$42$lcssa = 0, $put_buffer$42453 = 0, $put_buffer$43 = 0, $put_buffer$44$lcssa = 0;
 var $put_buffer$44442 = 0, $put_buffer$45 = 0, $put_buffer$46$lcssa = 0, $put_buffer$46431 = 0, $put_buffer$47 = 0, $put_buffer$48$lcssa = 0, $put_buffer$48420 = 0, $put_buffer$49 = 0, $put_buffer$5 = 0, $put_buffer$50$lcssa = 0, $put_buffer$50409 = 0, $put_buffer$51 = 0, $put_buffer$52$lcssa = 0, $put_buffer$52398 = 0, $put_buffer$53 = 0, $put_buffer$54$lcssa = 0, $put_buffer$54387 = 0, $put_buffer$55 = 0, $put_buffer$56$lcssa = 0, $put_buffer$56376 = 0;
 var $put_buffer$57 = 0, $put_buffer$58$lcssa = 0, $put_buffer$58365 = 0, $put_buffer$59 = 0, $put_buffer$6$lcssa = 0, $put_buffer$60$lcssa = 0, $put_buffer$60354 = 0, $put_buffer$61 = 0, $put_buffer$62$lcssa = 0, $put_buffer$62343 = 0, $put_buffer$63 = 0, $put_buffer$64$lcssa = 0, $put_buffer$64332 = 0, $put_buffer$65 = 0, $put_buffer$66$lcssa = 0, $put_buffer$66321 = 0, $put_buffer$67 = 0, $put_buffer$68$lcssa = 0, $put_buffer$68310 = 0, $put_buffer$69 = 0;
 var $put_buffer$7 = 0, $put_buffer$70$lcssa = 0, $put_buffer$70299 = 0, $put_buffer$71 = 0, $put_buffer$72$lcssa = 0, $put_buffer$72288 = 0, $put_buffer$73 = 0, $put_buffer$74$lcssa = 0, $put_buffer$74277 = 0, $put_buffer$75 = 0, $put_buffer$76$lcssa = 0, $put_buffer$76266 = 0, $put_buffer$77 = 0, $put_buffer$78$lcssa = 0, $put_buffer$78255 = 0, $put_buffer$79 = 0, $put_buffer$8$lcssa = 0, $put_buffer$80$lcssa = 0, $put_buffer$80244 = 0, $put_buffer$81 = 0;
 var $put_buffer$82$lcssa = 0, $put_buffer$82233 = 0, $put_buffer$83 = 0, $put_buffer$84$lcssa = 0, $put_buffer$84222 = 0, $put_buffer$85 = 0, $put_buffer$86$lcssa = 0, $put_buffer$86211 = 0, $put_buffer$8640 = 0, $put_buffer$87 = 0, $put_buffer$88$lcssa = 0, $put_buffer$88200 = 0, $put_buffer$89 = 0, $put_buffer$9 = 0, $put_buffer$90$lcssa = 0, $put_buffer$90189 = 0, $put_buffer$91 = 0, $put_buffer$92$lcssa = 0, $put_buffer$92178 = 0, $put_buffer$93 = 0;
 var $put_buffer$94$lcssa = 0, $put_buffer$94167 = 0, $put_buffer$95 = 0, $put_buffer$96$lcssa = 0, $put_buffer$96156 = 0, $put_buffer$97 = 0, $put_buffer$98$lcssa = 0, $put_buffer$98145 = 0, $put_buffer$99 = 0, $r$1 = 0, $r$10$lcssa = 0, $r$100$lcssa = 0, $r$100136 = 0, $r$101 = 0, $r$102$lcssa = 0, $r$102125 = 0, $r$103 = 0, $r$104$lcssa = 0, $r$104114 = 0, $r$105 = 0;
 var $r$106$lcssa = 0, $r$106103 = 0, $r$10631 = 0, $r$107 = 0, $r$108$lcssa = 0, $r$10892 = 0, $r$109 = 0, $r$11 = 0, $r$110$lcssa = 0, $r$11081 = 0, $r$111 = 0, $r$112$lcssa = 0, $r$11270 = 0, $r$113 = 0, $r$114$lcssa = 0, $r$11459 = 0, $r$115 = 0, $r$116$lcssa = 0, $r$11648 = 0, $r$117 = 0;
 var $r$118$lcssa = 0, $r$11837 = 0, $r$119 = 0, $r$12$lcssa = 0, $r$120$lcssa = 0, $r$12026 = 0, $r$121 = 0, $r$122$lcssa = 0, $r$12215 = 0, $r$123 = 0, $r$124$lcssa = 0, $r$1246 = 0, $r$12620 = 0, $r$13 = 0, $r$14$lcssa = 0, $r$14609 = 0, $r$15 = 0, $r$16$lcssa = 0, $r$16598 = 0, $r$17 = 0;
 var $r$18$lcssa = 0, $r$18587 = 0, $r$19 = 0, $r$20$lcssa = 0, $r$20576 = 0, $r$21 = 0, $r$22$lcssa = 0, $r$22565 = 0, $r$23 = 0, $r$24$lcssa = 0, $r$24554 = 0, $r$25 = 0, $r$26$lcssa = 0, $r$26543 = 0, $r$27 = 0, $r$28$lcssa = 0, $r$28532 = 0, $r$29 = 0, $r$3 = 0, $r$30$lcssa = 0;
 var $r$30521 = 0, $r$31 = 0, $r$32$lcssa = 0, $r$32510 = 0, $r$33 = 0, $r$34$lcssa = 0, $r$34499 = 0, $r$35 = 0, $r$36$lcssa = 0, $r$36488 = 0, $r$37 = 0, $r$38$lcssa = 0, $r$38477 = 0, $r$39 = 0, $r$4$lcssa = 0, $r$40$lcssa = 0, $r$40466 = 0, $r$41 = 0, $r$42$lcssa = 0, $r$42455 = 0;
 var $r$43 = 0, $r$44$lcssa = 0, $r$44444 = 0, $r$45 = 0, $r$46$lcssa = 0, $r$46433 = 0, $r$47 = 0, $r$48$lcssa = 0, $r$48422 = 0, $r$49 = 0, $r$5 = 0, $r$50$lcssa = 0, $r$50411 = 0, $r$51 = 0, $r$52$lcssa = 0, $r$52400 = 0, $r$53 = 0, $r$54$lcssa = 0, $r$54389 = 0, $r$55 = 0;
 var $r$56$lcssa = 0, $r$56378 = 0, $r$57 = 0, $r$58$lcssa = 0, $r$58367 = 0, $r$59 = 0, $r$6$lcssa = 0, $r$60$lcssa = 0, $r$60356 = 0, $r$61 = 0, $r$62$lcssa = 0, $r$62345 = 0, $r$63 = 0, $r$64$lcssa = 0, $r$64334 = 0, $r$65 = 0, $r$66$lcssa = 0, $r$66323 = 0, $r$67 = 0, $r$68$lcssa = 0;
 var $r$68312 = 0, $r$69 = 0, $r$7 = 0, $r$70$lcssa = 0, $r$70301 = 0, $r$71 = 0, $r$72$lcssa = 0, $r$72290 = 0, $r$73 = 0, $r$74$lcssa = 0, $r$74279 = 0, $r$75 = 0, $r$76$lcssa = 0, $r$76268 = 0, $r$77 = 0, $r$78$lcssa = 0, $r$78257 = 0, $r$79 = 0, $r$8$lcssa = 0, $r$80$lcssa = 0;
 var $r$80246 = 0, $r$81 = 0, $r$82$lcssa = 0, $r$82235 = 0, $r$83 = 0, $r$84$lcssa = 0, $r$84224 = 0, $r$85 = 0, $r$86$lcssa = 0, $r$86213 = 0, $r$8642 = 0, $r$87 = 0, $r$88$lcssa = 0, $r$88202 = 0, $r$89 = 0, $r$9 = 0, $r$90$lcssa = 0, $r$90191 = 0, $r$91 = 0, $r$92$lcssa = 0;
 var $r$92180 = 0, $r$93 = 0, $r$94$lcssa = 0, $r$94169 = 0, $r$95 = 0, $r$96$lcssa = 0, $r$96158 = 0, $r$97 = 0, $r$98$lcssa = 0, $r$98147 = 0, $r$99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $_buffer = sp;
 $0 = (($actbl) + 960|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($actbl) + 1264|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3 << 24 >> 24;
 $5 = (($state) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($state) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($state) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10>>>0)<(256);
 if ($11) {
  $buffer$0 = $_buffer;$localbuf$0 = 1;
 } else {
  $12 = HEAP32[$state>>2]|0;
  $buffer$0 = $12;$localbuf$0 = 0;
 }
 $13 = HEAP16[$block>>1]|0;
 $14 = $13 << 16 >> 16;
 $15 = (($14) - ($last_dc_val))|0;
 $16 = $15 >> 31;
 $17 = $16 ^ $15;
 $18 = (($17) - ($16))|0;
 $19 = (($16) + ($15))|0;
 $20 = (66264 + ($18)|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = $21&255;
 $23 = (($dctbl) + ($22<<2)|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ((($dctbl) + ($22)|0) + 1024|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = $26 << 24 >> 24;
 $28 = (($27) + ($8))|0;
 $29 = $6 << $27;
 $30 = $29 | $24;
 $31 = ($28|0)>(15);
 if ($31) {
  $32 = (($28) + -8)|0;
  $33 = $30 >>> $32;
  $34 = $33&255;
  $35 = (($buffer$0) + 1|0);
  HEAP8[$buffer$0>>0] = $34;
  $36 = $33 & 255;
  $37 = ($36|0)==(255);
  if ($37) {
   $38 = (($buffer$0) + 2|0);
   HEAP8[$35>>0] = 0;
   $buffer$1 = $38;
  } else {
   $buffer$1 = $35;
  }
  $39 = (($28) + -16)|0;
  $40 = $30 >>> $39;
  $41 = $40&255;
  $42 = (($buffer$1) + 1|0);
  HEAP8[$buffer$1>>0] = $41;
  $43 = $40 & 255;
  $44 = ($43|0)==(255);
  if ($44) {
   $45 = (($buffer$1) + 2|0);
   HEAP8[$42>>0] = 0;
   $buffer$2 = $45;$put_bits$0 = $39;
  } else {
   $buffer$2 = $42;$put_bits$0 = $39;
  }
 } else {
  $buffer$2 = $buffer$0;$put_bits$0 = $28;
 }
 $46 = 1 << $22;
 $47 = (($46) + -1)|0;
 $48 = $19 & $47;
 $49 = (($put_bits$0) + ($22))|0;
 $50 = $30 << $22;
 $51 = $50 | $48;
 $52 = ($49|0)>(15);
 if ($52) {
  $53 = (($49) + -8)|0;
  $54 = $51 >>> $53;
  $55 = $54&255;
  $56 = (($buffer$2) + 1|0);
  HEAP8[$buffer$2>>0] = $55;
  $57 = $54 & 255;
  $58 = ($57|0)==(255);
  if ($58) {
   $59 = (($buffer$2) + 2|0);
   HEAP8[$56>>0] = 0;
   $buffer$3 = $59;
  } else {
   $buffer$3 = $56;
  }
  $60 = (($49) + -16)|0;
  $61 = $51 >>> $60;
  $62 = $61&255;
  $63 = (($buffer$3) + 1|0);
  HEAP8[$buffer$3>>0] = $62;
  $64 = $61 & 255;
  $65 = ($64|0)==(255);
  if ($65) {
   $66 = (($buffer$3) + 2|0);
   HEAP8[$63>>0] = 0;
   $buffer$4 = $66;$put_bits$1 = $60;
  } else {
   $buffer$4 = $63;$put_bits$1 = $60;
  }
 } else {
  $buffer$4 = $buffer$2;$put_bits$1 = $49;
 }
 $67 = (($block) + 2|0);
 $68 = HEAP16[$67>>1]|0;
 $69 = $68 << 16 >> 16;
 $70 = ($68<<16>>16)==(0);
 if ($70) {
  $buffer$12 = $buffer$4;$put_bits$6 = $put_bits$1;$put_buffer$1 = $51;$r$1 = 1;
 } else {
  $71 = $69 >> 31;
  $72 = $71 ^ $69;
  $73 = (($72) - ($71))|0;
  $74 = (($71) + ($69))|0;
  $75 = (66264 + ($73)|0);
  $76 = HEAP8[$75>>0]|0;
  $77 = $76&255;
  $78 = (($actbl) + ($77<<2)|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = ((($actbl) + ($77)|0) + 1024|0);
  $81 = HEAP8[$80>>0]|0;
  $82 = $81 << 24 >> 24;
  $83 = 1 << $77;
  $84 = (($83) + -1)|0;
  $85 = $84 & $74;
  $86 = (($82) + ($put_bits$1))|0;
  $87 = $51 << $82;
  $88 = $87 | $79;
  $89 = ($86|0)>(15);
  if ($89) {
   $90 = (($86) + -8)|0;
   $91 = $88 >>> $90;
   $92 = $91&255;
   $93 = (($buffer$4) + 1|0);
   HEAP8[$buffer$4>>0] = $92;
   $94 = $91 & 255;
   $95 = ($94|0)==(255);
   if ($95) {
    $96 = (($buffer$4) + 2|0);
    HEAP8[$93>>0] = 0;
    $buffer$8 = $96;
   } else {
    $buffer$8 = $93;
   }
   $97 = (($86) + -16)|0;
   $98 = $88 >>> $97;
   $99 = $98&255;
   $100 = (($buffer$8) + 1|0);
   HEAP8[$buffer$8>>0] = $99;
   $101 = $98 & 255;
   $102 = ($101|0)==(255);
   if ($102) {
    $103 = (($buffer$8) + 2|0);
    HEAP8[$100>>0] = 0;
    $buffer$9 = $103;$put_bits$4 = $97;
   } else {
    $buffer$9 = $100;$put_bits$4 = $97;
   }
  } else {
   $buffer$9 = $buffer$4;$put_bits$4 = $86;
  }
  $104 = (($put_bits$4) + ($77))|0;
  $105 = $88 << $77;
  $106 = $105 | $85;
  $107 = ($104|0)>(15);
  if ($107) {
   $108 = (($104) + -8)|0;
   $109 = $106 >>> $108;
   $110 = $109&255;
   $111 = (($buffer$9) + 1|0);
   HEAP8[$buffer$9>>0] = $110;
   $112 = $109 & 255;
   $113 = ($112|0)==(255);
   if ($113) {
    $114 = (($buffer$9) + 2|0);
    HEAP8[$111>>0] = 0;
    $buffer$10 = $114;
   } else {
    $buffer$10 = $111;
   }
   $115 = (($104) + -16)|0;
   $116 = $106 >>> $115;
   $117 = $116&255;
   $118 = (($buffer$10) + 1|0);
   HEAP8[$buffer$10>>0] = $117;
   $119 = $116 & 255;
   $120 = ($119|0)==(255);
   if ($120) {
    $121 = (($buffer$10) + 2|0);
    HEAP8[$118>>0] = 0;
    $buffer$12 = $121;$put_bits$6 = $115;$put_buffer$1 = $106;$r$1 = 0;
   } else {
    $buffer$12 = $118;$put_bits$6 = $115;$put_buffer$1 = $106;$r$1 = 0;
   }
  } else {
   $buffer$12 = $buffer$9;$put_bits$6 = $104;$put_buffer$1 = $106;$r$1 = 0;
  }
 }
 $122 = (($block) + 16|0);
 $123 = HEAP16[$122>>1]|0;
 $124 = $123 << 16 >> 16;
 $125 = ($123<<16>>16)==(0);
 if ($125) {
  $126 = (($r$1) + 1)|0;
  $buffer$20 = $buffer$12;$put_bits$11 = $put_bits$6;$put_buffer$3 = $put_buffer$1;$r$3 = $126;
 } else {
  $127 = $124 >> 31;
  $128 = $127 ^ $124;
  $129 = (($128) - ($127))|0;
  $130 = (($127) + ($124))|0;
  $131 = (66264 + ($129)|0);
  $132 = HEAP8[$131>>0]|0;
  $133 = $132&255;
  $134 = $r$1 << 4;
  $135 = (($134) + ($133))|0;
  $136 = (($actbl) + ($135<<2)|0);
  $137 = HEAP32[$136>>2]|0;
  $138 = ((($actbl) + ($135)|0) + 1024|0);
  $139 = HEAP8[$138>>0]|0;
  $140 = $139 << 24 >> 24;
  $141 = 1 << $133;
  $142 = (($141) + -1)|0;
  $143 = $142 & $130;
  $144 = (($140) + ($put_bits$6))|0;
  $145 = $put_buffer$1 << $140;
  $146 = $145 | $137;
  $147 = ($144|0)>(15);
  if ($147) {
   $148 = (($144) + -8)|0;
   $149 = $146 >>> $148;
   $150 = $149&255;
   $151 = (($buffer$12) + 1|0);
   HEAP8[$buffer$12>>0] = $150;
   $152 = $149 & 255;
   $153 = ($152|0)==(255);
   if ($153) {
    $154 = (($buffer$12) + 2|0);
    HEAP8[$151>>0] = 0;
    $buffer$16 = $154;
   } else {
    $buffer$16 = $151;
   }
   $155 = (($144) + -16)|0;
   $156 = $146 >>> $155;
   $157 = $156&255;
   $158 = (($buffer$16) + 1|0);
   HEAP8[$buffer$16>>0] = $157;
   $159 = $156 & 255;
   $160 = ($159|0)==(255);
   if ($160) {
    $161 = (($buffer$16) + 2|0);
    HEAP8[$158>>0] = 0;
    $buffer$17 = $161;$put_bits$9 = $155;
   } else {
    $buffer$17 = $158;$put_bits$9 = $155;
   }
  } else {
   $buffer$17 = $buffer$12;$put_bits$9 = $144;
  }
  $162 = (($put_bits$9) + ($133))|0;
  $163 = $146 << $133;
  $164 = $163 | $143;
  $165 = ($162|0)>(15);
  if ($165) {
   $166 = (($162) + -8)|0;
   $167 = $164 >>> $166;
   $168 = $167&255;
   $169 = (($buffer$17) + 1|0);
   HEAP8[$buffer$17>>0] = $168;
   $170 = $167 & 255;
   $171 = ($170|0)==(255);
   if ($171) {
    $172 = (($buffer$17) + 2|0);
    HEAP8[$169>>0] = 0;
    $buffer$18 = $172;
   } else {
    $buffer$18 = $169;
   }
   $173 = (($162) + -16)|0;
   $174 = $164 >>> $173;
   $175 = $174&255;
   $176 = (($buffer$18) + 1|0);
   HEAP8[$buffer$18>>0] = $175;
   $177 = $174 & 255;
   $178 = ($177|0)==(255);
   if ($178) {
    $179 = (($buffer$18) + 2|0);
    HEAP8[$176>>0] = 0;
    $buffer$20 = $179;$put_bits$11 = $173;$put_buffer$3 = $164;$r$3 = 0;
   } else {
    $buffer$20 = $176;$put_bits$11 = $173;$put_buffer$3 = $164;$r$3 = 0;
   }
  } else {
   $buffer$20 = $buffer$17;$put_bits$11 = $162;$put_buffer$3 = $164;$r$3 = 0;
  }
 }
 $180 = (($block) + 32|0);
 $181 = HEAP16[$180>>1]|0;
 $182 = $181 << 16 >> 16;
 $183 = ($181<<16>>16)==(0);
 if ($183) {
  $184 = (($r$3) + 1)|0;
  $buffer$28 = $buffer$20;$put_bits$16 = $put_bits$11;$put_buffer$5 = $put_buffer$3;$r$5 = $184;
 } else {
  $185 = $182 >> 31;
  $186 = $185 ^ $182;
  $187 = (($186) - ($185))|0;
  $188 = (($185) + ($182))|0;
  $189 = (66264 + ($187)|0);
  $190 = HEAP8[$189>>0]|0;
  $191 = $190&255;
  $192 = ($r$3|0)>(15);
  if ($192) {
   $193 = (($put_bits$11) + ($4))|0;
   $194 = $put_buffer$3 << $4;
   $195 = $194 | $1;
   $196 = ($193|0)>(15);
   if ($196) {
    $197 = (($193) + -8)|0;
    $198 = $195 >>> $197;
    $199 = $198&255;
    $200 = (($buffer$20) + 1|0);
    HEAP8[$buffer$20>>0] = $199;
    $201 = $198 & 255;
    $202 = ($201|0)==(255);
    if ($202) {
     $203 = (($buffer$20) + 2|0);
     HEAP8[$200>>0] = 0;
     $buffer$22 = $203;
    } else {
     $buffer$22 = $200;
    }
    $204 = (($193) + -16)|0;
    $205 = $195 >>> $204;
    $206 = $205&255;
    $207 = (($buffer$22) + 1|0);
    HEAP8[$buffer$22>>0] = $206;
    $208 = $205 & 255;
    $209 = ($208|0)==(255);
    if ($209) {
     $210 = (($buffer$22) + 2|0);
     HEAP8[$207>>0] = 0;
     $buffer$23 = $210;$put_bits$13 = $204;
    } else {
     $buffer$23 = $207;$put_bits$13 = $204;
    }
   } else {
    $buffer$23 = $buffer$20;$put_bits$13 = $193;
   }
   $211 = $r$3 & 15;
   $buffer$21$lcssa = $buffer$23;$put_bits$12$lcssa = $put_bits$13;$put_buffer$4$lcssa = $195;$r$4$lcssa = $211;
  } else {
   $buffer$21$lcssa = $buffer$20;$put_bits$12$lcssa = $put_bits$11;$put_buffer$4$lcssa = $put_buffer$3;$r$4$lcssa = $r$3;
  }
  $212 = $r$4$lcssa << 4;
  $213 = (($212) + ($191))|0;
  $214 = (($actbl) + ($213<<2)|0);
  $215 = HEAP32[$214>>2]|0;
  $216 = ((($actbl) + ($213)|0) + 1024|0);
  $217 = HEAP8[$216>>0]|0;
  $218 = $217 << 24 >> 24;
  $219 = 1 << $191;
  $220 = (($219) + -1)|0;
  $221 = $220 & $188;
  $222 = (($218) + ($put_bits$12$lcssa))|0;
  $223 = $put_buffer$4$lcssa << $218;
  $224 = $223 | $215;
  $225 = ($222|0)>(15);
  if ($225) {
   $226 = (($222) + -8)|0;
   $227 = $224 >>> $226;
   $228 = $227&255;
   $229 = (($buffer$21$lcssa) + 1|0);
   HEAP8[$buffer$21$lcssa>>0] = $228;
   $230 = $227 & 255;
   $231 = ($230|0)==(255);
   if ($231) {
    $232 = (($buffer$21$lcssa) + 2|0);
    HEAP8[$229>>0] = 0;
    $buffer$24 = $232;
   } else {
    $buffer$24 = $229;
   }
   $233 = (($222) + -16)|0;
   $234 = $224 >>> $233;
   $235 = $234&255;
   $236 = (($buffer$24) + 1|0);
   HEAP8[$buffer$24>>0] = $235;
   $237 = $234 & 255;
   $238 = ($237|0)==(255);
   if ($238) {
    $239 = (($buffer$24) + 2|0);
    HEAP8[$236>>0] = 0;
    $buffer$25 = $239;$put_bits$14 = $233;
   } else {
    $buffer$25 = $236;$put_bits$14 = $233;
   }
  } else {
   $buffer$25 = $buffer$21$lcssa;$put_bits$14 = $222;
  }
  $240 = (($put_bits$14) + ($191))|0;
  $241 = $224 << $191;
  $242 = $241 | $221;
  $243 = ($240|0)>(15);
  if ($243) {
   $244 = (($240) + -8)|0;
   $245 = $242 >>> $244;
   $246 = $245&255;
   $247 = (($buffer$25) + 1|0);
   HEAP8[$buffer$25>>0] = $246;
   $248 = $245 & 255;
   $249 = ($248|0)==(255);
   if ($249) {
    $250 = (($buffer$25) + 2|0);
    HEAP8[$247>>0] = 0;
    $buffer$26 = $250;
   } else {
    $buffer$26 = $247;
   }
   $251 = (($240) + -16)|0;
   $252 = $242 >>> $251;
   $253 = $252&255;
   $254 = (($buffer$26) + 1|0);
   HEAP8[$buffer$26>>0] = $253;
   $255 = $252 & 255;
   $256 = ($255|0)==(255);
   if ($256) {
    $257 = (($buffer$26) + 2|0);
    HEAP8[$254>>0] = 0;
    $buffer$28 = $257;$put_bits$16 = $251;$put_buffer$5 = $242;$r$5 = 0;
   } else {
    $buffer$28 = $254;$put_bits$16 = $251;$put_buffer$5 = $242;$r$5 = 0;
   }
  } else {
   $buffer$28 = $buffer$25;$put_bits$16 = $240;$put_buffer$5 = $242;$r$5 = 0;
  }
 }
 $258 = (($block) + 18|0);
 $259 = HEAP16[$258>>1]|0;
 $260 = $259 << 16 >> 16;
 $261 = ($259<<16>>16)==(0);
 if ($261) {
  $262 = (($r$5) + 1)|0;
  $buffer$36 = $buffer$28;$put_bits$21 = $put_bits$16;$put_buffer$7 = $put_buffer$5;$r$7 = $262;
 } else {
  $263 = $260 >> 31;
  $264 = $263 ^ $260;
  $265 = (($264) - ($263))|0;
  $266 = (($263) + ($260))|0;
  $267 = (66264 + ($265)|0);
  $268 = HEAP8[$267>>0]|0;
  $269 = $268&255;
  $270 = ($r$5|0)>(15);
  if ($270) {
   $271 = (($put_bits$16) + ($4))|0;
   $272 = $put_buffer$5 << $4;
   $273 = $272 | $1;
   $274 = ($271|0)>(15);
   if ($274) {
    $275 = (($271) + -8)|0;
    $276 = $273 >>> $275;
    $277 = $276&255;
    $278 = (($buffer$28) + 1|0);
    HEAP8[$buffer$28>>0] = $277;
    $279 = $276 & 255;
    $280 = ($279|0)==(255);
    if ($280) {
     $281 = (($buffer$28) + 2|0);
     HEAP8[$278>>0] = 0;
     $buffer$30 = $281;
    } else {
     $buffer$30 = $278;
    }
    $282 = (($271) + -16)|0;
    $283 = $273 >>> $282;
    $284 = $283&255;
    $285 = (($buffer$30) + 1|0);
    HEAP8[$buffer$30>>0] = $284;
    $286 = $283 & 255;
    $287 = ($286|0)==(255);
    if ($287) {
     $288 = (($buffer$30) + 2|0);
     HEAP8[$285>>0] = 0;
     $buffer$31 = $288;$put_bits$18 = $282;
    } else {
     $buffer$31 = $285;$put_bits$18 = $282;
    }
   } else {
    $buffer$31 = $buffer$28;$put_bits$18 = $271;
   }
   $289 = $r$5 & 15;
   $buffer$29$lcssa = $buffer$31;$put_bits$17$lcssa = $put_bits$18;$put_buffer$6$lcssa = $273;$r$6$lcssa = $289;
  } else {
   $buffer$29$lcssa = $buffer$28;$put_bits$17$lcssa = $put_bits$16;$put_buffer$6$lcssa = $put_buffer$5;$r$6$lcssa = $r$5;
  }
  $290 = $r$6$lcssa << 4;
  $291 = (($290) + ($269))|0;
  $292 = (($actbl) + ($291<<2)|0);
  $293 = HEAP32[$292>>2]|0;
  $294 = ((($actbl) + ($291)|0) + 1024|0);
  $295 = HEAP8[$294>>0]|0;
  $296 = $295 << 24 >> 24;
  $297 = 1 << $269;
  $298 = (($297) + -1)|0;
  $299 = $298 & $266;
  $300 = (($296) + ($put_bits$17$lcssa))|0;
  $301 = $put_buffer$6$lcssa << $296;
  $302 = $301 | $293;
  $303 = ($300|0)>(15);
  if ($303) {
   $304 = (($300) + -8)|0;
   $305 = $302 >>> $304;
   $306 = $305&255;
   $307 = (($buffer$29$lcssa) + 1|0);
   HEAP8[$buffer$29$lcssa>>0] = $306;
   $308 = $305 & 255;
   $309 = ($308|0)==(255);
   if ($309) {
    $310 = (($buffer$29$lcssa) + 2|0);
    HEAP8[$307>>0] = 0;
    $buffer$32 = $310;
   } else {
    $buffer$32 = $307;
   }
   $311 = (($300) + -16)|0;
   $312 = $302 >>> $311;
   $313 = $312&255;
   $314 = (($buffer$32) + 1|0);
   HEAP8[$buffer$32>>0] = $313;
   $315 = $312 & 255;
   $316 = ($315|0)==(255);
   if ($316) {
    $317 = (($buffer$32) + 2|0);
    HEAP8[$314>>0] = 0;
    $buffer$33 = $317;$put_bits$19 = $311;
   } else {
    $buffer$33 = $314;$put_bits$19 = $311;
   }
  } else {
   $buffer$33 = $buffer$29$lcssa;$put_bits$19 = $300;
  }
  $318 = (($put_bits$19) + ($269))|0;
  $319 = $302 << $269;
  $320 = $319 | $299;
  $321 = ($318|0)>(15);
  if ($321) {
   $322 = (($318) + -8)|0;
   $323 = $320 >>> $322;
   $324 = $323&255;
   $325 = (($buffer$33) + 1|0);
   HEAP8[$buffer$33>>0] = $324;
   $326 = $323 & 255;
   $327 = ($326|0)==(255);
   if ($327) {
    $328 = (($buffer$33) + 2|0);
    HEAP8[$325>>0] = 0;
    $buffer$34 = $328;
   } else {
    $buffer$34 = $325;
   }
   $329 = (($318) + -16)|0;
   $330 = $320 >>> $329;
   $331 = $330&255;
   $332 = (($buffer$34) + 1|0);
   HEAP8[$buffer$34>>0] = $331;
   $333 = $330 & 255;
   $334 = ($333|0)==(255);
   if ($334) {
    $335 = (($buffer$34) + 2|0);
    HEAP8[$332>>0] = 0;
    $buffer$36 = $335;$put_bits$21 = $329;$put_buffer$7 = $320;$r$7 = 0;
   } else {
    $buffer$36 = $332;$put_bits$21 = $329;$put_buffer$7 = $320;$r$7 = 0;
   }
  } else {
   $buffer$36 = $buffer$33;$put_bits$21 = $318;$put_buffer$7 = $320;$r$7 = 0;
  }
 }
 $336 = (($block) + 4|0);
 $337 = HEAP16[$336>>1]|0;
 $338 = $337 << 16 >> 16;
 $339 = ($337<<16>>16)==(0);
 if ($339) {
  $340 = (($r$7) + 1)|0;
  $buffer$44 = $buffer$36;$put_bits$26 = $put_bits$21;$put_buffer$9 = $put_buffer$7;$r$9 = $340;
 } else {
  $341 = $338 >> 31;
  $342 = $341 ^ $338;
  $343 = (($342) - ($341))|0;
  $344 = (($341) + ($338))|0;
  $345 = (66264 + ($343)|0);
  $346 = HEAP8[$345>>0]|0;
  $347 = $346&255;
  $348 = ($r$7|0)>(15);
  if ($348) {
   $buffer$37641 = $buffer$36;$put_bits$22639 = $put_bits$21;$put_buffer$8640 = $put_buffer$7;$r$8642 = $r$7;
   while(1) {
    $349 = (($put_bits$22639) + ($4))|0;
    $350 = $put_buffer$8640 << $4;
    $351 = $350 | $1;
    $352 = ($349|0)>(15);
    if ($352) {
     $353 = (($349) + -8)|0;
     $354 = $351 >>> $353;
     $355 = $354&255;
     $356 = (($buffer$37641) + 1|0);
     HEAP8[$buffer$37641>>0] = $355;
     $357 = $354 & 255;
     $358 = ($357|0)==(255);
     if ($358) {
      $359 = (($buffer$37641) + 2|0);
      HEAP8[$356>>0] = 0;
      $buffer$38 = $359;
     } else {
      $buffer$38 = $356;
     }
     $360 = (($349) + -16)|0;
     $361 = $351 >>> $360;
     $362 = $361&255;
     $363 = (($buffer$38) + 1|0);
     HEAP8[$buffer$38>>0] = $362;
     $364 = $361 & 255;
     $365 = ($364|0)==(255);
     if ($365) {
      $366 = (($buffer$38) + 2|0);
      HEAP8[$363>>0] = 0;
      $buffer$39 = $366;$put_bits$23 = $360;
     } else {
      $buffer$39 = $363;$put_bits$23 = $360;
     }
    } else {
     $buffer$39 = $buffer$37641;$put_bits$23 = $349;
    }
    $367 = (($r$8642) + -16)|0;
    $368 = ($367|0)>(15);
    if ($368) {
     $buffer$37641 = $buffer$39;$put_bits$22639 = $put_bits$23;$put_buffer$8640 = $351;$r$8642 = $367;
    } else {
     break;
    }
   }
   $369 = $r$7 & 15;
   $buffer$37$lcssa = $buffer$39;$put_bits$22$lcssa = $put_bits$23;$put_buffer$8$lcssa = $351;$r$8$lcssa = $369;
  } else {
   $buffer$37$lcssa = $buffer$36;$put_bits$22$lcssa = $put_bits$21;$put_buffer$8$lcssa = $put_buffer$7;$r$8$lcssa = $r$7;
  }
  $370 = $r$8$lcssa << 4;
  $371 = (($370) + ($347))|0;
  $372 = (($actbl) + ($371<<2)|0);
  $373 = HEAP32[$372>>2]|0;
  $374 = ((($actbl) + ($371)|0) + 1024|0);
  $375 = HEAP8[$374>>0]|0;
  $376 = $375 << 24 >> 24;
  $377 = 1 << $347;
  $378 = (($377) + -1)|0;
  $379 = $378 & $344;
  $380 = (($376) + ($put_bits$22$lcssa))|0;
  $381 = $put_buffer$8$lcssa << $376;
  $382 = $381 | $373;
  $383 = ($380|0)>(15);
  if ($383) {
   $384 = (($380) + -8)|0;
   $385 = $382 >>> $384;
   $386 = $385&255;
   $387 = (($buffer$37$lcssa) + 1|0);
   HEAP8[$buffer$37$lcssa>>0] = $386;
   $388 = $385 & 255;
   $389 = ($388|0)==(255);
   if ($389) {
    $390 = (($buffer$37$lcssa) + 2|0);
    HEAP8[$387>>0] = 0;
    $buffer$40 = $390;
   } else {
    $buffer$40 = $387;
   }
   $391 = (($380) + -16)|0;
   $392 = $382 >>> $391;
   $393 = $392&255;
   $394 = (($buffer$40) + 1|0);
   HEAP8[$buffer$40>>0] = $393;
   $395 = $392 & 255;
   $396 = ($395|0)==(255);
   if ($396) {
    $397 = (($buffer$40) + 2|0);
    HEAP8[$394>>0] = 0;
    $buffer$41 = $397;$put_bits$24 = $391;
   } else {
    $buffer$41 = $394;$put_bits$24 = $391;
   }
  } else {
   $buffer$41 = $buffer$37$lcssa;$put_bits$24 = $380;
  }
  $398 = (($put_bits$24) + ($347))|0;
  $399 = $382 << $347;
  $400 = $399 | $379;
  $401 = ($398|0)>(15);
  if ($401) {
   $402 = (($398) + -8)|0;
   $403 = $400 >>> $402;
   $404 = $403&255;
   $405 = (($buffer$41) + 1|0);
   HEAP8[$buffer$41>>0] = $404;
   $406 = $403 & 255;
   $407 = ($406|0)==(255);
   if ($407) {
    $408 = (($buffer$41) + 2|0);
    HEAP8[$405>>0] = 0;
    $buffer$42 = $408;
   } else {
    $buffer$42 = $405;
   }
   $409 = (($398) + -16)|0;
   $410 = $400 >>> $409;
   $411 = $410&255;
   $412 = (($buffer$42) + 1|0);
   HEAP8[$buffer$42>>0] = $411;
   $413 = $410 & 255;
   $414 = ($413|0)==(255);
   if ($414) {
    $415 = (($buffer$42) + 2|0);
    HEAP8[$412>>0] = 0;
    $buffer$44 = $415;$put_bits$26 = $409;$put_buffer$9 = $400;$r$9 = 0;
   } else {
    $buffer$44 = $412;$put_bits$26 = $409;$put_buffer$9 = $400;$r$9 = 0;
   }
  } else {
   $buffer$44 = $buffer$41;$put_bits$26 = $398;$put_buffer$9 = $400;$r$9 = 0;
  }
 }
 $416 = (($block) + 6|0);
 $417 = HEAP16[$416>>1]|0;
 $418 = $417 << 16 >> 16;
 $419 = ($417<<16>>16)==(0);
 if ($419) {
  $420 = (($r$9) + 1)|0;
  $buffer$52 = $buffer$44;$put_bits$31 = $put_bits$26;$put_buffer$11 = $put_buffer$9;$r$11 = $420;
 } else {
  $421 = $418 >> 31;
  $422 = $421 ^ $418;
  $423 = (($422) - ($421))|0;
  $424 = (($421) + ($418))|0;
  $425 = (66264 + ($423)|0);
  $426 = HEAP8[$425>>0]|0;
  $427 = $426&255;
  $428 = ($r$9|0)>(15);
  if ($428) {
   $buffer$45630 = $buffer$44;$put_bits$27628 = $put_bits$26;$put_buffer$10629 = $put_buffer$9;$r$10631 = $r$9;
   while(1) {
    $429 = (($put_bits$27628) + ($4))|0;
    $430 = $put_buffer$10629 << $4;
    $431 = $430 | $1;
    $432 = ($429|0)>(15);
    if ($432) {
     $433 = (($429) + -8)|0;
     $434 = $431 >>> $433;
     $435 = $434&255;
     $436 = (($buffer$45630) + 1|0);
     HEAP8[$buffer$45630>>0] = $435;
     $437 = $434 & 255;
     $438 = ($437|0)==(255);
     if ($438) {
      $439 = (($buffer$45630) + 2|0);
      HEAP8[$436>>0] = 0;
      $buffer$46 = $439;
     } else {
      $buffer$46 = $436;
     }
     $440 = (($429) + -16)|0;
     $441 = $431 >>> $440;
     $442 = $441&255;
     $443 = (($buffer$46) + 1|0);
     HEAP8[$buffer$46>>0] = $442;
     $444 = $441 & 255;
     $445 = ($444|0)==(255);
     if ($445) {
      $446 = (($buffer$46) + 2|0);
      HEAP8[$443>>0] = 0;
      $buffer$47 = $446;$put_bits$28 = $440;
     } else {
      $buffer$47 = $443;$put_bits$28 = $440;
     }
    } else {
     $buffer$47 = $buffer$45630;$put_bits$28 = $429;
    }
    $447 = (($r$10631) + -16)|0;
    $448 = ($447|0)>(15);
    if ($448) {
     $buffer$45630 = $buffer$47;$put_bits$27628 = $put_bits$28;$put_buffer$10629 = $431;$r$10631 = $447;
    } else {
     break;
    }
   }
   $449 = $r$9 & 15;
   $buffer$45$lcssa = $buffer$47;$put_bits$27$lcssa = $put_bits$28;$put_buffer$10$lcssa = $431;$r$10$lcssa = $449;
  } else {
   $buffer$45$lcssa = $buffer$44;$put_bits$27$lcssa = $put_bits$26;$put_buffer$10$lcssa = $put_buffer$9;$r$10$lcssa = $r$9;
  }
  $450 = $r$10$lcssa << 4;
  $451 = (($450) + ($427))|0;
  $452 = (($actbl) + ($451<<2)|0);
  $453 = HEAP32[$452>>2]|0;
  $454 = ((($actbl) + ($451)|0) + 1024|0);
  $455 = HEAP8[$454>>0]|0;
  $456 = $455 << 24 >> 24;
  $457 = 1 << $427;
  $458 = (($457) + -1)|0;
  $459 = $458 & $424;
  $460 = (($456) + ($put_bits$27$lcssa))|0;
  $461 = $put_buffer$10$lcssa << $456;
  $462 = $461 | $453;
  $463 = ($460|0)>(15);
  if ($463) {
   $464 = (($460) + -8)|0;
   $465 = $462 >>> $464;
   $466 = $465&255;
   $467 = (($buffer$45$lcssa) + 1|0);
   HEAP8[$buffer$45$lcssa>>0] = $466;
   $468 = $465 & 255;
   $469 = ($468|0)==(255);
   if ($469) {
    $470 = (($buffer$45$lcssa) + 2|0);
    HEAP8[$467>>0] = 0;
    $buffer$48 = $470;
   } else {
    $buffer$48 = $467;
   }
   $471 = (($460) + -16)|0;
   $472 = $462 >>> $471;
   $473 = $472&255;
   $474 = (($buffer$48) + 1|0);
   HEAP8[$buffer$48>>0] = $473;
   $475 = $472 & 255;
   $476 = ($475|0)==(255);
   if ($476) {
    $477 = (($buffer$48) + 2|0);
    HEAP8[$474>>0] = 0;
    $buffer$49 = $477;$put_bits$29 = $471;
   } else {
    $buffer$49 = $474;$put_bits$29 = $471;
   }
  } else {
   $buffer$49 = $buffer$45$lcssa;$put_bits$29 = $460;
  }
  $478 = (($put_bits$29) + ($427))|0;
  $479 = $462 << $427;
  $480 = $479 | $459;
  $481 = ($478|0)>(15);
  if ($481) {
   $482 = (($478) + -8)|0;
   $483 = $480 >>> $482;
   $484 = $483&255;
   $485 = (($buffer$49) + 1|0);
   HEAP8[$buffer$49>>0] = $484;
   $486 = $483 & 255;
   $487 = ($486|0)==(255);
   if ($487) {
    $488 = (($buffer$49) + 2|0);
    HEAP8[$485>>0] = 0;
    $buffer$50 = $488;
   } else {
    $buffer$50 = $485;
   }
   $489 = (($478) + -16)|0;
   $490 = $480 >>> $489;
   $491 = $490&255;
   $492 = (($buffer$50) + 1|0);
   HEAP8[$buffer$50>>0] = $491;
   $493 = $490 & 255;
   $494 = ($493|0)==(255);
   if ($494) {
    $495 = (($buffer$50) + 2|0);
    HEAP8[$492>>0] = 0;
    $buffer$52 = $495;$put_bits$31 = $489;$put_buffer$11 = $480;$r$11 = 0;
   } else {
    $buffer$52 = $492;$put_bits$31 = $489;$put_buffer$11 = $480;$r$11 = 0;
   }
  } else {
   $buffer$52 = $buffer$49;$put_bits$31 = $478;$put_buffer$11 = $480;$r$11 = 0;
  }
 }
 $496 = (($block) + 20|0);
 $497 = HEAP16[$496>>1]|0;
 $498 = $497 << 16 >> 16;
 $499 = ($497<<16>>16)==(0);
 if ($499) {
  $500 = (($r$11) + 1)|0;
  $buffer$60 = $buffer$52;$put_bits$36 = $put_bits$31;$put_buffer$13 = $put_buffer$11;$r$13 = $500;
 } else {
  $501 = $498 >> 31;
  $502 = $501 ^ $498;
  $503 = (($502) - ($501))|0;
  $504 = (($501) + ($498))|0;
  $505 = (66264 + ($503)|0);
  $506 = HEAP8[$505>>0]|0;
  $507 = $506&255;
  $508 = ($r$11|0)>(15);
  if ($508) {
   $buffer$53619 = $buffer$52;$put_bits$32617 = $put_bits$31;$put_buffer$12618 = $put_buffer$11;$r$12620 = $r$11;
   while(1) {
    $509 = (($put_bits$32617) + ($4))|0;
    $510 = $put_buffer$12618 << $4;
    $511 = $510 | $1;
    $512 = ($509|0)>(15);
    if ($512) {
     $513 = (($509) + -8)|0;
     $514 = $511 >>> $513;
     $515 = $514&255;
     $516 = (($buffer$53619) + 1|0);
     HEAP8[$buffer$53619>>0] = $515;
     $517 = $514 & 255;
     $518 = ($517|0)==(255);
     if ($518) {
      $519 = (($buffer$53619) + 2|0);
      HEAP8[$516>>0] = 0;
      $buffer$54 = $519;
     } else {
      $buffer$54 = $516;
     }
     $520 = (($509) + -16)|0;
     $521 = $511 >>> $520;
     $522 = $521&255;
     $523 = (($buffer$54) + 1|0);
     HEAP8[$buffer$54>>0] = $522;
     $524 = $521 & 255;
     $525 = ($524|0)==(255);
     if ($525) {
      $526 = (($buffer$54) + 2|0);
      HEAP8[$523>>0] = 0;
      $buffer$55 = $526;$put_bits$33 = $520;
     } else {
      $buffer$55 = $523;$put_bits$33 = $520;
     }
    } else {
     $buffer$55 = $buffer$53619;$put_bits$33 = $509;
    }
    $527 = (($r$12620) + -16)|0;
    $528 = ($527|0)>(15);
    if ($528) {
     $buffer$53619 = $buffer$55;$put_bits$32617 = $put_bits$33;$put_buffer$12618 = $511;$r$12620 = $527;
    } else {
     break;
    }
   }
   $529 = $r$11 & 15;
   $buffer$53$lcssa = $buffer$55;$put_bits$32$lcssa = $put_bits$33;$put_buffer$12$lcssa = $511;$r$12$lcssa = $529;
  } else {
   $buffer$53$lcssa = $buffer$52;$put_bits$32$lcssa = $put_bits$31;$put_buffer$12$lcssa = $put_buffer$11;$r$12$lcssa = $r$11;
  }
  $530 = $r$12$lcssa << 4;
  $531 = (($530) + ($507))|0;
  $532 = (($actbl) + ($531<<2)|0);
  $533 = HEAP32[$532>>2]|0;
  $534 = ((($actbl) + ($531)|0) + 1024|0);
  $535 = HEAP8[$534>>0]|0;
  $536 = $535 << 24 >> 24;
  $537 = 1 << $507;
  $538 = (($537) + -1)|0;
  $539 = $538 & $504;
  $540 = (($536) + ($put_bits$32$lcssa))|0;
  $541 = $put_buffer$12$lcssa << $536;
  $542 = $541 | $533;
  $543 = ($540|0)>(15);
  if ($543) {
   $544 = (($540) + -8)|0;
   $545 = $542 >>> $544;
   $546 = $545&255;
   $547 = (($buffer$53$lcssa) + 1|0);
   HEAP8[$buffer$53$lcssa>>0] = $546;
   $548 = $545 & 255;
   $549 = ($548|0)==(255);
   if ($549) {
    $550 = (($buffer$53$lcssa) + 2|0);
    HEAP8[$547>>0] = 0;
    $buffer$56 = $550;
   } else {
    $buffer$56 = $547;
   }
   $551 = (($540) + -16)|0;
   $552 = $542 >>> $551;
   $553 = $552&255;
   $554 = (($buffer$56) + 1|0);
   HEAP8[$buffer$56>>0] = $553;
   $555 = $552 & 255;
   $556 = ($555|0)==(255);
   if ($556) {
    $557 = (($buffer$56) + 2|0);
    HEAP8[$554>>0] = 0;
    $buffer$57 = $557;$put_bits$34 = $551;
   } else {
    $buffer$57 = $554;$put_bits$34 = $551;
   }
  } else {
   $buffer$57 = $buffer$53$lcssa;$put_bits$34 = $540;
  }
  $558 = (($put_bits$34) + ($507))|0;
  $559 = $542 << $507;
  $560 = $559 | $539;
  $561 = ($558|0)>(15);
  if ($561) {
   $562 = (($558) + -8)|0;
   $563 = $560 >>> $562;
   $564 = $563&255;
   $565 = (($buffer$57) + 1|0);
   HEAP8[$buffer$57>>0] = $564;
   $566 = $563 & 255;
   $567 = ($566|0)==(255);
   if ($567) {
    $568 = (($buffer$57) + 2|0);
    HEAP8[$565>>0] = 0;
    $buffer$58 = $568;
   } else {
    $buffer$58 = $565;
   }
   $569 = (($558) + -16)|0;
   $570 = $560 >>> $569;
   $571 = $570&255;
   $572 = (($buffer$58) + 1|0);
   HEAP8[$buffer$58>>0] = $571;
   $573 = $570 & 255;
   $574 = ($573|0)==(255);
   if ($574) {
    $575 = (($buffer$58) + 2|0);
    HEAP8[$572>>0] = 0;
    $buffer$60 = $575;$put_bits$36 = $569;$put_buffer$13 = $560;$r$13 = 0;
   } else {
    $buffer$60 = $572;$put_bits$36 = $569;$put_buffer$13 = $560;$r$13 = 0;
   }
  } else {
   $buffer$60 = $buffer$57;$put_bits$36 = $558;$put_buffer$13 = $560;$r$13 = 0;
  }
 }
 $576 = (($block) + 34|0);
 $577 = HEAP16[$576>>1]|0;
 $578 = $577 << 16 >> 16;
 $579 = ($577<<16>>16)==(0);
 if ($579) {
  $580 = (($r$13) + 1)|0;
  $buffer$68 = $buffer$60;$put_bits$41 = $put_bits$36;$put_buffer$15 = $put_buffer$13;$r$15 = $580;
 } else {
  $581 = $578 >> 31;
  $582 = $581 ^ $578;
  $583 = (($582) - ($581))|0;
  $584 = (($581) + ($578))|0;
  $585 = (66264 + ($583)|0);
  $586 = HEAP8[$585>>0]|0;
  $587 = $586&255;
  $588 = ($r$13|0)>(15);
  if ($588) {
   $buffer$61608 = $buffer$60;$put_bits$37606 = $put_bits$36;$put_buffer$14607 = $put_buffer$13;$r$14609 = $r$13;
   while(1) {
    $589 = (($put_bits$37606) + ($4))|0;
    $590 = $put_buffer$14607 << $4;
    $591 = $590 | $1;
    $592 = ($589|0)>(15);
    if ($592) {
     $593 = (($589) + -8)|0;
     $594 = $591 >>> $593;
     $595 = $594&255;
     $596 = (($buffer$61608) + 1|0);
     HEAP8[$buffer$61608>>0] = $595;
     $597 = $594 & 255;
     $598 = ($597|0)==(255);
     if ($598) {
      $599 = (($buffer$61608) + 2|0);
      HEAP8[$596>>0] = 0;
      $buffer$62 = $599;
     } else {
      $buffer$62 = $596;
     }
     $600 = (($589) + -16)|0;
     $601 = $591 >>> $600;
     $602 = $601&255;
     $603 = (($buffer$62) + 1|0);
     HEAP8[$buffer$62>>0] = $602;
     $604 = $601 & 255;
     $605 = ($604|0)==(255);
     if ($605) {
      $606 = (($buffer$62) + 2|0);
      HEAP8[$603>>0] = 0;
      $buffer$63 = $606;$put_bits$38 = $600;
     } else {
      $buffer$63 = $603;$put_bits$38 = $600;
     }
    } else {
     $buffer$63 = $buffer$61608;$put_bits$38 = $589;
    }
    $607 = (($r$14609) + -16)|0;
    $608 = ($607|0)>(15);
    if ($608) {
     $buffer$61608 = $buffer$63;$put_bits$37606 = $put_bits$38;$put_buffer$14607 = $591;$r$14609 = $607;
    } else {
     break;
    }
   }
   $609 = $r$13 & 15;
   $buffer$61$lcssa = $buffer$63;$put_bits$37$lcssa = $put_bits$38;$put_buffer$14$lcssa = $591;$r$14$lcssa = $609;
  } else {
   $buffer$61$lcssa = $buffer$60;$put_bits$37$lcssa = $put_bits$36;$put_buffer$14$lcssa = $put_buffer$13;$r$14$lcssa = $r$13;
  }
  $610 = $r$14$lcssa << 4;
  $611 = (($610) + ($587))|0;
  $612 = (($actbl) + ($611<<2)|0);
  $613 = HEAP32[$612>>2]|0;
  $614 = ((($actbl) + ($611)|0) + 1024|0);
  $615 = HEAP8[$614>>0]|0;
  $616 = $615 << 24 >> 24;
  $617 = 1 << $587;
  $618 = (($617) + -1)|0;
  $619 = $618 & $584;
  $620 = (($616) + ($put_bits$37$lcssa))|0;
  $621 = $put_buffer$14$lcssa << $616;
  $622 = $621 | $613;
  $623 = ($620|0)>(15);
  if ($623) {
   $624 = (($620) + -8)|0;
   $625 = $622 >>> $624;
   $626 = $625&255;
   $627 = (($buffer$61$lcssa) + 1|0);
   HEAP8[$buffer$61$lcssa>>0] = $626;
   $628 = $625 & 255;
   $629 = ($628|0)==(255);
   if ($629) {
    $630 = (($buffer$61$lcssa) + 2|0);
    HEAP8[$627>>0] = 0;
    $buffer$64 = $630;
   } else {
    $buffer$64 = $627;
   }
   $631 = (($620) + -16)|0;
   $632 = $622 >>> $631;
   $633 = $632&255;
   $634 = (($buffer$64) + 1|0);
   HEAP8[$buffer$64>>0] = $633;
   $635 = $632 & 255;
   $636 = ($635|0)==(255);
   if ($636) {
    $637 = (($buffer$64) + 2|0);
    HEAP8[$634>>0] = 0;
    $buffer$65 = $637;$put_bits$39 = $631;
   } else {
    $buffer$65 = $634;$put_bits$39 = $631;
   }
  } else {
   $buffer$65 = $buffer$61$lcssa;$put_bits$39 = $620;
  }
  $638 = (($put_bits$39) + ($587))|0;
  $639 = $622 << $587;
  $640 = $639 | $619;
  $641 = ($638|0)>(15);
  if ($641) {
   $642 = (($638) + -8)|0;
   $643 = $640 >>> $642;
   $644 = $643&255;
   $645 = (($buffer$65) + 1|0);
   HEAP8[$buffer$65>>0] = $644;
   $646 = $643 & 255;
   $647 = ($646|0)==(255);
   if ($647) {
    $648 = (($buffer$65) + 2|0);
    HEAP8[$645>>0] = 0;
    $buffer$66 = $648;
   } else {
    $buffer$66 = $645;
   }
   $649 = (($638) + -16)|0;
   $650 = $640 >>> $649;
   $651 = $650&255;
   $652 = (($buffer$66) + 1|0);
   HEAP8[$buffer$66>>0] = $651;
   $653 = $650 & 255;
   $654 = ($653|0)==(255);
   if ($654) {
    $655 = (($buffer$66) + 2|0);
    HEAP8[$652>>0] = 0;
    $buffer$68 = $655;$put_bits$41 = $649;$put_buffer$15 = $640;$r$15 = 0;
   } else {
    $buffer$68 = $652;$put_bits$41 = $649;$put_buffer$15 = $640;$r$15 = 0;
   }
  } else {
   $buffer$68 = $buffer$65;$put_bits$41 = $638;$put_buffer$15 = $640;$r$15 = 0;
  }
 }
 $656 = (($block) + 48|0);
 $657 = HEAP16[$656>>1]|0;
 $658 = $657 << 16 >> 16;
 $659 = ($657<<16>>16)==(0);
 if ($659) {
  $660 = (($r$15) + 1)|0;
  $buffer$76 = $buffer$68;$put_bits$46 = $put_bits$41;$put_buffer$17 = $put_buffer$15;$r$17 = $660;
 } else {
  $661 = $658 >> 31;
  $662 = $661 ^ $658;
  $663 = (($662) - ($661))|0;
  $664 = (($661) + ($658))|0;
  $665 = (66264 + ($663)|0);
  $666 = HEAP8[$665>>0]|0;
  $667 = $666&255;
  $668 = ($r$15|0)>(15);
  if ($668) {
   $buffer$69597 = $buffer$68;$put_bits$42595 = $put_bits$41;$put_buffer$16596 = $put_buffer$15;$r$16598 = $r$15;
   while(1) {
    $669 = (($put_bits$42595) + ($4))|0;
    $670 = $put_buffer$16596 << $4;
    $671 = $670 | $1;
    $672 = ($669|0)>(15);
    if ($672) {
     $673 = (($669) + -8)|0;
     $674 = $671 >>> $673;
     $675 = $674&255;
     $676 = (($buffer$69597) + 1|0);
     HEAP8[$buffer$69597>>0] = $675;
     $677 = $674 & 255;
     $678 = ($677|0)==(255);
     if ($678) {
      $679 = (($buffer$69597) + 2|0);
      HEAP8[$676>>0] = 0;
      $buffer$70 = $679;
     } else {
      $buffer$70 = $676;
     }
     $680 = (($669) + -16)|0;
     $681 = $671 >>> $680;
     $682 = $681&255;
     $683 = (($buffer$70) + 1|0);
     HEAP8[$buffer$70>>0] = $682;
     $684 = $681 & 255;
     $685 = ($684|0)==(255);
     if ($685) {
      $686 = (($buffer$70) + 2|0);
      HEAP8[$683>>0] = 0;
      $buffer$71 = $686;$put_bits$43 = $680;
     } else {
      $buffer$71 = $683;$put_bits$43 = $680;
     }
    } else {
     $buffer$71 = $buffer$69597;$put_bits$43 = $669;
    }
    $687 = (($r$16598) + -16)|0;
    $688 = ($687|0)>(15);
    if ($688) {
     $buffer$69597 = $buffer$71;$put_bits$42595 = $put_bits$43;$put_buffer$16596 = $671;$r$16598 = $687;
    } else {
     break;
    }
   }
   $689 = $r$15 & 15;
   $buffer$69$lcssa = $buffer$71;$put_bits$42$lcssa = $put_bits$43;$put_buffer$16$lcssa = $671;$r$16$lcssa = $689;
  } else {
   $buffer$69$lcssa = $buffer$68;$put_bits$42$lcssa = $put_bits$41;$put_buffer$16$lcssa = $put_buffer$15;$r$16$lcssa = $r$15;
  }
  $690 = $r$16$lcssa << 4;
  $691 = (($690) + ($667))|0;
  $692 = (($actbl) + ($691<<2)|0);
  $693 = HEAP32[$692>>2]|0;
  $694 = ((($actbl) + ($691)|0) + 1024|0);
  $695 = HEAP8[$694>>0]|0;
  $696 = $695 << 24 >> 24;
  $697 = 1 << $667;
  $698 = (($697) + -1)|0;
  $699 = $698 & $664;
  $700 = (($696) + ($put_bits$42$lcssa))|0;
  $701 = $put_buffer$16$lcssa << $696;
  $702 = $701 | $693;
  $703 = ($700|0)>(15);
  if ($703) {
   $704 = (($700) + -8)|0;
   $705 = $702 >>> $704;
   $706 = $705&255;
   $707 = (($buffer$69$lcssa) + 1|0);
   HEAP8[$buffer$69$lcssa>>0] = $706;
   $708 = $705 & 255;
   $709 = ($708|0)==(255);
   if ($709) {
    $710 = (($buffer$69$lcssa) + 2|0);
    HEAP8[$707>>0] = 0;
    $buffer$72 = $710;
   } else {
    $buffer$72 = $707;
   }
   $711 = (($700) + -16)|0;
   $712 = $702 >>> $711;
   $713 = $712&255;
   $714 = (($buffer$72) + 1|0);
   HEAP8[$buffer$72>>0] = $713;
   $715 = $712 & 255;
   $716 = ($715|0)==(255);
   if ($716) {
    $717 = (($buffer$72) + 2|0);
    HEAP8[$714>>0] = 0;
    $buffer$73 = $717;$put_bits$44 = $711;
   } else {
    $buffer$73 = $714;$put_bits$44 = $711;
   }
  } else {
   $buffer$73 = $buffer$69$lcssa;$put_bits$44 = $700;
  }
  $718 = (($put_bits$44) + ($667))|0;
  $719 = $702 << $667;
  $720 = $719 | $699;
  $721 = ($718|0)>(15);
  if ($721) {
   $722 = (($718) + -8)|0;
   $723 = $720 >>> $722;
   $724 = $723&255;
   $725 = (($buffer$73) + 1|0);
   HEAP8[$buffer$73>>0] = $724;
   $726 = $723 & 255;
   $727 = ($726|0)==(255);
   if ($727) {
    $728 = (($buffer$73) + 2|0);
    HEAP8[$725>>0] = 0;
    $buffer$74 = $728;
   } else {
    $buffer$74 = $725;
   }
   $729 = (($718) + -16)|0;
   $730 = $720 >>> $729;
   $731 = $730&255;
   $732 = (($buffer$74) + 1|0);
   HEAP8[$buffer$74>>0] = $731;
   $733 = $730 & 255;
   $734 = ($733|0)==(255);
   if ($734) {
    $735 = (($buffer$74) + 2|0);
    HEAP8[$732>>0] = 0;
    $buffer$76 = $735;$put_bits$46 = $729;$put_buffer$17 = $720;$r$17 = 0;
   } else {
    $buffer$76 = $732;$put_bits$46 = $729;$put_buffer$17 = $720;$r$17 = 0;
   }
  } else {
   $buffer$76 = $buffer$73;$put_bits$46 = $718;$put_buffer$17 = $720;$r$17 = 0;
  }
 }
 $736 = (($block) + 64|0);
 $737 = HEAP16[$736>>1]|0;
 $738 = $737 << 16 >> 16;
 $739 = ($737<<16>>16)==(0);
 if ($739) {
  $740 = (($r$17) + 1)|0;
  $buffer$84 = $buffer$76;$put_bits$51 = $put_bits$46;$put_buffer$19 = $put_buffer$17;$r$19 = $740;
 } else {
  $741 = $738 >> 31;
  $742 = $741 ^ $738;
  $743 = (($742) - ($741))|0;
  $744 = (($741) + ($738))|0;
  $745 = (66264 + ($743)|0);
  $746 = HEAP8[$745>>0]|0;
  $747 = $746&255;
  $748 = ($r$17|0)>(15);
  if ($748) {
   $buffer$77586 = $buffer$76;$put_bits$47584 = $put_bits$46;$put_buffer$18585 = $put_buffer$17;$r$18587 = $r$17;
   while(1) {
    $749 = (($put_bits$47584) + ($4))|0;
    $750 = $put_buffer$18585 << $4;
    $751 = $750 | $1;
    $752 = ($749|0)>(15);
    do {
     if ($752) {
      $753 = (($749) + -8)|0;
      $754 = $751 >>> $753;
      $755 = $754&255;
      $756 = (($buffer$77586) + 1|0);
      HEAP8[$buffer$77586>>0] = $755;
      $757 = $754 & 255;
      $758 = ($757|0)==(255);
      if ($758) {
       $759 = (($buffer$77586) + 2|0);
       HEAP8[$756>>0] = 0;
       $buffer$78 = $759;
      } else {
       $buffer$78 = $756;
      }
      $760 = (($749) + -16)|0;
      $761 = $751 >>> $760;
      $762 = $761&255;
      $763 = (($buffer$78) + 1|0);
      HEAP8[$buffer$78>>0] = $762;
      $764 = $761 & 255;
      $765 = ($764|0)==(255);
      if (!($765)) {
       $buffer$79 = $763;$put_bits$48 = $760;
       break;
      }
      $766 = (($buffer$78) + 2|0);
      HEAP8[$763>>0] = 0;
      $buffer$79 = $766;$put_bits$48 = $760;
     } else {
      $buffer$79 = $buffer$77586;$put_bits$48 = $749;
     }
    } while(0);
    $767 = (($r$18587) + -16)|0;
    $768 = ($767|0)>(15);
    if ($768) {
     $buffer$77586 = $buffer$79;$put_bits$47584 = $put_bits$48;$put_buffer$18585 = $751;$r$18587 = $767;
    } else {
     break;
    }
   }
   $769 = $r$17 & 15;
   $buffer$77$lcssa = $buffer$79;$put_bits$47$lcssa = $put_bits$48;$put_buffer$18$lcssa = $751;$r$18$lcssa = $769;
  } else {
   $buffer$77$lcssa = $buffer$76;$put_bits$47$lcssa = $put_bits$46;$put_buffer$18$lcssa = $put_buffer$17;$r$18$lcssa = $r$17;
  }
  $770 = $r$18$lcssa << 4;
  $771 = (($770) + ($747))|0;
  $772 = (($actbl) + ($771<<2)|0);
  $773 = HEAP32[$772>>2]|0;
  $774 = ((($actbl) + ($771)|0) + 1024|0);
  $775 = HEAP8[$774>>0]|0;
  $776 = $775 << 24 >> 24;
  $777 = 1 << $747;
  $778 = (($777) + -1)|0;
  $779 = $778 & $744;
  $780 = (($776) + ($put_bits$47$lcssa))|0;
  $781 = $put_buffer$18$lcssa << $776;
  $782 = $781 | $773;
  $783 = ($780|0)>(15);
  if ($783) {
   $784 = (($780) + -8)|0;
   $785 = $782 >>> $784;
   $786 = $785&255;
   $787 = (($buffer$77$lcssa) + 1|0);
   HEAP8[$buffer$77$lcssa>>0] = $786;
   $788 = $785 & 255;
   $789 = ($788|0)==(255);
   if ($789) {
    $790 = (($buffer$77$lcssa) + 2|0);
    HEAP8[$787>>0] = 0;
    $buffer$80 = $790;
   } else {
    $buffer$80 = $787;
   }
   $791 = (($780) + -16)|0;
   $792 = $782 >>> $791;
   $793 = $792&255;
   $794 = (($buffer$80) + 1|0);
   HEAP8[$buffer$80>>0] = $793;
   $795 = $792 & 255;
   $796 = ($795|0)==(255);
   if ($796) {
    $797 = (($buffer$80) + 2|0);
    HEAP8[$794>>0] = 0;
    $buffer$81 = $797;$put_bits$49 = $791;
   } else {
    $buffer$81 = $794;$put_bits$49 = $791;
   }
  } else {
   $buffer$81 = $buffer$77$lcssa;$put_bits$49 = $780;
  }
  $798 = (($put_bits$49) + ($747))|0;
  $799 = $782 << $747;
  $800 = $799 | $779;
  $801 = ($798|0)>(15);
  if ($801) {
   $802 = (($798) + -8)|0;
   $803 = $800 >>> $802;
   $804 = $803&255;
   $805 = (($buffer$81) + 1|0);
   HEAP8[$buffer$81>>0] = $804;
   $806 = $803 & 255;
   $807 = ($806|0)==(255);
   if ($807) {
    $808 = (($buffer$81) + 2|0);
    HEAP8[$805>>0] = 0;
    $buffer$82 = $808;
   } else {
    $buffer$82 = $805;
   }
   $809 = (($798) + -16)|0;
   $810 = $800 >>> $809;
   $811 = $810&255;
   $812 = (($buffer$82) + 1|0);
   HEAP8[$buffer$82>>0] = $811;
   $813 = $810 & 255;
   $814 = ($813|0)==(255);
   if ($814) {
    $815 = (($buffer$82) + 2|0);
    HEAP8[$812>>0] = 0;
    $buffer$84 = $815;$put_bits$51 = $809;$put_buffer$19 = $800;$r$19 = 0;
   } else {
    $buffer$84 = $812;$put_bits$51 = $809;$put_buffer$19 = $800;$r$19 = 0;
   }
  } else {
   $buffer$84 = $buffer$81;$put_bits$51 = $798;$put_buffer$19 = $800;$r$19 = 0;
  }
 }
 $816 = (($block) + 50|0);
 $817 = HEAP16[$816>>1]|0;
 $818 = $817 << 16 >> 16;
 $819 = ($817<<16>>16)==(0);
 if ($819) {
  $820 = (($r$19) + 1)|0;
  $buffer$92 = $buffer$84;$put_bits$56 = $put_bits$51;$put_buffer$21 = $put_buffer$19;$r$21 = $820;
 } else {
  $821 = $818 >> 31;
  $822 = $821 ^ $818;
  $823 = (($822) - ($821))|0;
  $824 = (($821) + ($818))|0;
  $825 = (66264 + ($823)|0);
  $826 = HEAP8[$825>>0]|0;
  $827 = $826&255;
  $828 = ($r$19|0)>(15);
  if ($828) {
   $buffer$85575 = $buffer$84;$put_bits$52573 = $put_bits$51;$put_buffer$20574 = $put_buffer$19;$r$20576 = $r$19;
   while(1) {
    $829 = (($put_bits$52573) + ($4))|0;
    $830 = $put_buffer$20574 << $4;
    $831 = $830 | $1;
    $832 = ($829|0)>(15);
    do {
     if ($832) {
      $833 = (($829) + -8)|0;
      $834 = $831 >>> $833;
      $835 = $834&255;
      $836 = (($buffer$85575) + 1|0);
      HEAP8[$buffer$85575>>0] = $835;
      $837 = $834 & 255;
      $838 = ($837|0)==(255);
      if ($838) {
       $839 = (($buffer$85575) + 2|0);
       HEAP8[$836>>0] = 0;
       $buffer$86 = $839;
      } else {
       $buffer$86 = $836;
      }
      $840 = (($829) + -16)|0;
      $841 = $831 >>> $840;
      $842 = $841&255;
      $843 = (($buffer$86) + 1|0);
      HEAP8[$buffer$86>>0] = $842;
      $844 = $841 & 255;
      $845 = ($844|0)==(255);
      if (!($845)) {
       $buffer$87 = $843;$put_bits$53 = $840;
       break;
      }
      $846 = (($buffer$86) + 2|0);
      HEAP8[$843>>0] = 0;
      $buffer$87 = $846;$put_bits$53 = $840;
     } else {
      $buffer$87 = $buffer$85575;$put_bits$53 = $829;
     }
    } while(0);
    $847 = (($r$20576) + -16)|0;
    $848 = ($847|0)>(15);
    if ($848) {
     $buffer$85575 = $buffer$87;$put_bits$52573 = $put_bits$53;$put_buffer$20574 = $831;$r$20576 = $847;
    } else {
     break;
    }
   }
   $849 = $r$19 & 15;
   $buffer$85$lcssa = $buffer$87;$put_bits$52$lcssa = $put_bits$53;$put_buffer$20$lcssa = $831;$r$20$lcssa = $849;
  } else {
   $buffer$85$lcssa = $buffer$84;$put_bits$52$lcssa = $put_bits$51;$put_buffer$20$lcssa = $put_buffer$19;$r$20$lcssa = $r$19;
  }
  $850 = $r$20$lcssa << 4;
  $851 = (($850) + ($827))|0;
  $852 = (($actbl) + ($851<<2)|0);
  $853 = HEAP32[$852>>2]|0;
  $854 = ((($actbl) + ($851)|0) + 1024|0);
  $855 = HEAP8[$854>>0]|0;
  $856 = $855 << 24 >> 24;
  $857 = 1 << $827;
  $858 = (($857) + -1)|0;
  $859 = $858 & $824;
  $860 = (($856) + ($put_bits$52$lcssa))|0;
  $861 = $put_buffer$20$lcssa << $856;
  $862 = $861 | $853;
  $863 = ($860|0)>(15);
  if ($863) {
   $864 = (($860) + -8)|0;
   $865 = $862 >>> $864;
   $866 = $865&255;
   $867 = (($buffer$85$lcssa) + 1|0);
   HEAP8[$buffer$85$lcssa>>0] = $866;
   $868 = $865 & 255;
   $869 = ($868|0)==(255);
   if ($869) {
    $870 = (($buffer$85$lcssa) + 2|0);
    HEAP8[$867>>0] = 0;
    $buffer$88 = $870;
   } else {
    $buffer$88 = $867;
   }
   $871 = (($860) + -16)|0;
   $872 = $862 >>> $871;
   $873 = $872&255;
   $874 = (($buffer$88) + 1|0);
   HEAP8[$buffer$88>>0] = $873;
   $875 = $872 & 255;
   $876 = ($875|0)==(255);
   if ($876) {
    $877 = (($buffer$88) + 2|0);
    HEAP8[$874>>0] = 0;
    $buffer$89 = $877;$put_bits$54 = $871;
   } else {
    $buffer$89 = $874;$put_bits$54 = $871;
   }
  } else {
   $buffer$89 = $buffer$85$lcssa;$put_bits$54 = $860;
  }
  $878 = (($put_bits$54) + ($827))|0;
  $879 = $862 << $827;
  $880 = $879 | $859;
  $881 = ($878|0)>(15);
  if ($881) {
   $882 = (($878) + -8)|0;
   $883 = $880 >>> $882;
   $884 = $883&255;
   $885 = (($buffer$89) + 1|0);
   HEAP8[$buffer$89>>0] = $884;
   $886 = $883 & 255;
   $887 = ($886|0)==(255);
   if ($887) {
    $888 = (($buffer$89) + 2|0);
    HEAP8[$885>>0] = 0;
    $buffer$90 = $888;
   } else {
    $buffer$90 = $885;
   }
   $889 = (($878) + -16)|0;
   $890 = $880 >>> $889;
   $891 = $890&255;
   $892 = (($buffer$90) + 1|0);
   HEAP8[$buffer$90>>0] = $891;
   $893 = $890 & 255;
   $894 = ($893|0)==(255);
   if ($894) {
    $895 = (($buffer$90) + 2|0);
    HEAP8[$892>>0] = 0;
    $buffer$92 = $895;$put_bits$56 = $889;$put_buffer$21 = $880;$r$21 = 0;
   } else {
    $buffer$92 = $892;$put_bits$56 = $889;$put_buffer$21 = $880;$r$21 = 0;
   }
  } else {
   $buffer$92 = $buffer$89;$put_bits$56 = $878;$put_buffer$21 = $880;$r$21 = 0;
  }
 }
 $896 = (($block) + 36|0);
 $897 = HEAP16[$896>>1]|0;
 $898 = $897 << 16 >> 16;
 $899 = ($897<<16>>16)==(0);
 do {
  if ($899) {
   $900 = (($r$21) + 1)|0;
   $buffer$100 = $buffer$92;$put_bits$61 = $put_bits$56;$put_buffer$23 = $put_buffer$21;$r$23 = $900;
  } else {
   $901 = $898 >> 31;
   $902 = $901 ^ $898;
   $903 = (($902) - ($901))|0;
   $904 = (($901) + ($898))|0;
   $905 = (66264 + ($903)|0);
   $906 = HEAP8[$905>>0]|0;
   $907 = $906&255;
   $908 = ($r$21|0)>(15);
   if ($908) {
    $buffer$93564 = $buffer$92;$put_bits$57562 = $put_bits$56;$put_buffer$22563 = $put_buffer$21;$r$22565 = $r$21;
    while(1) {
     $909 = (($put_bits$57562) + ($4))|0;
     $910 = $put_buffer$22563 << $4;
     $911 = $910 | $1;
     $912 = ($909|0)>(15);
     do {
      if ($912) {
       $913 = (($909) + -8)|0;
       $914 = $911 >>> $913;
       $915 = $914&255;
       $916 = (($buffer$93564) + 1|0);
       HEAP8[$buffer$93564>>0] = $915;
       $917 = $914 & 255;
       $918 = ($917|0)==(255);
       if ($918) {
        $919 = (($buffer$93564) + 2|0);
        HEAP8[$916>>0] = 0;
        $buffer$94 = $919;
       } else {
        $buffer$94 = $916;
       }
       $920 = (($909) + -16)|0;
       $921 = $911 >>> $920;
       $922 = $921&255;
       $923 = (($buffer$94) + 1|0);
       HEAP8[$buffer$94>>0] = $922;
       $924 = $921 & 255;
       $925 = ($924|0)==(255);
       if (!($925)) {
        $buffer$95 = $923;$put_bits$58 = $920;
        break;
       }
       $926 = (($buffer$94) + 2|0);
       HEAP8[$923>>0] = 0;
       $buffer$95 = $926;$put_bits$58 = $920;
      } else {
       $buffer$95 = $buffer$93564;$put_bits$58 = $909;
      }
     } while(0);
     $927 = (($r$22565) + -16)|0;
     $928 = ($927|0)>(15);
     if ($928) {
      $buffer$93564 = $buffer$95;$put_bits$57562 = $put_bits$58;$put_buffer$22563 = $911;$r$22565 = $927;
     } else {
      break;
     }
    }
    $929 = $r$21 & 15;
    $buffer$93$lcssa = $buffer$95;$put_bits$57$lcssa = $put_bits$58;$put_buffer$22$lcssa = $911;$r$22$lcssa = $929;
   } else {
    $buffer$93$lcssa = $buffer$92;$put_bits$57$lcssa = $put_bits$56;$put_buffer$22$lcssa = $put_buffer$21;$r$22$lcssa = $r$21;
   }
   $930 = $r$22$lcssa << 4;
   $931 = (($930) + ($907))|0;
   $932 = (($actbl) + ($931<<2)|0);
   $933 = HEAP32[$932>>2]|0;
   $934 = ((($actbl) + ($931)|0) + 1024|0);
   $935 = HEAP8[$934>>0]|0;
   $936 = $935 << 24 >> 24;
   $937 = 1 << $907;
   $938 = (($937) + -1)|0;
   $939 = $938 & $904;
   $940 = (($936) + ($put_bits$57$lcssa))|0;
   $941 = $put_buffer$22$lcssa << $936;
   $942 = $941 | $933;
   $943 = ($940|0)>(15);
   do {
    if ($943) {
     $944 = (($940) + -8)|0;
     $945 = $942 >>> $944;
     $946 = $945&255;
     $947 = (($buffer$93$lcssa) + 1|0);
     HEAP8[$buffer$93$lcssa>>0] = $946;
     $948 = $945 & 255;
     $949 = ($948|0)==(255);
     if ($949) {
      $950 = (($buffer$93$lcssa) + 2|0);
      HEAP8[$947>>0] = 0;
      $buffer$96 = $950;
     } else {
      $buffer$96 = $947;
     }
     $951 = (($940) + -16)|0;
     $952 = $942 >>> $951;
     $953 = $952&255;
     $954 = (($buffer$96) + 1|0);
     HEAP8[$buffer$96>>0] = $953;
     $955 = $952 & 255;
     $956 = ($955|0)==(255);
     if (!($956)) {
      $buffer$97 = $954;$put_bits$59 = $951;
      break;
     }
     $957 = (($buffer$96) + 2|0);
     HEAP8[$954>>0] = 0;
     $buffer$97 = $957;$put_bits$59 = $951;
    } else {
     $buffer$97 = $buffer$93$lcssa;$put_bits$59 = $940;
    }
   } while(0);
   $958 = (($put_bits$59) + ($907))|0;
   $959 = $942 << $907;
   $960 = $959 | $939;
   $961 = ($958|0)>(15);
   if ($961) {
    $962 = (($958) + -8)|0;
    $963 = $960 >>> $962;
    $964 = $963&255;
    $965 = (($buffer$97) + 1|0);
    HEAP8[$buffer$97>>0] = $964;
    $966 = $963 & 255;
    $967 = ($966|0)==(255);
    if ($967) {
     $968 = (($buffer$97) + 2|0);
     HEAP8[$965>>0] = 0;
     $buffer$98 = $968;
    } else {
     $buffer$98 = $965;
    }
    $969 = (($958) + -16)|0;
    $970 = $960 >>> $969;
    $971 = $970&255;
    $972 = (($buffer$98) + 1|0);
    HEAP8[$buffer$98>>0] = $971;
    $973 = $970 & 255;
    $974 = ($973|0)==(255);
    if (!($974)) {
     $buffer$100 = $972;$put_bits$61 = $969;$put_buffer$23 = $960;$r$23 = 0;
     break;
    }
    $975 = (($buffer$98) + 2|0);
    HEAP8[$972>>0] = 0;
    $buffer$100 = $975;$put_bits$61 = $969;$put_buffer$23 = $960;$r$23 = 0;
   } else {
    $buffer$100 = $buffer$97;$put_bits$61 = $958;$put_buffer$23 = $960;$r$23 = 0;
   }
  }
 } while(0);
 $976 = (($block) + 22|0);
 $977 = HEAP16[$976>>1]|0;
 $978 = $977 << 16 >> 16;
 $979 = ($977<<16>>16)==(0);
 do {
  if ($979) {
   $980 = (($r$23) + 1)|0;
   $buffer$108 = $buffer$100;$put_bits$66 = $put_bits$61;$put_buffer$25 = $put_buffer$23;$r$25 = $980;
  } else {
   $981 = $978 >> 31;
   $982 = $981 ^ $978;
   $983 = (($982) - ($981))|0;
   $984 = (($981) + ($978))|0;
   $985 = (66264 + ($983)|0);
   $986 = HEAP8[$985>>0]|0;
   $987 = $986&255;
   $988 = ($r$23|0)>(15);
   if ($988) {
    $buffer$101553 = $buffer$100;$put_bits$62551 = $put_bits$61;$put_buffer$24552 = $put_buffer$23;$r$24554 = $r$23;
    while(1) {
     $989 = (($put_bits$62551) + ($4))|0;
     $990 = $put_buffer$24552 << $4;
     $991 = $990 | $1;
     $992 = ($989|0)>(15);
     do {
      if ($992) {
       $993 = (($989) + -8)|0;
       $994 = $991 >>> $993;
       $995 = $994&255;
       $996 = (($buffer$101553) + 1|0);
       HEAP8[$buffer$101553>>0] = $995;
       $997 = $994 & 255;
       $998 = ($997|0)==(255);
       if ($998) {
        $999 = (($buffer$101553) + 2|0);
        HEAP8[$996>>0] = 0;
        $buffer$102 = $999;
       } else {
        $buffer$102 = $996;
       }
       $1000 = (($989) + -16)|0;
       $1001 = $991 >>> $1000;
       $1002 = $1001&255;
       $1003 = (($buffer$102) + 1|0);
       HEAP8[$buffer$102>>0] = $1002;
       $1004 = $1001 & 255;
       $1005 = ($1004|0)==(255);
       if (!($1005)) {
        $buffer$103 = $1003;$put_bits$63 = $1000;
        break;
       }
       $1006 = (($buffer$102) + 2|0);
       HEAP8[$1003>>0] = 0;
       $buffer$103 = $1006;$put_bits$63 = $1000;
      } else {
       $buffer$103 = $buffer$101553;$put_bits$63 = $989;
      }
     } while(0);
     $1007 = (($r$24554) + -16)|0;
     $1008 = ($1007|0)>(15);
     if ($1008) {
      $buffer$101553 = $buffer$103;$put_bits$62551 = $put_bits$63;$put_buffer$24552 = $991;$r$24554 = $1007;
     } else {
      break;
     }
    }
    $1009 = $r$23 & 15;
    $buffer$101$lcssa = $buffer$103;$put_bits$62$lcssa = $put_bits$63;$put_buffer$24$lcssa = $991;$r$24$lcssa = $1009;
   } else {
    $buffer$101$lcssa = $buffer$100;$put_bits$62$lcssa = $put_bits$61;$put_buffer$24$lcssa = $put_buffer$23;$r$24$lcssa = $r$23;
   }
   $1010 = $r$24$lcssa << 4;
   $1011 = (($1010) + ($987))|0;
   $1012 = (($actbl) + ($1011<<2)|0);
   $1013 = HEAP32[$1012>>2]|0;
   $1014 = ((($actbl) + ($1011)|0) + 1024|0);
   $1015 = HEAP8[$1014>>0]|0;
   $1016 = $1015 << 24 >> 24;
   $1017 = 1 << $987;
   $1018 = (($1017) + -1)|0;
   $1019 = $1018 & $984;
   $1020 = (($1016) + ($put_bits$62$lcssa))|0;
   $1021 = $put_buffer$24$lcssa << $1016;
   $1022 = $1021 | $1013;
   $1023 = ($1020|0)>(15);
   do {
    if ($1023) {
     $1024 = (($1020) + -8)|0;
     $1025 = $1022 >>> $1024;
     $1026 = $1025&255;
     $1027 = (($buffer$101$lcssa) + 1|0);
     HEAP8[$buffer$101$lcssa>>0] = $1026;
     $1028 = $1025 & 255;
     $1029 = ($1028|0)==(255);
     if ($1029) {
      $1030 = (($buffer$101$lcssa) + 2|0);
      HEAP8[$1027>>0] = 0;
      $buffer$104 = $1030;
     } else {
      $buffer$104 = $1027;
     }
     $1031 = (($1020) + -16)|0;
     $1032 = $1022 >>> $1031;
     $1033 = $1032&255;
     $1034 = (($buffer$104) + 1|0);
     HEAP8[$buffer$104>>0] = $1033;
     $1035 = $1032 & 255;
     $1036 = ($1035|0)==(255);
     if (!($1036)) {
      $buffer$105 = $1034;$put_bits$64 = $1031;
      break;
     }
     $1037 = (($buffer$104) + 2|0);
     HEAP8[$1034>>0] = 0;
     $buffer$105 = $1037;$put_bits$64 = $1031;
    } else {
     $buffer$105 = $buffer$101$lcssa;$put_bits$64 = $1020;
    }
   } while(0);
   $1038 = (($put_bits$64) + ($987))|0;
   $1039 = $1022 << $987;
   $1040 = $1039 | $1019;
   $1041 = ($1038|0)>(15);
   if ($1041) {
    $1042 = (($1038) + -8)|0;
    $1043 = $1040 >>> $1042;
    $1044 = $1043&255;
    $1045 = (($buffer$105) + 1|0);
    HEAP8[$buffer$105>>0] = $1044;
    $1046 = $1043 & 255;
    $1047 = ($1046|0)==(255);
    if ($1047) {
     $1048 = (($buffer$105) + 2|0);
     HEAP8[$1045>>0] = 0;
     $buffer$106 = $1048;
    } else {
     $buffer$106 = $1045;
    }
    $1049 = (($1038) + -16)|0;
    $1050 = $1040 >>> $1049;
    $1051 = $1050&255;
    $1052 = (($buffer$106) + 1|0);
    HEAP8[$buffer$106>>0] = $1051;
    $1053 = $1050 & 255;
    $1054 = ($1053|0)==(255);
    if (!($1054)) {
     $buffer$108 = $1052;$put_bits$66 = $1049;$put_buffer$25 = $1040;$r$25 = 0;
     break;
    }
    $1055 = (($buffer$106) + 2|0);
    HEAP8[$1052>>0] = 0;
    $buffer$108 = $1055;$put_bits$66 = $1049;$put_buffer$25 = $1040;$r$25 = 0;
   } else {
    $buffer$108 = $buffer$105;$put_bits$66 = $1038;$put_buffer$25 = $1040;$r$25 = 0;
   }
  }
 } while(0);
 $1056 = (($block) + 8|0);
 $1057 = HEAP16[$1056>>1]|0;
 $1058 = $1057 << 16 >> 16;
 $1059 = ($1057<<16>>16)==(0);
 do {
  if ($1059) {
   $1060 = (($r$25) + 1)|0;
   $buffer$116 = $buffer$108;$put_bits$71 = $put_bits$66;$put_buffer$27 = $put_buffer$25;$r$27 = $1060;
  } else {
   $1061 = $1058 >> 31;
   $1062 = $1061 ^ $1058;
   $1063 = (($1062) - ($1061))|0;
   $1064 = (($1061) + ($1058))|0;
   $1065 = (66264 + ($1063)|0);
   $1066 = HEAP8[$1065>>0]|0;
   $1067 = $1066&255;
   $1068 = ($r$25|0)>(15);
   if ($1068) {
    $buffer$109542 = $buffer$108;$put_bits$67540 = $put_bits$66;$put_buffer$26541 = $put_buffer$25;$r$26543 = $r$25;
    while(1) {
     $1069 = (($put_bits$67540) + ($4))|0;
     $1070 = $put_buffer$26541 << $4;
     $1071 = $1070 | $1;
     $1072 = ($1069|0)>(15);
     do {
      if ($1072) {
       $1073 = (($1069) + -8)|0;
       $1074 = $1071 >>> $1073;
       $1075 = $1074&255;
       $1076 = (($buffer$109542) + 1|0);
       HEAP8[$buffer$109542>>0] = $1075;
       $1077 = $1074 & 255;
       $1078 = ($1077|0)==(255);
       if ($1078) {
        $1079 = (($buffer$109542) + 2|0);
        HEAP8[$1076>>0] = 0;
        $buffer$110 = $1079;
       } else {
        $buffer$110 = $1076;
       }
       $1080 = (($1069) + -16)|0;
       $1081 = $1071 >>> $1080;
       $1082 = $1081&255;
       $1083 = (($buffer$110) + 1|0);
       HEAP8[$buffer$110>>0] = $1082;
       $1084 = $1081 & 255;
       $1085 = ($1084|0)==(255);
       if (!($1085)) {
        $buffer$111 = $1083;$put_bits$68 = $1080;
        break;
       }
       $1086 = (($buffer$110) + 2|0);
       HEAP8[$1083>>0] = 0;
       $buffer$111 = $1086;$put_bits$68 = $1080;
      } else {
       $buffer$111 = $buffer$109542;$put_bits$68 = $1069;
      }
     } while(0);
     $1087 = (($r$26543) + -16)|0;
     $1088 = ($1087|0)>(15);
     if ($1088) {
      $buffer$109542 = $buffer$111;$put_bits$67540 = $put_bits$68;$put_buffer$26541 = $1071;$r$26543 = $1087;
     } else {
      break;
     }
    }
    $1089 = $r$25 & 15;
    $buffer$109$lcssa = $buffer$111;$put_bits$67$lcssa = $put_bits$68;$put_buffer$26$lcssa = $1071;$r$26$lcssa = $1089;
   } else {
    $buffer$109$lcssa = $buffer$108;$put_bits$67$lcssa = $put_bits$66;$put_buffer$26$lcssa = $put_buffer$25;$r$26$lcssa = $r$25;
   }
   $1090 = $r$26$lcssa << 4;
   $1091 = (($1090) + ($1067))|0;
   $1092 = (($actbl) + ($1091<<2)|0);
   $1093 = HEAP32[$1092>>2]|0;
   $1094 = ((($actbl) + ($1091)|0) + 1024|0);
   $1095 = HEAP8[$1094>>0]|0;
   $1096 = $1095 << 24 >> 24;
   $1097 = 1 << $1067;
   $1098 = (($1097) + -1)|0;
   $1099 = $1098 & $1064;
   $1100 = (($1096) + ($put_bits$67$lcssa))|0;
   $1101 = $put_buffer$26$lcssa << $1096;
   $1102 = $1101 | $1093;
   $1103 = ($1100|0)>(15);
   do {
    if ($1103) {
     $1104 = (($1100) + -8)|0;
     $1105 = $1102 >>> $1104;
     $1106 = $1105&255;
     $1107 = (($buffer$109$lcssa) + 1|0);
     HEAP8[$buffer$109$lcssa>>0] = $1106;
     $1108 = $1105 & 255;
     $1109 = ($1108|0)==(255);
     if ($1109) {
      $1110 = (($buffer$109$lcssa) + 2|0);
      HEAP8[$1107>>0] = 0;
      $buffer$112 = $1110;
     } else {
      $buffer$112 = $1107;
     }
     $1111 = (($1100) + -16)|0;
     $1112 = $1102 >>> $1111;
     $1113 = $1112&255;
     $1114 = (($buffer$112) + 1|0);
     HEAP8[$buffer$112>>0] = $1113;
     $1115 = $1112 & 255;
     $1116 = ($1115|0)==(255);
     if (!($1116)) {
      $buffer$113 = $1114;$put_bits$69 = $1111;
      break;
     }
     $1117 = (($buffer$112) + 2|0);
     HEAP8[$1114>>0] = 0;
     $buffer$113 = $1117;$put_bits$69 = $1111;
    } else {
     $buffer$113 = $buffer$109$lcssa;$put_bits$69 = $1100;
    }
   } while(0);
   $1118 = (($put_bits$69) + ($1067))|0;
   $1119 = $1102 << $1067;
   $1120 = $1119 | $1099;
   $1121 = ($1118|0)>(15);
   if (!($1121)) {
    $buffer$116 = $buffer$113;$put_bits$71 = $1118;$put_buffer$27 = $1120;$r$27 = 0;
    break;
   }
   $1122 = (($1118) + -8)|0;
   $1123 = $1120 >>> $1122;
   $1124 = $1123&255;
   $1125 = (($buffer$113) + 1|0);
   HEAP8[$buffer$113>>0] = $1124;
   $1126 = $1123 & 255;
   $1127 = ($1126|0)==(255);
   if ($1127) {
    $1128 = (($buffer$113) + 2|0);
    HEAP8[$1125>>0] = 0;
    $buffer$114 = $1128;
   } else {
    $buffer$114 = $1125;
   }
   $1129 = (($1118) + -16)|0;
   $1130 = $1120 >>> $1129;
   $1131 = $1130&255;
   $1132 = (($buffer$114) + 1|0);
   HEAP8[$buffer$114>>0] = $1131;
   $1133 = $1130 & 255;
   $1134 = ($1133|0)==(255);
   if (!($1134)) {
    $buffer$116 = $1132;$put_bits$71 = $1129;$put_buffer$27 = $1120;$r$27 = 0;
    break;
   }
   $1135 = (($buffer$114) + 2|0);
   HEAP8[$1132>>0] = 0;
   $buffer$116 = $1135;$put_bits$71 = $1129;$put_buffer$27 = $1120;$r$27 = 0;
  }
 } while(0);
 $1136 = (($block) + 10|0);
 $1137 = HEAP16[$1136>>1]|0;
 $1138 = $1137 << 16 >> 16;
 $1139 = ($1137<<16>>16)==(0);
 do {
  if ($1139) {
   $1140 = (($r$27) + 1)|0;
   $buffer$124 = $buffer$116;$put_bits$76 = $put_bits$71;$put_buffer$29 = $put_buffer$27;$r$29 = $1140;
  } else {
   $1141 = $1138 >> 31;
   $1142 = $1141 ^ $1138;
   $1143 = (($1142) - ($1141))|0;
   $1144 = (($1141) + ($1138))|0;
   $1145 = (66264 + ($1143)|0);
   $1146 = HEAP8[$1145>>0]|0;
   $1147 = $1146&255;
   $1148 = ($r$27|0)>(15);
   if ($1148) {
    $buffer$117531 = $buffer$116;$put_bits$72529 = $put_bits$71;$put_buffer$28530 = $put_buffer$27;$r$28532 = $r$27;
    while(1) {
     $1149 = (($put_bits$72529) + ($4))|0;
     $1150 = $put_buffer$28530 << $4;
     $1151 = $1150 | $1;
     $1152 = ($1149|0)>(15);
     do {
      if ($1152) {
       $1153 = (($1149) + -8)|0;
       $1154 = $1151 >>> $1153;
       $1155 = $1154&255;
       $1156 = (($buffer$117531) + 1|0);
       HEAP8[$buffer$117531>>0] = $1155;
       $1157 = $1154 & 255;
       $1158 = ($1157|0)==(255);
       if ($1158) {
        $1159 = (($buffer$117531) + 2|0);
        HEAP8[$1156>>0] = 0;
        $buffer$118 = $1159;
       } else {
        $buffer$118 = $1156;
       }
       $1160 = (($1149) + -16)|0;
       $1161 = $1151 >>> $1160;
       $1162 = $1161&255;
       $1163 = (($buffer$118) + 1|0);
       HEAP8[$buffer$118>>0] = $1162;
       $1164 = $1161 & 255;
       $1165 = ($1164|0)==(255);
       if (!($1165)) {
        $buffer$119 = $1163;$put_bits$73 = $1160;
        break;
       }
       $1166 = (($buffer$118) + 2|0);
       HEAP8[$1163>>0] = 0;
       $buffer$119 = $1166;$put_bits$73 = $1160;
      } else {
       $buffer$119 = $buffer$117531;$put_bits$73 = $1149;
      }
     } while(0);
     $1167 = (($r$28532) + -16)|0;
     $1168 = ($1167|0)>(15);
     if ($1168) {
      $buffer$117531 = $buffer$119;$put_bits$72529 = $put_bits$73;$put_buffer$28530 = $1151;$r$28532 = $1167;
     } else {
      break;
     }
    }
    $1169 = $r$27 & 15;
    $buffer$117$lcssa = $buffer$119;$put_bits$72$lcssa = $put_bits$73;$put_buffer$28$lcssa = $1151;$r$28$lcssa = $1169;
   } else {
    $buffer$117$lcssa = $buffer$116;$put_bits$72$lcssa = $put_bits$71;$put_buffer$28$lcssa = $put_buffer$27;$r$28$lcssa = $r$27;
   }
   $1170 = $r$28$lcssa << 4;
   $1171 = (($1170) + ($1147))|0;
   $1172 = (($actbl) + ($1171<<2)|0);
   $1173 = HEAP32[$1172>>2]|0;
   $1174 = ((($actbl) + ($1171)|0) + 1024|0);
   $1175 = HEAP8[$1174>>0]|0;
   $1176 = $1175 << 24 >> 24;
   $1177 = 1 << $1147;
   $1178 = (($1177) + -1)|0;
   $1179 = $1178 & $1144;
   $1180 = (($1176) + ($put_bits$72$lcssa))|0;
   $1181 = $put_buffer$28$lcssa << $1176;
   $1182 = $1181 | $1173;
   $1183 = ($1180|0)>(15);
   do {
    if ($1183) {
     $1184 = (($1180) + -8)|0;
     $1185 = $1182 >>> $1184;
     $1186 = $1185&255;
     $1187 = (($buffer$117$lcssa) + 1|0);
     HEAP8[$buffer$117$lcssa>>0] = $1186;
     $1188 = $1185 & 255;
     $1189 = ($1188|0)==(255);
     if ($1189) {
      $1190 = (($buffer$117$lcssa) + 2|0);
      HEAP8[$1187>>0] = 0;
      $buffer$120 = $1190;
     } else {
      $buffer$120 = $1187;
     }
     $1191 = (($1180) + -16)|0;
     $1192 = $1182 >>> $1191;
     $1193 = $1192&255;
     $1194 = (($buffer$120) + 1|0);
     HEAP8[$buffer$120>>0] = $1193;
     $1195 = $1192 & 255;
     $1196 = ($1195|0)==(255);
     if (!($1196)) {
      $buffer$121 = $1194;$put_bits$74 = $1191;
      break;
     }
     $1197 = (($buffer$120) + 2|0);
     HEAP8[$1194>>0] = 0;
     $buffer$121 = $1197;$put_bits$74 = $1191;
    } else {
     $buffer$121 = $buffer$117$lcssa;$put_bits$74 = $1180;
    }
   } while(0);
   $1198 = (($put_bits$74) + ($1147))|0;
   $1199 = $1182 << $1147;
   $1200 = $1199 | $1179;
   $1201 = ($1198|0)>(15);
   if (!($1201)) {
    $buffer$124 = $buffer$121;$put_bits$76 = $1198;$put_buffer$29 = $1200;$r$29 = 0;
    break;
   }
   $1202 = (($1198) + -8)|0;
   $1203 = $1200 >>> $1202;
   $1204 = $1203&255;
   $1205 = (($buffer$121) + 1|0);
   HEAP8[$buffer$121>>0] = $1204;
   $1206 = $1203 & 255;
   $1207 = ($1206|0)==(255);
   if ($1207) {
    $1208 = (($buffer$121) + 2|0);
    HEAP8[$1205>>0] = 0;
    $buffer$122 = $1208;
   } else {
    $buffer$122 = $1205;
   }
   $1209 = (($1198) + -16)|0;
   $1210 = $1200 >>> $1209;
   $1211 = $1210&255;
   $1212 = (($buffer$122) + 1|0);
   HEAP8[$buffer$122>>0] = $1211;
   $1213 = $1210 & 255;
   $1214 = ($1213|0)==(255);
   if (!($1214)) {
    $buffer$124 = $1212;$put_bits$76 = $1209;$put_buffer$29 = $1200;$r$29 = 0;
    break;
   }
   $1215 = (($buffer$122) + 2|0);
   HEAP8[$1212>>0] = 0;
   $buffer$124 = $1215;$put_bits$76 = $1209;$put_buffer$29 = $1200;$r$29 = 0;
  }
 } while(0);
 $1216 = (($block) + 24|0);
 $1217 = HEAP16[$1216>>1]|0;
 $1218 = $1217 << 16 >> 16;
 $1219 = ($1217<<16>>16)==(0);
 do {
  if ($1219) {
   $1220 = (($r$29) + 1)|0;
   $buffer$132 = $buffer$124;$put_bits$81 = $put_bits$76;$put_buffer$31 = $put_buffer$29;$r$31 = $1220;
  } else {
   $1221 = $1218 >> 31;
   $1222 = $1221 ^ $1218;
   $1223 = (($1222) - ($1221))|0;
   $1224 = (($1221) + ($1218))|0;
   $1225 = (66264 + ($1223)|0);
   $1226 = HEAP8[$1225>>0]|0;
   $1227 = $1226&255;
   $1228 = ($r$29|0)>(15);
   if ($1228) {
    $buffer$125520 = $buffer$124;$put_bits$77518 = $put_bits$76;$put_buffer$30519 = $put_buffer$29;$r$30521 = $r$29;
    while(1) {
     $1229 = (($put_bits$77518) + ($4))|0;
     $1230 = $put_buffer$30519 << $4;
     $1231 = $1230 | $1;
     $1232 = ($1229|0)>(15);
     do {
      if ($1232) {
       $1233 = (($1229) + -8)|0;
       $1234 = $1231 >>> $1233;
       $1235 = $1234&255;
       $1236 = (($buffer$125520) + 1|0);
       HEAP8[$buffer$125520>>0] = $1235;
       $1237 = $1234 & 255;
       $1238 = ($1237|0)==(255);
       if ($1238) {
        $1239 = (($buffer$125520) + 2|0);
        HEAP8[$1236>>0] = 0;
        $buffer$126 = $1239;
       } else {
        $buffer$126 = $1236;
       }
       $1240 = (($1229) + -16)|0;
       $1241 = $1231 >>> $1240;
       $1242 = $1241&255;
       $1243 = (($buffer$126) + 1|0);
       HEAP8[$buffer$126>>0] = $1242;
       $1244 = $1241 & 255;
       $1245 = ($1244|0)==(255);
       if (!($1245)) {
        $buffer$127 = $1243;$put_bits$78 = $1240;
        break;
       }
       $1246 = (($buffer$126) + 2|0);
       HEAP8[$1243>>0] = 0;
       $buffer$127 = $1246;$put_bits$78 = $1240;
      } else {
       $buffer$127 = $buffer$125520;$put_bits$78 = $1229;
      }
     } while(0);
     $1247 = (($r$30521) + -16)|0;
     $1248 = ($1247|0)>(15);
     if ($1248) {
      $buffer$125520 = $buffer$127;$put_bits$77518 = $put_bits$78;$put_buffer$30519 = $1231;$r$30521 = $1247;
     } else {
      break;
     }
    }
    $1249 = $r$29 & 15;
    $buffer$125$lcssa = $buffer$127;$put_bits$77$lcssa = $put_bits$78;$put_buffer$30$lcssa = $1231;$r$30$lcssa = $1249;
   } else {
    $buffer$125$lcssa = $buffer$124;$put_bits$77$lcssa = $put_bits$76;$put_buffer$30$lcssa = $put_buffer$29;$r$30$lcssa = $r$29;
   }
   $1250 = $r$30$lcssa << 4;
   $1251 = (($1250) + ($1227))|0;
   $1252 = (($actbl) + ($1251<<2)|0);
   $1253 = HEAP32[$1252>>2]|0;
   $1254 = ((($actbl) + ($1251)|0) + 1024|0);
   $1255 = HEAP8[$1254>>0]|0;
   $1256 = $1255 << 24 >> 24;
   $1257 = 1 << $1227;
   $1258 = (($1257) + -1)|0;
   $1259 = $1258 & $1224;
   $1260 = (($1256) + ($put_bits$77$lcssa))|0;
   $1261 = $put_buffer$30$lcssa << $1256;
   $1262 = $1261 | $1253;
   $1263 = ($1260|0)>(15);
   do {
    if ($1263) {
     $1264 = (($1260) + -8)|0;
     $1265 = $1262 >>> $1264;
     $1266 = $1265&255;
     $1267 = (($buffer$125$lcssa) + 1|0);
     HEAP8[$buffer$125$lcssa>>0] = $1266;
     $1268 = $1265 & 255;
     $1269 = ($1268|0)==(255);
     if ($1269) {
      $1270 = (($buffer$125$lcssa) + 2|0);
      HEAP8[$1267>>0] = 0;
      $buffer$128 = $1270;
     } else {
      $buffer$128 = $1267;
     }
     $1271 = (($1260) + -16)|0;
     $1272 = $1262 >>> $1271;
     $1273 = $1272&255;
     $1274 = (($buffer$128) + 1|0);
     HEAP8[$buffer$128>>0] = $1273;
     $1275 = $1272 & 255;
     $1276 = ($1275|0)==(255);
     if (!($1276)) {
      $buffer$129 = $1274;$put_bits$79 = $1271;
      break;
     }
     $1277 = (($buffer$128) + 2|0);
     HEAP8[$1274>>0] = 0;
     $buffer$129 = $1277;$put_bits$79 = $1271;
    } else {
     $buffer$129 = $buffer$125$lcssa;$put_bits$79 = $1260;
    }
   } while(0);
   $1278 = (($put_bits$79) + ($1227))|0;
   $1279 = $1262 << $1227;
   $1280 = $1279 | $1259;
   $1281 = ($1278|0)>(15);
   if (!($1281)) {
    $buffer$132 = $buffer$129;$put_bits$81 = $1278;$put_buffer$31 = $1280;$r$31 = 0;
    break;
   }
   $1282 = (($1278) + -8)|0;
   $1283 = $1280 >>> $1282;
   $1284 = $1283&255;
   $1285 = (($buffer$129) + 1|0);
   HEAP8[$buffer$129>>0] = $1284;
   $1286 = $1283 & 255;
   $1287 = ($1286|0)==(255);
   if ($1287) {
    $1288 = (($buffer$129) + 2|0);
    HEAP8[$1285>>0] = 0;
    $buffer$130 = $1288;
   } else {
    $buffer$130 = $1285;
   }
   $1289 = (($1278) + -16)|0;
   $1290 = $1280 >>> $1289;
   $1291 = $1290&255;
   $1292 = (($buffer$130) + 1|0);
   HEAP8[$buffer$130>>0] = $1291;
   $1293 = $1290 & 255;
   $1294 = ($1293|0)==(255);
   if (!($1294)) {
    $buffer$132 = $1292;$put_bits$81 = $1289;$put_buffer$31 = $1280;$r$31 = 0;
    break;
   }
   $1295 = (($buffer$130) + 2|0);
   HEAP8[$1292>>0] = 0;
   $buffer$132 = $1295;$put_bits$81 = $1289;$put_buffer$31 = $1280;$r$31 = 0;
  }
 } while(0);
 $1296 = (($block) + 38|0);
 $1297 = HEAP16[$1296>>1]|0;
 $1298 = $1297 << 16 >> 16;
 $1299 = ($1297<<16>>16)==(0);
 do {
  if ($1299) {
   $1300 = (($r$31) + 1)|0;
   $buffer$140 = $buffer$132;$put_bits$86 = $put_bits$81;$put_buffer$33 = $put_buffer$31;$r$33 = $1300;
  } else {
   $1301 = $1298 >> 31;
   $1302 = $1301 ^ $1298;
   $1303 = (($1302) - ($1301))|0;
   $1304 = (($1301) + ($1298))|0;
   $1305 = (66264 + ($1303)|0);
   $1306 = HEAP8[$1305>>0]|0;
   $1307 = $1306&255;
   $1308 = ($r$31|0)>(15);
   if ($1308) {
    $buffer$133509 = $buffer$132;$put_bits$82507 = $put_bits$81;$put_buffer$32508 = $put_buffer$31;$r$32510 = $r$31;
    while(1) {
     $1309 = (($put_bits$82507) + ($4))|0;
     $1310 = $put_buffer$32508 << $4;
     $1311 = $1310 | $1;
     $1312 = ($1309|0)>(15);
     do {
      if ($1312) {
       $1313 = (($1309) + -8)|0;
       $1314 = $1311 >>> $1313;
       $1315 = $1314&255;
       $1316 = (($buffer$133509) + 1|0);
       HEAP8[$buffer$133509>>0] = $1315;
       $1317 = $1314 & 255;
       $1318 = ($1317|0)==(255);
       if ($1318) {
        $1319 = (($buffer$133509) + 2|0);
        HEAP8[$1316>>0] = 0;
        $buffer$134 = $1319;
       } else {
        $buffer$134 = $1316;
       }
       $1320 = (($1309) + -16)|0;
       $1321 = $1311 >>> $1320;
       $1322 = $1321&255;
       $1323 = (($buffer$134) + 1|0);
       HEAP8[$buffer$134>>0] = $1322;
       $1324 = $1321 & 255;
       $1325 = ($1324|0)==(255);
       if (!($1325)) {
        $buffer$135 = $1323;$put_bits$83 = $1320;
        break;
       }
       $1326 = (($buffer$134) + 2|0);
       HEAP8[$1323>>0] = 0;
       $buffer$135 = $1326;$put_bits$83 = $1320;
      } else {
       $buffer$135 = $buffer$133509;$put_bits$83 = $1309;
      }
     } while(0);
     $1327 = (($r$32510) + -16)|0;
     $1328 = ($1327|0)>(15);
     if ($1328) {
      $buffer$133509 = $buffer$135;$put_bits$82507 = $put_bits$83;$put_buffer$32508 = $1311;$r$32510 = $1327;
     } else {
      break;
     }
    }
    $1329 = $r$31 & 15;
    $buffer$133$lcssa = $buffer$135;$put_bits$82$lcssa = $put_bits$83;$put_buffer$32$lcssa = $1311;$r$32$lcssa = $1329;
   } else {
    $buffer$133$lcssa = $buffer$132;$put_bits$82$lcssa = $put_bits$81;$put_buffer$32$lcssa = $put_buffer$31;$r$32$lcssa = $r$31;
   }
   $1330 = $r$32$lcssa << 4;
   $1331 = (($1330) + ($1307))|0;
   $1332 = (($actbl) + ($1331<<2)|0);
   $1333 = HEAP32[$1332>>2]|0;
   $1334 = ((($actbl) + ($1331)|0) + 1024|0);
   $1335 = HEAP8[$1334>>0]|0;
   $1336 = $1335 << 24 >> 24;
   $1337 = 1 << $1307;
   $1338 = (($1337) + -1)|0;
   $1339 = $1338 & $1304;
   $1340 = (($1336) + ($put_bits$82$lcssa))|0;
   $1341 = $put_buffer$32$lcssa << $1336;
   $1342 = $1341 | $1333;
   $1343 = ($1340|0)>(15);
   do {
    if ($1343) {
     $1344 = (($1340) + -8)|0;
     $1345 = $1342 >>> $1344;
     $1346 = $1345&255;
     $1347 = (($buffer$133$lcssa) + 1|0);
     HEAP8[$buffer$133$lcssa>>0] = $1346;
     $1348 = $1345 & 255;
     $1349 = ($1348|0)==(255);
     if ($1349) {
      $1350 = (($buffer$133$lcssa) + 2|0);
      HEAP8[$1347>>0] = 0;
      $buffer$136 = $1350;
     } else {
      $buffer$136 = $1347;
     }
     $1351 = (($1340) + -16)|0;
     $1352 = $1342 >>> $1351;
     $1353 = $1352&255;
     $1354 = (($buffer$136) + 1|0);
     HEAP8[$buffer$136>>0] = $1353;
     $1355 = $1352 & 255;
     $1356 = ($1355|0)==(255);
     if (!($1356)) {
      $buffer$137 = $1354;$put_bits$84 = $1351;
      break;
     }
     $1357 = (($buffer$136) + 2|0);
     HEAP8[$1354>>0] = 0;
     $buffer$137 = $1357;$put_bits$84 = $1351;
    } else {
     $buffer$137 = $buffer$133$lcssa;$put_bits$84 = $1340;
    }
   } while(0);
   $1358 = (($put_bits$84) + ($1307))|0;
   $1359 = $1342 << $1307;
   $1360 = $1359 | $1339;
   $1361 = ($1358|0)>(15);
   if (!($1361)) {
    $buffer$140 = $buffer$137;$put_bits$86 = $1358;$put_buffer$33 = $1360;$r$33 = 0;
    break;
   }
   $1362 = (($1358) + -8)|0;
   $1363 = $1360 >>> $1362;
   $1364 = $1363&255;
   $1365 = (($buffer$137) + 1|0);
   HEAP8[$buffer$137>>0] = $1364;
   $1366 = $1363 & 255;
   $1367 = ($1366|0)==(255);
   if ($1367) {
    $1368 = (($buffer$137) + 2|0);
    HEAP8[$1365>>0] = 0;
    $buffer$138 = $1368;
   } else {
    $buffer$138 = $1365;
   }
   $1369 = (($1358) + -16)|0;
   $1370 = $1360 >>> $1369;
   $1371 = $1370&255;
   $1372 = (($buffer$138) + 1|0);
   HEAP8[$buffer$138>>0] = $1371;
   $1373 = $1370 & 255;
   $1374 = ($1373|0)==(255);
   if (!($1374)) {
    $buffer$140 = $1372;$put_bits$86 = $1369;$put_buffer$33 = $1360;$r$33 = 0;
    break;
   }
   $1375 = (($buffer$138) + 2|0);
   HEAP8[$1372>>0] = 0;
   $buffer$140 = $1375;$put_bits$86 = $1369;$put_buffer$33 = $1360;$r$33 = 0;
  }
 } while(0);
 $1376 = (($block) + 52|0);
 $1377 = HEAP16[$1376>>1]|0;
 $1378 = $1377 << 16 >> 16;
 $1379 = ($1377<<16>>16)==(0);
 do {
  if ($1379) {
   $1380 = (($r$33) + 1)|0;
   $buffer$148 = $buffer$140;$put_bits$91 = $put_bits$86;$put_buffer$35 = $put_buffer$33;$r$35 = $1380;
  } else {
   $1381 = $1378 >> 31;
   $1382 = $1381 ^ $1378;
   $1383 = (($1382) - ($1381))|0;
   $1384 = (($1381) + ($1378))|0;
   $1385 = (66264 + ($1383)|0);
   $1386 = HEAP8[$1385>>0]|0;
   $1387 = $1386&255;
   $1388 = ($r$33|0)>(15);
   if ($1388) {
    $buffer$141498 = $buffer$140;$put_bits$87496 = $put_bits$86;$put_buffer$34497 = $put_buffer$33;$r$34499 = $r$33;
    while(1) {
     $1389 = (($put_bits$87496) + ($4))|0;
     $1390 = $put_buffer$34497 << $4;
     $1391 = $1390 | $1;
     $1392 = ($1389|0)>(15);
     do {
      if ($1392) {
       $1393 = (($1389) + -8)|0;
       $1394 = $1391 >>> $1393;
       $1395 = $1394&255;
       $1396 = (($buffer$141498) + 1|0);
       HEAP8[$buffer$141498>>0] = $1395;
       $1397 = $1394 & 255;
       $1398 = ($1397|0)==(255);
       if ($1398) {
        $1399 = (($buffer$141498) + 2|0);
        HEAP8[$1396>>0] = 0;
        $buffer$142 = $1399;
       } else {
        $buffer$142 = $1396;
       }
       $1400 = (($1389) + -16)|0;
       $1401 = $1391 >>> $1400;
       $1402 = $1401&255;
       $1403 = (($buffer$142) + 1|0);
       HEAP8[$buffer$142>>0] = $1402;
       $1404 = $1401 & 255;
       $1405 = ($1404|0)==(255);
       if (!($1405)) {
        $buffer$143 = $1403;$put_bits$88 = $1400;
        break;
       }
       $1406 = (($buffer$142) + 2|0);
       HEAP8[$1403>>0] = 0;
       $buffer$143 = $1406;$put_bits$88 = $1400;
      } else {
       $buffer$143 = $buffer$141498;$put_bits$88 = $1389;
      }
     } while(0);
     $1407 = (($r$34499) + -16)|0;
     $1408 = ($1407|0)>(15);
     if ($1408) {
      $buffer$141498 = $buffer$143;$put_bits$87496 = $put_bits$88;$put_buffer$34497 = $1391;$r$34499 = $1407;
     } else {
      break;
     }
    }
    $1409 = $r$33 & 15;
    $buffer$141$lcssa = $buffer$143;$put_bits$87$lcssa = $put_bits$88;$put_buffer$34$lcssa = $1391;$r$34$lcssa = $1409;
   } else {
    $buffer$141$lcssa = $buffer$140;$put_bits$87$lcssa = $put_bits$86;$put_buffer$34$lcssa = $put_buffer$33;$r$34$lcssa = $r$33;
   }
   $1410 = $r$34$lcssa << 4;
   $1411 = (($1410) + ($1387))|0;
   $1412 = (($actbl) + ($1411<<2)|0);
   $1413 = HEAP32[$1412>>2]|0;
   $1414 = ((($actbl) + ($1411)|0) + 1024|0);
   $1415 = HEAP8[$1414>>0]|0;
   $1416 = $1415 << 24 >> 24;
   $1417 = 1 << $1387;
   $1418 = (($1417) + -1)|0;
   $1419 = $1418 & $1384;
   $1420 = (($1416) + ($put_bits$87$lcssa))|0;
   $1421 = $put_buffer$34$lcssa << $1416;
   $1422 = $1421 | $1413;
   $1423 = ($1420|0)>(15);
   do {
    if ($1423) {
     $1424 = (($1420) + -8)|0;
     $1425 = $1422 >>> $1424;
     $1426 = $1425&255;
     $1427 = (($buffer$141$lcssa) + 1|0);
     HEAP8[$buffer$141$lcssa>>0] = $1426;
     $1428 = $1425 & 255;
     $1429 = ($1428|0)==(255);
     if ($1429) {
      $1430 = (($buffer$141$lcssa) + 2|0);
      HEAP8[$1427>>0] = 0;
      $buffer$144 = $1430;
     } else {
      $buffer$144 = $1427;
     }
     $1431 = (($1420) + -16)|0;
     $1432 = $1422 >>> $1431;
     $1433 = $1432&255;
     $1434 = (($buffer$144) + 1|0);
     HEAP8[$buffer$144>>0] = $1433;
     $1435 = $1432 & 255;
     $1436 = ($1435|0)==(255);
     if (!($1436)) {
      $buffer$145 = $1434;$put_bits$89 = $1431;
      break;
     }
     $1437 = (($buffer$144) + 2|0);
     HEAP8[$1434>>0] = 0;
     $buffer$145 = $1437;$put_bits$89 = $1431;
    } else {
     $buffer$145 = $buffer$141$lcssa;$put_bits$89 = $1420;
    }
   } while(0);
   $1438 = (($put_bits$89) + ($1387))|0;
   $1439 = $1422 << $1387;
   $1440 = $1439 | $1419;
   $1441 = ($1438|0)>(15);
   if (!($1441)) {
    $buffer$148 = $buffer$145;$put_bits$91 = $1438;$put_buffer$35 = $1440;$r$35 = 0;
    break;
   }
   $1442 = (($1438) + -8)|0;
   $1443 = $1440 >>> $1442;
   $1444 = $1443&255;
   $1445 = (($buffer$145) + 1|0);
   HEAP8[$buffer$145>>0] = $1444;
   $1446 = $1443 & 255;
   $1447 = ($1446|0)==(255);
   if ($1447) {
    $1448 = (($buffer$145) + 2|0);
    HEAP8[$1445>>0] = 0;
    $buffer$146 = $1448;
   } else {
    $buffer$146 = $1445;
   }
   $1449 = (($1438) + -16)|0;
   $1450 = $1440 >>> $1449;
   $1451 = $1450&255;
   $1452 = (($buffer$146) + 1|0);
   HEAP8[$buffer$146>>0] = $1451;
   $1453 = $1450 & 255;
   $1454 = ($1453|0)==(255);
   if (!($1454)) {
    $buffer$148 = $1452;$put_bits$91 = $1449;$put_buffer$35 = $1440;$r$35 = 0;
    break;
   }
   $1455 = (($buffer$146) + 2|0);
   HEAP8[$1452>>0] = 0;
   $buffer$148 = $1455;$put_bits$91 = $1449;$put_buffer$35 = $1440;$r$35 = 0;
  }
 } while(0);
 $1456 = (($block) + 66|0);
 $1457 = HEAP16[$1456>>1]|0;
 $1458 = $1457 << 16 >> 16;
 $1459 = ($1457<<16>>16)==(0);
 do {
  if ($1459) {
   $1460 = (($r$35) + 1)|0;
   $buffer$156 = $buffer$148;$put_bits$96 = $put_bits$91;$put_buffer$37 = $put_buffer$35;$r$37 = $1460;
  } else {
   $1461 = $1458 >> 31;
   $1462 = $1461 ^ $1458;
   $1463 = (($1462) - ($1461))|0;
   $1464 = (($1461) + ($1458))|0;
   $1465 = (66264 + ($1463)|0);
   $1466 = HEAP8[$1465>>0]|0;
   $1467 = $1466&255;
   $1468 = ($r$35|0)>(15);
   if ($1468) {
    $buffer$149487 = $buffer$148;$put_bits$92485 = $put_bits$91;$put_buffer$36486 = $put_buffer$35;$r$36488 = $r$35;
    while(1) {
     $1469 = (($put_bits$92485) + ($4))|0;
     $1470 = $put_buffer$36486 << $4;
     $1471 = $1470 | $1;
     $1472 = ($1469|0)>(15);
     do {
      if ($1472) {
       $1473 = (($1469) + -8)|0;
       $1474 = $1471 >>> $1473;
       $1475 = $1474&255;
       $1476 = (($buffer$149487) + 1|0);
       HEAP8[$buffer$149487>>0] = $1475;
       $1477 = $1474 & 255;
       $1478 = ($1477|0)==(255);
       if ($1478) {
        $1479 = (($buffer$149487) + 2|0);
        HEAP8[$1476>>0] = 0;
        $buffer$150 = $1479;
       } else {
        $buffer$150 = $1476;
       }
       $1480 = (($1469) + -16)|0;
       $1481 = $1471 >>> $1480;
       $1482 = $1481&255;
       $1483 = (($buffer$150) + 1|0);
       HEAP8[$buffer$150>>0] = $1482;
       $1484 = $1481 & 255;
       $1485 = ($1484|0)==(255);
       if (!($1485)) {
        $buffer$151 = $1483;$put_bits$93 = $1480;
        break;
       }
       $1486 = (($buffer$150) + 2|0);
       HEAP8[$1483>>0] = 0;
       $buffer$151 = $1486;$put_bits$93 = $1480;
      } else {
       $buffer$151 = $buffer$149487;$put_bits$93 = $1469;
      }
     } while(0);
     $1487 = (($r$36488) + -16)|0;
     $1488 = ($1487|0)>(15);
     if ($1488) {
      $buffer$149487 = $buffer$151;$put_bits$92485 = $put_bits$93;$put_buffer$36486 = $1471;$r$36488 = $1487;
     } else {
      break;
     }
    }
    $1489 = $r$35 & 15;
    $buffer$149$lcssa = $buffer$151;$put_bits$92$lcssa = $put_bits$93;$put_buffer$36$lcssa = $1471;$r$36$lcssa = $1489;
   } else {
    $buffer$149$lcssa = $buffer$148;$put_bits$92$lcssa = $put_bits$91;$put_buffer$36$lcssa = $put_buffer$35;$r$36$lcssa = $r$35;
   }
   $1490 = $r$36$lcssa << 4;
   $1491 = (($1490) + ($1467))|0;
   $1492 = (($actbl) + ($1491<<2)|0);
   $1493 = HEAP32[$1492>>2]|0;
   $1494 = ((($actbl) + ($1491)|0) + 1024|0);
   $1495 = HEAP8[$1494>>0]|0;
   $1496 = $1495 << 24 >> 24;
   $1497 = 1 << $1467;
   $1498 = (($1497) + -1)|0;
   $1499 = $1498 & $1464;
   $1500 = (($1496) + ($put_bits$92$lcssa))|0;
   $1501 = $put_buffer$36$lcssa << $1496;
   $1502 = $1501 | $1493;
   $1503 = ($1500|0)>(15);
   do {
    if ($1503) {
     $1504 = (($1500) + -8)|0;
     $1505 = $1502 >>> $1504;
     $1506 = $1505&255;
     $1507 = (($buffer$149$lcssa) + 1|0);
     HEAP8[$buffer$149$lcssa>>0] = $1506;
     $1508 = $1505 & 255;
     $1509 = ($1508|0)==(255);
     if ($1509) {
      $1510 = (($buffer$149$lcssa) + 2|0);
      HEAP8[$1507>>0] = 0;
      $buffer$152 = $1510;
     } else {
      $buffer$152 = $1507;
     }
     $1511 = (($1500) + -16)|0;
     $1512 = $1502 >>> $1511;
     $1513 = $1512&255;
     $1514 = (($buffer$152) + 1|0);
     HEAP8[$buffer$152>>0] = $1513;
     $1515 = $1512 & 255;
     $1516 = ($1515|0)==(255);
     if (!($1516)) {
      $buffer$153 = $1514;$put_bits$94 = $1511;
      break;
     }
     $1517 = (($buffer$152) + 2|0);
     HEAP8[$1514>>0] = 0;
     $buffer$153 = $1517;$put_bits$94 = $1511;
    } else {
     $buffer$153 = $buffer$149$lcssa;$put_bits$94 = $1500;
    }
   } while(0);
   $1518 = (($put_bits$94) + ($1467))|0;
   $1519 = $1502 << $1467;
   $1520 = $1519 | $1499;
   $1521 = ($1518|0)>(15);
   if (!($1521)) {
    $buffer$156 = $buffer$153;$put_bits$96 = $1518;$put_buffer$37 = $1520;$r$37 = 0;
    break;
   }
   $1522 = (($1518) + -8)|0;
   $1523 = $1520 >>> $1522;
   $1524 = $1523&255;
   $1525 = (($buffer$153) + 1|0);
   HEAP8[$buffer$153>>0] = $1524;
   $1526 = $1523 & 255;
   $1527 = ($1526|0)==(255);
   if ($1527) {
    $1528 = (($buffer$153) + 2|0);
    HEAP8[$1525>>0] = 0;
    $buffer$154 = $1528;
   } else {
    $buffer$154 = $1525;
   }
   $1529 = (($1518) + -16)|0;
   $1530 = $1520 >>> $1529;
   $1531 = $1530&255;
   $1532 = (($buffer$154) + 1|0);
   HEAP8[$buffer$154>>0] = $1531;
   $1533 = $1530 & 255;
   $1534 = ($1533|0)==(255);
   if (!($1534)) {
    $buffer$156 = $1532;$put_bits$96 = $1529;$put_buffer$37 = $1520;$r$37 = 0;
    break;
   }
   $1535 = (($buffer$154) + 2|0);
   HEAP8[$1532>>0] = 0;
   $buffer$156 = $1535;$put_bits$96 = $1529;$put_buffer$37 = $1520;$r$37 = 0;
  }
 } while(0);
 $1536 = (($block) + 80|0);
 $1537 = HEAP16[$1536>>1]|0;
 $1538 = $1537 << 16 >> 16;
 $1539 = ($1537<<16>>16)==(0);
 do {
  if ($1539) {
   $1540 = (($r$37) + 1)|0;
   $buffer$164 = $buffer$156;$put_bits$101 = $put_bits$96;$put_buffer$39 = $put_buffer$37;$r$39 = $1540;
  } else {
   $1541 = $1538 >> 31;
   $1542 = $1541 ^ $1538;
   $1543 = (($1542) - ($1541))|0;
   $1544 = (($1541) + ($1538))|0;
   $1545 = (66264 + ($1543)|0);
   $1546 = HEAP8[$1545>>0]|0;
   $1547 = $1546&255;
   $1548 = ($r$37|0)>(15);
   if ($1548) {
    $buffer$157476 = $buffer$156;$put_bits$97474 = $put_bits$96;$put_buffer$38475 = $put_buffer$37;$r$38477 = $r$37;
    while(1) {
     $1549 = (($put_bits$97474) + ($4))|0;
     $1550 = $put_buffer$38475 << $4;
     $1551 = $1550 | $1;
     $1552 = ($1549|0)>(15);
     do {
      if ($1552) {
       $1553 = (($1549) + -8)|0;
       $1554 = $1551 >>> $1553;
       $1555 = $1554&255;
       $1556 = (($buffer$157476) + 1|0);
       HEAP8[$buffer$157476>>0] = $1555;
       $1557 = $1554 & 255;
       $1558 = ($1557|0)==(255);
       if ($1558) {
        $1559 = (($buffer$157476) + 2|0);
        HEAP8[$1556>>0] = 0;
        $buffer$158 = $1559;
       } else {
        $buffer$158 = $1556;
       }
       $1560 = (($1549) + -16)|0;
       $1561 = $1551 >>> $1560;
       $1562 = $1561&255;
       $1563 = (($buffer$158) + 1|0);
       HEAP8[$buffer$158>>0] = $1562;
       $1564 = $1561 & 255;
       $1565 = ($1564|0)==(255);
       if (!($1565)) {
        $buffer$159 = $1563;$put_bits$98 = $1560;
        break;
       }
       $1566 = (($buffer$158) + 2|0);
       HEAP8[$1563>>0] = 0;
       $buffer$159 = $1566;$put_bits$98 = $1560;
      } else {
       $buffer$159 = $buffer$157476;$put_bits$98 = $1549;
      }
     } while(0);
     $1567 = (($r$38477) + -16)|0;
     $1568 = ($1567|0)>(15);
     if ($1568) {
      $buffer$157476 = $buffer$159;$put_bits$97474 = $put_bits$98;$put_buffer$38475 = $1551;$r$38477 = $1567;
     } else {
      break;
     }
    }
    $1569 = $r$37 & 15;
    $buffer$157$lcssa = $buffer$159;$put_bits$97$lcssa = $put_bits$98;$put_buffer$38$lcssa = $1551;$r$38$lcssa = $1569;
   } else {
    $buffer$157$lcssa = $buffer$156;$put_bits$97$lcssa = $put_bits$96;$put_buffer$38$lcssa = $put_buffer$37;$r$38$lcssa = $r$37;
   }
   $1570 = $r$38$lcssa << 4;
   $1571 = (($1570) + ($1547))|0;
   $1572 = (($actbl) + ($1571<<2)|0);
   $1573 = HEAP32[$1572>>2]|0;
   $1574 = ((($actbl) + ($1571)|0) + 1024|0);
   $1575 = HEAP8[$1574>>0]|0;
   $1576 = $1575 << 24 >> 24;
   $1577 = 1 << $1547;
   $1578 = (($1577) + -1)|0;
   $1579 = $1578 & $1544;
   $1580 = (($1576) + ($put_bits$97$lcssa))|0;
   $1581 = $put_buffer$38$lcssa << $1576;
   $1582 = $1581 | $1573;
   $1583 = ($1580|0)>(15);
   do {
    if ($1583) {
     $1584 = (($1580) + -8)|0;
     $1585 = $1582 >>> $1584;
     $1586 = $1585&255;
     $1587 = (($buffer$157$lcssa) + 1|0);
     HEAP8[$buffer$157$lcssa>>0] = $1586;
     $1588 = $1585 & 255;
     $1589 = ($1588|0)==(255);
     if ($1589) {
      $1590 = (($buffer$157$lcssa) + 2|0);
      HEAP8[$1587>>0] = 0;
      $buffer$160 = $1590;
     } else {
      $buffer$160 = $1587;
     }
     $1591 = (($1580) + -16)|0;
     $1592 = $1582 >>> $1591;
     $1593 = $1592&255;
     $1594 = (($buffer$160) + 1|0);
     HEAP8[$buffer$160>>0] = $1593;
     $1595 = $1592 & 255;
     $1596 = ($1595|0)==(255);
     if (!($1596)) {
      $buffer$161 = $1594;$put_bits$99 = $1591;
      break;
     }
     $1597 = (($buffer$160) + 2|0);
     HEAP8[$1594>>0] = 0;
     $buffer$161 = $1597;$put_bits$99 = $1591;
    } else {
     $buffer$161 = $buffer$157$lcssa;$put_bits$99 = $1580;
    }
   } while(0);
   $1598 = (($put_bits$99) + ($1547))|0;
   $1599 = $1582 << $1547;
   $1600 = $1599 | $1579;
   $1601 = ($1598|0)>(15);
   if (!($1601)) {
    $buffer$164 = $buffer$161;$put_bits$101 = $1598;$put_buffer$39 = $1600;$r$39 = 0;
    break;
   }
   $1602 = (($1598) + -8)|0;
   $1603 = $1600 >>> $1602;
   $1604 = $1603&255;
   $1605 = (($buffer$161) + 1|0);
   HEAP8[$buffer$161>>0] = $1604;
   $1606 = $1603 & 255;
   $1607 = ($1606|0)==(255);
   if ($1607) {
    $1608 = (($buffer$161) + 2|0);
    HEAP8[$1605>>0] = 0;
    $buffer$162 = $1608;
   } else {
    $buffer$162 = $1605;
   }
   $1609 = (($1598) + -16)|0;
   $1610 = $1600 >>> $1609;
   $1611 = $1610&255;
   $1612 = (($buffer$162) + 1|0);
   HEAP8[$buffer$162>>0] = $1611;
   $1613 = $1610 & 255;
   $1614 = ($1613|0)==(255);
   if (!($1614)) {
    $buffer$164 = $1612;$put_bits$101 = $1609;$put_buffer$39 = $1600;$r$39 = 0;
    break;
   }
   $1615 = (($buffer$162) + 2|0);
   HEAP8[$1612>>0] = 0;
   $buffer$164 = $1615;$put_bits$101 = $1609;$put_buffer$39 = $1600;$r$39 = 0;
  }
 } while(0);
 $1616 = (($block) + 96|0);
 $1617 = HEAP16[$1616>>1]|0;
 $1618 = $1617 << 16 >> 16;
 $1619 = ($1617<<16>>16)==(0);
 do {
  if ($1619) {
   $1620 = (($r$39) + 1)|0;
   $buffer$172 = $buffer$164;$put_bits$106 = $put_bits$101;$put_buffer$41 = $put_buffer$39;$r$41 = $1620;
  } else {
   $1621 = $1618 >> 31;
   $1622 = $1621 ^ $1618;
   $1623 = (($1622) - ($1621))|0;
   $1624 = (($1621) + ($1618))|0;
   $1625 = (66264 + ($1623)|0);
   $1626 = HEAP8[$1625>>0]|0;
   $1627 = $1626&255;
   $1628 = ($r$39|0)>(15);
   if ($1628) {
    $buffer$165465 = $buffer$164;$put_bits$102463 = $put_bits$101;$put_buffer$40464 = $put_buffer$39;$r$40466 = $r$39;
    while(1) {
     $1629 = (($put_bits$102463) + ($4))|0;
     $1630 = $put_buffer$40464 << $4;
     $1631 = $1630 | $1;
     $1632 = ($1629|0)>(15);
     do {
      if ($1632) {
       $1633 = (($1629) + -8)|0;
       $1634 = $1631 >>> $1633;
       $1635 = $1634&255;
       $1636 = (($buffer$165465) + 1|0);
       HEAP8[$buffer$165465>>0] = $1635;
       $1637 = $1634 & 255;
       $1638 = ($1637|0)==(255);
       if ($1638) {
        $1639 = (($buffer$165465) + 2|0);
        HEAP8[$1636>>0] = 0;
        $buffer$166 = $1639;
       } else {
        $buffer$166 = $1636;
       }
       $1640 = (($1629) + -16)|0;
       $1641 = $1631 >>> $1640;
       $1642 = $1641&255;
       $1643 = (($buffer$166) + 1|0);
       HEAP8[$buffer$166>>0] = $1642;
       $1644 = $1641 & 255;
       $1645 = ($1644|0)==(255);
       if (!($1645)) {
        $buffer$167 = $1643;$put_bits$103 = $1640;
        break;
       }
       $1646 = (($buffer$166) + 2|0);
       HEAP8[$1643>>0] = 0;
       $buffer$167 = $1646;$put_bits$103 = $1640;
      } else {
       $buffer$167 = $buffer$165465;$put_bits$103 = $1629;
      }
     } while(0);
     $1647 = (($r$40466) + -16)|0;
     $1648 = ($1647|0)>(15);
     if ($1648) {
      $buffer$165465 = $buffer$167;$put_bits$102463 = $put_bits$103;$put_buffer$40464 = $1631;$r$40466 = $1647;
     } else {
      break;
     }
    }
    $1649 = $r$39 & 15;
    $buffer$165$lcssa = $buffer$167;$put_bits$102$lcssa = $put_bits$103;$put_buffer$40$lcssa = $1631;$r$40$lcssa = $1649;
   } else {
    $buffer$165$lcssa = $buffer$164;$put_bits$102$lcssa = $put_bits$101;$put_buffer$40$lcssa = $put_buffer$39;$r$40$lcssa = $r$39;
   }
   $1650 = $r$40$lcssa << 4;
   $1651 = (($1650) + ($1627))|0;
   $1652 = (($actbl) + ($1651<<2)|0);
   $1653 = HEAP32[$1652>>2]|0;
   $1654 = ((($actbl) + ($1651)|0) + 1024|0);
   $1655 = HEAP8[$1654>>0]|0;
   $1656 = $1655 << 24 >> 24;
   $1657 = 1 << $1627;
   $1658 = (($1657) + -1)|0;
   $1659 = $1658 & $1624;
   $1660 = (($1656) + ($put_bits$102$lcssa))|0;
   $1661 = $put_buffer$40$lcssa << $1656;
   $1662 = $1661 | $1653;
   $1663 = ($1660|0)>(15);
   do {
    if ($1663) {
     $1664 = (($1660) + -8)|0;
     $1665 = $1662 >>> $1664;
     $1666 = $1665&255;
     $1667 = (($buffer$165$lcssa) + 1|0);
     HEAP8[$buffer$165$lcssa>>0] = $1666;
     $1668 = $1665 & 255;
     $1669 = ($1668|0)==(255);
     if ($1669) {
      $1670 = (($buffer$165$lcssa) + 2|0);
      HEAP8[$1667>>0] = 0;
      $buffer$168 = $1670;
     } else {
      $buffer$168 = $1667;
     }
     $1671 = (($1660) + -16)|0;
     $1672 = $1662 >>> $1671;
     $1673 = $1672&255;
     $1674 = (($buffer$168) + 1|0);
     HEAP8[$buffer$168>>0] = $1673;
     $1675 = $1672 & 255;
     $1676 = ($1675|0)==(255);
     if (!($1676)) {
      $buffer$169 = $1674;$put_bits$104 = $1671;
      break;
     }
     $1677 = (($buffer$168) + 2|0);
     HEAP8[$1674>>0] = 0;
     $buffer$169 = $1677;$put_bits$104 = $1671;
    } else {
     $buffer$169 = $buffer$165$lcssa;$put_bits$104 = $1660;
    }
   } while(0);
   $1678 = (($put_bits$104) + ($1627))|0;
   $1679 = $1662 << $1627;
   $1680 = $1679 | $1659;
   $1681 = ($1678|0)>(15);
   if (!($1681)) {
    $buffer$172 = $buffer$169;$put_bits$106 = $1678;$put_buffer$41 = $1680;$r$41 = 0;
    break;
   }
   $1682 = (($1678) + -8)|0;
   $1683 = $1680 >>> $1682;
   $1684 = $1683&255;
   $1685 = (($buffer$169) + 1|0);
   HEAP8[$buffer$169>>0] = $1684;
   $1686 = $1683 & 255;
   $1687 = ($1686|0)==(255);
   if ($1687) {
    $1688 = (($buffer$169) + 2|0);
    HEAP8[$1685>>0] = 0;
    $buffer$170 = $1688;
   } else {
    $buffer$170 = $1685;
   }
   $1689 = (($1678) + -16)|0;
   $1690 = $1680 >>> $1689;
   $1691 = $1690&255;
   $1692 = (($buffer$170) + 1|0);
   HEAP8[$buffer$170>>0] = $1691;
   $1693 = $1690 & 255;
   $1694 = ($1693|0)==(255);
   if (!($1694)) {
    $buffer$172 = $1692;$put_bits$106 = $1689;$put_buffer$41 = $1680;$r$41 = 0;
    break;
   }
   $1695 = (($buffer$170) + 2|0);
   HEAP8[$1692>>0] = 0;
   $buffer$172 = $1695;$put_bits$106 = $1689;$put_buffer$41 = $1680;$r$41 = 0;
  }
 } while(0);
 $1696 = (($block) + 82|0);
 $1697 = HEAP16[$1696>>1]|0;
 $1698 = $1697 << 16 >> 16;
 $1699 = ($1697<<16>>16)==(0);
 do {
  if ($1699) {
   $1700 = (($r$41) + 1)|0;
   $buffer$180 = $buffer$172;$put_bits$111 = $put_bits$106;$put_buffer$43 = $put_buffer$41;$r$43 = $1700;
  } else {
   $1701 = $1698 >> 31;
   $1702 = $1701 ^ $1698;
   $1703 = (($1702) - ($1701))|0;
   $1704 = (($1701) + ($1698))|0;
   $1705 = (66264 + ($1703)|0);
   $1706 = HEAP8[$1705>>0]|0;
   $1707 = $1706&255;
   $1708 = ($r$41|0)>(15);
   if ($1708) {
    $buffer$173454 = $buffer$172;$put_bits$107452 = $put_bits$106;$put_buffer$42453 = $put_buffer$41;$r$42455 = $r$41;
    while(1) {
     $1709 = (($put_bits$107452) + ($4))|0;
     $1710 = $put_buffer$42453 << $4;
     $1711 = $1710 | $1;
     $1712 = ($1709|0)>(15);
     do {
      if ($1712) {
       $1713 = (($1709) + -8)|0;
       $1714 = $1711 >>> $1713;
       $1715 = $1714&255;
       $1716 = (($buffer$173454) + 1|0);
       HEAP8[$buffer$173454>>0] = $1715;
       $1717 = $1714 & 255;
       $1718 = ($1717|0)==(255);
       if ($1718) {
        $1719 = (($buffer$173454) + 2|0);
        HEAP8[$1716>>0] = 0;
        $buffer$174 = $1719;
       } else {
        $buffer$174 = $1716;
       }
       $1720 = (($1709) + -16)|0;
       $1721 = $1711 >>> $1720;
       $1722 = $1721&255;
       $1723 = (($buffer$174) + 1|0);
       HEAP8[$buffer$174>>0] = $1722;
       $1724 = $1721 & 255;
       $1725 = ($1724|0)==(255);
       if (!($1725)) {
        $buffer$175 = $1723;$put_bits$108 = $1720;
        break;
       }
       $1726 = (($buffer$174) + 2|0);
       HEAP8[$1723>>0] = 0;
       $buffer$175 = $1726;$put_bits$108 = $1720;
      } else {
       $buffer$175 = $buffer$173454;$put_bits$108 = $1709;
      }
     } while(0);
     $1727 = (($r$42455) + -16)|0;
     $1728 = ($1727|0)>(15);
     if ($1728) {
      $buffer$173454 = $buffer$175;$put_bits$107452 = $put_bits$108;$put_buffer$42453 = $1711;$r$42455 = $1727;
     } else {
      break;
     }
    }
    $1729 = $r$41 & 15;
    $buffer$173$lcssa = $buffer$175;$put_bits$107$lcssa = $put_bits$108;$put_buffer$42$lcssa = $1711;$r$42$lcssa = $1729;
   } else {
    $buffer$173$lcssa = $buffer$172;$put_bits$107$lcssa = $put_bits$106;$put_buffer$42$lcssa = $put_buffer$41;$r$42$lcssa = $r$41;
   }
   $1730 = $r$42$lcssa << 4;
   $1731 = (($1730) + ($1707))|0;
   $1732 = (($actbl) + ($1731<<2)|0);
   $1733 = HEAP32[$1732>>2]|0;
   $1734 = ((($actbl) + ($1731)|0) + 1024|0);
   $1735 = HEAP8[$1734>>0]|0;
   $1736 = $1735 << 24 >> 24;
   $1737 = 1 << $1707;
   $1738 = (($1737) + -1)|0;
   $1739 = $1738 & $1704;
   $1740 = (($1736) + ($put_bits$107$lcssa))|0;
   $1741 = $put_buffer$42$lcssa << $1736;
   $1742 = $1741 | $1733;
   $1743 = ($1740|0)>(15);
   do {
    if ($1743) {
     $1744 = (($1740) + -8)|0;
     $1745 = $1742 >>> $1744;
     $1746 = $1745&255;
     $1747 = (($buffer$173$lcssa) + 1|0);
     HEAP8[$buffer$173$lcssa>>0] = $1746;
     $1748 = $1745 & 255;
     $1749 = ($1748|0)==(255);
     if ($1749) {
      $1750 = (($buffer$173$lcssa) + 2|0);
      HEAP8[$1747>>0] = 0;
      $buffer$176 = $1750;
     } else {
      $buffer$176 = $1747;
     }
     $1751 = (($1740) + -16)|0;
     $1752 = $1742 >>> $1751;
     $1753 = $1752&255;
     $1754 = (($buffer$176) + 1|0);
     HEAP8[$buffer$176>>0] = $1753;
     $1755 = $1752 & 255;
     $1756 = ($1755|0)==(255);
     if (!($1756)) {
      $buffer$177 = $1754;$put_bits$109 = $1751;
      break;
     }
     $1757 = (($buffer$176) + 2|0);
     HEAP8[$1754>>0] = 0;
     $buffer$177 = $1757;$put_bits$109 = $1751;
    } else {
     $buffer$177 = $buffer$173$lcssa;$put_bits$109 = $1740;
    }
   } while(0);
   $1758 = (($put_bits$109) + ($1707))|0;
   $1759 = $1742 << $1707;
   $1760 = $1759 | $1739;
   $1761 = ($1758|0)>(15);
   if (!($1761)) {
    $buffer$180 = $buffer$177;$put_bits$111 = $1758;$put_buffer$43 = $1760;$r$43 = 0;
    break;
   }
   $1762 = (($1758) + -8)|0;
   $1763 = $1760 >>> $1762;
   $1764 = $1763&255;
   $1765 = (($buffer$177) + 1|0);
   HEAP8[$buffer$177>>0] = $1764;
   $1766 = $1763 & 255;
   $1767 = ($1766|0)==(255);
   if ($1767) {
    $1768 = (($buffer$177) + 2|0);
    HEAP8[$1765>>0] = 0;
    $buffer$178 = $1768;
   } else {
    $buffer$178 = $1765;
   }
   $1769 = (($1758) + -16)|0;
   $1770 = $1760 >>> $1769;
   $1771 = $1770&255;
   $1772 = (($buffer$178) + 1|0);
   HEAP8[$buffer$178>>0] = $1771;
   $1773 = $1770 & 255;
   $1774 = ($1773|0)==(255);
   if (!($1774)) {
    $buffer$180 = $1772;$put_bits$111 = $1769;$put_buffer$43 = $1760;$r$43 = 0;
    break;
   }
   $1775 = (($buffer$178) + 2|0);
   HEAP8[$1772>>0] = 0;
   $buffer$180 = $1775;$put_bits$111 = $1769;$put_buffer$43 = $1760;$r$43 = 0;
  }
 } while(0);
 $1776 = (($block) + 68|0);
 $1777 = HEAP16[$1776>>1]|0;
 $1778 = $1777 << 16 >> 16;
 $1779 = ($1777<<16>>16)==(0);
 do {
  if ($1779) {
   $1780 = (($r$43) + 1)|0;
   $buffer$188 = $buffer$180;$put_bits$116 = $put_bits$111;$put_buffer$45 = $put_buffer$43;$r$45 = $1780;
  } else {
   $1781 = $1778 >> 31;
   $1782 = $1781 ^ $1778;
   $1783 = (($1782) - ($1781))|0;
   $1784 = (($1781) + ($1778))|0;
   $1785 = (66264 + ($1783)|0);
   $1786 = HEAP8[$1785>>0]|0;
   $1787 = $1786&255;
   $1788 = ($r$43|0)>(15);
   if ($1788) {
    $buffer$181443 = $buffer$180;$put_bits$112441 = $put_bits$111;$put_buffer$44442 = $put_buffer$43;$r$44444 = $r$43;
    while(1) {
     $1789 = (($put_bits$112441) + ($4))|0;
     $1790 = $put_buffer$44442 << $4;
     $1791 = $1790 | $1;
     $1792 = ($1789|0)>(15);
     do {
      if ($1792) {
       $1793 = (($1789) + -8)|0;
       $1794 = $1791 >>> $1793;
       $1795 = $1794&255;
       $1796 = (($buffer$181443) + 1|0);
       HEAP8[$buffer$181443>>0] = $1795;
       $1797 = $1794 & 255;
       $1798 = ($1797|0)==(255);
       if ($1798) {
        $1799 = (($buffer$181443) + 2|0);
        HEAP8[$1796>>0] = 0;
        $buffer$182 = $1799;
       } else {
        $buffer$182 = $1796;
       }
       $1800 = (($1789) + -16)|0;
       $1801 = $1791 >>> $1800;
       $1802 = $1801&255;
       $1803 = (($buffer$182) + 1|0);
       HEAP8[$buffer$182>>0] = $1802;
       $1804 = $1801 & 255;
       $1805 = ($1804|0)==(255);
       if (!($1805)) {
        $buffer$183 = $1803;$put_bits$113 = $1800;
        break;
       }
       $1806 = (($buffer$182) + 2|0);
       HEAP8[$1803>>0] = 0;
       $buffer$183 = $1806;$put_bits$113 = $1800;
      } else {
       $buffer$183 = $buffer$181443;$put_bits$113 = $1789;
      }
     } while(0);
     $1807 = (($r$44444) + -16)|0;
     $1808 = ($1807|0)>(15);
     if ($1808) {
      $buffer$181443 = $buffer$183;$put_bits$112441 = $put_bits$113;$put_buffer$44442 = $1791;$r$44444 = $1807;
     } else {
      break;
     }
    }
    $1809 = $r$43 & 15;
    $buffer$181$lcssa = $buffer$183;$put_bits$112$lcssa = $put_bits$113;$put_buffer$44$lcssa = $1791;$r$44$lcssa = $1809;
   } else {
    $buffer$181$lcssa = $buffer$180;$put_bits$112$lcssa = $put_bits$111;$put_buffer$44$lcssa = $put_buffer$43;$r$44$lcssa = $r$43;
   }
   $1810 = $r$44$lcssa << 4;
   $1811 = (($1810) + ($1787))|0;
   $1812 = (($actbl) + ($1811<<2)|0);
   $1813 = HEAP32[$1812>>2]|0;
   $1814 = ((($actbl) + ($1811)|0) + 1024|0);
   $1815 = HEAP8[$1814>>0]|0;
   $1816 = $1815 << 24 >> 24;
   $1817 = 1 << $1787;
   $1818 = (($1817) + -1)|0;
   $1819 = $1818 & $1784;
   $1820 = (($1816) + ($put_bits$112$lcssa))|0;
   $1821 = $put_buffer$44$lcssa << $1816;
   $1822 = $1821 | $1813;
   $1823 = ($1820|0)>(15);
   do {
    if ($1823) {
     $1824 = (($1820) + -8)|0;
     $1825 = $1822 >>> $1824;
     $1826 = $1825&255;
     $1827 = (($buffer$181$lcssa) + 1|0);
     HEAP8[$buffer$181$lcssa>>0] = $1826;
     $1828 = $1825 & 255;
     $1829 = ($1828|0)==(255);
     if ($1829) {
      $1830 = (($buffer$181$lcssa) + 2|0);
      HEAP8[$1827>>0] = 0;
      $buffer$184 = $1830;
     } else {
      $buffer$184 = $1827;
     }
     $1831 = (($1820) + -16)|0;
     $1832 = $1822 >>> $1831;
     $1833 = $1832&255;
     $1834 = (($buffer$184) + 1|0);
     HEAP8[$buffer$184>>0] = $1833;
     $1835 = $1832 & 255;
     $1836 = ($1835|0)==(255);
     if (!($1836)) {
      $buffer$185 = $1834;$put_bits$114 = $1831;
      break;
     }
     $1837 = (($buffer$184) + 2|0);
     HEAP8[$1834>>0] = 0;
     $buffer$185 = $1837;$put_bits$114 = $1831;
    } else {
     $buffer$185 = $buffer$181$lcssa;$put_bits$114 = $1820;
    }
   } while(0);
   $1838 = (($put_bits$114) + ($1787))|0;
   $1839 = $1822 << $1787;
   $1840 = $1839 | $1819;
   $1841 = ($1838|0)>(15);
   if (!($1841)) {
    $buffer$188 = $buffer$185;$put_bits$116 = $1838;$put_buffer$45 = $1840;$r$45 = 0;
    break;
   }
   $1842 = (($1838) + -8)|0;
   $1843 = $1840 >>> $1842;
   $1844 = $1843&255;
   $1845 = (($buffer$185) + 1|0);
   HEAP8[$buffer$185>>0] = $1844;
   $1846 = $1843 & 255;
   $1847 = ($1846|0)==(255);
   if ($1847) {
    $1848 = (($buffer$185) + 2|0);
    HEAP8[$1845>>0] = 0;
    $buffer$186 = $1848;
   } else {
    $buffer$186 = $1845;
   }
   $1849 = (($1838) + -16)|0;
   $1850 = $1840 >>> $1849;
   $1851 = $1850&255;
   $1852 = (($buffer$186) + 1|0);
   HEAP8[$buffer$186>>0] = $1851;
   $1853 = $1850 & 255;
   $1854 = ($1853|0)==(255);
   if (!($1854)) {
    $buffer$188 = $1852;$put_bits$116 = $1849;$put_buffer$45 = $1840;$r$45 = 0;
    break;
   }
   $1855 = (($buffer$186) + 2|0);
   HEAP8[$1852>>0] = 0;
   $buffer$188 = $1855;$put_bits$116 = $1849;$put_buffer$45 = $1840;$r$45 = 0;
  }
 } while(0);
 $1856 = (($block) + 54|0);
 $1857 = HEAP16[$1856>>1]|0;
 $1858 = $1857 << 16 >> 16;
 $1859 = ($1857<<16>>16)==(0);
 do {
  if ($1859) {
   $1860 = (($r$45) + 1)|0;
   $buffer$196 = $buffer$188;$put_bits$121 = $put_bits$116;$put_buffer$47 = $put_buffer$45;$r$47 = $1860;
  } else {
   $1861 = $1858 >> 31;
   $1862 = $1861 ^ $1858;
   $1863 = (($1862) - ($1861))|0;
   $1864 = (($1861) + ($1858))|0;
   $1865 = (66264 + ($1863)|0);
   $1866 = HEAP8[$1865>>0]|0;
   $1867 = $1866&255;
   $1868 = ($r$45|0)>(15);
   if ($1868) {
    $buffer$189432 = $buffer$188;$put_bits$117430 = $put_bits$116;$put_buffer$46431 = $put_buffer$45;$r$46433 = $r$45;
    while(1) {
     $1869 = (($put_bits$117430) + ($4))|0;
     $1870 = $put_buffer$46431 << $4;
     $1871 = $1870 | $1;
     $1872 = ($1869|0)>(15);
     do {
      if ($1872) {
       $1873 = (($1869) + -8)|0;
       $1874 = $1871 >>> $1873;
       $1875 = $1874&255;
       $1876 = (($buffer$189432) + 1|0);
       HEAP8[$buffer$189432>>0] = $1875;
       $1877 = $1874 & 255;
       $1878 = ($1877|0)==(255);
       if ($1878) {
        $1879 = (($buffer$189432) + 2|0);
        HEAP8[$1876>>0] = 0;
        $buffer$190 = $1879;
       } else {
        $buffer$190 = $1876;
       }
       $1880 = (($1869) + -16)|0;
       $1881 = $1871 >>> $1880;
       $1882 = $1881&255;
       $1883 = (($buffer$190) + 1|0);
       HEAP8[$buffer$190>>0] = $1882;
       $1884 = $1881 & 255;
       $1885 = ($1884|0)==(255);
       if (!($1885)) {
        $buffer$191 = $1883;$put_bits$118 = $1880;
        break;
       }
       $1886 = (($buffer$190) + 2|0);
       HEAP8[$1883>>0] = 0;
       $buffer$191 = $1886;$put_bits$118 = $1880;
      } else {
       $buffer$191 = $buffer$189432;$put_bits$118 = $1869;
      }
     } while(0);
     $1887 = (($r$46433) + -16)|0;
     $1888 = ($1887|0)>(15);
     if ($1888) {
      $buffer$189432 = $buffer$191;$put_bits$117430 = $put_bits$118;$put_buffer$46431 = $1871;$r$46433 = $1887;
     } else {
      break;
     }
    }
    $1889 = $r$45 & 15;
    $buffer$189$lcssa = $buffer$191;$put_bits$117$lcssa = $put_bits$118;$put_buffer$46$lcssa = $1871;$r$46$lcssa = $1889;
   } else {
    $buffer$189$lcssa = $buffer$188;$put_bits$117$lcssa = $put_bits$116;$put_buffer$46$lcssa = $put_buffer$45;$r$46$lcssa = $r$45;
   }
   $1890 = $r$46$lcssa << 4;
   $1891 = (($1890) + ($1867))|0;
   $1892 = (($actbl) + ($1891<<2)|0);
   $1893 = HEAP32[$1892>>2]|0;
   $1894 = ((($actbl) + ($1891)|0) + 1024|0);
   $1895 = HEAP8[$1894>>0]|0;
   $1896 = $1895 << 24 >> 24;
   $1897 = 1 << $1867;
   $1898 = (($1897) + -1)|0;
   $1899 = $1898 & $1864;
   $1900 = (($1896) + ($put_bits$117$lcssa))|0;
   $1901 = $put_buffer$46$lcssa << $1896;
   $1902 = $1901 | $1893;
   $1903 = ($1900|0)>(15);
   do {
    if ($1903) {
     $1904 = (($1900) + -8)|0;
     $1905 = $1902 >>> $1904;
     $1906 = $1905&255;
     $1907 = (($buffer$189$lcssa) + 1|0);
     HEAP8[$buffer$189$lcssa>>0] = $1906;
     $1908 = $1905 & 255;
     $1909 = ($1908|0)==(255);
     if ($1909) {
      $1910 = (($buffer$189$lcssa) + 2|0);
      HEAP8[$1907>>0] = 0;
      $buffer$192 = $1910;
     } else {
      $buffer$192 = $1907;
     }
     $1911 = (($1900) + -16)|0;
     $1912 = $1902 >>> $1911;
     $1913 = $1912&255;
     $1914 = (($buffer$192) + 1|0);
     HEAP8[$buffer$192>>0] = $1913;
     $1915 = $1912 & 255;
     $1916 = ($1915|0)==(255);
     if (!($1916)) {
      $buffer$193 = $1914;$put_bits$119 = $1911;
      break;
     }
     $1917 = (($buffer$192) + 2|0);
     HEAP8[$1914>>0] = 0;
     $buffer$193 = $1917;$put_bits$119 = $1911;
    } else {
     $buffer$193 = $buffer$189$lcssa;$put_bits$119 = $1900;
    }
   } while(0);
   $1918 = (($put_bits$119) + ($1867))|0;
   $1919 = $1902 << $1867;
   $1920 = $1919 | $1899;
   $1921 = ($1918|0)>(15);
   if (!($1921)) {
    $buffer$196 = $buffer$193;$put_bits$121 = $1918;$put_buffer$47 = $1920;$r$47 = 0;
    break;
   }
   $1922 = (($1918) + -8)|0;
   $1923 = $1920 >>> $1922;
   $1924 = $1923&255;
   $1925 = (($buffer$193) + 1|0);
   HEAP8[$buffer$193>>0] = $1924;
   $1926 = $1923 & 255;
   $1927 = ($1926|0)==(255);
   if ($1927) {
    $1928 = (($buffer$193) + 2|0);
    HEAP8[$1925>>0] = 0;
    $buffer$194 = $1928;
   } else {
    $buffer$194 = $1925;
   }
   $1929 = (($1918) + -16)|0;
   $1930 = $1920 >>> $1929;
   $1931 = $1930&255;
   $1932 = (($buffer$194) + 1|0);
   HEAP8[$buffer$194>>0] = $1931;
   $1933 = $1930 & 255;
   $1934 = ($1933|0)==(255);
   if (!($1934)) {
    $buffer$196 = $1932;$put_bits$121 = $1929;$put_buffer$47 = $1920;$r$47 = 0;
    break;
   }
   $1935 = (($buffer$194) + 2|0);
   HEAP8[$1932>>0] = 0;
   $buffer$196 = $1935;$put_bits$121 = $1929;$put_buffer$47 = $1920;$r$47 = 0;
  }
 } while(0);
 $1936 = (($block) + 40|0);
 $1937 = HEAP16[$1936>>1]|0;
 $1938 = $1937 << 16 >> 16;
 $1939 = ($1937<<16>>16)==(0);
 do {
  if ($1939) {
   $1940 = (($r$47) + 1)|0;
   $buffer$204 = $buffer$196;$put_bits$126 = $put_bits$121;$put_buffer$49 = $put_buffer$47;$r$49 = $1940;
  } else {
   $1941 = $1938 >> 31;
   $1942 = $1941 ^ $1938;
   $1943 = (($1942) - ($1941))|0;
   $1944 = (($1941) + ($1938))|0;
   $1945 = (66264 + ($1943)|0);
   $1946 = HEAP8[$1945>>0]|0;
   $1947 = $1946&255;
   $1948 = ($r$47|0)>(15);
   if ($1948) {
    $buffer$197421 = $buffer$196;$put_bits$122419 = $put_bits$121;$put_buffer$48420 = $put_buffer$47;$r$48422 = $r$47;
    while(1) {
     $1949 = (($put_bits$122419) + ($4))|0;
     $1950 = $put_buffer$48420 << $4;
     $1951 = $1950 | $1;
     $1952 = ($1949|0)>(15);
     do {
      if ($1952) {
       $1953 = (($1949) + -8)|0;
       $1954 = $1951 >>> $1953;
       $1955 = $1954&255;
       $1956 = (($buffer$197421) + 1|0);
       HEAP8[$buffer$197421>>0] = $1955;
       $1957 = $1954 & 255;
       $1958 = ($1957|0)==(255);
       if ($1958) {
        $1959 = (($buffer$197421) + 2|0);
        HEAP8[$1956>>0] = 0;
        $buffer$198 = $1959;
       } else {
        $buffer$198 = $1956;
       }
       $1960 = (($1949) + -16)|0;
       $1961 = $1951 >>> $1960;
       $1962 = $1961&255;
       $1963 = (($buffer$198) + 1|0);
       HEAP8[$buffer$198>>0] = $1962;
       $1964 = $1961 & 255;
       $1965 = ($1964|0)==(255);
       if (!($1965)) {
        $buffer$199 = $1963;$put_bits$123 = $1960;
        break;
       }
       $1966 = (($buffer$198) + 2|0);
       HEAP8[$1963>>0] = 0;
       $buffer$199 = $1966;$put_bits$123 = $1960;
      } else {
       $buffer$199 = $buffer$197421;$put_bits$123 = $1949;
      }
     } while(0);
     $1967 = (($r$48422) + -16)|0;
     $1968 = ($1967|0)>(15);
     if ($1968) {
      $buffer$197421 = $buffer$199;$put_bits$122419 = $put_bits$123;$put_buffer$48420 = $1951;$r$48422 = $1967;
     } else {
      break;
     }
    }
    $1969 = $r$47 & 15;
    $buffer$197$lcssa = $buffer$199;$put_bits$122$lcssa = $put_bits$123;$put_buffer$48$lcssa = $1951;$r$48$lcssa = $1969;
   } else {
    $buffer$197$lcssa = $buffer$196;$put_bits$122$lcssa = $put_bits$121;$put_buffer$48$lcssa = $put_buffer$47;$r$48$lcssa = $r$47;
   }
   $1970 = $r$48$lcssa << 4;
   $1971 = (($1970) + ($1947))|0;
   $1972 = (($actbl) + ($1971<<2)|0);
   $1973 = HEAP32[$1972>>2]|0;
   $1974 = ((($actbl) + ($1971)|0) + 1024|0);
   $1975 = HEAP8[$1974>>0]|0;
   $1976 = $1975 << 24 >> 24;
   $1977 = 1 << $1947;
   $1978 = (($1977) + -1)|0;
   $1979 = $1978 & $1944;
   $1980 = (($1976) + ($put_bits$122$lcssa))|0;
   $1981 = $put_buffer$48$lcssa << $1976;
   $1982 = $1981 | $1973;
   $1983 = ($1980|0)>(15);
   do {
    if ($1983) {
     $1984 = (($1980) + -8)|0;
     $1985 = $1982 >>> $1984;
     $1986 = $1985&255;
     $1987 = (($buffer$197$lcssa) + 1|0);
     HEAP8[$buffer$197$lcssa>>0] = $1986;
     $1988 = $1985 & 255;
     $1989 = ($1988|0)==(255);
     if ($1989) {
      $1990 = (($buffer$197$lcssa) + 2|0);
      HEAP8[$1987>>0] = 0;
      $buffer$200 = $1990;
     } else {
      $buffer$200 = $1987;
     }
     $1991 = (($1980) + -16)|0;
     $1992 = $1982 >>> $1991;
     $1993 = $1992&255;
     $1994 = (($buffer$200) + 1|0);
     HEAP8[$buffer$200>>0] = $1993;
     $1995 = $1992 & 255;
     $1996 = ($1995|0)==(255);
     if (!($1996)) {
      $buffer$201 = $1994;$put_bits$124 = $1991;
      break;
     }
     $1997 = (($buffer$200) + 2|0);
     HEAP8[$1994>>0] = 0;
     $buffer$201 = $1997;$put_bits$124 = $1991;
    } else {
     $buffer$201 = $buffer$197$lcssa;$put_bits$124 = $1980;
    }
   } while(0);
   $1998 = (($put_bits$124) + ($1947))|0;
   $1999 = $1982 << $1947;
   $2000 = $1999 | $1979;
   $2001 = ($1998|0)>(15);
   if (!($2001)) {
    $buffer$204 = $buffer$201;$put_bits$126 = $1998;$put_buffer$49 = $2000;$r$49 = 0;
    break;
   }
   $2002 = (($1998) + -8)|0;
   $2003 = $2000 >>> $2002;
   $2004 = $2003&255;
   $2005 = (($buffer$201) + 1|0);
   HEAP8[$buffer$201>>0] = $2004;
   $2006 = $2003 & 255;
   $2007 = ($2006|0)==(255);
   if ($2007) {
    $2008 = (($buffer$201) + 2|0);
    HEAP8[$2005>>0] = 0;
    $buffer$202 = $2008;
   } else {
    $buffer$202 = $2005;
   }
   $2009 = (($1998) + -16)|0;
   $2010 = $2000 >>> $2009;
   $2011 = $2010&255;
   $2012 = (($buffer$202) + 1|0);
   HEAP8[$buffer$202>>0] = $2011;
   $2013 = $2010 & 255;
   $2014 = ($2013|0)==(255);
   if (!($2014)) {
    $buffer$204 = $2012;$put_bits$126 = $2009;$put_buffer$49 = $2000;$r$49 = 0;
    break;
   }
   $2015 = (($buffer$202) + 2|0);
   HEAP8[$2012>>0] = 0;
   $buffer$204 = $2015;$put_bits$126 = $2009;$put_buffer$49 = $2000;$r$49 = 0;
  }
 } while(0);
 $2016 = (($block) + 26|0);
 $2017 = HEAP16[$2016>>1]|0;
 $2018 = $2017 << 16 >> 16;
 $2019 = ($2017<<16>>16)==(0);
 do {
  if ($2019) {
   $2020 = (($r$49) + 1)|0;
   $buffer$212 = $buffer$204;$put_bits$131 = $put_bits$126;$put_buffer$51 = $put_buffer$49;$r$51 = $2020;
  } else {
   $2021 = $2018 >> 31;
   $2022 = $2021 ^ $2018;
   $2023 = (($2022) - ($2021))|0;
   $2024 = (($2021) + ($2018))|0;
   $2025 = (66264 + ($2023)|0);
   $2026 = HEAP8[$2025>>0]|0;
   $2027 = $2026&255;
   $2028 = ($r$49|0)>(15);
   if ($2028) {
    $buffer$205410 = $buffer$204;$put_bits$127408 = $put_bits$126;$put_buffer$50409 = $put_buffer$49;$r$50411 = $r$49;
    while(1) {
     $2029 = (($put_bits$127408) + ($4))|0;
     $2030 = $put_buffer$50409 << $4;
     $2031 = $2030 | $1;
     $2032 = ($2029|0)>(15);
     do {
      if ($2032) {
       $2033 = (($2029) + -8)|0;
       $2034 = $2031 >>> $2033;
       $2035 = $2034&255;
       $2036 = (($buffer$205410) + 1|0);
       HEAP8[$buffer$205410>>0] = $2035;
       $2037 = $2034 & 255;
       $2038 = ($2037|0)==(255);
       if ($2038) {
        $2039 = (($buffer$205410) + 2|0);
        HEAP8[$2036>>0] = 0;
        $buffer$206 = $2039;
       } else {
        $buffer$206 = $2036;
       }
       $2040 = (($2029) + -16)|0;
       $2041 = $2031 >>> $2040;
       $2042 = $2041&255;
       $2043 = (($buffer$206) + 1|0);
       HEAP8[$buffer$206>>0] = $2042;
       $2044 = $2041 & 255;
       $2045 = ($2044|0)==(255);
       if (!($2045)) {
        $buffer$207 = $2043;$put_bits$128 = $2040;
        break;
       }
       $2046 = (($buffer$206) + 2|0);
       HEAP8[$2043>>0] = 0;
       $buffer$207 = $2046;$put_bits$128 = $2040;
      } else {
       $buffer$207 = $buffer$205410;$put_bits$128 = $2029;
      }
     } while(0);
     $2047 = (($r$50411) + -16)|0;
     $2048 = ($2047|0)>(15);
     if ($2048) {
      $buffer$205410 = $buffer$207;$put_bits$127408 = $put_bits$128;$put_buffer$50409 = $2031;$r$50411 = $2047;
     } else {
      break;
     }
    }
    $2049 = $r$49 & 15;
    $buffer$205$lcssa = $buffer$207;$put_bits$127$lcssa = $put_bits$128;$put_buffer$50$lcssa = $2031;$r$50$lcssa = $2049;
   } else {
    $buffer$205$lcssa = $buffer$204;$put_bits$127$lcssa = $put_bits$126;$put_buffer$50$lcssa = $put_buffer$49;$r$50$lcssa = $r$49;
   }
   $2050 = $r$50$lcssa << 4;
   $2051 = (($2050) + ($2027))|0;
   $2052 = (($actbl) + ($2051<<2)|0);
   $2053 = HEAP32[$2052>>2]|0;
   $2054 = ((($actbl) + ($2051)|0) + 1024|0);
   $2055 = HEAP8[$2054>>0]|0;
   $2056 = $2055 << 24 >> 24;
   $2057 = 1 << $2027;
   $2058 = (($2057) + -1)|0;
   $2059 = $2058 & $2024;
   $2060 = (($2056) + ($put_bits$127$lcssa))|0;
   $2061 = $put_buffer$50$lcssa << $2056;
   $2062 = $2061 | $2053;
   $2063 = ($2060|0)>(15);
   do {
    if ($2063) {
     $2064 = (($2060) + -8)|0;
     $2065 = $2062 >>> $2064;
     $2066 = $2065&255;
     $2067 = (($buffer$205$lcssa) + 1|0);
     HEAP8[$buffer$205$lcssa>>0] = $2066;
     $2068 = $2065 & 255;
     $2069 = ($2068|0)==(255);
     if ($2069) {
      $2070 = (($buffer$205$lcssa) + 2|0);
      HEAP8[$2067>>0] = 0;
      $buffer$208 = $2070;
     } else {
      $buffer$208 = $2067;
     }
     $2071 = (($2060) + -16)|0;
     $2072 = $2062 >>> $2071;
     $2073 = $2072&255;
     $2074 = (($buffer$208) + 1|0);
     HEAP8[$buffer$208>>0] = $2073;
     $2075 = $2072 & 255;
     $2076 = ($2075|0)==(255);
     if (!($2076)) {
      $buffer$209 = $2074;$put_bits$129 = $2071;
      break;
     }
     $2077 = (($buffer$208) + 2|0);
     HEAP8[$2074>>0] = 0;
     $buffer$209 = $2077;$put_bits$129 = $2071;
    } else {
     $buffer$209 = $buffer$205$lcssa;$put_bits$129 = $2060;
    }
   } while(0);
   $2078 = (($put_bits$129) + ($2027))|0;
   $2079 = $2062 << $2027;
   $2080 = $2079 | $2059;
   $2081 = ($2078|0)>(15);
   if (!($2081)) {
    $buffer$212 = $buffer$209;$put_bits$131 = $2078;$put_buffer$51 = $2080;$r$51 = 0;
    break;
   }
   $2082 = (($2078) + -8)|0;
   $2083 = $2080 >>> $2082;
   $2084 = $2083&255;
   $2085 = (($buffer$209) + 1|0);
   HEAP8[$buffer$209>>0] = $2084;
   $2086 = $2083 & 255;
   $2087 = ($2086|0)==(255);
   if ($2087) {
    $2088 = (($buffer$209) + 2|0);
    HEAP8[$2085>>0] = 0;
    $buffer$210 = $2088;
   } else {
    $buffer$210 = $2085;
   }
   $2089 = (($2078) + -16)|0;
   $2090 = $2080 >>> $2089;
   $2091 = $2090&255;
   $2092 = (($buffer$210) + 1|0);
   HEAP8[$buffer$210>>0] = $2091;
   $2093 = $2090 & 255;
   $2094 = ($2093|0)==(255);
   if (!($2094)) {
    $buffer$212 = $2092;$put_bits$131 = $2089;$put_buffer$51 = $2080;$r$51 = 0;
    break;
   }
   $2095 = (($buffer$210) + 2|0);
   HEAP8[$2092>>0] = 0;
   $buffer$212 = $2095;$put_bits$131 = $2089;$put_buffer$51 = $2080;$r$51 = 0;
  }
 } while(0);
 $2096 = (($block) + 12|0);
 $2097 = HEAP16[$2096>>1]|0;
 $2098 = $2097 << 16 >> 16;
 $2099 = ($2097<<16>>16)==(0);
 do {
  if ($2099) {
   $2100 = (($r$51) + 1)|0;
   $buffer$220 = $buffer$212;$put_bits$136 = $put_bits$131;$put_buffer$53 = $put_buffer$51;$r$53 = $2100;
  } else {
   $2101 = $2098 >> 31;
   $2102 = $2101 ^ $2098;
   $2103 = (($2102) - ($2101))|0;
   $2104 = (($2101) + ($2098))|0;
   $2105 = (66264 + ($2103)|0);
   $2106 = HEAP8[$2105>>0]|0;
   $2107 = $2106&255;
   $2108 = ($r$51|0)>(15);
   if ($2108) {
    $buffer$213399 = $buffer$212;$put_bits$132397 = $put_bits$131;$put_buffer$52398 = $put_buffer$51;$r$52400 = $r$51;
    while(1) {
     $2109 = (($put_bits$132397) + ($4))|0;
     $2110 = $put_buffer$52398 << $4;
     $2111 = $2110 | $1;
     $2112 = ($2109|0)>(15);
     do {
      if ($2112) {
       $2113 = (($2109) + -8)|0;
       $2114 = $2111 >>> $2113;
       $2115 = $2114&255;
       $2116 = (($buffer$213399) + 1|0);
       HEAP8[$buffer$213399>>0] = $2115;
       $2117 = $2114 & 255;
       $2118 = ($2117|0)==(255);
       if ($2118) {
        $2119 = (($buffer$213399) + 2|0);
        HEAP8[$2116>>0] = 0;
        $buffer$214 = $2119;
       } else {
        $buffer$214 = $2116;
       }
       $2120 = (($2109) + -16)|0;
       $2121 = $2111 >>> $2120;
       $2122 = $2121&255;
       $2123 = (($buffer$214) + 1|0);
       HEAP8[$buffer$214>>0] = $2122;
       $2124 = $2121 & 255;
       $2125 = ($2124|0)==(255);
       if (!($2125)) {
        $buffer$215 = $2123;$put_bits$133 = $2120;
        break;
       }
       $2126 = (($buffer$214) + 2|0);
       HEAP8[$2123>>0] = 0;
       $buffer$215 = $2126;$put_bits$133 = $2120;
      } else {
       $buffer$215 = $buffer$213399;$put_bits$133 = $2109;
      }
     } while(0);
     $2127 = (($r$52400) + -16)|0;
     $2128 = ($2127|0)>(15);
     if ($2128) {
      $buffer$213399 = $buffer$215;$put_bits$132397 = $put_bits$133;$put_buffer$52398 = $2111;$r$52400 = $2127;
     } else {
      break;
     }
    }
    $2129 = $r$51 & 15;
    $buffer$213$lcssa = $buffer$215;$put_bits$132$lcssa = $put_bits$133;$put_buffer$52$lcssa = $2111;$r$52$lcssa = $2129;
   } else {
    $buffer$213$lcssa = $buffer$212;$put_bits$132$lcssa = $put_bits$131;$put_buffer$52$lcssa = $put_buffer$51;$r$52$lcssa = $r$51;
   }
   $2130 = $r$52$lcssa << 4;
   $2131 = (($2130) + ($2107))|0;
   $2132 = (($actbl) + ($2131<<2)|0);
   $2133 = HEAP32[$2132>>2]|0;
   $2134 = ((($actbl) + ($2131)|0) + 1024|0);
   $2135 = HEAP8[$2134>>0]|0;
   $2136 = $2135 << 24 >> 24;
   $2137 = 1 << $2107;
   $2138 = (($2137) + -1)|0;
   $2139 = $2138 & $2104;
   $2140 = (($2136) + ($put_bits$132$lcssa))|0;
   $2141 = $put_buffer$52$lcssa << $2136;
   $2142 = $2141 | $2133;
   $2143 = ($2140|0)>(15);
   do {
    if ($2143) {
     $2144 = (($2140) + -8)|0;
     $2145 = $2142 >>> $2144;
     $2146 = $2145&255;
     $2147 = (($buffer$213$lcssa) + 1|0);
     HEAP8[$buffer$213$lcssa>>0] = $2146;
     $2148 = $2145 & 255;
     $2149 = ($2148|0)==(255);
     if ($2149) {
      $2150 = (($buffer$213$lcssa) + 2|0);
      HEAP8[$2147>>0] = 0;
      $buffer$216 = $2150;
     } else {
      $buffer$216 = $2147;
     }
     $2151 = (($2140) + -16)|0;
     $2152 = $2142 >>> $2151;
     $2153 = $2152&255;
     $2154 = (($buffer$216) + 1|0);
     HEAP8[$buffer$216>>0] = $2153;
     $2155 = $2152 & 255;
     $2156 = ($2155|0)==(255);
     if (!($2156)) {
      $buffer$217 = $2154;$put_bits$134 = $2151;
      break;
     }
     $2157 = (($buffer$216) + 2|0);
     HEAP8[$2154>>0] = 0;
     $buffer$217 = $2157;$put_bits$134 = $2151;
    } else {
     $buffer$217 = $buffer$213$lcssa;$put_bits$134 = $2140;
    }
   } while(0);
   $2158 = (($put_bits$134) + ($2107))|0;
   $2159 = $2142 << $2107;
   $2160 = $2159 | $2139;
   $2161 = ($2158|0)>(15);
   if (!($2161)) {
    $buffer$220 = $buffer$217;$put_bits$136 = $2158;$put_buffer$53 = $2160;$r$53 = 0;
    break;
   }
   $2162 = (($2158) + -8)|0;
   $2163 = $2160 >>> $2162;
   $2164 = $2163&255;
   $2165 = (($buffer$217) + 1|0);
   HEAP8[$buffer$217>>0] = $2164;
   $2166 = $2163 & 255;
   $2167 = ($2166|0)==(255);
   if ($2167) {
    $2168 = (($buffer$217) + 2|0);
    HEAP8[$2165>>0] = 0;
    $buffer$218 = $2168;
   } else {
    $buffer$218 = $2165;
   }
   $2169 = (($2158) + -16)|0;
   $2170 = $2160 >>> $2169;
   $2171 = $2170&255;
   $2172 = (($buffer$218) + 1|0);
   HEAP8[$buffer$218>>0] = $2171;
   $2173 = $2170 & 255;
   $2174 = ($2173|0)==(255);
   if (!($2174)) {
    $buffer$220 = $2172;$put_bits$136 = $2169;$put_buffer$53 = $2160;$r$53 = 0;
    break;
   }
   $2175 = (($buffer$218) + 2|0);
   HEAP8[$2172>>0] = 0;
   $buffer$220 = $2175;$put_bits$136 = $2169;$put_buffer$53 = $2160;$r$53 = 0;
  }
 } while(0);
 $2176 = (($block) + 14|0);
 $2177 = HEAP16[$2176>>1]|0;
 $2178 = $2177 << 16 >> 16;
 $2179 = ($2177<<16>>16)==(0);
 do {
  if ($2179) {
   $2180 = (($r$53) + 1)|0;
   $buffer$228 = $buffer$220;$put_bits$141 = $put_bits$136;$put_buffer$55 = $put_buffer$53;$r$55 = $2180;
  } else {
   $2181 = $2178 >> 31;
   $2182 = $2181 ^ $2178;
   $2183 = (($2182) - ($2181))|0;
   $2184 = (($2181) + ($2178))|0;
   $2185 = (66264 + ($2183)|0);
   $2186 = HEAP8[$2185>>0]|0;
   $2187 = $2186&255;
   $2188 = ($r$53|0)>(15);
   if ($2188) {
    $buffer$221388 = $buffer$220;$put_bits$137386 = $put_bits$136;$put_buffer$54387 = $put_buffer$53;$r$54389 = $r$53;
    while(1) {
     $2189 = (($put_bits$137386) + ($4))|0;
     $2190 = $put_buffer$54387 << $4;
     $2191 = $2190 | $1;
     $2192 = ($2189|0)>(15);
     do {
      if ($2192) {
       $2193 = (($2189) + -8)|0;
       $2194 = $2191 >>> $2193;
       $2195 = $2194&255;
       $2196 = (($buffer$221388) + 1|0);
       HEAP8[$buffer$221388>>0] = $2195;
       $2197 = $2194 & 255;
       $2198 = ($2197|0)==(255);
       if ($2198) {
        $2199 = (($buffer$221388) + 2|0);
        HEAP8[$2196>>0] = 0;
        $buffer$222 = $2199;
       } else {
        $buffer$222 = $2196;
       }
       $2200 = (($2189) + -16)|0;
       $2201 = $2191 >>> $2200;
       $2202 = $2201&255;
       $2203 = (($buffer$222) + 1|0);
       HEAP8[$buffer$222>>0] = $2202;
       $2204 = $2201 & 255;
       $2205 = ($2204|0)==(255);
       if (!($2205)) {
        $buffer$223 = $2203;$put_bits$138 = $2200;
        break;
       }
       $2206 = (($buffer$222) + 2|0);
       HEAP8[$2203>>0] = 0;
       $buffer$223 = $2206;$put_bits$138 = $2200;
      } else {
       $buffer$223 = $buffer$221388;$put_bits$138 = $2189;
      }
     } while(0);
     $2207 = (($r$54389) + -16)|0;
     $2208 = ($2207|0)>(15);
     if ($2208) {
      $buffer$221388 = $buffer$223;$put_bits$137386 = $put_bits$138;$put_buffer$54387 = $2191;$r$54389 = $2207;
     } else {
      break;
     }
    }
    $2209 = $r$53 & 15;
    $buffer$221$lcssa = $buffer$223;$put_bits$137$lcssa = $put_bits$138;$put_buffer$54$lcssa = $2191;$r$54$lcssa = $2209;
   } else {
    $buffer$221$lcssa = $buffer$220;$put_bits$137$lcssa = $put_bits$136;$put_buffer$54$lcssa = $put_buffer$53;$r$54$lcssa = $r$53;
   }
   $2210 = $r$54$lcssa << 4;
   $2211 = (($2210) + ($2187))|0;
   $2212 = (($actbl) + ($2211<<2)|0);
   $2213 = HEAP32[$2212>>2]|0;
   $2214 = ((($actbl) + ($2211)|0) + 1024|0);
   $2215 = HEAP8[$2214>>0]|0;
   $2216 = $2215 << 24 >> 24;
   $2217 = 1 << $2187;
   $2218 = (($2217) + -1)|0;
   $2219 = $2218 & $2184;
   $2220 = (($2216) + ($put_bits$137$lcssa))|0;
   $2221 = $put_buffer$54$lcssa << $2216;
   $2222 = $2221 | $2213;
   $2223 = ($2220|0)>(15);
   do {
    if ($2223) {
     $2224 = (($2220) + -8)|0;
     $2225 = $2222 >>> $2224;
     $2226 = $2225&255;
     $2227 = (($buffer$221$lcssa) + 1|0);
     HEAP8[$buffer$221$lcssa>>0] = $2226;
     $2228 = $2225 & 255;
     $2229 = ($2228|0)==(255);
     if ($2229) {
      $2230 = (($buffer$221$lcssa) + 2|0);
      HEAP8[$2227>>0] = 0;
      $buffer$224 = $2230;
     } else {
      $buffer$224 = $2227;
     }
     $2231 = (($2220) + -16)|0;
     $2232 = $2222 >>> $2231;
     $2233 = $2232&255;
     $2234 = (($buffer$224) + 1|0);
     HEAP8[$buffer$224>>0] = $2233;
     $2235 = $2232 & 255;
     $2236 = ($2235|0)==(255);
     if (!($2236)) {
      $buffer$225 = $2234;$put_bits$139 = $2231;
      break;
     }
     $2237 = (($buffer$224) + 2|0);
     HEAP8[$2234>>0] = 0;
     $buffer$225 = $2237;$put_bits$139 = $2231;
    } else {
     $buffer$225 = $buffer$221$lcssa;$put_bits$139 = $2220;
    }
   } while(0);
   $2238 = (($put_bits$139) + ($2187))|0;
   $2239 = $2222 << $2187;
   $2240 = $2239 | $2219;
   $2241 = ($2238|0)>(15);
   if (!($2241)) {
    $buffer$228 = $buffer$225;$put_bits$141 = $2238;$put_buffer$55 = $2240;$r$55 = 0;
    break;
   }
   $2242 = (($2238) + -8)|0;
   $2243 = $2240 >>> $2242;
   $2244 = $2243&255;
   $2245 = (($buffer$225) + 1|0);
   HEAP8[$buffer$225>>0] = $2244;
   $2246 = $2243 & 255;
   $2247 = ($2246|0)==(255);
   if ($2247) {
    $2248 = (($buffer$225) + 2|0);
    HEAP8[$2245>>0] = 0;
    $buffer$226 = $2248;
   } else {
    $buffer$226 = $2245;
   }
   $2249 = (($2238) + -16)|0;
   $2250 = $2240 >>> $2249;
   $2251 = $2250&255;
   $2252 = (($buffer$226) + 1|0);
   HEAP8[$buffer$226>>0] = $2251;
   $2253 = $2250 & 255;
   $2254 = ($2253|0)==(255);
   if (!($2254)) {
    $buffer$228 = $2252;$put_bits$141 = $2249;$put_buffer$55 = $2240;$r$55 = 0;
    break;
   }
   $2255 = (($buffer$226) + 2|0);
   HEAP8[$2252>>0] = 0;
   $buffer$228 = $2255;$put_bits$141 = $2249;$put_buffer$55 = $2240;$r$55 = 0;
  }
 } while(0);
 $2256 = (($block) + 28|0);
 $2257 = HEAP16[$2256>>1]|0;
 $2258 = $2257 << 16 >> 16;
 $2259 = ($2257<<16>>16)==(0);
 do {
  if ($2259) {
   $2260 = (($r$55) + 1)|0;
   $buffer$236 = $buffer$228;$put_bits$146 = $put_bits$141;$put_buffer$57 = $put_buffer$55;$r$57 = $2260;
  } else {
   $2261 = $2258 >> 31;
   $2262 = $2261 ^ $2258;
   $2263 = (($2262) - ($2261))|0;
   $2264 = (($2261) + ($2258))|0;
   $2265 = (66264 + ($2263)|0);
   $2266 = HEAP8[$2265>>0]|0;
   $2267 = $2266&255;
   $2268 = ($r$55|0)>(15);
   if ($2268) {
    $buffer$229377 = $buffer$228;$put_bits$142375 = $put_bits$141;$put_buffer$56376 = $put_buffer$55;$r$56378 = $r$55;
    while(1) {
     $2269 = (($put_bits$142375) + ($4))|0;
     $2270 = $put_buffer$56376 << $4;
     $2271 = $2270 | $1;
     $2272 = ($2269|0)>(15);
     do {
      if ($2272) {
       $2273 = (($2269) + -8)|0;
       $2274 = $2271 >>> $2273;
       $2275 = $2274&255;
       $2276 = (($buffer$229377) + 1|0);
       HEAP8[$buffer$229377>>0] = $2275;
       $2277 = $2274 & 255;
       $2278 = ($2277|0)==(255);
       if ($2278) {
        $2279 = (($buffer$229377) + 2|0);
        HEAP8[$2276>>0] = 0;
        $buffer$230 = $2279;
       } else {
        $buffer$230 = $2276;
       }
       $2280 = (($2269) + -16)|0;
       $2281 = $2271 >>> $2280;
       $2282 = $2281&255;
       $2283 = (($buffer$230) + 1|0);
       HEAP8[$buffer$230>>0] = $2282;
       $2284 = $2281 & 255;
       $2285 = ($2284|0)==(255);
       if (!($2285)) {
        $buffer$231 = $2283;$put_bits$143 = $2280;
        break;
       }
       $2286 = (($buffer$230) + 2|0);
       HEAP8[$2283>>0] = 0;
       $buffer$231 = $2286;$put_bits$143 = $2280;
      } else {
       $buffer$231 = $buffer$229377;$put_bits$143 = $2269;
      }
     } while(0);
     $2287 = (($r$56378) + -16)|0;
     $2288 = ($2287|0)>(15);
     if ($2288) {
      $buffer$229377 = $buffer$231;$put_bits$142375 = $put_bits$143;$put_buffer$56376 = $2271;$r$56378 = $2287;
     } else {
      break;
     }
    }
    $2289 = $r$55 & 15;
    $buffer$229$lcssa = $buffer$231;$put_bits$142$lcssa = $put_bits$143;$put_buffer$56$lcssa = $2271;$r$56$lcssa = $2289;
   } else {
    $buffer$229$lcssa = $buffer$228;$put_bits$142$lcssa = $put_bits$141;$put_buffer$56$lcssa = $put_buffer$55;$r$56$lcssa = $r$55;
   }
   $2290 = $r$56$lcssa << 4;
   $2291 = (($2290) + ($2267))|0;
   $2292 = (($actbl) + ($2291<<2)|0);
   $2293 = HEAP32[$2292>>2]|0;
   $2294 = ((($actbl) + ($2291)|0) + 1024|0);
   $2295 = HEAP8[$2294>>0]|0;
   $2296 = $2295 << 24 >> 24;
   $2297 = 1 << $2267;
   $2298 = (($2297) + -1)|0;
   $2299 = $2298 & $2264;
   $2300 = (($2296) + ($put_bits$142$lcssa))|0;
   $2301 = $put_buffer$56$lcssa << $2296;
   $2302 = $2301 | $2293;
   $2303 = ($2300|0)>(15);
   do {
    if ($2303) {
     $2304 = (($2300) + -8)|0;
     $2305 = $2302 >>> $2304;
     $2306 = $2305&255;
     $2307 = (($buffer$229$lcssa) + 1|0);
     HEAP8[$buffer$229$lcssa>>0] = $2306;
     $2308 = $2305 & 255;
     $2309 = ($2308|0)==(255);
     if ($2309) {
      $2310 = (($buffer$229$lcssa) + 2|0);
      HEAP8[$2307>>0] = 0;
      $buffer$232 = $2310;
     } else {
      $buffer$232 = $2307;
     }
     $2311 = (($2300) + -16)|0;
     $2312 = $2302 >>> $2311;
     $2313 = $2312&255;
     $2314 = (($buffer$232) + 1|0);
     HEAP8[$buffer$232>>0] = $2313;
     $2315 = $2312 & 255;
     $2316 = ($2315|0)==(255);
     if (!($2316)) {
      $buffer$233 = $2314;$put_bits$144 = $2311;
      break;
     }
     $2317 = (($buffer$232) + 2|0);
     HEAP8[$2314>>0] = 0;
     $buffer$233 = $2317;$put_bits$144 = $2311;
    } else {
     $buffer$233 = $buffer$229$lcssa;$put_bits$144 = $2300;
    }
   } while(0);
   $2318 = (($put_bits$144) + ($2267))|0;
   $2319 = $2302 << $2267;
   $2320 = $2319 | $2299;
   $2321 = ($2318|0)>(15);
   if (!($2321)) {
    $buffer$236 = $buffer$233;$put_bits$146 = $2318;$put_buffer$57 = $2320;$r$57 = 0;
    break;
   }
   $2322 = (($2318) + -8)|0;
   $2323 = $2320 >>> $2322;
   $2324 = $2323&255;
   $2325 = (($buffer$233) + 1|0);
   HEAP8[$buffer$233>>0] = $2324;
   $2326 = $2323 & 255;
   $2327 = ($2326|0)==(255);
   if ($2327) {
    $2328 = (($buffer$233) + 2|0);
    HEAP8[$2325>>0] = 0;
    $buffer$234 = $2328;
   } else {
    $buffer$234 = $2325;
   }
   $2329 = (($2318) + -16)|0;
   $2330 = $2320 >>> $2329;
   $2331 = $2330&255;
   $2332 = (($buffer$234) + 1|0);
   HEAP8[$buffer$234>>0] = $2331;
   $2333 = $2330 & 255;
   $2334 = ($2333|0)==(255);
   if (!($2334)) {
    $buffer$236 = $2332;$put_bits$146 = $2329;$put_buffer$57 = $2320;$r$57 = 0;
    break;
   }
   $2335 = (($buffer$234) + 2|0);
   HEAP8[$2332>>0] = 0;
   $buffer$236 = $2335;$put_bits$146 = $2329;$put_buffer$57 = $2320;$r$57 = 0;
  }
 } while(0);
 $2336 = (($block) + 42|0);
 $2337 = HEAP16[$2336>>1]|0;
 $2338 = $2337 << 16 >> 16;
 $2339 = ($2337<<16>>16)==(0);
 do {
  if ($2339) {
   $2340 = (($r$57) + 1)|0;
   $buffer$244 = $buffer$236;$put_bits$151 = $put_bits$146;$put_buffer$59 = $put_buffer$57;$r$59 = $2340;
  } else {
   $2341 = $2338 >> 31;
   $2342 = $2341 ^ $2338;
   $2343 = (($2342) - ($2341))|0;
   $2344 = (($2341) + ($2338))|0;
   $2345 = (66264 + ($2343)|0);
   $2346 = HEAP8[$2345>>0]|0;
   $2347 = $2346&255;
   $2348 = ($r$57|0)>(15);
   if ($2348) {
    $buffer$237366 = $buffer$236;$put_bits$147364 = $put_bits$146;$put_buffer$58365 = $put_buffer$57;$r$58367 = $r$57;
    while(1) {
     $2349 = (($put_bits$147364) + ($4))|0;
     $2350 = $put_buffer$58365 << $4;
     $2351 = $2350 | $1;
     $2352 = ($2349|0)>(15);
     do {
      if ($2352) {
       $2353 = (($2349) + -8)|0;
       $2354 = $2351 >>> $2353;
       $2355 = $2354&255;
       $2356 = (($buffer$237366) + 1|0);
       HEAP8[$buffer$237366>>0] = $2355;
       $2357 = $2354 & 255;
       $2358 = ($2357|0)==(255);
       if ($2358) {
        $2359 = (($buffer$237366) + 2|0);
        HEAP8[$2356>>0] = 0;
        $buffer$238 = $2359;
       } else {
        $buffer$238 = $2356;
       }
       $2360 = (($2349) + -16)|0;
       $2361 = $2351 >>> $2360;
       $2362 = $2361&255;
       $2363 = (($buffer$238) + 1|0);
       HEAP8[$buffer$238>>0] = $2362;
       $2364 = $2361 & 255;
       $2365 = ($2364|0)==(255);
       if (!($2365)) {
        $buffer$239 = $2363;$put_bits$148 = $2360;
        break;
       }
       $2366 = (($buffer$238) + 2|0);
       HEAP8[$2363>>0] = 0;
       $buffer$239 = $2366;$put_bits$148 = $2360;
      } else {
       $buffer$239 = $buffer$237366;$put_bits$148 = $2349;
      }
     } while(0);
     $2367 = (($r$58367) + -16)|0;
     $2368 = ($2367|0)>(15);
     if ($2368) {
      $buffer$237366 = $buffer$239;$put_bits$147364 = $put_bits$148;$put_buffer$58365 = $2351;$r$58367 = $2367;
     } else {
      break;
     }
    }
    $2369 = $r$57 & 15;
    $buffer$237$lcssa = $buffer$239;$put_bits$147$lcssa = $put_bits$148;$put_buffer$58$lcssa = $2351;$r$58$lcssa = $2369;
   } else {
    $buffer$237$lcssa = $buffer$236;$put_bits$147$lcssa = $put_bits$146;$put_buffer$58$lcssa = $put_buffer$57;$r$58$lcssa = $r$57;
   }
   $2370 = $r$58$lcssa << 4;
   $2371 = (($2370) + ($2347))|0;
   $2372 = (($actbl) + ($2371<<2)|0);
   $2373 = HEAP32[$2372>>2]|0;
   $2374 = ((($actbl) + ($2371)|0) + 1024|0);
   $2375 = HEAP8[$2374>>0]|0;
   $2376 = $2375 << 24 >> 24;
   $2377 = 1 << $2347;
   $2378 = (($2377) + -1)|0;
   $2379 = $2378 & $2344;
   $2380 = (($2376) + ($put_bits$147$lcssa))|0;
   $2381 = $put_buffer$58$lcssa << $2376;
   $2382 = $2381 | $2373;
   $2383 = ($2380|0)>(15);
   do {
    if ($2383) {
     $2384 = (($2380) + -8)|0;
     $2385 = $2382 >>> $2384;
     $2386 = $2385&255;
     $2387 = (($buffer$237$lcssa) + 1|0);
     HEAP8[$buffer$237$lcssa>>0] = $2386;
     $2388 = $2385 & 255;
     $2389 = ($2388|0)==(255);
     if ($2389) {
      $2390 = (($buffer$237$lcssa) + 2|0);
      HEAP8[$2387>>0] = 0;
      $buffer$240 = $2390;
     } else {
      $buffer$240 = $2387;
     }
     $2391 = (($2380) + -16)|0;
     $2392 = $2382 >>> $2391;
     $2393 = $2392&255;
     $2394 = (($buffer$240) + 1|0);
     HEAP8[$buffer$240>>0] = $2393;
     $2395 = $2392 & 255;
     $2396 = ($2395|0)==(255);
     if (!($2396)) {
      $buffer$241 = $2394;$put_bits$149 = $2391;
      break;
     }
     $2397 = (($buffer$240) + 2|0);
     HEAP8[$2394>>0] = 0;
     $buffer$241 = $2397;$put_bits$149 = $2391;
    } else {
     $buffer$241 = $buffer$237$lcssa;$put_bits$149 = $2380;
    }
   } while(0);
   $2398 = (($put_bits$149) + ($2347))|0;
   $2399 = $2382 << $2347;
   $2400 = $2399 | $2379;
   $2401 = ($2398|0)>(15);
   if (!($2401)) {
    $buffer$244 = $buffer$241;$put_bits$151 = $2398;$put_buffer$59 = $2400;$r$59 = 0;
    break;
   }
   $2402 = (($2398) + -8)|0;
   $2403 = $2400 >>> $2402;
   $2404 = $2403&255;
   $2405 = (($buffer$241) + 1|0);
   HEAP8[$buffer$241>>0] = $2404;
   $2406 = $2403 & 255;
   $2407 = ($2406|0)==(255);
   if ($2407) {
    $2408 = (($buffer$241) + 2|0);
    HEAP8[$2405>>0] = 0;
    $buffer$242 = $2408;
   } else {
    $buffer$242 = $2405;
   }
   $2409 = (($2398) + -16)|0;
   $2410 = $2400 >>> $2409;
   $2411 = $2410&255;
   $2412 = (($buffer$242) + 1|0);
   HEAP8[$buffer$242>>0] = $2411;
   $2413 = $2410 & 255;
   $2414 = ($2413|0)==(255);
   if (!($2414)) {
    $buffer$244 = $2412;$put_bits$151 = $2409;$put_buffer$59 = $2400;$r$59 = 0;
    break;
   }
   $2415 = (($buffer$242) + 2|0);
   HEAP8[$2412>>0] = 0;
   $buffer$244 = $2415;$put_bits$151 = $2409;$put_buffer$59 = $2400;$r$59 = 0;
  }
 } while(0);
 $2416 = (($block) + 56|0);
 $2417 = HEAP16[$2416>>1]|0;
 $2418 = $2417 << 16 >> 16;
 $2419 = ($2417<<16>>16)==(0);
 do {
  if ($2419) {
   $2420 = (($r$59) + 1)|0;
   $buffer$252 = $buffer$244;$put_bits$156 = $put_bits$151;$put_buffer$61 = $put_buffer$59;$r$61 = $2420;
  } else {
   $2421 = $2418 >> 31;
   $2422 = $2421 ^ $2418;
   $2423 = (($2422) - ($2421))|0;
   $2424 = (($2421) + ($2418))|0;
   $2425 = (66264 + ($2423)|0);
   $2426 = HEAP8[$2425>>0]|0;
   $2427 = $2426&255;
   $2428 = ($r$59|0)>(15);
   if ($2428) {
    $buffer$245355 = $buffer$244;$put_bits$152353 = $put_bits$151;$put_buffer$60354 = $put_buffer$59;$r$60356 = $r$59;
    while(1) {
     $2429 = (($put_bits$152353) + ($4))|0;
     $2430 = $put_buffer$60354 << $4;
     $2431 = $2430 | $1;
     $2432 = ($2429|0)>(15);
     do {
      if ($2432) {
       $2433 = (($2429) + -8)|0;
       $2434 = $2431 >>> $2433;
       $2435 = $2434&255;
       $2436 = (($buffer$245355) + 1|0);
       HEAP8[$buffer$245355>>0] = $2435;
       $2437 = $2434 & 255;
       $2438 = ($2437|0)==(255);
       if ($2438) {
        $2439 = (($buffer$245355) + 2|0);
        HEAP8[$2436>>0] = 0;
        $buffer$246 = $2439;
       } else {
        $buffer$246 = $2436;
       }
       $2440 = (($2429) + -16)|0;
       $2441 = $2431 >>> $2440;
       $2442 = $2441&255;
       $2443 = (($buffer$246) + 1|0);
       HEAP8[$buffer$246>>0] = $2442;
       $2444 = $2441 & 255;
       $2445 = ($2444|0)==(255);
       if (!($2445)) {
        $buffer$247 = $2443;$put_bits$153 = $2440;
        break;
       }
       $2446 = (($buffer$246) + 2|0);
       HEAP8[$2443>>0] = 0;
       $buffer$247 = $2446;$put_bits$153 = $2440;
      } else {
       $buffer$247 = $buffer$245355;$put_bits$153 = $2429;
      }
     } while(0);
     $2447 = (($r$60356) + -16)|0;
     $2448 = ($2447|0)>(15);
     if ($2448) {
      $buffer$245355 = $buffer$247;$put_bits$152353 = $put_bits$153;$put_buffer$60354 = $2431;$r$60356 = $2447;
     } else {
      break;
     }
    }
    $2449 = $r$59 & 15;
    $buffer$245$lcssa = $buffer$247;$put_bits$152$lcssa = $put_bits$153;$put_buffer$60$lcssa = $2431;$r$60$lcssa = $2449;
   } else {
    $buffer$245$lcssa = $buffer$244;$put_bits$152$lcssa = $put_bits$151;$put_buffer$60$lcssa = $put_buffer$59;$r$60$lcssa = $r$59;
   }
   $2450 = $r$60$lcssa << 4;
   $2451 = (($2450) + ($2427))|0;
   $2452 = (($actbl) + ($2451<<2)|0);
   $2453 = HEAP32[$2452>>2]|0;
   $2454 = ((($actbl) + ($2451)|0) + 1024|0);
   $2455 = HEAP8[$2454>>0]|0;
   $2456 = $2455 << 24 >> 24;
   $2457 = 1 << $2427;
   $2458 = (($2457) + -1)|0;
   $2459 = $2458 & $2424;
   $2460 = (($2456) + ($put_bits$152$lcssa))|0;
   $2461 = $put_buffer$60$lcssa << $2456;
   $2462 = $2461 | $2453;
   $2463 = ($2460|0)>(15);
   do {
    if ($2463) {
     $2464 = (($2460) + -8)|0;
     $2465 = $2462 >>> $2464;
     $2466 = $2465&255;
     $2467 = (($buffer$245$lcssa) + 1|0);
     HEAP8[$buffer$245$lcssa>>0] = $2466;
     $2468 = $2465 & 255;
     $2469 = ($2468|0)==(255);
     if ($2469) {
      $2470 = (($buffer$245$lcssa) + 2|0);
      HEAP8[$2467>>0] = 0;
      $buffer$248 = $2470;
     } else {
      $buffer$248 = $2467;
     }
     $2471 = (($2460) + -16)|0;
     $2472 = $2462 >>> $2471;
     $2473 = $2472&255;
     $2474 = (($buffer$248) + 1|0);
     HEAP8[$buffer$248>>0] = $2473;
     $2475 = $2472 & 255;
     $2476 = ($2475|0)==(255);
     if (!($2476)) {
      $buffer$249 = $2474;$put_bits$154 = $2471;
      break;
     }
     $2477 = (($buffer$248) + 2|0);
     HEAP8[$2474>>0] = 0;
     $buffer$249 = $2477;$put_bits$154 = $2471;
    } else {
     $buffer$249 = $buffer$245$lcssa;$put_bits$154 = $2460;
    }
   } while(0);
   $2478 = (($put_bits$154) + ($2427))|0;
   $2479 = $2462 << $2427;
   $2480 = $2479 | $2459;
   $2481 = ($2478|0)>(15);
   if (!($2481)) {
    $buffer$252 = $buffer$249;$put_bits$156 = $2478;$put_buffer$61 = $2480;$r$61 = 0;
    break;
   }
   $2482 = (($2478) + -8)|0;
   $2483 = $2480 >>> $2482;
   $2484 = $2483&255;
   $2485 = (($buffer$249) + 1|0);
   HEAP8[$buffer$249>>0] = $2484;
   $2486 = $2483 & 255;
   $2487 = ($2486|0)==(255);
   if ($2487) {
    $2488 = (($buffer$249) + 2|0);
    HEAP8[$2485>>0] = 0;
    $buffer$250 = $2488;
   } else {
    $buffer$250 = $2485;
   }
   $2489 = (($2478) + -16)|0;
   $2490 = $2480 >>> $2489;
   $2491 = $2490&255;
   $2492 = (($buffer$250) + 1|0);
   HEAP8[$buffer$250>>0] = $2491;
   $2493 = $2490 & 255;
   $2494 = ($2493|0)==(255);
   if (!($2494)) {
    $buffer$252 = $2492;$put_bits$156 = $2489;$put_buffer$61 = $2480;$r$61 = 0;
    break;
   }
   $2495 = (($buffer$250) + 2|0);
   HEAP8[$2492>>0] = 0;
   $buffer$252 = $2495;$put_bits$156 = $2489;$put_buffer$61 = $2480;$r$61 = 0;
  }
 } while(0);
 $2496 = (($block) + 70|0);
 $2497 = HEAP16[$2496>>1]|0;
 $2498 = $2497 << 16 >> 16;
 $2499 = ($2497<<16>>16)==(0);
 do {
  if ($2499) {
   $2500 = (($r$61) + 1)|0;
   $buffer$260 = $buffer$252;$put_bits$161 = $put_bits$156;$put_buffer$63 = $put_buffer$61;$r$63 = $2500;
  } else {
   $2501 = $2498 >> 31;
   $2502 = $2501 ^ $2498;
   $2503 = (($2502) - ($2501))|0;
   $2504 = (($2501) + ($2498))|0;
   $2505 = (66264 + ($2503)|0);
   $2506 = HEAP8[$2505>>0]|0;
   $2507 = $2506&255;
   $2508 = ($r$61|0)>(15);
   if ($2508) {
    $buffer$253344 = $buffer$252;$put_bits$157342 = $put_bits$156;$put_buffer$62343 = $put_buffer$61;$r$62345 = $r$61;
    while(1) {
     $2509 = (($put_bits$157342) + ($4))|0;
     $2510 = $put_buffer$62343 << $4;
     $2511 = $2510 | $1;
     $2512 = ($2509|0)>(15);
     do {
      if ($2512) {
       $2513 = (($2509) + -8)|0;
       $2514 = $2511 >>> $2513;
       $2515 = $2514&255;
       $2516 = (($buffer$253344) + 1|0);
       HEAP8[$buffer$253344>>0] = $2515;
       $2517 = $2514 & 255;
       $2518 = ($2517|0)==(255);
       if ($2518) {
        $2519 = (($buffer$253344) + 2|0);
        HEAP8[$2516>>0] = 0;
        $buffer$254 = $2519;
       } else {
        $buffer$254 = $2516;
       }
       $2520 = (($2509) + -16)|0;
       $2521 = $2511 >>> $2520;
       $2522 = $2521&255;
       $2523 = (($buffer$254) + 1|0);
       HEAP8[$buffer$254>>0] = $2522;
       $2524 = $2521 & 255;
       $2525 = ($2524|0)==(255);
       if (!($2525)) {
        $buffer$255 = $2523;$put_bits$158 = $2520;
        break;
       }
       $2526 = (($buffer$254) + 2|0);
       HEAP8[$2523>>0] = 0;
       $buffer$255 = $2526;$put_bits$158 = $2520;
      } else {
       $buffer$255 = $buffer$253344;$put_bits$158 = $2509;
      }
     } while(0);
     $2527 = (($r$62345) + -16)|0;
     $2528 = ($2527|0)>(15);
     if ($2528) {
      $buffer$253344 = $buffer$255;$put_bits$157342 = $put_bits$158;$put_buffer$62343 = $2511;$r$62345 = $2527;
     } else {
      break;
     }
    }
    $2529 = $r$61 & 15;
    $buffer$253$lcssa = $buffer$255;$put_bits$157$lcssa = $put_bits$158;$put_buffer$62$lcssa = $2511;$r$62$lcssa = $2529;
   } else {
    $buffer$253$lcssa = $buffer$252;$put_bits$157$lcssa = $put_bits$156;$put_buffer$62$lcssa = $put_buffer$61;$r$62$lcssa = $r$61;
   }
   $2530 = $r$62$lcssa << 4;
   $2531 = (($2530) + ($2507))|0;
   $2532 = (($actbl) + ($2531<<2)|0);
   $2533 = HEAP32[$2532>>2]|0;
   $2534 = ((($actbl) + ($2531)|0) + 1024|0);
   $2535 = HEAP8[$2534>>0]|0;
   $2536 = $2535 << 24 >> 24;
   $2537 = 1 << $2507;
   $2538 = (($2537) + -1)|0;
   $2539 = $2538 & $2504;
   $2540 = (($2536) + ($put_bits$157$lcssa))|0;
   $2541 = $put_buffer$62$lcssa << $2536;
   $2542 = $2541 | $2533;
   $2543 = ($2540|0)>(15);
   do {
    if ($2543) {
     $2544 = (($2540) + -8)|0;
     $2545 = $2542 >>> $2544;
     $2546 = $2545&255;
     $2547 = (($buffer$253$lcssa) + 1|0);
     HEAP8[$buffer$253$lcssa>>0] = $2546;
     $2548 = $2545 & 255;
     $2549 = ($2548|0)==(255);
     if ($2549) {
      $2550 = (($buffer$253$lcssa) + 2|0);
      HEAP8[$2547>>0] = 0;
      $buffer$256 = $2550;
     } else {
      $buffer$256 = $2547;
     }
     $2551 = (($2540) + -16)|0;
     $2552 = $2542 >>> $2551;
     $2553 = $2552&255;
     $2554 = (($buffer$256) + 1|0);
     HEAP8[$buffer$256>>0] = $2553;
     $2555 = $2552 & 255;
     $2556 = ($2555|0)==(255);
     if (!($2556)) {
      $buffer$257 = $2554;$put_bits$159 = $2551;
      break;
     }
     $2557 = (($buffer$256) + 2|0);
     HEAP8[$2554>>0] = 0;
     $buffer$257 = $2557;$put_bits$159 = $2551;
    } else {
     $buffer$257 = $buffer$253$lcssa;$put_bits$159 = $2540;
    }
   } while(0);
   $2558 = (($put_bits$159) + ($2507))|0;
   $2559 = $2542 << $2507;
   $2560 = $2559 | $2539;
   $2561 = ($2558|0)>(15);
   if (!($2561)) {
    $buffer$260 = $buffer$257;$put_bits$161 = $2558;$put_buffer$63 = $2560;$r$63 = 0;
    break;
   }
   $2562 = (($2558) + -8)|0;
   $2563 = $2560 >>> $2562;
   $2564 = $2563&255;
   $2565 = (($buffer$257) + 1|0);
   HEAP8[$buffer$257>>0] = $2564;
   $2566 = $2563 & 255;
   $2567 = ($2566|0)==(255);
   if ($2567) {
    $2568 = (($buffer$257) + 2|0);
    HEAP8[$2565>>0] = 0;
    $buffer$258 = $2568;
   } else {
    $buffer$258 = $2565;
   }
   $2569 = (($2558) + -16)|0;
   $2570 = $2560 >>> $2569;
   $2571 = $2570&255;
   $2572 = (($buffer$258) + 1|0);
   HEAP8[$buffer$258>>0] = $2571;
   $2573 = $2570 & 255;
   $2574 = ($2573|0)==(255);
   if (!($2574)) {
    $buffer$260 = $2572;$put_bits$161 = $2569;$put_buffer$63 = $2560;$r$63 = 0;
    break;
   }
   $2575 = (($buffer$258) + 2|0);
   HEAP8[$2572>>0] = 0;
   $buffer$260 = $2575;$put_bits$161 = $2569;$put_buffer$63 = $2560;$r$63 = 0;
  }
 } while(0);
 $2576 = (($block) + 84|0);
 $2577 = HEAP16[$2576>>1]|0;
 $2578 = $2577 << 16 >> 16;
 $2579 = ($2577<<16>>16)==(0);
 do {
  if ($2579) {
   $2580 = (($r$63) + 1)|0;
   $buffer$268 = $buffer$260;$put_bits$166 = $put_bits$161;$put_buffer$65 = $put_buffer$63;$r$65 = $2580;
  } else {
   $2581 = $2578 >> 31;
   $2582 = $2581 ^ $2578;
   $2583 = (($2582) - ($2581))|0;
   $2584 = (($2581) + ($2578))|0;
   $2585 = (66264 + ($2583)|0);
   $2586 = HEAP8[$2585>>0]|0;
   $2587 = $2586&255;
   $2588 = ($r$63|0)>(15);
   if ($2588) {
    $buffer$261333 = $buffer$260;$put_bits$162331 = $put_bits$161;$put_buffer$64332 = $put_buffer$63;$r$64334 = $r$63;
    while(1) {
     $2589 = (($put_bits$162331) + ($4))|0;
     $2590 = $put_buffer$64332 << $4;
     $2591 = $2590 | $1;
     $2592 = ($2589|0)>(15);
     do {
      if ($2592) {
       $2593 = (($2589) + -8)|0;
       $2594 = $2591 >>> $2593;
       $2595 = $2594&255;
       $2596 = (($buffer$261333) + 1|0);
       HEAP8[$buffer$261333>>0] = $2595;
       $2597 = $2594 & 255;
       $2598 = ($2597|0)==(255);
       if ($2598) {
        $2599 = (($buffer$261333) + 2|0);
        HEAP8[$2596>>0] = 0;
        $buffer$262 = $2599;
       } else {
        $buffer$262 = $2596;
       }
       $2600 = (($2589) + -16)|0;
       $2601 = $2591 >>> $2600;
       $2602 = $2601&255;
       $2603 = (($buffer$262) + 1|0);
       HEAP8[$buffer$262>>0] = $2602;
       $2604 = $2601 & 255;
       $2605 = ($2604|0)==(255);
       if (!($2605)) {
        $buffer$263 = $2603;$put_bits$163 = $2600;
        break;
       }
       $2606 = (($buffer$262) + 2|0);
       HEAP8[$2603>>0] = 0;
       $buffer$263 = $2606;$put_bits$163 = $2600;
      } else {
       $buffer$263 = $buffer$261333;$put_bits$163 = $2589;
      }
     } while(0);
     $2607 = (($r$64334) + -16)|0;
     $2608 = ($2607|0)>(15);
     if ($2608) {
      $buffer$261333 = $buffer$263;$put_bits$162331 = $put_bits$163;$put_buffer$64332 = $2591;$r$64334 = $2607;
     } else {
      break;
     }
    }
    $2609 = $r$63 & 15;
    $buffer$261$lcssa = $buffer$263;$put_bits$162$lcssa = $put_bits$163;$put_buffer$64$lcssa = $2591;$r$64$lcssa = $2609;
   } else {
    $buffer$261$lcssa = $buffer$260;$put_bits$162$lcssa = $put_bits$161;$put_buffer$64$lcssa = $put_buffer$63;$r$64$lcssa = $r$63;
   }
   $2610 = $r$64$lcssa << 4;
   $2611 = (($2610) + ($2587))|0;
   $2612 = (($actbl) + ($2611<<2)|0);
   $2613 = HEAP32[$2612>>2]|0;
   $2614 = ((($actbl) + ($2611)|0) + 1024|0);
   $2615 = HEAP8[$2614>>0]|0;
   $2616 = $2615 << 24 >> 24;
   $2617 = 1 << $2587;
   $2618 = (($2617) + -1)|0;
   $2619 = $2618 & $2584;
   $2620 = (($2616) + ($put_bits$162$lcssa))|0;
   $2621 = $put_buffer$64$lcssa << $2616;
   $2622 = $2621 | $2613;
   $2623 = ($2620|0)>(15);
   do {
    if ($2623) {
     $2624 = (($2620) + -8)|0;
     $2625 = $2622 >>> $2624;
     $2626 = $2625&255;
     $2627 = (($buffer$261$lcssa) + 1|0);
     HEAP8[$buffer$261$lcssa>>0] = $2626;
     $2628 = $2625 & 255;
     $2629 = ($2628|0)==(255);
     if ($2629) {
      $2630 = (($buffer$261$lcssa) + 2|0);
      HEAP8[$2627>>0] = 0;
      $buffer$264 = $2630;
     } else {
      $buffer$264 = $2627;
     }
     $2631 = (($2620) + -16)|0;
     $2632 = $2622 >>> $2631;
     $2633 = $2632&255;
     $2634 = (($buffer$264) + 1|0);
     HEAP8[$buffer$264>>0] = $2633;
     $2635 = $2632 & 255;
     $2636 = ($2635|0)==(255);
     if (!($2636)) {
      $buffer$265 = $2634;$put_bits$164 = $2631;
      break;
     }
     $2637 = (($buffer$264) + 2|0);
     HEAP8[$2634>>0] = 0;
     $buffer$265 = $2637;$put_bits$164 = $2631;
    } else {
     $buffer$265 = $buffer$261$lcssa;$put_bits$164 = $2620;
    }
   } while(0);
   $2638 = (($put_bits$164) + ($2587))|0;
   $2639 = $2622 << $2587;
   $2640 = $2639 | $2619;
   $2641 = ($2638|0)>(15);
   if (!($2641)) {
    $buffer$268 = $buffer$265;$put_bits$166 = $2638;$put_buffer$65 = $2640;$r$65 = 0;
    break;
   }
   $2642 = (($2638) + -8)|0;
   $2643 = $2640 >>> $2642;
   $2644 = $2643&255;
   $2645 = (($buffer$265) + 1|0);
   HEAP8[$buffer$265>>0] = $2644;
   $2646 = $2643 & 255;
   $2647 = ($2646|0)==(255);
   if ($2647) {
    $2648 = (($buffer$265) + 2|0);
    HEAP8[$2645>>0] = 0;
    $buffer$266 = $2648;
   } else {
    $buffer$266 = $2645;
   }
   $2649 = (($2638) + -16)|0;
   $2650 = $2640 >>> $2649;
   $2651 = $2650&255;
   $2652 = (($buffer$266) + 1|0);
   HEAP8[$buffer$266>>0] = $2651;
   $2653 = $2650 & 255;
   $2654 = ($2653|0)==(255);
   if (!($2654)) {
    $buffer$268 = $2652;$put_bits$166 = $2649;$put_buffer$65 = $2640;$r$65 = 0;
    break;
   }
   $2655 = (($buffer$266) + 2|0);
   HEAP8[$2652>>0] = 0;
   $buffer$268 = $2655;$put_bits$166 = $2649;$put_buffer$65 = $2640;$r$65 = 0;
  }
 } while(0);
 $2656 = (($block) + 98|0);
 $2657 = HEAP16[$2656>>1]|0;
 $2658 = $2657 << 16 >> 16;
 $2659 = ($2657<<16>>16)==(0);
 do {
  if ($2659) {
   $2660 = (($r$65) + 1)|0;
   $buffer$276 = $buffer$268;$put_bits$171 = $put_bits$166;$put_buffer$67 = $put_buffer$65;$r$67 = $2660;
  } else {
   $2661 = $2658 >> 31;
   $2662 = $2661 ^ $2658;
   $2663 = (($2662) - ($2661))|0;
   $2664 = (($2661) + ($2658))|0;
   $2665 = (66264 + ($2663)|0);
   $2666 = HEAP8[$2665>>0]|0;
   $2667 = $2666&255;
   $2668 = ($r$65|0)>(15);
   if ($2668) {
    $buffer$269322 = $buffer$268;$put_bits$167320 = $put_bits$166;$put_buffer$66321 = $put_buffer$65;$r$66323 = $r$65;
    while(1) {
     $2669 = (($put_bits$167320) + ($4))|0;
     $2670 = $put_buffer$66321 << $4;
     $2671 = $2670 | $1;
     $2672 = ($2669|0)>(15);
     do {
      if ($2672) {
       $2673 = (($2669) + -8)|0;
       $2674 = $2671 >>> $2673;
       $2675 = $2674&255;
       $2676 = (($buffer$269322) + 1|0);
       HEAP8[$buffer$269322>>0] = $2675;
       $2677 = $2674 & 255;
       $2678 = ($2677|0)==(255);
       if ($2678) {
        $2679 = (($buffer$269322) + 2|0);
        HEAP8[$2676>>0] = 0;
        $buffer$270 = $2679;
       } else {
        $buffer$270 = $2676;
       }
       $2680 = (($2669) + -16)|0;
       $2681 = $2671 >>> $2680;
       $2682 = $2681&255;
       $2683 = (($buffer$270) + 1|0);
       HEAP8[$buffer$270>>0] = $2682;
       $2684 = $2681 & 255;
       $2685 = ($2684|0)==(255);
       if (!($2685)) {
        $buffer$271 = $2683;$put_bits$168 = $2680;
        break;
       }
       $2686 = (($buffer$270) + 2|0);
       HEAP8[$2683>>0] = 0;
       $buffer$271 = $2686;$put_bits$168 = $2680;
      } else {
       $buffer$271 = $buffer$269322;$put_bits$168 = $2669;
      }
     } while(0);
     $2687 = (($r$66323) + -16)|0;
     $2688 = ($2687|0)>(15);
     if ($2688) {
      $buffer$269322 = $buffer$271;$put_bits$167320 = $put_bits$168;$put_buffer$66321 = $2671;$r$66323 = $2687;
     } else {
      break;
     }
    }
    $2689 = $r$65 & 15;
    $buffer$269$lcssa = $buffer$271;$put_bits$167$lcssa = $put_bits$168;$put_buffer$66$lcssa = $2671;$r$66$lcssa = $2689;
   } else {
    $buffer$269$lcssa = $buffer$268;$put_bits$167$lcssa = $put_bits$166;$put_buffer$66$lcssa = $put_buffer$65;$r$66$lcssa = $r$65;
   }
   $2690 = $r$66$lcssa << 4;
   $2691 = (($2690) + ($2667))|0;
   $2692 = (($actbl) + ($2691<<2)|0);
   $2693 = HEAP32[$2692>>2]|0;
   $2694 = ((($actbl) + ($2691)|0) + 1024|0);
   $2695 = HEAP8[$2694>>0]|0;
   $2696 = $2695 << 24 >> 24;
   $2697 = 1 << $2667;
   $2698 = (($2697) + -1)|0;
   $2699 = $2698 & $2664;
   $2700 = (($2696) + ($put_bits$167$lcssa))|0;
   $2701 = $put_buffer$66$lcssa << $2696;
   $2702 = $2701 | $2693;
   $2703 = ($2700|0)>(15);
   do {
    if ($2703) {
     $2704 = (($2700) + -8)|0;
     $2705 = $2702 >>> $2704;
     $2706 = $2705&255;
     $2707 = (($buffer$269$lcssa) + 1|0);
     HEAP8[$buffer$269$lcssa>>0] = $2706;
     $2708 = $2705 & 255;
     $2709 = ($2708|0)==(255);
     if ($2709) {
      $2710 = (($buffer$269$lcssa) + 2|0);
      HEAP8[$2707>>0] = 0;
      $buffer$272 = $2710;
     } else {
      $buffer$272 = $2707;
     }
     $2711 = (($2700) + -16)|0;
     $2712 = $2702 >>> $2711;
     $2713 = $2712&255;
     $2714 = (($buffer$272) + 1|0);
     HEAP8[$buffer$272>>0] = $2713;
     $2715 = $2712 & 255;
     $2716 = ($2715|0)==(255);
     if (!($2716)) {
      $buffer$273 = $2714;$put_bits$169 = $2711;
      break;
     }
     $2717 = (($buffer$272) + 2|0);
     HEAP8[$2714>>0] = 0;
     $buffer$273 = $2717;$put_bits$169 = $2711;
    } else {
     $buffer$273 = $buffer$269$lcssa;$put_bits$169 = $2700;
    }
   } while(0);
   $2718 = (($put_bits$169) + ($2667))|0;
   $2719 = $2702 << $2667;
   $2720 = $2719 | $2699;
   $2721 = ($2718|0)>(15);
   if (!($2721)) {
    $buffer$276 = $buffer$273;$put_bits$171 = $2718;$put_buffer$67 = $2720;$r$67 = 0;
    break;
   }
   $2722 = (($2718) + -8)|0;
   $2723 = $2720 >>> $2722;
   $2724 = $2723&255;
   $2725 = (($buffer$273) + 1|0);
   HEAP8[$buffer$273>>0] = $2724;
   $2726 = $2723 & 255;
   $2727 = ($2726|0)==(255);
   if ($2727) {
    $2728 = (($buffer$273) + 2|0);
    HEAP8[$2725>>0] = 0;
    $buffer$274 = $2728;
   } else {
    $buffer$274 = $2725;
   }
   $2729 = (($2718) + -16)|0;
   $2730 = $2720 >>> $2729;
   $2731 = $2730&255;
   $2732 = (($buffer$274) + 1|0);
   HEAP8[$buffer$274>>0] = $2731;
   $2733 = $2730 & 255;
   $2734 = ($2733|0)==(255);
   if (!($2734)) {
    $buffer$276 = $2732;$put_bits$171 = $2729;$put_buffer$67 = $2720;$r$67 = 0;
    break;
   }
   $2735 = (($buffer$274) + 2|0);
   HEAP8[$2732>>0] = 0;
   $buffer$276 = $2735;$put_bits$171 = $2729;$put_buffer$67 = $2720;$r$67 = 0;
  }
 } while(0);
 $2736 = (($block) + 112|0);
 $2737 = HEAP16[$2736>>1]|0;
 $2738 = $2737 << 16 >> 16;
 $2739 = ($2737<<16>>16)==(0);
 do {
  if ($2739) {
   $2740 = (($r$67) + 1)|0;
   $buffer$284 = $buffer$276;$put_bits$176 = $put_bits$171;$put_buffer$69 = $put_buffer$67;$r$69 = $2740;
  } else {
   $2741 = $2738 >> 31;
   $2742 = $2741 ^ $2738;
   $2743 = (($2742) - ($2741))|0;
   $2744 = (($2741) + ($2738))|0;
   $2745 = (66264 + ($2743)|0);
   $2746 = HEAP8[$2745>>0]|0;
   $2747 = $2746&255;
   $2748 = ($r$67|0)>(15);
   if ($2748) {
    $buffer$277311 = $buffer$276;$put_bits$172309 = $put_bits$171;$put_buffer$68310 = $put_buffer$67;$r$68312 = $r$67;
    while(1) {
     $2749 = (($put_bits$172309) + ($4))|0;
     $2750 = $put_buffer$68310 << $4;
     $2751 = $2750 | $1;
     $2752 = ($2749|0)>(15);
     do {
      if ($2752) {
       $2753 = (($2749) + -8)|0;
       $2754 = $2751 >>> $2753;
       $2755 = $2754&255;
       $2756 = (($buffer$277311) + 1|0);
       HEAP8[$buffer$277311>>0] = $2755;
       $2757 = $2754 & 255;
       $2758 = ($2757|0)==(255);
       if ($2758) {
        $2759 = (($buffer$277311) + 2|0);
        HEAP8[$2756>>0] = 0;
        $buffer$278 = $2759;
       } else {
        $buffer$278 = $2756;
       }
       $2760 = (($2749) + -16)|0;
       $2761 = $2751 >>> $2760;
       $2762 = $2761&255;
       $2763 = (($buffer$278) + 1|0);
       HEAP8[$buffer$278>>0] = $2762;
       $2764 = $2761 & 255;
       $2765 = ($2764|0)==(255);
       if (!($2765)) {
        $buffer$279 = $2763;$put_bits$173 = $2760;
        break;
       }
       $2766 = (($buffer$278) + 2|0);
       HEAP8[$2763>>0] = 0;
       $buffer$279 = $2766;$put_bits$173 = $2760;
      } else {
       $buffer$279 = $buffer$277311;$put_bits$173 = $2749;
      }
     } while(0);
     $2767 = (($r$68312) + -16)|0;
     $2768 = ($2767|0)>(15);
     if ($2768) {
      $buffer$277311 = $buffer$279;$put_bits$172309 = $put_bits$173;$put_buffer$68310 = $2751;$r$68312 = $2767;
     } else {
      break;
     }
    }
    $2769 = $r$67 & 15;
    $buffer$277$lcssa = $buffer$279;$put_bits$172$lcssa = $put_bits$173;$put_buffer$68$lcssa = $2751;$r$68$lcssa = $2769;
   } else {
    $buffer$277$lcssa = $buffer$276;$put_bits$172$lcssa = $put_bits$171;$put_buffer$68$lcssa = $put_buffer$67;$r$68$lcssa = $r$67;
   }
   $2770 = $r$68$lcssa << 4;
   $2771 = (($2770) + ($2747))|0;
   $2772 = (($actbl) + ($2771<<2)|0);
   $2773 = HEAP32[$2772>>2]|0;
   $2774 = ((($actbl) + ($2771)|0) + 1024|0);
   $2775 = HEAP8[$2774>>0]|0;
   $2776 = $2775 << 24 >> 24;
   $2777 = 1 << $2747;
   $2778 = (($2777) + -1)|0;
   $2779 = $2778 & $2744;
   $2780 = (($2776) + ($put_bits$172$lcssa))|0;
   $2781 = $put_buffer$68$lcssa << $2776;
   $2782 = $2781 | $2773;
   $2783 = ($2780|0)>(15);
   do {
    if ($2783) {
     $2784 = (($2780) + -8)|0;
     $2785 = $2782 >>> $2784;
     $2786 = $2785&255;
     $2787 = (($buffer$277$lcssa) + 1|0);
     HEAP8[$buffer$277$lcssa>>0] = $2786;
     $2788 = $2785 & 255;
     $2789 = ($2788|0)==(255);
     if ($2789) {
      $2790 = (($buffer$277$lcssa) + 2|0);
      HEAP8[$2787>>0] = 0;
      $buffer$280 = $2790;
     } else {
      $buffer$280 = $2787;
     }
     $2791 = (($2780) + -16)|0;
     $2792 = $2782 >>> $2791;
     $2793 = $2792&255;
     $2794 = (($buffer$280) + 1|0);
     HEAP8[$buffer$280>>0] = $2793;
     $2795 = $2792 & 255;
     $2796 = ($2795|0)==(255);
     if (!($2796)) {
      $buffer$281 = $2794;$put_bits$174 = $2791;
      break;
     }
     $2797 = (($buffer$280) + 2|0);
     HEAP8[$2794>>0] = 0;
     $buffer$281 = $2797;$put_bits$174 = $2791;
    } else {
     $buffer$281 = $buffer$277$lcssa;$put_bits$174 = $2780;
    }
   } while(0);
   $2798 = (($put_bits$174) + ($2747))|0;
   $2799 = $2782 << $2747;
   $2800 = $2799 | $2779;
   $2801 = ($2798|0)>(15);
   if (!($2801)) {
    $buffer$284 = $buffer$281;$put_bits$176 = $2798;$put_buffer$69 = $2800;$r$69 = 0;
    break;
   }
   $2802 = (($2798) + -8)|0;
   $2803 = $2800 >>> $2802;
   $2804 = $2803&255;
   $2805 = (($buffer$281) + 1|0);
   HEAP8[$buffer$281>>0] = $2804;
   $2806 = $2803 & 255;
   $2807 = ($2806|0)==(255);
   if ($2807) {
    $2808 = (($buffer$281) + 2|0);
    HEAP8[$2805>>0] = 0;
    $buffer$282 = $2808;
   } else {
    $buffer$282 = $2805;
   }
   $2809 = (($2798) + -16)|0;
   $2810 = $2800 >>> $2809;
   $2811 = $2810&255;
   $2812 = (($buffer$282) + 1|0);
   HEAP8[$buffer$282>>0] = $2811;
   $2813 = $2810 & 255;
   $2814 = ($2813|0)==(255);
   if (!($2814)) {
    $buffer$284 = $2812;$put_bits$176 = $2809;$put_buffer$69 = $2800;$r$69 = 0;
    break;
   }
   $2815 = (($buffer$282) + 2|0);
   HEAP8[$2812>>0] = 0;
   $buffer$284 = $2815;$put_bits$176 = $2809;$put_buffer$69 = $2800;$r$69 = 0;
  }
 } while(0);
 $2816 = (($block) + 114|0);
 $2817 = HEAP16[$2816>>1]|0;
 $2818 = $2817 << 16 >> 16;
 $2819 = ($2817<<16>>16)==(0);
 do {
  if ($2819) {
   $2820 = (($r$69) + 1)|0;
   $buffer$292 = $buffer$284;$put_bits$181 = $put_bits$176;$put_buffer$71 = $put_buffer$69;$r$71 = $2820;
  } else {
   $2821 = $2818 >> 31;
   $2822 = $2821 ^ $2818;
   $2823 = (($2822) - ($2821))|0;
   $2824 = (($2821) + ($2818))|0;
   $2825 = (66264 + ($2823)|0);
   $2826 = HEAP8[$2825>>0]|0;
   $2827 = $2826&255;
   $2828 = ($r$69|0)>(15);
   if ($2828) {
    $buffer$285300 = $buffer$284;$put_bits$177298 = $put_bits$176;$put_buffer$70299 = $put_buffer$69;$r$70301 = $r$69;
    while(1) {
     $2829 = (($put_bits$177298) + ($4))|0;
     $2830 = $put_buffer$70299 << $4;
     $2831 = $2830 | $1;
     $2832 = ($2829|0)>(15);
     do {
      if ($2832) {
       $2833 = (($2829) + -8)|0;
       $2834 = $2831 >>> $2833;
       $2835 = $2834&255;
       $2836 = (($buffer$285300) + 1|0);
       HEAP8[$buffer$285300>>0] = $2835;
       $2837 = $2834 & 255;
       $2838 = ($2837|0)==(255);
       if ($2838) {
        $2839 = (($buffer$285300) + 2|0);
        HEAP8[$2836>>0] = 0;
        $buffer$286 = $2839;
       } else {
        $buffer$286 = $2836;
       }
       $2840 = (($2829) + -16)|0;
       $2841 = $2831 >>> $2840;
       $2842 = $2841&255;
       $2843 = (($buffer$286) + 1|0);
       HEAP8[$buffer$286>>0] = $2842;
       $2844 = $2841 & 255;
       $2845 = ($2844|0)==(255);
       if (!($2845)) {
        $buffer$287 = $2843;$put_bits$178 = $2840;
        break;
       }
       $2846 = (($buffer$286) + 2|0);
       HEAP8[$2843>>0] = 0;
       $buffer$287 = $2846;$put_bits$178 = $2840;
      } else {
       $buffer$287 = $buffer$285300;$put_bits$178 = $2829;
      }
     } while(0);
     $2847 = (($r$70301) + -16)|0;
     $2848 = ($2847|0)>(15);
     if ($2848) {
      $buffer$285300 = $buffer$287;$put_bits$177298 = $put_bits$178;$put_buffer$70299 = $2831;$r$70301 = $2847;
     } else {
      break;
     }
    }
    $2849 = $r$69 & 15;
    $buffer$285$lcssa = $buffer$287;$put_bits$177$lcssa = $put_bits$178;$put_buffer$70$lcssa = $2831;$r$70$lcssa = $2849;
   } else {
    $buffer$285$lcssa = $buffer$284;$put_bits$177$lcssa = $put_bits$176;$put_buffer$70$lcssa = $put_buffer$69;$r$70$lcssa = $r$69;
   }
   $2850 = $r$70$lcssa << 4;
   $2851 = (($2850) + ($2827))|0;
   $2852 = (($actbl) + ($2851<<2)|0);
   $2853 = HEAP32[$2852>>2]|0;
   $2854 = ((($actbl) + ($2851)|0) + 1024|0);
   $2855 = HEAP8[$2854>>0]|0;
   $2856 = $2855 << 24 >> 24;
   $2857 = 1 << $2827;
   $2858 = (($2857) + -1)|0;
   $2859 = $2858 & $2824;
   $2860 = (($2856) + ($put_bits$177$lcssa))|0;
   $2861 = $put_buffer$70$lcssa << $2856;
   $2862 = $2861 | $2853;
   $2863 = ($2860|0)>(15);
   do {
    if ($2863) {
     $2864 = (($2860) + -8)|0;
     $2865 = $2862 >>> $2864;
     $2866 = $2865&255;
     $2867 = (($buffer$285$lcssa) + 1|0);
     HEAP8[$buffer$285$lcssa>>0] = $2866;
     $2868 = $2865 & 255;
     $2869 = ($2868|0)==(255);
     if ($2869) {
      $2870 = (($buffer$285$lcssa) + 2|0);
      HEAP8[$2867>>0] = 0;
      $buffer$288 = $2870;
     } else {
      $buffer$288 = $2867;
     }
     $2871 = (($2860) + -16)|0;
     $2872 = $2862 >>> $2871;
     $2873 = $2872&255;
     $2874 = (($buffer$288) + 1|0);
     HEAP8[$buffer$288>>0] = $2873;
     $2875 = $2872 & 255;
     $2876 = ($2875|0)==(255);
     if (!($2876)) {
      $buffer$289 = $2874;$put_bits$179 = $2871;
      break;
     }
     $2877 = (($buffer$288) + 2|0);
     HEAP8[$2874>>0] = 0;
     $buffer$289 = $2877;$put_bits$179 = $2871;
    } else {
     $buffer$289 = $buffer$285$lcssa;$put_bits$179 = $2860;
    }
   } while(0);
   $2878 = (($put_bits$179) + ($2827))|0;
   $2879 = $2862 << $2827;
   $2880 = $2879 | $2859;
   $2881 = ($2878|0)>(15);
   if (!($2881)) {
    $buffer$292 = $buffer$289;$put_bits$181 = $2878;$put_buffer$71 = $2880;$r$71 = 0;
    break;
   }
   $2882 = (($2878) + -8)|0;
   $2883 = $2880 >>> $2882;
   $2884 = $2883&255;
   $2885 = (($buffer$289) + 1|0);
   HEAP8[$buffer$289>>0] = $2884;
   $2886 = $2883 & 255;
   $2887 = ($2886|0)==(255);
   if ($2887) {
    $2888 = (($buffer$289) + 2|0);
    HEAP8[$2885>>0] = 0;
    $buffer$290 = $2888;
   } else {
    $buffer$290 = $2885;
   }
   $2889 = (($2878) + -16)|0;
   $2890 = $2880 >>> $2889;
   $2891 = $2890&255;
   $2892 = (($buffer$290) + 1|0);
   HEAP8[$buffer$290>>0] = $2891;
   $2893 = $2890 & 255;
   $2894 = ($2893|0)==(255);
   if (!($2894)) {
    $buffer$292 = $2892;$put_bits$181 = $2889;$put_buffer$71 = $2880;$r$71 = 0;
    break;
   }
   $2895 = (($buffer$290) + 2|0);
   HEAP8[$2892>>0] = 0;
   $buffer$292 = $2895;$put_bits$181 = $2889;$put_buffer$71 = $2880;$r$71 = 0;
  }
 } while(0);
 $2896 = (($block) + 100|0);
 $2897 = HEAP16[$2896>>1]|0;
 $2898 = $2897 << 16 >> 16;
 $2899 = ($2897<<16>>16)==(0);
 do {
  if ($2899) {
   $2900 = (($r$71) + 1)|0;
   $buffer$300 = $buffer$292;$put_bits$186 = $put_bits$181;$put_buffer$73 = $put_buffer$71;$r$73 = $2900;
  } else {
   $2901 = $2898 >> 31;
   $2902 = $2901 ^ $2898;
   $2903 = (($2902) - ($2901))|0;
   $2904 = (($2901) + ($2898))|0;
   $2905 = (66264 + ($2903)|0);
   $2906 = HEAP8[$2905>>0]|0;
   $2907 = $2906&255;
   $2908 = ($r$71|0)>(15);
   if ($2908) {
    $buffer$293289 = $buffer$292;$put_bits$182287 = $put_bits$181;$put_buffer$72288 = $put_buffer$71;$r$72290 = $r$71;
    while(1) {
     $2909 = (($put_bits$182287) + ($4))|0;
     $2910 = $put_buffer$72288 << $4;
     $2911 = $2910 | $1;
     $2912 = ($2909|0)>(15);
     do {
      if ($2912) {
       $2913 = (($2909) + -8)|0;
       $2914 = $2911 >>> $2913;
       $2915 = $2914&255;
       $2916 = (($buffer$293289) + 1|0);
       HEAP8[$buffer$293289>>0] = $2915;
       $2917 = $2914 & 255;
       $2918 = ($2917|0)==(255);
       if ($2918) {
        $2919 = (($buffer$293289) + 2|0);
        HEAP8[$2916>>0] = 0;
        $buffer$294 = $2919;
       } else {
        $buffer$294 = $2916;
       }
       $2920 = (($2909) + -16)|0;
       $2921 = $2911 >>> $2920;
       $2922 = $2921&255;
       $2923 = (($buffer$294) + 1|0);
       HEAP8[$buffer$294>>0] = $2922;
       $2924 = $2921 & 255;
       $2925 = ($2924|0)==(255);
       if (!($2925)) {
        $buffer$295 = $2923;$put_bits$183 = $2920;
        break;
       }
       $2926 = (($buffer$294) + 2|0);
       HEAP8[$2923>>0] = 0;
       $buffer$295 = $2926;$put_bits$183 = $2920;
      } else {
       $buffer$295 = $buffer$293289;$put_bits$183 = $2909;
      }
     } while(0);
     $2927 = (($r$72290) + -16)|0;
     $2928 = ($2927|0)>(15);
     if ($2928) {
      $buffer$293289 = $buffer$295;$put_bits$182287 = $put_bits$183;$put_buffer$72288 = $2911;$r$72290 = $2927;
     } else {
      break;
     }
    }
    $2929 = $r$71 & 15;
    $buffer$293$lcssa = $buffer$295;$put_bits$182$lcssa = $put_bits$183;$put_buffer$72$lcssa = $2911;$r$72$lcssa = $2929;
   } else {
    $buffer$293$lcssa = $buffer$292;$put_bits$182$lcssa = $put_bits$181;$put_buffer$72$lcssa = $put_buffer$71;$r$72$lcssa = $r$71;
   }
   $2930 = $r$72$lcssa << 4;
   $2931 = (($2930) + ($2907))|0;
   $2932 = (($actbl) + ($2931<<2)|0);
   $2933 = HEAP32[$2932>>2]|0;
   $2934 = ((($actbl) + ($2931)|0) + 1024|0);
   $2935 = HEAP8[$2934>>0]|0;
   $2936 = $2935 << 24 >> 24;
   $2937 = 1 << $2907;
   $2938 = (($2937) + -1)|0;
   $2939 = $2938 & $2904;
   $2940 = (($2936) + ($put_bits$182$lcssa))|0;
   $2941 = $put_buffer$72$lcssa << $2936;
   $2942 = $2941 | $2933;
   $2943 = ($2940|0)>(15);
   do {
    if ($2943) {
     $2944 = (($2940) + -8)|0;
     $2945 = $2942 >>> $2944;
     $2946 = $2945&255;
     $2947 = (($buffer$293$lcssa) + 1|0);
     HEAP8[$buffer$293$lcssa>>0] = $2946;
     $2948 = $2945 & 255;
     $2949 = ($2948|0)==(255);
     if ($2949) {
      $2950 = (($buffer$293$lcssa) + 2|0);
      HEAP8[$2947>>0] = 0;
      $buffer$296 = $2950;
     } else {
      $buffer$296 = $2947;
     }
     $2951 = (($2940) + -16)|0;
     $2952 = $2942 >>> $2951;
     $2953 = $2952&255;
     $2954 = (($buffer$296) + 1|0);
     HEAP8[$buffer$296>>0] = $2953;
     $2955 = $2952 & 255;
     $2956 = ($2955|0)==(255);
     if (!($2956)) {
      $buffer$297 = $2954;$put_bits$184 = $2951;
      break;
     }
     $2957 = (($buffer$296) + 2|0);
     HEAP8[$2954>>0] = 0;
     $buffer$297 = $2957;$put_bits$184 = $2951;
    } else {
     $buffer$297 = $buffer$293$lcssa;$put_bits$184 = $2940;
    }
   } while(0);
   $2958 = (($put_bits$184) + ($2907))|0;
   $2959 = $2942 << $2907;
   $2960 = $2959 | $2939;
   $2961 = ($2958|0)>(15);
   if (!($2961)) {
    $buffer$300 = $buffer$297;$put_bits$186 = $2958;$put_buffer$73 = $2960;$r$73 = 0;
    break;
   }
   $2962 = (($2958) + -8)|0;
   $2963 = $2960 >>> $2962;
   $2964 = $2963&255;
   $2965 = (($buffer$297) + 1|0);
   HEAP8[$buffer$297>>0] = $2964;
   $2966 = $2963 & 255;
   $2967 = ($2966|0)==(255);
   if ($2967) {
    $2968 = (($buffer$297) + 2|0);
    HEAP8[$2965>>0] = 0;
    $buffer$298 = $2968;
   } else {
    $buffer$298 = $2965;
   }
   $2969 = (($2958) + -16)|0;
   $2970 = $2960 >>> $2969;
   $2971 = $2970&255;
   $2972 = (($buffer$298) + 1|0);
   HEAP8[$buffer$298>>0] = $2971;
   $2973 = $2970 & 255;
   $2974 = ($2973|0)==(255);
   if (!($2974)) {
    $buffer$300 = $2972;$put_bits$186 = $2969;$put_buffer$73 = $2960;$r$73 = 0;
    break;
   }
   $2975 = (($buffer$298) + 2|0);
   HEAP8[$2972>>0] = 0;
   $buffer$300 = $2975;$put_bits$186 = $2969;$put_buffer$73 = $2960;$r$73 = 0;
  }
 } while(0);
 $2976 = (($block) + 86|0);
 $2977 = HEAP16[$2976>>1]|0;
 $2978 = $2977 << 16 >> 16;
 $2979 = ($2977<<16>>16)==(0);
 do {
  if ($2979) {
   $2980 = (($r$73) + 1)|0;
   $buffer$308 = $buffer$300;$put_bits$191 = $put_bits$186;$put_buffer$75 = $put_buffer$73;$r$75 = $2980;
  } else {
   $2981 = $2978 >> 31;
   $2982 = $2981 ^ $2978;
   $2983 = (($2982) - ($2981))|0;
   $2984 = (($2981) + ($2978))|0;
   $2985 = (66264 + ($2983)|0);
   $2986 = HEAP8[$2985>>0]|0;
   $2987 = $2986&255;
   $2988 = ($r$73|0)>(15);
   if ($2988) {
    $buffer$301278 = $buffer$300;$put_bits$187276 = $put_bits$186;$put_buffer$74277 = $put_buffer$73;$r$74279 = $r$73;
    while(1) {
     $2989 = (($put_bits$187276) + ($4))|0;
     $2990 = $put_buffer$74277 << $4;
     $2991 = $2990 | $1;
     $2992 = ($2989|0)>(15);
     do {
      if ($2992) {
       $2993 = (($2989) + -8)|0;
       $2994 = $2991 >>> $2993;
       $2995 = $2994&255;
       $2996 = (($buffer$301278) + 1|0);
       HEAP8[$buffer$301278>>0] = $2995;
       $2997 = $2994 & 255;
       $2998 = ($2997|0)==(255);
       if ($2998) {
        $2999 = (($buffer$301278) + 2|0);
        HEAP8[$2996>>0] = 0;
        $buffer$302 = $2999;
       } else {
        $buffer$302 = $2996;
       }
       $3000 = (($2989) + -16)|0;
       $3001 = $2991 >>> $3000;
       $3002 = $3001&255;
       $3003 = (($buffer$302) + 1|0);
       HEAP8[$buffer$302>>0] = $3002;
       $3004 = $3001 & 255;
       $3005 = ($3004|0)==(255);
       if (!($3005)) {
        $buffer$303 = $3003;$put_bits$188 = $3000;
        break;
       }
       $3006 = (($buffer$302) + 2|0);
       HEAP8[$3003>>0] = 0;
       $buffer$303 = $3006;$put_bits$188 = $3000;
      } else {
       $buffer$303 = $buffer$301278;$put_bits$188 = $2989;
      }
     } while(0);
     $3007 = (($r$74279) + -16)|0;
     $3008 = ($3007|0)>(15);
     if ($3008) {
      $buffer$301278 = $buffer$303;$put_bits$187276 = $put_bits$188;$put_buffer$74277 = $2991;$r$74279 = $3007;
     } else {
      break;
     }
    }
    $3009 = $r$73 & 15;
    $buffer$301$lcssa = $buffer$303;$put_bits$187$lcssa = $put_bits$188;$put_buffer$74$lcssa = $2991;$r$74$lcssa = $3009;
   } else {
    $buffer$301$lcssa = $buffer$300;$put_bits$187$lcssa = $put_bits$186;$put_buffer$74$lcssa = $put_buffer$73;$r$74$lcssa = $r$73;
   }
   $3010 = $r$74$lcssa << 4;
   $3011 = (($3010) + ($2987))|0;
   $3012 = (($actbl) + ($3011<<2)|0);
   $3013 = HEAP32[$3012>>2]|0;
   $3014 = ((($actbl) + ($3011)|0) + 1024|0);
   $3015 = HEAP8[$3014>>0]|0;
   $3016 = $3015 << 24 >> 24;
   $3017 = 1 << $2987;
   $3018 = (($3017) + -1)|0;
   $3019 = $3018 & $2984;
   $3020 = (($3016) + ($put_bits$187$lcssa))|0;
   $3021 = $put_buffer$74$lcssa << $3016;
   $3022 = $3021 | $3013;
   $3023 = ($3020|0)>(15);
   do {
    if ($3023) {
     $3024 = (($3020) + -8)|0;
     $3025 = $3022 >>> $3024;
     $3026 = $3025&255;
     $3027 = (($buffer$301$lcssa) + 1|0);
     HEAP8[$buffer$301$lcssa>>0] = $3026;
     $3028 = $3025 & 255;
     $3029 = ($3028|0)==(255);
     if ($3029) {
      $3030 = (($buffer$301$lcssa) + 2|0);
      HEAP8[$3027>>0] = 0;
      $buffer$304 = $3030;
     } else {
      $buffer$304 = $3027;
     }
     $3031 = (($3020) + -16)|0;
     $3032 = $3022 >>> $3031;
     $3033 = $3032&255;
     $3034 = (($buffer$304) + 1|0);
     HEAP8[$buffer$304>>0] = $3033;
     $3035 = $3032 & 255;
     $3036 = ($3035|0)==(255);
     if (!($3036)) {
      $buffer$305 = $3034;$put_bits$189 = $3031;
      break;
     }
     $3037 = (($buffer$304) + 2|0);
     HEAP8[$3034>>0] = 0;
     $buffer$305 = $3037;$put_bits$189 = $3031;
    } else {
     $buffer$305 = $buffer$301$lcssa;$put_bits$189 = $3020;
    }
   } while(0);
   $3038 = (($put_bits$189) + ($2987))|0;
   $3039 = $3022 << $2987;
   $3040 = $3039 | $3019;
   $3041 = ($3038|0)>(15);
   if (!($3041)) {
    $buffer$308 = $buffer$305;$put_bits$191 = $3038;$put_buffer$75 = $3040;$r$75 = 0;
    break;
   }
   $3042 = (($3038) + -8)|0;
   $3043 = $3040 >>> $3042;
   $3044 = $3043&255;
   $3045 = (($buffer$305) + 1|0);
   HEAP8[$buffer$305>>0] = $3044;
   $3046 = $3043 & 255;
   $3047 = ($3046|0)==(255);
   if ($3047) {
    $3048 = (($buffer$305) + 2|0);
    HEAP8[$3045>>0] = 0;
    $buffer$306 = $3048;
   } else {
    $buffer$306 = $3045;
   }
   $3049 = (($3038) + -16)|0;
   $3050 = $3040 >>> $3049;
   $3051 = $3050&255;
   $3052 = (($buffer$306) + 1|0);
   HEAP8[$buffer$306>>0] = $3051;
   $3053 = $3050 & 255;
   $3054 = ($3053|0)==(255);
   if (!($3054)) {
    $buffer$308 = $3052;$put_bits$191 = $3049;$put_buffer$75 = $3040;$r$75 = 0;
    break;
   }
   $3055 = (($buffer$306) + 2|0);
   HEAP8[$3052>>0] = 0;
   $buffer$308 = $3055;$put_bits$191 = $3049;$put_buffer$75 = $3040;$r$75 = 0;
  }
 } while(0);
 $3056 = (($block) + 72|0);
 $3057 = HEAP16[$3056>>1]|0;
 $3058 = $3057 << 16 >> 16;
 $3059 = ($3057<<16>>16)==(0);
 do {
  if ($3059) {
   $3060 = (($r$75) + 1)|0;
   $buffer$316 = $buffer$308;$put_bits$196 = $put_bits$191;$put_buffer$77 = $put_buffer$75;$r$77 = $3060;
  } else {
   $3061 = $3058 >> 31;
   $3062 = $3061 ^ $3058;
   $3063 = (($3062) - ($3061))|0;
   $3064 = (($3061) + ($3058))|0;
   $3065 = (66264 + ($3063)|0);
   $3066 = HEAP8[$3065>>0]|0;
   $3067 = $3066&255;
   $3068 = ($r$75|0)>(15);
   if ($3068) {
    $buffer$309267 = $buffer$308;$put_bits$192265 = $put_bits$191;$put_buffer$76266 = $put_buffer$75;$r$76268 = $r$75;
    while(1) {
     $3069 = (($put_bits$192265) + ($4))|0;
     $3070 = $put_buffer$76266 << $4;
     $3071 = $3070 | $1;
     $3072 = ($3069|0)>(15);
     do {
      if ($3072) {
       $3073 = (($3069) + -8)|0;
       $3074 = $3071 >>> $3073;
       $3075 = $3074&255;
       $3076 = (($buffer$309267) + 1|0);
       HEAP8[$buffer$309267>>0] = $3075;
       $3077 = $3074 & 255;
       $3078 = ($3077|0)==(255);
       if ($3078) {
        $3079 = (($buffer$309267) + 2|0);
        HEAP8[$3076>>0] = 0;
        $buffer$310 = $3079;
       } else {
        $buffer$310 = $3076;
       }
       $3080 = (($3069) + -16)|0;
       $3081 = $3071 >>> $3080;
       $3082 = $3081&255;
       $3083 = (($buffer$310) + 1|0);
       HEAP8[$buffer$310>>0] = $3082;
       $3084 = $3081 & 255;
       $3085 = ($3084|0)==(255);
       if (!($3085)) {
        $buffer$311 = $3083;$put_bits$193 = $3080;
        break;
       }
       $3086 = (($buffer$310) + 2|0);
       HEAP8[$3083>>0] = 0;
       $buffer$311 = $3086;$put_bits$193 = $3080;
      } else {
       $buffer$311 = $buffer$309267;$put_bits$193 = $3069;
      }
     } while(0);
     $3087 = (($r$76268) + -16)|0;
     $3088 = ($3087|0)>(15);
     if ($3088) {
      $buffer$309267 = $buffer$311;$put_bits$192265 = $put_bits$193;$put_buffer$76266 = $3071;$r$76268 = $3087;
     } else {
      break;
     }
    }
    $3089 = $r$75 & 15;
    $buffer$309$lcssa = $buffer$311;$put_bits$192$lcssa = $put_bits$193;$put_buffer$76$lcssa = $3071;$r$76$lcssa = $3089;
   } else {
    $buffer$309$lcssa = $buffer$308;$put_bits$192$lcssa = $put_bits$191;$put_buffer$76$lcssa = $put_buffer$75;$r$76$lcssa = $r$75;
   }
   $3090 = $r$76$lcssa << 4;
   $3091 = (($3090) + ($3067))|0;
   $3092 = (($actbl) + ($3091<<2)|0);
   $3093 = HEAP32[$3092>>2]|0;
   $3094 = ((($actbl) + ($3091)|0) + 1024|0);
   $3095 = HEAP8[$3094>>0]|0;
   $3096 = $3095 << 24 >> 24;
   $3097 = 1 << $3067;
   $3098 = (($3097) + -1)|0;
   $3099 = $3098 & $3064;
   $3100 = (($3096) + ($put_bits$192$lcssa))|0;
   $3101 = $put_buffer$76$lcssa << $3096;
   $3102 = $3101 | $3093;
   $3103 = ($3100|0)>(15);
   do {
    if ($3103) {
     $3104 = (($3100) + -8)|0;
     $3105 = $3102 >>> $3104;
     $3106 = $3105&255;
     $3107 = (($buffer$309$lcssa) + 1|0);
     HEAP8[$buffer$309$lcssa>>0] = $3106;
     $3108 = $3105 & 255;
     $3109 = ($3108|0)==(255);
     if ($3109) {
      $3110 = (($buffer$309$lcssa) + 2|0);
      HEAP8[$3107>>0] = 0;
      $buffer$312 = $3110;
     } else {
      $buffer$312 = $3107;
     }
     $3111 = (($3100) + -16)|0;
     $3112 = $3102 >>> $3111;
     $3113 = $3112&255;
     $3114 = (($buffer$312) + 1|0);
     HEAP8[$buffer$312>>0] = $3113;
     $3115 = $3112 & 255;
     $3116 = ($3115|0)==(255);
     if (!($3116)) {
      $buffer$313 = $3114;$put_bits$194 = $3111;
      break;
     }
     $3117 = (($buffer$312) + 2|0);
     HEAP8[$3114>>0] = 0;
     $buffer$313 = $3117;$put_bits$194 = $3111;
    } else {
     $buffer$313 = $buffer$309$lcssa;$put_bits$194 = $3100;
    }
   } while(0);
   $3118 = (($put_bits$194) + ($3067))|0;
   $3119 = $3102 << $3067;
   $3120 = $3119 | $3099;
   $3121 = ($3118|0)>(15);
   if (!($3121)) {
    $buffer$316 = $buffer$313;$put_bits$196 = $3118;$put_buffer$77 = $3120;$r$77 = 0;
    break;
   }
   $3122 = (($3118) + -8)|0;
   $3123 = $3120 >>> $3122;
   $3124 = $3123&255;
   $3125 = (($buffer$313) + 1|0);
   HEAP8[$buffer$313>>0] = $3124;
   $3126 = $3123 & 255;
   $3127 = ($3126|0)==(255);
   if ($3127) {
    $3128 = (($buffer$313) + 2|0);
    HEAP8[$3125>>0] = 0;
    $buffer$314 = $3128;
   } else {
    $buffer$314 = $3125;
   }
   $3129 = (($3118) + -16)|0;
   $3130 = $3120 >>> $3129;
   $3131 = $3130&255;
   $3132 = (($buffer$314) + 1|0);
   HEAP8[$buffer$314>>0] = $3131;
   $3133 = $3130 & 255;
   $3134 = ($3133|0)==(255);
   if (!($3134)) {
    $buffer$316 = $3132;$put_bits$196 = $3129;$put_buffer$77 = $3120;$r$77 = 0;
    break;
   }
   $3135 = (($buffer$314) + 2|0);
   HEAP8[$3132>>0] = 0;
   $buffer$316 = $3135;$put_bits$196 = $3129;$put_buffer$77 = $3120;$r$77 = 0;
  }
 } while(0);
 $3136 = (($block) + 58|0);
 $3137 = HEAP16[$3136>>1]|0;
 $3138 = $3137 << 16 >> 16;
 $3139 = ($3137<<16>>16)==(0);
 do {
  if ($3139) {
   $3140 = (($r$77) + 1)|0;
   $buffer$324 = $buffer$316;$put_bits$201 = $put_bits$196;$put_buffer$79 = $put_buffer$77;$r$79 = $3140;
  } else {
   $3141 = $3138 >> 31;
   $3142 = $3141 ^ $3138;
   $3143 = (($3142) - ($3141))|0;
   $3144 = (($3141) + ($3138))|0;
   $3145 = (66264 + ($3143)|0);
   $3146 = HEAP8[$3145>>0]|0;
   $3147 = $3146&255;
   $3148 = ($r$77|0)>(15);
   if ($3148) {
    $buffer$317256 = $buffer$316;$put_bits$197254 = $put_bits$196;$put_buffer$78255 = $put_buffer$77;$r$78257 = $r$77;
    while(1) {
     $3149 = (($put_bits$197254) + ($4))|0;
     $3150 = $put_buffer$78255 << $4;
     $3151 = $3150 | $1;
     $3152 = ($3149|0)>(15);
     do {
      if ($3152) {
       $3153 = (($3149) + -8)|0;
       $3154 = $3151 >>> $3153;
       $3155 = $3154&255;
       $3156 = (($buffer$317256) + 1|0);
       HEAP8[$buffer$317256>>0] = $3155;
       $3157 = $3154 & 255;
       $3158 = ($3157|0)==(255);
       if ($3158) {
        $3159 = (($buffer$317256) + 2|0);
        HEAP8[$3156>>0] = 0;
        $buffer$318 = $3159;
       } else {
        $buffer$318 = $3156;
       }
       $3160 = (($3149) + -16)|0;
       $3161 = $3151 >>> $3160;
       $3162 = $3161&255;
       $3163 = (($buffer$318) + 1|0);
       HEAP8[$buffer$318>>0] = $3162;
       $3164 = $3161 & 255;
       $3165 = ($3164|0)==(255);
       if (!($3165)) {
        $buffer$319 = $3163;$put_bits$198 = $3160;
        break;
       }
       $3166 = (($buffer$318) + 2|0);
       HEAP8[$3163>>0] = 0;
       $buffer$319 = $3166;$put_bits$198 = $3160;
      } else {
       $buffer$319 = $buffer$317256;$put_bits$198 = $3149;
      }
     } while(0);
     $3167 = (($r$78257) + -16)|0;
     $3168 = ($3167|0)>(15);
     if ($3168) {
      $buffer$317256 = $buffer$319;$put_bits$197254 = $put_bits$198;$put_buffer$78255 = $3151;$r$78257 = $3167;
     } else {
      break;
     }
    }
    $3169 = $r$77 & 15;
    $buffer$317$lcssa = $buffer$319;$put_bits$197$lcssa = $put_bits$198;$put_buffer$78$lcssa = $3151;$r$78$lcssa = $3169;
   } else {
    $buffer$317$lcssa = $buffer$316;$put_bits$197$lcssa = $put_bits$196;$put_buffer$78$lcssa = $put_buffer$77;$r$78$lcssa = $r$77;
   }
   $3170 = $r$78$lcssa << 4;
   $3171 = (($3170) + ($3147))|0;
   $3172 = (($actbl) + ($3171<<2)|0);
   $3173 = HEAP32[$3172>>2]|0;
   $3174 = ((($actbl) + ($3171)|0) + 1024|0);
   $3175 = HEAP8[$3174>>0]|0;
   $3176 = $3175 << 24 >> 24;
   $3177 = 1 << $3147;
   $3178 = (($3177) + -1)|0;
   $3179 = $3178 & $3144;
   $3180 = (($3176) + ($put_bits$197$lcssa))|0;
   $3181 = $put_buffer$78$lcssa << $3176;
   $3182 = $3181 | $3173;
   $3183 = ($3180|0)>(15);
   do {
    if ($3183) {
     $3184 = (($3180) + -8)|0;
     $3185 = $3182 >>> $3184;
     $3186 = $3185&255;
     $3187 = (($buffer$317$lcssa) + 1|0);
     HEAP8[$buffer$317$lcssa>>0] = $3186;
     $3188 = $3185 & 255;
     $3189 = ($3188|0)==(255);
     if ($3189) {
      $3190 = (($buffer$317$lcssa) + 2|0);
      HEAP8[$3187>>0] = 0;
      $buffer$320 = $3190;
     } else {
      $buffer$320 = $3187;
     }
     $3191 = (($3180) + -16)|0;
     $3192 = $3182 >>> $3191;
     $3193 = $3192&255;
     $3194 = (($buffer$320) + 1|0);
     HEAP8[$buffer$320>>0] = $3193;
     $3195 = $3192 & 255;
     $3196 = ($3195|0)==(255);
     if (!($3196)) {
      $buffer$321 = $3194;$put_bits$199 = $3191;
      break;
     }
     $3197 = (($buffer$320) + 2|0);
     HEAP8[$3194>>0] = 0;
     $buffer$321 = $3197;$put_bits$199 = $3191;
    } else {
     $buffer$321 = $buffer$317$lcssa;$put_bits$199 = $3180;
    }
   } while(0);
   $3198 = (($put_bits$199) + ($3147))|0;
   $3199 = $3182 << $3147;
   $3200 = $3199 | $3179;
   $3201 = ($3198|0)>(15);
   if (!($3201)) {
    $buffer$324 = $buffer$321;$put_bits$201 = $3198;$put_buffer$79 = $3200;$r$79 = 0;
    break;
   }
   $3202 = (($3198) + -8)|0;
   $3203 = $3200 >>> $3202;
   $3204 = $3203&255;
   $3205 = (($buffer$321) + 1|0);
   HEAP8[$buffer$321>>0] = $3204;
   $3206 = $3203 & 255;
   $3207 = ($3206|0)==(255);
   if ($3207) {
    $3208 = (($buffer$321) + 2|0);
    HEAP8[$3205>>0] = 0;
    $buffer$322 = $3208;
   } else {
    $buffer$322 = $3205;
   }
   $3209 = (($3198) + -16)|0;
   $3210 = $3200 >>> $3209;
   $3211 = $3210&255;
   $3212 = (($buffer$322) + 1|0);
   HEAP8[$buffer$322>>0] = $3211;
   $3213 = $3210 & 255;
   $3214 = ($3213|0)==(255);
   if (!($3214)) {
    $buffer$324 = $3212;$put_bits$201 = $3209;$put_buffer$79 = $3200;$r$79 = 0;
    break;
   }
   $3215 = (($buffer$322) + 2|0);
   HEAP8[$3212>>0] = 0;
   $buffer$324 = $3215;$put_bits$201 = $3209;$put_buffer$79 = $3200;$r$79 = 0;
  }
 } while(0);
 $3216 = (($block) + 44|0);
 $3217 = HEAP16[$3216>>1]|0;
 $3218 = $3217 << 16 >> 16;
 $3219 = ($3217<<16>>16)==(0);
 do {
  if ($3219) {
   $3220 = (($r$79) + 1)|0;
   $buffer$332 = $buffer$324;$put_bits$206 = $put_bits$201;$put_buffer$81 = $put_buffer$79;$r$81 = $3220;
  } else {
   $3221 = $3218 >> 31;
   $3222 = $3221 ^ $3218;
   $3223 = (($3222) - ($3221))|0;
   $3224 = (($3221) + ($3218))|0;
   $3225 = (66264 + ($3223)|0);
   $3226 = HEAP8[$3225>>0]|0;
   $3227 = $3226&255;
   $3228 = ($r$79|0)>(15);
   if ($3228) {
    $buffer$325245 = $buffer$324;$put_bits$202243 = $put_bits$201;$put_buffer$80244 = $put_buffer$79;$r$80246 = $r$79;
    while(1) {
     $3229 = (($put_bits$202243) + ($4))|0;
     $3230 = $put_buffer$80244 << $4;
     $3231 = $3230 | $1;
     $3232 = ($3229|0)>(15);
     do {
      if ($3232) {
       $3233 = (($3229) + -8)|0;
       $3234 = $3231 >>> $3233;
       $3235 = $3234&255;
       $3236 = (($buffer$325245) + 1|0);
       HEAP8[$buffer$325245>>0] = $3235;
       $3237 = $3234 & 255;
       $3238 = ($3237|0)==(255);
       if ($3238) {
        $3239 = (($buffer$325245) + 2|0);
        HEAP8[$3236>>0] = 0;
        $buffer$326 = $3239;
       } else {
        $buffer$326 = $3236;
       }
       $3240 = (($3229) + -16)|0;
       $3241 = $3231 >>> $3240;
       $3242 = $3241&255;
       $3243 = (($buffer$326) + 1|0);
       HEAP8[$buffer$326>>0] = $3242;
       $3244 = $3241 & 255;
       $3245 = ($3244|0)==(255);
       if (!($3245)) {
        $buffer$327 = $3243;$put_bits$203 = $3240;
        break;
       }
       $3246 = (($buffer$326) + 2|0);
       HEAP8[$3243>>0] = 0;
       $buffer$327 = $3246;$put_bits$203 = $3240;
      } else {
       $buffer$327 = $buffer$325245;$put_bits$203 = $3229;
      }
     } while(0);
     $3247 = (($r$80246) + -16)|0;
     $3248 = ($3247|0)>(15);
     if ($3248) {
      $buffer$325245 = $buffer$327;$put_bits$202243 = $put_bits$203;$put_buffer$80244 = $3231;$r$80246 = $3247;
     } else {
      break;
     }
    }
    $3249 = $r$79 & 15;
    $buffer$325$lcssa = $buffer$327;$put_bits$202$lcssa = $put_bits$203;$put_buffer$80$lcssa = $3231;$r$80$lcssa = $3249;
   } else {
    $buffer$325$lcssa = $buffer$324;$put_bits$202$lcssa = $put_bits$201;$put_buffer$80$lcssa = $put_buffer$79;$r$80$lcssa = $r$79;
   }
   $3250 = $r$80$lcssa << 4;
   $3251 = (($3250) + ($3227))|0;
   $3252 = (($actbl) + ($3251<<2)|0);
   $3253 = HEAP32[$3252>>2]|0;
   $3254 = ((($actbl) + ($3251)|0) + 1024|0);
   $3255 = HEAP8[$3254>>0]|0;
   $3256 = $3255 << 24 >> 24;
   $3257 = 1 << $3227;
   $3258 = (($3257) + -1)|0;
   $3259 = $3258 & $3224;
   $3260 = (($3256) + ($put_bits$202$lcssa))|0;
   $3261 = $put_buffer$80$lcssa << $3256;
   $3262 = $3261 | $3253;
   $3263 = ($3260|0)>(15);
   do {
    if ($3263) {
     $3264 = (($3260) + -8)|0;
     $3265 = $3262 >>> $3264;
     $3266 = $3265&255;
     $3267 = (($buffer$325$lcssa) + 1|0);
     HEAP8[$buffer$325$lcssa>>0] = $3266;
     $3268 = $3265 & 255;
     $3269 = ($3268|0)==(255);
     if ($3269) {
      $3270 = (($buffer$325$lcssa) + 2|0);
      HEAP8[$3267>>0] = 0;
      $buffer$328 = $3270;
     } else {
      $buffer$328 = $3267;
     }
     $3271 = (($3260) + -16)|0;
     $3272 = $3262 >>> $3271;
     $3273 = $3272&255;
     $3274 = (($buffer$328) + 1|0);
     HEAP8[$buffer$328>>0] = $3273;
     $3275 = $3272 & 255;
     $3276 = ($3275|0)==(255);
     if (!($3276)) {
      $buffer$329 = $3274;$put_bits$204 = $3271;
      break;
     }
     $3277 = (($buffer$328) + 2|0);
     HEAP8[$3274>>0] = 0;
     $buffer$329 = $3277;$put_bits$204 = $3271;
    } else {
     $buffer$329 = $buffer$325$lcssa;$put_bits$204 = $3260;
    }
   } while(0);
   $3278 = (($put_bits$204) + ($3227))|0;
   $3279 = $3262 << $3227;
   $3280 = $3279 | $3259;
   $3281 = ($3278|0)>(15);
   if (!($3281)) {
    $buffer$332 = $buffer$329;$put_bits$206 = $3278;$put_buffer$81 = $3280;$r$81 = 0;
    break;
   }
   $3282 = (($3278) + -8)|0;
   $3283 = $3280 >>> $3282;
   $3284 = $3283&255;
   $3285 = (($buffer$329) + 1|0);
   HEAP8[$buffer$329>>0] = $3284;
   $3286 = $3283 & 255;
   $3287 = ($3286|0)==(255);
   if ($3287) {
    $3288 = (($buffer$329) + 2|0);
    HEAP8[$3285>>0] = 0;
    $buffer$330 = $3288;
   } else {
    $buffer$330 = $3285;
   }
   $3289 = (($3278) + -16)|0;
   $3290 = $3280 >>> $3289;
   $3291 = $3290&255;
   $3292 = (($buffer$330) + 1|0);
   HEAP8[$buffer$330>>0] = $3291;
   $3293 = $3290 & 255;
   $3294 = ($3293|0)==(255);
   if (!($3294)) {
    $buffer$332 = $3292;$put_bits$206 = $3289;$put_buffer$81 = $3280;$r$81 = 0;
    break;
   }
   $3295 = (($buffer$330) + 2|0);
   HEAP8[$3292>>0] = 0;
   $buffer$332 = $3295;$put_bits$206 = $3289;$put_buffer$81 = $3280;$r$81 = 0;
  }
 } while(0);
 $3296 = (($block) + 30|0);
 $3297 = HEAP16[$3296>>1]|0;
 $3298 = $3297 << 16 >> 16;
 $3299 = ($3297<<16>>16)==(0);
 do {
  if ($3299) {
   $3300 = (($r$81) + 1)|0;
   $buffer$340 = $buffer$332;$put_bits$211 = $put_bits$206;$put_buffer$83 = $put_buffer$81;$r$83 = $3300;
  } else {
   $3301 = $3298 >> 31;
   $3302 = $3301 ^ $3298;
   $3303 = (($3302) - ($3301))|0;
   $3304 = (($3301) + ($3298))|0;
   $3305 = (66264 + ($3303)|0);
   $3306 = HEAP8[$3305>>0]|0;
   $3307 = $3306&255;
   $3308 = ($r$81|0)>(15);
   if ($3308) {
    $buffer$333234 = $buffer$332;$put_bits$207232 = $put_bits$206;$put_buffer$82233 = $put_buffer$81;$r$82235 = $r$81;
    while(1) {
     $3309 = (($put_bits$207232) + ($4))|0;
     $3310 = $put_buffer$82233 << $4;
     $3311 = $3310 | $1;
     $3312 = ($3309|0)>(15);
     do {
      if ($3312) {
       $3313 = (($3309) + -8)|0;
       $3314 = $3311 >>> $3313;
       $3315 = $3314&255;
       $3316 = (($buffer$333234) + 1|0);
       HEAP8[$buffer$333234>>0] = $3315;
       $3317 = $3314 & 255;
       $3318 = ($3317|0)==(255);
       if ($3318) {
        $3319 = (($buffer$333234) + 2|0);
        HEAP8[$3316>>0] = 0;
        $buffer$334 = $3319;
       } else {
        $buffer$334 = $3316;
       }
       $3320 = (($3309) + -16)|0;
       $3321 = $3311 >>> $3320;
       $3322 = $3321&255;
       $3323 = (($buffer$334) + 1|0);
       HEAP8[$buffer$334>>0] = $3322;
       $3324 = $3321 & 255;
       $3325 = ($3324|0)==(255);
       if (!($3325)) {
        $buffer$335 = $3323;$put_bits$208 = $3320;
        break;
       }
       $3326 = (($buffer$334) + 2|0);
       HEAP8[$3323>>0] = 0;
       $buffer$335 = $3326;$put_bits$208 = $3320;
      } else {
       $buffer$335 = $buffer$333234;$put_bits$208 = $3309;
      }
     } while(0);
     $3327 = (($r$82235) + -16)|0;
     $3328 = ($3327|0)>(15);
     if ($3328) {
      $buffer$333234 = $buffer$335;$put_bits$207232 = $put_bits$208;$put_buffer$82233 = $3311;$r$82235 = $3327;
     } else {
      break;
     }
    }
    $3329 = $r$81 & 15;
    $buffer$333$lcssa = $buffer$335;$put_bits$207$lcssa = $put_bits$208;$put_buffer$82$lcssa = $3311;$r$82$lcssa = $3329;
   } else {
    $buffer$333$lcssa = $buffer$332;$put_bits$207$lcssa = $put_bits$206;$put_buffer$82$lcssa = $put_buffer$81;$r$82$lcssa = $r$81;
   }
   $3330 = $r$82$lcssa << 4;
   $3331 = (($3330) + ($3307))|0;
   $3332 = (($actbl) + ($3331<<2)|0);
   $3333 = HEAP32[$3332>>2]|0;
   $3334 = ((($actbl) + ($3331)|0) + 1024|0);
   $3335 = HEAP8[$3334>>0]|0;
   $3336 = $3335 << 24 >> 24;
   $3337 = 1 << $3307;
   $3338 = (($3337) + -1)|0;
   $3339 = $3338 & $3304;
   $3340 = (($3336) + ($put_bits$207$lcssa))|0;
   $3341 = $put_buffer$82$lcssa << $3336;
   $3342 = $3341 | $3333;
   $3343 = ($3340|0)>(15);
   do {
    if ($3343) {
     $3344 = (($3340) + -8)|0;
     $3345 = $3342 >>> $3344;
     $3346 = $3345&255;
     $3347 = (($buffer$333$lcssa) + 1|0);
     HEAP8[$buffer$333$lcssa>>0] = $3346;
     $3348 = $3345 & 255;
     $3349 = ($3348|0)==(255);
     if ($3349) {
      $3350 = (($buffer$333$lcssa) + 2|0);
      HEAP8[$3347>>0] = 0;
      $buffer$336 = $3350;
     } else {
      $buffer$336 = $3347;
     }
     $3351 = (($3340) + -16)|0;
     $3352 = $3342 >>> $3351;
     $3353 = $3352&255;
     $3354 = (($buffer$336) + 1|0);
     HEAP8[$buffer$336>>0] = $3353;
     $3355 = $3352 & 255;
     $3356 = ($3355|0)==(255);
     if (!($3356)) {
      $buffer$337 = $3354;$put_bits$209 = $3351;
      break;
     }
     $3357 = (($buffer$336) + 2|0);
     HEAP8[$3354>>0] = 0;
     $buffer$337 = $3357;$put_bits$209 = $3351;
    } else {
     $buffer$337 = $buffer$333$lcssa;$put_bits$209 = $3340;
    }
   } while(0);
   $3358 = (($put_bits$209) + ($3307))|0;
   $3359 = $3342 << $3307;
   $3360 = $3359 | $3339;
   $3361 = ($3358|0)>(15);
   if (!($3361)) {
    $buffer$340 = $buffer$337;$put_bits$211 = $3358;$put_buffer$83 = $3360;$r$83 = 0;
    break;
   }
   $3362 = (($3358) + -8)|0;
   $3363 = $3360 >>> $3362;
   $3364 = $3363&255;
   $3365 = (($buffer$337) + 1|0);
   HEAP8[$buffer$337>>0] = $3364;
   $3366 = $3363 & 255;
   $3367 = ($3366|0)==(255);
   if ($3367) {
    $3368 = (($buffer$337) + 2|0);
    HEAP8[$3365>>0] = 0;
    $buffer$338 = $3368;
   } else {
    $buffer$338 = $3365;
   }
   $3369 = (($3358) + -16)|0;
   $3370 = $3360 >>> $3369;
   $3371 = $3370&255;
   $3372 = (($buffer$338) + 1|0);
   HEAP8[$buffer$338>>0] = $3371;
   $3373 = $3370 & 255;
   $3374 = ($3373|0)==(255);
   if (!($3374)) {
    $buffer$340 = $3372;$put_bits$211 = $3369;$put_buffer$83 = $3360;$r$83 = 0;
    break;
   }
   $3375 = (($buffer$338) + 2|0);
   HEAP8[$3372>>0] = 0;
   $buffer$340 = $3375;$put_bits$211 = $3369;$put_buffer$83 = $3360;$r$83 = 0;
  }
 } while(0);
 $3376 = (($block) + 46|0);
 $3377 = HEAP16[$3376>>1]|0;
 $3378 = $3377 << 16 >> 16;
 $3379 = ($3377<<16>>16)==(0);
 do {
  if ($3379) {
   $3380 = (($r$83) + 1)|0;
   $buffer$348 = $buffer$340;$put_bits$216 = $put_bits$211;$put_buffer$85 = $put_buffer$83;$r$85 = $3380;
  } else {
   $3381 = $3378 >> 31;
   $3382 = $3381 ^ $3378;
   $3383 = (($3382) - ($3381))|0;
   $3384 = (($3381) + ($3378))|0;
   $3385 = (66264 + ($3383)|0);
   $3386 = HEAP8[$3385>>0]|0;
   $3387 = $3386&255;
   $3388 = ($r$83|0)>(15);
   if ($3388) {
    $buffer$341223 = $buffer$340;$put_bits$212221 = $put_bits$211;$put_buffer$84222 = $put_buffer$83;$r$84224 = $r$83;
    while(1) {
     $3389 = (($put_bits$212221) + ($4))|0;
     $3390 = $put_buffer$84222 << $4;
     $3391 = $3390 | $1;
     $3392 = ($3389|0)>(15);
     do {
      if ($3392) {
       $3393 = (($3389) + -8)|0;
       $3394 = $3391 >>> $3393;
       $3395 = $3394&255;
       $3396 = (($buffer$341223) + 1|0);
       HEAP8[$buffer$341223>>0] = $3395;
       $3397 = $3394 & 255;
       $3398 = ($3397|0)==(255);
       if ($3398) {
        $3399 = (($buffer$341223) + 2|0);
        HEAP8[$3396>>0] = 0;
        $buffer$342 = $3399;
       } else {
        $buffer$342 = $3396;
       }
       $3400 = (($3389) + -16)|0;
       $3401 = $3391 >>> $3400;
       $3402 = $3401&255;
       $3403 = (($buffer$342) + 1|0);
       HEAP8[$buffer$342>>0] = $3402;
       $3404 = $3401 & 255;
       $3405 = ($3404|0)==(255);
       if (!($3405)) {
        $buffer$343 = $3403;$put_bits$213 = $3400;
        break;
       }
       $3406 = (($buffer$342) + 2|0);
       HEAP8[$3403>>0] = 0;
       $buffer$343 = $3406;$put_bits$213 = $3400;
      } else {
       $buffer$343 = $buffer$341223;$put_bits$213 = $3389;
      }
     } while(0);
     $3407 = (($r$84224) + -16)|0;
     $3408 = ($3407|0)>(15);
     if ($3408) {
      $buffer$341223 = $buffer$343;$put_bits$212221 = $put_bits$213;$put_buffer$84222 = $3391;$r$84224 = $3407;
     } else {
      break;
     }
    }
    $3409 = $r$83 & 15;
    $buffer$341$lcssa = $buffer$343;$put_bits$212$lcssa = $put_bits$213;$put_buffer$84$lcssa = $3391;$r$84$lcssa = $3409;
   } else {
    $buffer$341$lcssa = $buffer$340;$put_bits$212$lcssa = $put_bits$211;$put_buffer$84$lcssa = $put_buffer$83;$r$84$lcssa = $r$83;
   }
   $3410 = $r$84$lcssa << 4;
   $3411 = (($3410) + ($3387))|0;
   $3412 = (($actbl) + ($3411<<2)|0);
   $3413 = HEAP32[$3412>>2]|0;
   $3414 = ((($actbl) + ($3411)|0) + 1024|0);
   $3415 = HEAP8[$3414>>0]|0;
   $3416 = $3415 << 24 >> 24;
   $3417 = 1 << $3387;
   $3418 = (($3417) + -1)|0;
   $3419 = $3418 & $3384;
   $3420 = (($3416) + ($put_bits$212$lcssa))|0;
   $3421 = $put_buffer$84$lcssa << $3416;
   $3422 = $3421 | $3413;
   $3423 = ($3420|0)>(15);
   do {
    if ($3423) {
     $3424 = (($3420) + -8)|0;
     $3425 = $3422 >>> $3424;
     $3426 = $3425&255;
     $3427 = (($buffer$341$lcssa) + 1|0);
     HEAP8[$buffer$341$lcssa>>0] = $3426;
     $3428 = $3425 & 255;
     $3429 = ($3428|0)==(255);
     if ($3429) {
      $3430 = (($buffer$341$lcssa) + 2|0);
      HEAP8[$3427>>0] = 0;
      $buffer$344 = $3430;
     } else {
      $buffer$344 = $3427;
     }
     $3431 = (($3420) + -16)|0;
     $3432 = $3422 >>> $3431;
     $3433 = $3432&255;
     $3434 = (($buffer$344) + 1|0);
     HEAP8[$buffer$344>>0] = $3433;
     $3435 = $3432 & 255;
     $3436 = ($3435|0)==(255);
     if (!($3436)) {
      $buffer$345 = $3434;$put_bits$214 = $3431;
      break;
     }
     $3437 = (($buffer$344) + 2|0);
     HEAP8[$3434>>0] = 0;
     $buffer$345 = $3437;$put_bits$214 = $3431;
    } else {
     $buffer$345 = $buffer$341$lcssa;$put_bits$214 = $3420;
    }
   } while(0);
   $3438 = (($put_bits$214) + ($3387))|0;
   $3439 = $3422 << $3387;
   $3440 = $3439 | $3419;
   $3441 = ($3438|0)>(15);
   if (!($3441)) {
    $buffer$348 = $buffer$345;$put_bits$216 = $3438;$put_buffer$85 = $3440;$r$85 = 0;
    break;
   }
   $3442 = (($3438) + -8)|0;
   $3443 = $3440 >>> $3442;
   $3444 = $3443&255;
   $3445 = (($buffer$345) + 1|0);
   HEAP8[$buffer$345>>0] = $3444;
   $3446 = $3443 & 255;
   $3447 = ($3446|0)==(255);
   if ($3447) {
    $3448 = (($buffer$345) + 2|0);
    HEAP8[$3445>>0] = 0;
    $buffer$346 = $3448;
   } else {
    $buffer$346 = $3445;
   }
   $3449 = (($3438) + -16)|0;
   $3450 = $3440 >>> $3449;
   $3451 = $3450&255;
   $3452 = (($buffer$346) + 1|0);
   HEAP8[$buffer$346>>0] = $3451;
   $3453 = $3450 & 255;
   $3454 = ($3453|0)==(255);
   if (!($3454)) {
    $buffer$348 = $3452;$put_bits$216 = $3449;$put_buffer$85 = $3440;$r$85 = 0;
    break;
   }
   $3455 = (($buffer$346) + 2|0);
   HEAP8[$3452>>0] = 0;
   $buffer$348 = $3455;$put_bits$216 = $3449;$put_buffer$85 = $3440;$r$85 = 0;
  }
 } while(0);
 $3456 = (($block) + 60|0);
 $3457 = HEAP16[$3456>>1]|0;
 $3458 = $3457 << 16 >> 16;
 $3459 = ($3457<<16>>16)==(0);
 do {
  if ($3459) {
   $3460 = (($r$85) + 1)|0;
   $buffer$356 = $buffer$348;$put_bits$221 = $put_bits$216;$put_buffer$87 = $put_buffer$85;$r$87 = $3460;
  } else {
   $3461 = $3458 >> 31;
   $3462 = $3461 ^ $3458;
   $3463 = (($3462) - ($3461))|0;
   $3464 = (($3461) + ($3458))|0;
   $3465 = (66264 + ($3463)|0);
   $3466 = HEAP8[$3465>>0]|0;
   $3467 = $3466&255;
   $3468 = ($r$85|0)>(15);
   if ($3468) {
    $buffer$349212 = $buffer$348;$put_bits$217210 = $put_bits$216;$put_buffer$86211 = $put_buffer$85;$r$86213 = $r$85;
    while(1) {
     $3469 = (($put_bits$217210) + ($4))|0;
     $3470 = $put_buffer$86211 << $4;
     $3471 = $3470 | $1;
     $3472 = ($3469|0)>(15);
     do {
      if ($3472) {
       $3473 = (($3469) + -8)|0;
       $3474 = $3471 >>> $3473;
       $3475 = $3474&255;
       $3476 = (($buffer$349212) + 1|0);
       HEAP8[$buffer$349212>>0] = $3475;
       $3477 = $3474 & 255;
       $3478 = ($3477|0)==(255);
       if ($3478) {
        $3479 = (($buffer$349212) + 2|0);
        HEAP8[$3476>>0] = 0;
        $buffer$350 = $3479;
       } else {
        $buffer$350 = $3476;
       }
       $3480 = (($3469) + -16)|0;
       $3481 = $3471 >>> $3480;
       $3482 = $3481&255;
       $3483 = (($buffer$350) + 1|0);
       HEAP8[$buffer$350>>0] = $3482;
       $3484 = $3481 & 255;
       $3485 = ($3484|0)==(255);
       if (!($3485)) {
        $buffer$351 = $3483;$put_bits$218 = $3480;
        break;
       }
       $3486 = (($buffer$350) + 2|0);
       HEAP8[$3483>>0] = 0;
       $buffer$351 = $3486;$put_bits$218 = $3480;
      } else {
       $buffer$351 = $buffer$349212;$put_bits$218 = $3469;
      }
     } while(0);
     $3487 = (($r$86213) + -16)|0;
     $3488 = ($3487|0)>(15);
     if ($3488) {
      $buffer$349212 = $buffer$351;$put_bits$217210 = $put_bits$218;$put_buffer$86211 = $3471;$r$86213 = $3487;
     } else {
      break;
     }
    }
    $3489 = $r$85 & 15;
    $buffer$349$lcssa = $buffer$351;$put_bits$217$lcssa = $put_bits$218;$put_buffer$86$lcssa = $3471;$r$86$lcssa = $3489;
   } else {
    $buffer$349$lcssa = $buffer$348;$put_bits$217$lcssa = $put_bits$216;$put_buffer$86$lcssa = $put_buffer$85;$r$86$lcssa = $r$85;
   }
   $3490 = $r$86$lcssa << 4;
   $3491 = (($3490) + ($3467))|0;
   $3492 = (($actbl) + ($3491<<2)|0);
   $3493 = HEAP32[$3492>>2]|0;
   $3494 = ((($actbl) + ($3491)|0) + 1024|0);
   $3495 = HEAP8[$3494>>0]|0;
   $3496 = $3495 << 24 >> 24;
   $3497 = 1 << $3467;
   $3498 = (($3497) + -1)|0;
   $3499 = $3498 & $3464;
   $3500 = (($3496) + ($put_bits$217$lcssa))|0;
   $3501 = $put_buffer$86$lcssa << $3496;
   $3502 = $3501 | $3493;
   $3503 = ($3500|0)>(15);
   do {
    if ($3503) {
     $3504 = (($3500) + -8)|0;
     $3505 = $3502 >>> $3504;
     $3506 = $3505&255;
     $3507 = (($buffer$349$lcssa) + 1|0);
     HEAP8[$buffer$349$lcssa>>0] = $3506;
     $3508 = $3505 & 255;
     $3509 = ($3508|0)==(255);
     if ($3509) {
      $3510 = (($buffer$349$lcssa) + 2|0);
      HEAP8[$3507>>0] = 0;
      $buffer$352 = $3510;
     } else {
      $buffer$352 = $3507;
     }
     $3511 = (($3500) + -16)|0;
     $3512 = $3502 >>> $3511;
     $3513 = $3512&255;
     $3514 = (($buffer$352) + 1|0);
     HEAP8[$buffer$352>>0] = $3513;
     $3515 = $3512 & 255;
     $3516 = ($3515|0)==(255);
     if (!($3516)) {
      $buffer$353 = $3514;$put_bits$219 = $3511;
      break;
     }
     $3517 = (($buffer$352) + 2|0);
     HEAP8[$3514>>0] = 0;
     $buffer$353 = $3517;$put_bits$219 = $3511;
    } else {
     $buffer$353 = $buffer$349$lcssa;$put_bits$219 = $3500;
    }
   } while(0);
   $3518 = (($put_bits$219) + ($3467))|0;
   $3519 = $3502 << $3467;
   $3520 = $3519 | $3499;
   $3521 = ($3518|0)>(15);
   if (!($3521)) {
    $buffer$356 = $buffer$353;$put_bits$221 = $3518;$put_buffer$87 = $3520;$r$87 = 0;
    break;
   }
   $3522 = (($3518) + -8)|0;
   $3523 = $3520 >>> $3522;
   $3524 = $3523&255;
   $3525 = (($buffer$353) + 1|0);
   HEAP8[$buffer$353>>0] = $3524;
   $3526 = $3523 & 255;
   $3527 = ($3526|0)==(255);
   if ($3527) {
    $3528 = (($buffer$353) + 2|0);
    HEAP8[$3525>>0] = 0;
    $buffer$354 = $3528;
   } else {
    $buffer$354 = $3525;
   }
   $3529 = (($3518) + -16)|0;
   $3530 = $3520 >>> $3529;
   $3531 = $3530&255;
   $3532 = (($buffer$354) + 1|0);
   HEAP8[$buffer$354>>0] = $3531;
   $3533 = $3530 & 255;
   $3534 = ($3533|0)==(255);
   if (!($3534)) {
    $buffer$356 = $3532;$put_bits$221 = $3529;$put_buffer$87 = $3520;$r$87 = 0;
    break;
   }
   $3535 = (($buffer$354) + 2|0);
   HEAP8[$3532>>0] = 0;
   $buffer$356 = $3535;$put_bits$221 = $3529;$put_buffer$87 = $3520;$r$87 = 0;
  }
 } while(0);
 $3536 = (($block) + 74|0);
 $3537 = HEAP16[$3536>>1]|0;
 $3538 = $3537 << 16 >> 16;
 $3539 = ($3537<<16>>16)==(0);
 do {
  if ($3539) {
   $3540 = (($r$87) + 1)|0;
   $buffer$364 = $buffer$356;$put_bits$226 = $put_bits$221;$put_buffer$89 = $put_buffer$87;$r$89 = $3540;
  } else {
   $3541 = $3538 >> 31;
   $3542 = $3541 ^ $3538;
   $3543 = (($3542) - ($3541))|0;
   $3544 = (($3541) + ($3538))|0;
   $3545 = (66264 + ($3543)|0);
   $3546 = HEAP8[$3545>>0]|0;
   $3547 = $3546&255;
   $3548 = ($r$87|0)>(15);
   if ($3548) {
    $buffer$357201 = $buffer$356;$put_bits$222199 = $put_bits$221;$put_buffer$88200 = $put_buffer$87;$r$88202 = $r$87;
    while(1) {
     $3549 = (($put_bits$222199) + ($4))|0;
     $3550 = $put_buffer$88200 << $4;
     $3551 = $3550 | $1;
     $3552 = ($3549|0)>(15);
     do {
      if ($3552) {
       $3553 = (($3549) + -8)|0;
       $3554 = $3551 >>> $3553;
       $3555 = $3554&255;
       $3556 = (($buffer$357201) + 1|0);
       HEAP8[$buffer$357201>>0] = $3555;
       $3557 = $3554 & 255;
       $3558 = ($3557|0)==(255);
       if ($3558) {
        $3559 = (($buffer$357201) + 2|0);
        HEAP8[$3556>>0] = 0;
        $buffer$358 = $3559;
       } else {
        $buffer$358 = $3556;
       }
       $3560 = (($3549) + -16)|0;
       $3561 = $3551 >>> $3560;
       $3562 = $3561&255;
       $3563 = (($buffer$358) + 1|0);
       HEAP8[$buffer$358>>0] = $3562;
       $3564 = $3561 & 255;
       $3565 = ($3564|0)==(255);
       if (!($3565)) {
        $buffer$359 = $3563;$put_bits$223 = $3560;
        break;
       }
       $3566 = (($buffer$358) + 2|0);
       HEAP8[$3563>>0] = 0;
       $buffer$359 = $3566;$put_bits$223 = $3560;
      } else {
       $buffer$359 = $buffer$357201;$put_bits$223 = $3549;
      }
     } while(0);
     $3567 = (($r$88202) + -16)|0;
     $3568 = ($3567|0)>(15);
     if ($3568) {
      $buffer$357201 = $buffer$359;$put_bits$222199 = $put_bits$223;$put_buffer$88200 = $3551;$r$88202 = $3567;
     } else {
      break;
     }
    }
    $3569 = $r$87 & 15;
    $buffer$357$lcssa = $buffer$359;$put_bits$222$lcssa = $put_bits$223;$put_buffer$88$lcssa = $3551;$r$88$lcssa = $3569;
   } else {
    $buffer$357$lcssa = $buffer$356;$put_bits$222$lcssa = $put_bits$221;$put_buffer$88$lcssa = $put_buffer$87;$r$88$lcssa = $r$87;
   }
   $3570 = $r$88$lcssa << 4;
   $3571 = (($3570) + ($3547))|0;
   $3572 = (($actbl) + ($3571<<2)|0);
   $3573 = HEAP32[$3572>>2]|0;
   $3574 = ((($actbl) + ($3571)|0) + 1024|0);
   $3575 = HEAP8[$3574>>0]|0;
   $3576 = $3575 << 24 >> 24;
   $3577 = 1 << $3547;
   $3578 = (($3577) + -1)|0;
   $3579 = $3578 & $3544;
   $3580 = (($3576) + ($put_bits$222$lcssa))|0;
   $3581 = $put_buffer$88$lcssa << $3576;
   $3582 = $3581 | $3573;
   $3583 = ($3580|0)>(15);
   do {
    if ($3583) {
     $3584 = (($3580) + -8)|0;
     $3585 = $3582 >>> $3584;
     $3586 = $3585&255;
     $3587 = (($buffer$357$lcssa) + 1|0);
     HEAP8[$buffer$357$lcssa>>0] = $3586;
     $3588 = $3585 & 255;
     $3589 = ($3588|0)==(255);
     if ($3589) {
      $3590 = (($buffer$357$lcssa) + 2|0);
      HEAP8[$3587>>0] = 0;
      $buffer$360 = $3590;
     } else {
      $buffer$360 = $3587;
     }
     $3591 = (($3580) + -16)|0;
     $3592 = $3582 >>> $3591;
     $3593 = $3592&255;
     $3594 = (($buffer$360) + 1|0);
     HEAP8[$buffer$360>>0] = $3593;
     $3595 = $3592 & 255;
     $3596 = ($3595|0)==(255);
     if (!($3596)) {
      $buffer$361 = $3594;$put_bits$224 = $3591;
      break;
     }
     $3597 = (($buffer$360) + 2|0);
     HEAP8[$3594>>0] = 0;
     $buffer$361 = $3597;$put_bits$224 = $3591;
    } else {
     $buffer$361 = $buffer$357$lcssa;$put_bits$224 = $3580;
    }
   } while(0);
   $3598 = (($put_bits$224) + ($3547))|0;
   $3599 = $3582 << $3547;
   $3600 = $3599 | $3579;
   $3601 = ($3598|0)>(15);
   if (!($3601)) {
    $buffer$364 = $buffer$361;$put_bits$226 = $3598;$put_buffer$89 = $3600;$r$89 = 0;
    break;
   }
   $3602 = (($3598) + -8)|0;
   $3603 = $3600 >>> $3602;
   $3604 = $3603&255;
   $3605 = (($buffer$361) + 1|0);
   HEAP8[$buffer$361>>0] = $3604;
   $3606 = $3603 & 255;
   $3607 = ($3606|0)==(255);
   if ($3607) {
    $3608 = (($buffer$361) + 2|0);
    HEAP8[$3605>>0] = 0;
    $buffer$362 = $3608;
   } else {
    $buffer$362 = $3605;
   }
   $3609 = (($3598) + -16)|0;
   $3610 = $3600 >>> $3609;
   $3611 = $3610&255;
   $3612 = (($buffer$362) + 1|0);
   HEAP8[$buffer$362>>0] = $3611;
   $3613 = $3610 & 255;
   $3614 = ($3613|0)==(255);
   if (!($3614)) {
    $buffer$364 = $3612;$put_bits$226 = $3609;$put_buffer$89 = $3600;$r$89 = 0;
    break;
   }
   $3615 = (($buffer$362) + 2|0);
   HEAP8[$3612>>0] = 0;
   $buffer$364 = $3615;$put_bits$226 = $3609;$put_buffer$89 = $3600;$r$89 = 0;
  }
 } while(0);
 $3616 = (($block) + 88|0);
 $3617 = HEAP16[$3616>>1]|0;
 $3618 = $3617 << 16 >> 16;
 $3619 = ($3617<<16>>16)==(0);
 do {
  if ($3619) {
   $3620 = (($r$89) + 1)|0;
   $buffer$372 = $buffer$364;$put_bits$231 = $put_bits$226;$put_buffer$91 = $put_buffer$89;$r$91 = $3620;
  } else {
   $3621 = $3618 >> 31;
   $3622 = $3621 ^ $3618;
   $3623 = (($3622) - ($3621))|0;
   $3624 = (($3621) + ($3618))|0;
   $3625 = (66264 + ($3623)|0);
   $3626 = HEAP8[$3625>>0]|0;
   $3627 = $3626&255;
   $3628 = ($r$89|0)>(15);
   if ($3628) {
    $buffer$365190 = $buffer$364;$put_bits$227188 = $put_bits$226;$put_buffer$90189 = $put_buffer$89;$r$90191 = $r$89;
    while(1) {
     $3629 = (($put_bits$227188) + ($4))|0;
     $3630 = $put_buffer$90189 << $4;
     $3631 = $3630 | $1;
     $3632 = ($3629|0)>(15);
     do {
      if ($3632) {
       $3633 = (($3629) + -8)|0;
       $3634 = $3631 >>> $3633;
       $3635 = $3634&255;
       $3636 = (($buffer$365190) + 1|0);
       HEAP8[$buffer$365190>>0] = $3635;
       $3637 = $3634 & 255;
       $3638 = ($3637|0)==(255);
       if ($3638) {
        $3639 = (($buffer$365190) + 2|0);
        HEAP8[$3636>>0] = 0;
        $buffer$366 = $3639;
       } else {
        $buffer$366 = $3636;
       }
       $3640 = (($3629) + -16)|0;
       $3641 = $3631 >>> $3640;
       $3642 = $3641&255;
       $3643 = (($buffer$366) + 1|0);
       HEAP8[$buffer$366>>0] = $3642;
       $3644 = $3641 & 255;
       $3645 = ($3644|0)==(255);
       if (!($3645)) {
        $buffer$367 = $3643;$put_bits$228 = $3640;
        break;
       }
       $3646 = (($buffer$366) + 2|0);
       HEAP8[$3643>>0] = 0;
       $buffer$367 = $3646;$put_bits$228 = $3640;
      } else {
       $buffer$367 = $buffer$365190;$put_bits$228 = $3629;
      }
     } while(0);
     $3647 = (($r$90191) + -16)|0;
     $3648 = ($3647|0)>(15);
     if ($3648) {
      $buffer$365190 = $buffer$367;$put_bits$227188 = $put_bits$228;$put_buffer$90189 = $3631;$r$90191 = $3647;
     } else {
      break;
     }
    }
    $3649 = $r$89 & 15;
    $buffer$365$lcssa = $buffer$367;$put_bits$227$lcssa = $put_bits$228;$put_buffer$90$lcssa = $3631;$r$90$lcssa = $3649;
   } else {
    $buffer$365$lcssa = $buffer$364;$put_bits$227$lcssa = $put_bits$226;$put_buffer$90$lcssa = $put_buffer$89;$r$90$lcssa = $r$89;
   }
   $3650 = $r$90$lcssa << 4;
   $3651 = (($3650) + ($3627))|0;
   $3652 = (($actbl) + ($3651<<2)|0);
   $3653 = HEAP32[$3652>>2]|0;
   $3654 = ((($actbl) + ($3651)|0) + 1024|0);
   $3655 = HEAP8[$3654>>0]|0;
   $3656 = $3655 << 24 >> 24;
   $3657 = 1 << $3627;
   $3658 = (($3657) + -1)|0;
   $3659 = $3658 & $3624;
   $3660 = (($3656) + ($put_bits$227$lcssa))|0;
   $3661 = $put_buffer$90$lcssa << $3656;
   $3662 = $3661 | $3653;
   $3663 = ($3660|0)>(15);
   do {
    if ($3663) {
     $3664 = (($3660) + -8)|0;
     $3665 = $3662 >>> $3664;
     $3666 = $3665&255;
     $3667 = (($buffer$365$lcssa) + 1|0);
     HEAP8[$buffer$365$lcssa>>0] = $3666;
     $3668 = $3665 & 255;
     $3669 = ($3668|0)==(255);
     if ($3669) {
      $3670 = (($buffer$365$lcssa) + 2|0);
      HEAP8[$3667>>0] = 0;
      $buffer$368 = $3670;
     } else {
      $buffer$368 = $3667;
     }
     $3671 = (($3660) + -16)|0;
     $3672 = $3662 >>> $3671;
     $3673 = $3672&255;
     $3674 = (($buffer$368) + 1|0);
     HEAP8[$buffer$368>>0] = $3673;
     $3675 = $3672 & 255;
     $3676 = ($3675|0)==(255);
     if (!($3676)) {
      $buffer$369 = $3674;$put_bits$229 = $3671;
      break;
     }
     $3677 = (($buffer$368) + 2|0);
     HEAP8[$3674>>0] = 0;
     $buffer$369 = $3677;$put_bits$229 = $3671;
    } else {
     $buffer$369 = $buffer$365$lcssa;$put_bits$229 = $3660;
    }
   } while(0);
   $3678 = (($put_bits$229) + ($3627))|0;
   $3679 = $3662 << $3627;
   $3680 = $3679 | $3659;
   $3681 = ($3678|0)>(15);
   if (!($3681)) {
    $buffer$372 = $buffer$369;$put_bits$231 = $3678;$put_buffer$91 = $3680;$r$91 = 0;
    break;
   }
   $3682 = (($3678) + -8)|0;
   $3683 = $3680 >>> $3682;
   $3684 = $3683&255;
   $3685 = (($buffer$369) + 1|0);
   HEAP8[$buffer$369>>0] = $3684;
   $3686 = $3683 & 255;
   $3687 = ($3686|0)==(255);
   if ($3687) {
    $3688 = (($buffer$369) + 2|0);
    HEAP8[$3685>>0] = 0;
    $buffer$370 = $3688;
   } else {
    $buffer$370 = $3685;
   }
   $3689 = (($3678) + -16)|0;
   $3690 = $3680 >>> $3689;
   $3691 = $3690&255;
   $3692 = (($buffer$370) + 1|0);
   HEAP8[$buffer$370>>0] = $3691;
   $3693 = $3690 & 255;
   $3694 = ($3693|0)==(255);
   if (!($3694)) {
    $buffer$372 = $3692;$put_bits$231 = $3689;$put_buffer$91 = $3680;$r$91 = 0;
    break;
   }
   $3695 = (($buffer$370) + 2|0);
   HEAP8[$3692>>0] = 0;
   $buffer$372 = $3695;$put_bits$231 = $3689;$put_buffer$91 = $3680;$r$91 = 0;
  }
 } while(0);
 $3696 = (($block) + 102|0);
 $3697 = HEAP16[$3696>>1]|0;
 $3698 = $3697 << 16 >> 16;
 $3699 = ($3697<<16>>16)==(0);
 do {
  if ($3699) {
   $3700 = (($r$91) + 1)|0;
   $buffer$380 = $buffer$372;$put_bits$236 = $put_bits$231;$put_buffer$93 = $put_buffer$91;$r$93 = $3700;
  } else {
   $3701 = $3698 >> 31;
   $3702 = $3701 ^ $3698;
   $3703 = (($3702) - ($3701))|0;
   $3704 = (($3701) + ($3698))|0;
   $3705 = (66264 + ($3703)|0);
   $3706 = HEAP8[$3705>>0]|0;
   $3707 = $3706&255;
   $3708 = ($r$91|0)>(15);
   if ($3708) {
    $buffer$373179 = $buffer$372;$put_bits$232177 = $put_bits$231;$put_buffer$92178 = $put_buffer$91;$r$92180 = $r$91;
    while(1) {
     $3709 = (($put_bits$232177) + ($4))|0;
     $3710 = $put_buffer$92178 << $4;
     $3711 = $3710 | $1;
     $3712 = ($3709|0)>(15);
     do {
      if ($3712) {
       $3713 = (($3709) + -8)|0;
       $3714 = $3711 >>> $3713;
       $3715 = $3714&255;
       $3716 = (($buffer$373179) + 1|0);
       HEAP8[$buffer$373179>>0] = $3715;
       $3717 = $3714 & 255;
       $3718 = ($3717|0)==(255);
       if ($3718) {
        $3719 = (($buffer$373179) + 2|0);
        HEAP8[$3716>>0] = 0;
        $buffer$374 = $3719;
       } else {
        $buffer$374 = $3716;
       }
       $3720 = (($3709) + -16)|0;
       $3721 = $3711 >>> $3720;
       $3722 = $3721&255;
       $3723 = (($buffer$374) + 1|0);
       HEAP8[$buffer$374>>0] = $3722;
       $3724 = $3721 & 255;
       $3725 = ($3724|0)==(255);
       if (!($3725)) {
        $buffer$375 = $3723;$put_bits$233 = $3720;
        break;
       }
       $3726 = (($buffer$374) + 2|0);
       HEAP8[$3723>>0] = 0;
       $buffer$375 = $3726;$put_bits$233 = $3720;
      } else {
       $buffer$375 = $buffer$373179;$put_bits$233 = $3709;
      }
     } while(0);
     $3727 = (($r$92180) + -16)|0;
     $3728 = ($3727|0)>(15);
     if ($3728) {
      $buffer$373179 = $buffer$375;$put_bits$232177 = $put_bits$233;$put_buffer$92178 = $3711;$r$92180 = $3727;
     } else {
      break;
     }
    }
    $3729 = $r$91 & 15;
    $buffer$373$lcssa = $buffer$375;$put_bits$232$lcssa = $put_bits$233;$put_buffer$92$lcssa = $3711;$r$92$lcssa = $3729;
   } else {
    $buffer$373$lcssa = $buffer$372;$put_bits$232$lcssa = $put_bits$231;$put_buffer$92$lcssa = $put_buffer$91;$r$92$lcssa = $r$91;
   }
   $3730 = $r$92$lcssa << 4;
   $3731 = (($3730) + ($3707))|0;
   $3732 = (($actbl) + ($3731<<2)|0);
   $3733 = HEAP32[$3732>>2]|0;
   $3734 = ((($actbl) + ($3731)|0) + 1024|0);
   $3735 = HEAP8[$3734>>0]|0;
   $3736 = $3735 << 24 >> 24;
   $3737 = 1 << $3707;
   $3738 = (($3737) + -1)|0;
   $3739 = $3738 & $3704;
   $3740 = (($3736) + ($put_bits$232$lcssa))|0;
   $3741 = $put_buffer$92$lcssa << $3736;
   $3742 = $3741 | $3733;
   $3743 = ($3740|0)>(15);
   do {
    if ($3743) {
     $3744 = (($3740) + -8)|0;
     $3745 = $3742 >>> $3744;
     $3746 = $3745&255;
     $3747 = (($buffer$373$lcssa) + 1|0);
     HEAP8[$buffer$373$lcssa>>0] = $3746;
     $3748 = $3745 & 255;
     $3749 = ($3748|0)==(255);
     if ($3749) {
      $3750 = (($buffer$373$lcssa) + 2|0);
      HEAP8[$3747>>0] = 0;
      $buffer$376 = $3750;
     } else {
      $buffer$376 = $3747;
     }
     $3751 = (($3740) + -16)|0;
     $3752 = $3742 >>> $3751;
     $3753 = $3752&255;
     $3754 = (($buffer$376) + 1|0);
     HEAP8[$buffer$376>>0] = $3753;
     $3755 = $3752 & 255;
     $3756 = ($3755|0)==(255);
     if (!($3756)) {
      $buffer$377 = $3754;$put_bits$234 = $3751;
      break;
     }
     $3757 = (($buffer$376) + 2|0);
     HEAP8[$3754>>0] = 0;
     $buffer$377 = $3757;$put_bits$234 = $3751;
    } else {
     $buffer$377 = $buffer$373$lcssa;$put_bits$234 = $3740;
    }
   } while(0);
   $3758 = (($put_bits$234) + ($3707))|0;
   $3759 = $3742 << $3707;
   $3760 = $3759 | $3739;
   $3761 = ($3758|0)>(15);
   if (!($3761)) {
    $buffer$380 = $buffer$377;$put_bits$236 = $3758;$put_buffer$93 = $3760;$r$93 = 0;
    break;
   }
   $3762 = (($3758) + -8)|0;
   $3763 = $3760 >>> $3762;
   $3764 = $3763&255;
   $3765 = (($buffer$377) + 1|0);
   HEAP8[$buffer$377>>0] = $3764;
   $3766 = $3763 & 255;
   $3767 = ($3766|0)==(255);
   if ($3767) {
    $3768 = (($buffer$377) + 2|0);
    HEAP8[$3765>>0] = 0;
    $buffer$378 = $3768;
   } else {
    $buffer$378 = $3765;
   }
   $3769 = (($3758) + -16)|0;
   $3770 = $3760 >>> $3769;
   $3771 = $3770&255;
   $3772 = (($buffer$378) + 1|0);
   HEAP8[$buffer$378>>0] = $3771;
   $3773 = $3770 & 255;
   $3774 = ($3773|0)==(255);
   if (!($3774)) {
    $buffer$380 = $3772;$put_bits$236 = $3769;$put_buffer$93 = $3760;$r$93 = 0;
    break;
   }
   $3775 = (($buffer$378) + 2|0);
   HEAP8[$3772>>0] = 0;
   $buffer$380 = $3775;$put_bits$236 = $3769;$put_buffer$93 = $3760;$r$93 = 0;
  }
 } while(0);
 $3776 = (($block) + 116|0);
 $3777 = HEAP16[$3776>>1]|0;
 $3778 = $3777 << 16 >> 16;
 $3779 = ($3777<<16>>16)==(0);
 do {
  if ($3779) {
   $3780 = (($r$93) + 1)|0;
   $buffer$388 = $buffer$380;$put_bits$241 = $put_bits$236;$put_buffer$95 = $put_buffer$93;$r$95 = $3780;
  } else {
   $3781 = $3778 >> 31;
   $3782 = $3781 ^ $3778;
   $3783 = (($3782) - ($3781))|0;
   $3784 = (($3781) + ($3778))|0;
   $3785 = (66264 + ($3783)|0);
   $3786 = HEAP8[$3785>>0]|0;
   $3787 = $3786&255;
   $3788 = ($r$93|0)>(15);
   if ($3788) {
    $buffer$381168 = $buffer$380;$put_bits$237166 = $put_bits$236;$put_buffer$94167 = $put_buffer$93;$r$94169 = $r$93;
    while(1) {
     $3789 = (($put_bits$237166) + ($4))|0;
     $3790 = $put_buffer$94167 << $4;
     $3791 = $3790 | $1;
     $3792 = ($3789|0)>(15);
     do {
      if ($3792) {
       $3793 = (($3789) + -8)|0;
       $3794 = $3791 >>> $3793;
       $3795 = $3794&255;
       $3796 = (($buffer$381168) + 1|0);
       HEAP8[$buffer$381168>>0] = $3795;
       $3797 = $3794 & 255;
       $3798 = ($3797|0)==(255);
       if ($3798) {
        $3799 = (($buffer$381168) + 2|0);
        HEAP8[$3796>>0] = 0;
        $buffer$382 = $3799;
       } else {
        $buffer$382 = $3796;
       }
       $3800 = (($3789) + -16)|0;
       $3801 = $3791 >>> $3800;
       $3802 = $3801&255;
       $3803 = (($buffer$382) + 1|0);
       HEAP8[$buffer$382>>0] = $3802;
       $3804 = $3801 & 255;
       $3805 = ($3804|0)==(255);
       if (!($3805)) {
        $buffer$383 = $3803;$put_bits$238 = $3800;
        break;
       }
       $3806 = (($buffer$382) + 2|0);
       HEAP8[$3803>>0] = 0;
       $buffer$383 = $3806;$put_bits$238 = $3800;
      } else {
       $buffer$383 = $buffer$381168;$put_bits$238 = $3789;
      }
     } while(0);
     $3807 = (($r$94169) + -16)|0;
     $3808 = ($3807|0)>(15);
     if ($3808) {
      $buffer$381168 = $buffer$383;$put_bits$237166 = $put_bits$238;$put_buffer$94167 = $3791;$r$94169 = $3807;
     } else {
      break;
     }
    }
    $3809 = $r$93 & 15;
    $buffer$381$lcssa = $buffer$383;$put_bits$237$lcssa = $put_bits$238;$put_buffer$94$lcssa = $3791;$r$94$lcssa = $3809;
   } else {
    $buffer$381$lcssa = $buffer$380;$put_bits$237$lcssa = $put_bits$236;$put_buffer$94$lcssa = $put_buffer$93;$r$94$lcssa = $r$93;
   }
   $3810 = $r$94$lcssa << 4;
   $3811 = (($3810) + ($3787))|0;
   $3812 = (($actbl) + ($3811<<2)|0);
   $3813 = HEAP32[$3812>>2]|0;
   $3814 = ((($actbl) + ($3811)|0) + 1024|0);
   $3815 = HEAP8[$3814>>0]|0;
   $3816 = $3815 << 24 >> 24;
   $3817 = 1 << $3787;
   $3818 = (($3817) + -1)|0;
   $3819 = $3818 & $3784;
   $3820 = (($3816) + ($put_bits$237$lcssa))|0;
   $3821 = $put_buffer$94$lcssa << $3816;
   $3822 = $3821 | $3813;
   $3823 = ($3820|0)>(15);
   do {
    if ($3823) {
     $3824 = (($3820) + -8)|0;
     $3825 = $3822 >>> $3824;
     $3826 = $3825&255;
     $3827 = (($buffer$381$lcssa) + 1|0);
     HEAP8[$buffer$381$lcssa>>0] = $3826;
     $3828 = $3825 & 255;
     $3829 = ($3828|0)==(255);
     if ($3829) {
      $3830 = (($buffer$381$lcssa) + 2|0);
      HEAP8[$3827>>0] = 0;
      $buffer$384 = $3830;
     } else {
      $buffer$384 = $3827;
     }
     $3831 = (($3820) + -16)|0;
     $3832 = $3822 >>> $3831;
     $3833 = $3832&255;
     $3834 = (($buffer$384) + 1|0);
     HEAP8[$buffer$384>>0] = $3833;
     $3835 = $3832 & 255;
     $3836 = ($3835|0)==(255);
     if (!($3836)) {
      $buffer$385 = $3834;$put_bits$239 = $3831;
      break;
     }
     $3837 = (($buffer$384) + 2|0);
     HEAP8[$3834>>0] = 0;
     $buffer$385 = $3837;$put_bits$239 = $3831;
    } else {
     $buffer$385 = $buffer$381$lcssa;$put_bits$239 = $3820;
    }
   } while(0);
   $3838 = (($put_bits$239) + ($3787))|0;
   $3839 = $3822 << $3787;
   $3840 = $3839 | $3819;
   $3841 = ($3838|0)>(15);
   if (!($3841)) {
    $buffer$388 = $buffer$385;$put_bits$241 = $3838;$put_buffer$95 = $3840;$r$95 = 0;
    break;
   }
   $3842 = (($3838) + -8)|0;
   $3843 = $3840 >>> $3842;
   $3844 = $3843&255;
   $3845 = (($buffer$385) + 1|0);
   HEAP8[$buffer$385>>0] = $3844;
   $3846 = $3843 & 255;
   $3847 = ($3846|0)==(255);
   if ($3847) {
    $3848 = (($buffer$385) + 2|0);
    HEAP8[$3845>>0] = 0;
    $buffer$386 = $3848;
   } else {
    $buffer$386 = $3845;
   }
   $3849 = (($3838) + -16)|0;
   $3850 = $3840 >>> $3849;
   $3851 = $3850&255;
   $3852 = (($buffer$386) + 1|0);
   HEAP8[$buffer$386>>0] = $3851;
   $3853 = $3850 & 255;
   $3854 = ($3853|0)==(255);
   if (!($3854)) {
    $buffer$388 = $3852;$put_bits$241 = $3849;$put_buffer$95 = $3840;$r$95 = 0;
    break;
   }
   $3855 = (($buffer$386) + 2|0);
   HEAP8[$3852>>0] = 0;
   $buffer$388 = $3855;$put_bits$241 = $3849;$put_buffer$95 = $3840;$r$95 = 0;
  }
 } while(0);
 $3856 = (($block) + 118|0);
 $3857 = HEAP16[$3856>>1]|0;
 $3858 = $3857 << 16 >> 16;
 $3859 = ($3857<<16>>16)==(0);
 do {
  if ($3859) {
   $3860 = (($r$95) + 1)|0;
   $buffer$396 = $buffer$388;$put_bits$246 = $put_bits$241;$put_buffer$97 = $put_buffer$95;$r$97 = $3860;
  } else {
   $3861 = $3858 >> 31;
   $3862 = $3861 ^ $3858;
   $3863 = (($3862) - ($3861))|0;
   $3864 = (($3861) + ($3858))|0;
   $3865 = (66264 + ($3863)|0);
   $3866 = HEAP8[$3865>>0]|0;
   $3867 = $3866&255;
   $3868 = ($r$95|0)>(15);
   if ($3868) {
    $buffer$389157 = $buffer$388;$put_bits$242155 = $put_bits$241;$put_buffer$96156 = $put_buffer$95;$r$96158 = $r$95;
    while(1) {
     $3869 = (($put_bits$242155) + ($4))|0;
     $3870 = $put_buffer$96156 << $4;
     $3871 = $3870 | $1;
     $3872 = ($3869|0)>(15);
     do {
      if ($3872) {
       $3873 = (($3869) + -8)|0;
       $3874 = $3871 >>> $3873;
       $3875 = $3874&255;
       $3876 = (($buffer$389157) + 1|0);
       HEAP8[$buffer$389157>>0] = $3875;
       $3877 = $3874 & 255;
       $3878 = ($3877|0)==(255);
       if ($3878) {
        $3879 = (($buffer$389157) + 2|0);
        HEAP8[$3876>>0] = 0;
        $buffer$390 = $3879;
       } else {
        $buffer$390 = $3876;
       }
       $3880 = (($3869) + -16)|0;
       $3881 = $3871 >>> $3880;
       $3882 = $3881&255;
       $3883 = (($buffer$390) + 1|0);
       HEAP8[$buffer$390>>0] = $3882;
       $3884 = $3881 & 255;
       $3885 = ($3884|0)==(255);
       if (!($3885)) {
        $buffer$391 = $3883;$put_bits$243 = $3880;
        break;
       }
       $3886 = (($buffer$390) + 2|0);
       HEAP8[$3883>>0] = 0;
       $buffer$391 = $3886;$put_bits$243 = $3880;
      } else {
       $buffer$391 = $buffer$389157;$put_bits$243 = $3869;
      }
     } while(0);
     $3887 = (($r$96158) + -16)|0;
     $3888 = ($3887|0)>(15);
     if ($3888) {
      $buffer$389157 = $buffer$391;$put_bits$242155 = $put_bits$243;$put_buffer$96156 = $3871;$r$96158 = $3887;
     } else {
      break;
     }
    }
    $3889 = $r$95 & 15;
    $buffer$389$lcssa = $buffer$391;$put_bits$242$lcssa = $put_bits$243;$put_buffer$96$lcssa = $3871;$r$96$lcssa = $3889;
   } else {
    $buffer$389$lcssa = $buffer$388;$put_bits$242$lcssa = $put_bits$241;$put_buffer$96$lcssa = $put_buffer$95;$r$96$lcssa = $r$95;
   }
   $3890 = $r$96$lcssa << 4;
   $3891 = (($3890) + ($3867))|0;
   $3892 = (($actbl) + ($3891<<2)|0);
   $3893 = HEAP32[$3892>>2]|0;
   $3894 = ((($actbl) + ($3891)|0) + 1024|0);
   $3895 = HEAP8[$3894>>0]|0;
   $3896 = $3895 << 24 >> 24;
   $3897 = 1 << $3867;
   $3898 = (($3897) + -1)|0;
   $3899 = $3898 & $3864;
   $3900 = (($3896) + ($put_bits$242$lcssa))|0;
   $3901 = $put_buffer$96$lcssa << $3896;
   $3902 = $3901 | $3893;
   $3903 = ($3900|0)>(15);
   do {
    if ($3903) {
     $3904 = (($3900) + -8)|0;
     $3905 = $3902 >>> $3904;
     $3906 = $3905&255;
     $3907 = (($buffer$389$lcssa) + 1|0);
     HEAP8[$buffer$389$lcssa>>0] = $3906;
     $3908 = $3905 & 255;
     $3909 = ($3908|0)==(255);
     if ($3909) {
      $3910 = (($buffer$389$lcssa) + 2|0);
      HEAP8[$3907>>0] = 0;
      $buffer$392 = $3910;
     } else {
      $buffer$392 = $3907;
     }
     $3911 = (($3900) + -16)|0;
     $3912 = $3902 >>> $3911;
     $3913 = $3912&255;
     $3914 = (($buffer$392) + 1|0);
     HEAP8[$buffer$392>>0] = $3913;
     $3915 = $3912 & 255;
     $3916 = ($3915|0)==(255);
     if (!($3916)) {
      $buffer$393 = $3914;$put_bits$244 = $3911;
      break;
     }
     $3917 = (($buffer$392) + 2|0);
     HEAP8[$3914>>0] = 0;
     $buffer$393 = $3917;$put_bits$244 = $3911;
    } else {
     $buffer$393 = $buffer$389$lcssa;$put_bits$244 = $3900;
    }
   } while(0);
   $3918 = (($put_bits$244) + ($3867))|0;
   $3919 = $3902 << $3867;
   $3920 = $3919 | $3899;
   $3921 = ($3918|0)>(15);
   if (!($3921)) {
    $buffer$396 = $buffer$393;$put_bits$246 = $3918;$put_buffer$97 = $3920;$r$97 = 0;
    break;
   }
   $3922 = (($3918) + -8)|0;
   $3923 = $3920 >>> $3922;
   $3924 = $3923&255;
   $3925 = (($buffer$393) + 1|0);
   HEAP8[$buffer$393>>0] = $3924;
   $3926 = $3923 & 255;
   $3927 = ($3926|0)==(255);
   if ($3927) {
    $3928 = (($buffer$393) + 2|0);
    HEAP8[$3925>>0] = 0;
    $buffer$394 = $3928;
   } else {
    $buffer$394 = $3925;
   }
   $3929 = (($3918) + -16)|0;
   $3930 = $3920 >>> $3929;
   $3931 = $3930&255;
   $3932 = (($buffer$394) + 1|0);
   HEAP8[$buffer$394>>0] = $3931;
   $3933 = $3930 & 255;
   $3934 = ($3933|0)==(255);
   if (!($3934)) {
    $buffer$396 = $3932;$put_bits$246 = $3929;$put_buffer$97 = $3920;$r$97 = 0;
    break;
   }
   $3935 = (($buffer$394) + 2|0);
   HEAP8[$3932>>0] = 0;
   $buffer$396 = $3935;$put_bits$246 = $3929;$put_buffer$97 = $3920;$r$97 = 0;
  }
 } while(0);
 $3936 = (($block) + 104|0);
 $3937 = HEAP16[$3936>>1]|0;
 $3938 = $3937 << 16 >> 16;
 $3939 = ($3937<<16>>16)==(0);
 do {
  if ($3939) {
   $3940 = (($r$97) + 1)|0;
   $buffer$404 = $buffer$396;$put_bits$251 = $put_bits$246;$put_buffer$99 = $put_buffer$97;$r$99 = $3940;
  } else {
   $3941 = $3938 >> 31;
   $3942 = $3941 ^ $3938;
   $3943 = (($3942) - ($3941))|0;
   $3944 = (($3941) + ($3938))|0;
   $3945 = (66264 + ($3943)|0);
   $3946 = HEAP8[$3945>>0]|0;
   $3947 = $3946&255;
   $3948 = ($r$97|0)>(15);
   if ($3948) {
    $buffer$397146 = $buffer$396;$put_bits$247144 = $put_bits$246;$put_buffer$98145 = $put_buffer$97;$r$98147 = $r$97;
    while(1) {
     $3949 = (($put_bits$247144) + ($4))|0;
     $3950 = $put_buffer$98145 << $4;
     $3951 = $3950 | $1;
     $3952 = ($3949|0)>(15);
     do {
      if ($3952) {
       $3953 = (($3949) + -8)|0;
       $3954 = $3951 >>> $3953;
       $3955 = $3954&255;
       $3956 = (($buffer$397146) + 1|0);
       HEAP8[$buffer$397146>>0] = $3955;
       $3957 = $3954 & 255;
       $3958 = ($3957|0)==(255);
       if ($3958) {
        $3959 = (($buffer$397146) + 2|0);
        HEAP8[$3956>>0] = 0;
        $buffer$398 = $3959;
       } else {
        $buffer$398 = $3956;
       }
       $3960 = (($3949) + -16)|0;
       $3961 = $3951 >>> $3960;
       $3962 = $3961&255;
       $3963 = (($buffer$398) + 1|0);
       HEAP8[$buffer$398>>0] = $3962;
       $3964 = $3961 & 255;
       $3965 = ($3964|0)==(255);
       if (!($3965)) {
        $buffer$399 = $3963;$put_bits$248 = $3960;
        break;
       }
       $3966 = (($buffer$398) + 2|0);
       HEAP8[$3963>>0] = 0;
       $buffer$399 = $3966;$put_bits$248 = $3960;
      } else {
       $buffer$399 = $buffer$397146;$put_bits$248 = $3949;
      }
     } while(0);
     $3967 = (($r$98147) + -16)|0;
     $3968 = ($3967|0)>(15);
     if ($3968) {
      $buffer$397146 = $buffer$399;$put_bits$247144 = $put_bits$248;$put_buffer$98145 = $3951;$r$98147 = $3967;
     } else {
      break;
     }
    }
    $3969 = $r$97 & 15;
    $buffer$397$lcssa = $buffer$399;$put_bits$247$lcssa = $put_bits$248;$put_buffer$98$lcssa = $3951;$r$98$lcssa = $3969;
   } else {
    $buffer$397$lcssa = $buffer$396;$put_bits$247$lcssa = $put_bits$246;$put_buffer$98$lcssa = $put_buffer$97;$r$98$lcssa = $r$97;
   }
   $3970 = $r$98$lcssa << 4;
   $3971 = (($3970) + ($3947))|0;
   $3972 = (($actbl) + ($3971<<2)|0);
   $3973 = HEAP32[$3972>>2]|0;
   $3974 = ((($actbl) + ($3971)|0) + 1024|0);
   $3975 = HEAP8[$3974>>0]|0;
   $3976 = $3975 << 24 >> 24;
   $3977 = 1 << $3947;
   $3978 = (($3977) + -1)|0;
   $3979 = $3978 & $3944;
   $3980 = (($3976) + ($put_bits$247$lcssa))|0;
   $3981 = $put_buffer$98$lcssa << $3976;
   $3982 = $3981 | $3973;
   $3983 = ($3980|0)>(15);
   do {
    if ($3983) {
     $3984 = (($3980) + -8)|0;
     $3985 = $3982 >>> $3984;
     $3986 = $3985&255;
     $3987 = (($buffer$397$lcssa) + 1|0);
     HEAP8[$buffer$397$lcssa>>0] = $3986;
     $3988 = $3985 & 255;
     $3989 = ($3988|0)==(255);
     if ($3989) {
      $3990 = (($buffer$397$lcssa) + 2|0);
      HEAP8[$3987>>0] = 0;
      $buffer$400 = $3990;
     } else {
      $buffer$400 = $3987;
     }
     $3991 = (($3980) + -16)|0;
     $3992 = $3982 >>> $3991;
     $3993 = $3992&255;
     $3994 = (($buffer$400) + 1|0);
     HEAP8[$buffer$400>>0] = $3993;
     $3995 = $3992 & 255;
     $3996 = ($3995|0)==(255);
     if (!($3996)) {
      $buffer$401 = $3994;$put_bits$249 = $3991;
      break;
     }
     $3997 = (($buffer$400) + 2|0);
     HEAP8[$3994>>0] = 0;
     $buffer$401 = $3997;$put_bits$249 = $3991;
    } else {
     $buffer$401 = $buffer$397$lcssa;$put_bits$249 = $3980;
    }
   } while(0);
   $3998 = (($put_bits$249) + ($3947))|0;
   $3999 = $3982 << $3947;
   $4000 = $3999 | $3979;
   $4001 = ($3998|0)>(15);
   if (!($4001)) {
    $buffer$404 = $buffer$401;$put_bits$251 = $3998;$put_buffer$99 = $4000;$r$99 = 0;
    break;
   }
   $4002 = (($3998) + -8)|0;
   $4003 = $4000 >>> $4002;
   $4004 = $4003&255;
   $4005 = (($buffer$401) + 1|0);
   HEAP8[$buffer$401>>0] = $4004;
   $4006 = $4003 & 255;
   $4007 = ($4006|0)==(255);
   if ($4007) {
    $4008 = (($buffer$401) + 2|0);
    HEAP8[$4005>>0] = 0;
    $buffer$402 = $4008;
   } else {
    $buffer$402 = $4005;
   }
   $4009 = (($3998) + -16)|0;
   $4010 = $4000 >>> $4009;
   $4011 = $4010&255;
   $4012 = (($buffer$402) + 1|0);
   HEAP8[$buffer$402>>0] = $4011;
   $4013 = $4010 & 255;
   $4014 = ($4013|0)==(255);
   if (!($4014)) {
    $buffer$404 = $4012;$put_bits$251 = $4009;$put_buffer$99 = $4000;$r$99 = 0;
    break;
   }
   $4015 = (($buffer$402) + 2|0);
   HEAP8[$4012>>0] = 0;
   $buffer$404 = $4015;$put_bits$251 = $4009;$put_buffer$99 = $4000;$r$99 = 0;
  }
 } while(0);
 $4016 = (($block) + 90|0);
 $4017 = HEAP16[$4016>>1]|0;
 $4018 = $4017 << 16 >> 16;
 $4019 = ($4017<<16>>16)==(0);
 do {
  if ($4019) {
   $4020 = (($r$99) + 1)|0;
   $buffer$412 = $buffer$404;$put_bits$256 = $put_bits$251;$put_buffer$101 = $put_buffer$99;$r$101 = $4020;
  } else {
   $4021 = $4018 >> 31;
   $4022 = $4021 ^ $4018;
   $4023 = (($4022) - ($4021))|0;
   $4024 = (($4021) + ($4018))|0;
   $4025 = (66264 + ($4023)|0);
   $4026 = HEAP8[$4025>>0]|0;
   $4027 = $4026&255;
   $4028 = ($r$99|0)>(15);
   if ($4028) {
    $buffer$405135 = $buffer$404;$put_bits$252133 = $put_bits$251;$put_buffer$100134 = $put_buffer$99;$r$100136 = $r$99;
    while(1) {
     $4029 = (($put_bits$252133) + ($4))|0;
     $4030 = $put_buffer$100134 << $4;
     $4031 = $4030 | $1;
     $4032 = ($4029|0)>(15);
     do {
      if ($4032) {
       $4033 = (($4029) + -8)|0;
       $4034 = $4031 >>> $4033;
       $4035 = $4034&255;
       $4036 = (($buffer$405135) + 1|0);
       HEAP8[$buffer$405135>>0] = $4035;
       $4037 = $4034 & 255;
       $4038 = ($4037|0)==(255);
       if ($4038) {
        $4039 = (($buffer$405135) + 2|0);
        HEAP8[$4036>>0] = 0;
        $buffer$406 = $4039;
       } else {
        $buffer$406 = $4036;
       }
       $4040 = (($4029) + -16)|0;
       $4041 = $4031 >>> $4040;
       $4042 = $4041&255;
       $4043 = (($buffer$406) + 1|0);
       HEAP8[$buffer$406>>0] = $4042;
       $4044 = $4041 & 255;
       $4045 = ($4044|0)==(255);
       if (!($4045)) {
        $buffer$407 = $4043;$put_bits$253 = $4040;
        break;
       }
       $4046 = (($buffer$406) + 2|0);
       HEAP8[$4043>>0] = 0;
       $buffer$407 = $4046;$put_bits$253 = $4040;
      } else {
       $buffer$407 = $buffer$405135;$put_bits$253 = $4029;
      }
     } while(0);
     $4047 = (($r$100136) + -16)|0;
     $4048 = ($4047|0)>(15);
     if ($4048) {
      $buffer$405135 = $buffer$407;$put_bits$252133 = $put_bits$253;$put_buffer$100134 = $4031;$r$100136 = $4047;
     } else {
      break;
     }
    }
    $4049 = $r$99 & 15;
    $buffer$405$lcssa = $buffer$407;$put_bits$252$lcssa = $put_bits$253;$put_buffer$100$lcssa = $4031;$r$100$lcssa = $4049;
   } else {
    $buffer$405$lcssa = $buffer$404;$put_bits$252$lcssa = $put_bits$251;$put_buffer$100$lcssa = $put_buffer$99;$r$100$lcssa = $r$99;
   }
   $4050 = $r$100$lcssa << 4;
   $4051 = (($4050) + ($4027))|0;
   $4052 = (($actbl) + ($4051<<2)|0);
   $4053 = HEAP32[$4052>>2]|0;
   $4054 = ((($actbl) + ($4051)|0) + 1024|0);
   $4055 = HEAP8[$4054>>0]|0;
   $4056 = $4055 << 24 >> 24;
   $4057 = 1 << $4027;
   $4058 = (($4057) + -1)|0;
   $4059 = $4058 & $4024;
   $4060 = (($4056) + ($put_bits$252$lcssa))|0;
   $4061 = $put_buffer$100$lcssa << $4056;
   $4062 = $4061 | $4053;
   $4063 = ($4060|0)>(15);
   do {
    if ($4063) {
     $4064 = (($4060) + -8)|0;
     $4065 = $4062 >>> $4064;
     $4066 = $4065&255;
     $4067 = (($buffer$405$lcssa) + 1|0);
     HEAP8[$buffer$405$lcssa>>0] = $4066;
     $4068 = $4065 & 255;
     $4069 = ($4068|0)==(255);
     if ($4069) {
      $4070 = (($buffer$405$lcssa) + 2|0);
      HEAP8[$4067>>0] = 0;
      $buffer$408 = $4070;
     } else {
      $buffer$408 = $4067;
     }
     $4071 = (($4060) + -16)|0;
     $4072 = $4062 >>> $4071;
     $4073 = $4072&255;
     $4074 = (($buffer$408) + 1|0);
     HEAP8[$buffer$408>>0] = $4073;
     $4075 = $4072 & 255;
     $4076 = ($4075|0)==(255);
     if (!($4076)) {
      $buffer$409 = $4074;$put_bits$254 = $4071;
      break;
     }
     $4077 = (($buffer$408) + 2|0);
     HEAP8[$4074>>0] = 0;
     $buffer$409 = $4077;$put_bits$254 = $4071;
    } else {
     $buffer$409 = $buffer$405$lcssa;$put_bits$254 = $4060;
    }
   } while(0);
   $4078 = (($put_bits$254) + ($4027))|0;
   $4079 = $4062 << $4027;
   $4080 = $4079 | $4059;
   $4081 = ($4078|0)>(15);
   if (!($4081)) {
    $buffer$412 = $buffer$409;$put_bits$256 = $4078;$put_buffer$101 = $4080;$r$101 = 0;
    break;
   }
   $4082 = (($4078) + -8)|0;
   $4083 = $4080 >>> $4082;
   $4084 = $4083&255;
   $4085 = (($buffer$409) + 1|0);
   HEAP8[$buffer$409>>0] = $4084;
   $4086 = $4083 & 255;
   $4087 = ($4086|0)==(255);
   if ($4087) {
    $4088 = (($buffer$409) + 2|0);
    HEAP8[$4085>>0] = 0;
    $buffer$410 = $4088;
   } else {
    $buffer$410 = $4085;
   }
   $4089 = (($4078) + -16)|0;
   $4090 = $4080 >>> $4089;
   $4091 = $4090&255;
   $4092 = (($buffer$410) + 1|0);
   HEAP8[$buffer$410>>0] = $4091;
   $4093 = $4090 & 255;
   $4094 = ($4093|0)==(255);
   if (!($4094)) {
    $buffer$412 = $4092;$put_bits$256 = $4089;$put_buffer$101 = $4080;$r$101 = 0;
    break;
   }
   $4095 = (($buffer$410) + 2|0);
   HEAP8[$4092>>0] = 0;
   $buffer$412 = $4095;$put_bits$256 = $4089;$put_buffer$101 = $4080;$r$101 = 0;
  }
 } while(0);
 $4096 = (($block) + 76|0);
 $4097 = HEAP16[$4096>>1]|0;
 $4098 = $4097 << 16 >> 16;
 $4099 = ($4097<<16>>16)==(0);
 do {
  if ($4099) {
   $4100 = (($r$101) + 1)|0;
   $buffer$420 = $buffer$412;$put_bits$261 = $put_bits$256;$put_buffer$103 = $put_buffer$101;$r$103 = $4100;
  } else {
   $4101 = $4098 >> 31;
   $4102 = $4101 ^ $4098;
   $4103 = (($4102) - ($4101))|0;
   $4104 = (($4101) + ($4098))|0;
   $4105 = (66264 + ($4103)|0);
   $4106 = HEAP8[$4105>>0]|0;
   $4107 = $4106&255;
   $4108 = ($r$101|0)>(15);
   if ($4108) {
    $buffer$413124 = $buffer$412;$put_bits$257122 = $put_bits$256;$put_buffer$102123 = $put_buffer$101;$r$102125 = $r$101;
    while(1) {
     $4109 = (($put_bits$257122) + ($4))|0;
     $4110 = $put_buffer$102123 << $4;
     $4111 = $4110 | $1;
     $4112 = ($4109|0)>(15);
     do {
      if ($4112) {
       $4113 = (($4109) + -8)|0;
       $4114 = $4111 >>> $4113;
       $4115 = $4114&255;
       $4116 = (($buffer$413124) + 1|0);
       HEAP8[$buffer$413124>>0] = $4115;
       $4117 = $4114 & 255;
       $4118 = ($4117|0)==(255);
       if ($4118) {
        $4119 = (($buffer$413124) + 2|0);
        HEAP8[$4116>>0] = 0;
        $buffer$414 = $4119;
       } else {
        $buffer$414 = $4116;
       }
       $4120 = (($4109) + -16)|0;
       $4121 = $4111 >>> $4120;
       $4122 = $4121&255;
       $4123 = (($buffer$414) + 1|0);
       HEAP8[$buffer$414>>0] = $4122;
       $4124 = $4121 & 255;
       $4125 = ($4124|0)==(255);
       if (!($4125)) {
        $buffer$415 = $4123;$put_bits$258 = $4120;
        break;
       }
       $4126 = (($buffer$414) + 2|0);
       HEAP8[$4123>>0] = 0;
       $buffer$415 = $4126;$put_bits$258 = $4120;
      } else {
       $buffer$415 = $buffer$413124;$put_bits$258 = $4109;
      }
     } while(0);
     $4127 = (($r$102125) + -16)|0;
     $4128 = ($4127|0)>(15);
     if ($4128) {
      $buffer$413124 = $buffer$415;$put_bits$257122 = $put_bits$258;$put_buffer$102123 = $4111;$r$102125 = $4127;
     } else {
      break;
     }
    }
    $4129 = $r$101 & 15;
    $buffer$413$lcssa = $buffer$415;$put_bits$257$lcssa = $put_bits$258;$put_buffer$102$lcssa = $4111;$r$102$lcssa = $4129;
   } else {
    $buffer$413$lcssa = $buffer$412;$put_bits$257$lcssa = $put_bits$256;$put_buffer$102$lcssa = $put_buffer$101;$r$102$lcssa = $r$101;
   }
   $4130 = $r$102$lcssa << 4;
   $4131 = (($4130) + ($4107))|0;
   $4132 = (($actbl) + ($4131<<2)|0);
   $4133 = HEAP32[$4132>>2]|0;
   $4134 = ((($actbl) + ($4131)|0) + 1024|0);
   $4135 = HEAP8[$4134>>0]|0;
   $4136 = $4135 << 24 >> 24;
   $4137 = 1 << $4107;
   $4138 = (($4137) + -1)|0;
   $4139 = $4138 & $4104;
   $4140 = (($4136) + ($put_bits$257$lcssa))|0;
   $4141 = $put_buffer$102$lcssa << $4136;
   $4142 = $4141 | $4133;
   $4143 = ($4140|0)>(15);
   do {
    if ($4143) {
     $4144 = (($4140) + -8)|0;
     $4145 = $4142 >>> $4144;
     $4146 = $4145&255;
     $4147 = (($buffer$413$lcssa) + 1|0);
     HEAP8[$buffer$413$lcssa>>0] = $4146;
     $4148 = $4145 & 255;
     $4149 = ($4148|0)==(255);
     if ($4149) {
      $4150 = (($buffer$413$lcssa) + 2|0);
      HEAP8[$4147>>0] = 0;
      $buffer$416 = $4150;
     } else {
      $buffer$416 = $4147;
     }
     $4151 = (($4140) + -16)|0;
     $4152 = $4142 >>> $4151;
     $4153 = $4152&255;
     $4154 = (($buffer$416) + 1|0);
     HEAP8[$buffer$416>>0] = $4153;
     $4155 = $4152 & 255;
     $4156 = ($4155|0)==(255);
     if (!($4156)) {
      $buffer$417 = $4154;$put_bits$259 = $4151;
      break;
     }
     $4157 = (($buffer$416) + 2|0);
     HEAP8[$4154>>0] = 0;
     $buffer$417 = $4157;$put_bits$259 = $4151;
    } else {
     $buffer$417 = $buffer$413$lcssa;$put_bits$259 = $4140;
    }
   } while(0);
   $4158 = (($put_bits$259) + ($4107))|0;
   $4159 = $4142 << $4107;
   $4160 = $4159 | $4139;
   $4161 = ($4158|0)>(15);
   if (!($4161)) {
    $buffer$420 = $buffer$417;$put_bits$261 = $4158;$put_buffer$103 = $4160;$r$103 = 0;
    break;
   }
   $4162 = (($4158) + -8)|0;
   $4163 = $4160 >>> $4162;
   $4164 = $4163&255;
   $4165 = (($buffer$417) + 1|0);
   HEAP8[$buffer$417>>0] = $4164;
   $4166 = $4163 & 255;
   $4167 = ($4166|0)==(255);
   if ($4167) {
    $4168 = (($buffer$417) + 2|0);
    HEAP8[$4165>>0] = 0;
    $buffer$418 = $4168;
   } else {
    $buffer$418 = $4165;
   }
   $4169 = (($4158) + -16)|0;
   $4170 = $4160 >>> $4169;
   $4171 = $4170&255;
   $4172 = (($buffer$418) + 1|0);
   HEAP8[$buffer$418>>0] = $4171;
   $4173 = $4170 & 255;
   $4174 = ($4173|0)==(255);
   if (!($4174)) {
    $buffer$420 = $4172;$put_bits$261 = $4169;$put_buffer$103 = $4160;$r$103 = 0;
    break;
   }
   $4175 = (($buffer$418) + 2|0);
   HEAP8[$4172>>0] = 0;
   $buffer$420 = $4175;$put_bits$261 = $4169;$put_buffer$103 = $4160;$r$103 = 0;
  }
 } while(0);
 $4176 = (($block) + 62|0);
 $4177 = HEAP16[$4176>>1]|0;
 $4178 = $4177 << 16 >> 16;
 $4179 = ($4177<<16>>16)==(0);
 do {
  if ($4179) {
   $4180 = (($r$103) + 1)|0;
   $buffer$428 = $buffer$420;$put_bits$266 = $put_bits$261;$put_buffer$105 = $put_buffer$103;$r$105 = $4180;
  } else {
   $4181 = $4178 >> 31;
   $4182 = $4181 ^ $4178;
   $4183 = (($4182) - ($4181))|0;
   $4184 = (($4181) + ($4178))|0;
   $4185 = (66264 + ($4183)|0);
   $4186 = HEAP8[$4185>>0]|0;
   $4187 = $4186&255;
   $4188 = ($r$103|0)>(15);
   if ($4188) {
    $buffer$421113 = $buffer$420;$put_bits$262111 = $put_bits$261;$put_buffer$104112 = $put_buffer$103;$r$104114 = $r$103;
    while(1) {
     $4189 = (($put_bits$262111) + ($4))|0;
     $4190 = $put_buffer$104112 << $4;
     $4191 = $4190 | $1;
     $4192 = ($4189|0)>(15);
     do {
      if ($4192) {
       $4193 = (($4189) + -8)|0;
       $4194 = $4191 >>> $4193;
       $4195 = $4194&255;
       $4196 = (($buffer$421113) + 1|0);
       HEAP8[$buffer$421113>>0] = $4195;
       $4197 = $4194 & 255;
       $4198 = ($4197|0)==(255);
       if ($4198) {
        $4199 = (($buffer$421113) + 2|0);
        HEAP8[$4196>>0] = 0;
        $buffer$422 = $4199;
       } else {
        $buffer$422 = $4196;
       }
       $4200 = (($4189) + -16)|0;
       $4201 = $4191 >>> $4200;
       $4202 = $4201&255;
       $4203 = (($buffer$422) + 1|0);
       HEAP8[$buffer$422>>0] = $4202;
       $4204 = $4201 & 255;
       $4205 = ($4204|0)==(255);
       if (!($4205)) {
        $buffer$423 = $4203;$put_bits$263 = $4200;
        break;
       }
       $4206 = (($buffer$422) + 2|0);
       HEAP8[$4203>>0] = 0;
       $buffer$423 = $4206;$put_bits$263 = $4200;
      } else {
       $buffer$423 = $buffer$421113;$put_bits$263 = $4189;
      }
     } while(0);
     $4207 = (($r$104114) + -16)|0;
     $4208 = ($4207|0)>(15);
     if ($4208) {
      $buffer$421113 = $buffer$423;$put_bits$262111 = $put_bits$263;$put_buffer$104112 = $4191;$r$104114 = $4207;
     } else {
      break;
     }
    }
    $4209 = $r$103 & 15;
    $buffer$421$lcssa = $buffer$423;$put_bits$262$lcssa = $put_bits$263;$put_buffer$104$lcssa = $4191;$r$104$lcssa = $4209;
   } else {
    $buffer$421$lcssa = $buffer$420;$put_bits$262$lcssa = $put_bits$261;$put_buffer$104$lcssa = $put_buffer$103;$r$104$lcssa = $r$103;
   }
   $4210 = $r$104$lcssa << 4;
   $4211 = (($4210) + ($4187))|0;
   $4212 = (($actbl) + ($4211<<2)|0);
   $4213 = HEAP32[$4212>>2]|0;
   $4214 = ((($actbl) + ($4211)|0) + 1024|0);
   $4215 = HEAP8[$4214>>0]|0;
   $4216 = $4215 << 24 >> 24;
   $4217 = 1 << $4187;
   $4218 = (($4217) + -1)|0;
   $4219 = $4218 & $4184;
   $4220 = (($4216) + ($put_bits$262$lcssa))|0;
   $4221 = $put_buffer$104$lcssa << $4216;
   $4222 = $4221 | $4213;
   $4223 = ($4220|0)>(15);
   do {
    if ($4223) {
     $4224 = (($4220) + -8)|0;
     $4225 = $4222 >>> $4224;
     $4226 = $4225&255;
     $4227 = (($buffer$421$lcssa) + 1|0);
     HEAP8[$buffer$421$lcssa>>0] = $4226;
     $4228 = $4225 & 255;
     $4229 = ($4228|0)==(255);
     if ($4229) {
      $4230 = (($buffer$421$lcssa) + 2|0);
      HEAP8[$4227>>0] = 0;
      $buffer$424 = $4230;
     } else {
      $buffer$424 = $4227;
     }
     $4231 = (($4220) + -16)|0;
     $4232 = $4222 >>> $4231;
     $4233 = $4232&255;
     $4234 = (($buffer$424) + 1|0);
     HEAP8[$buffer$424>>0] = $4233;
     $4235 = $4232 & 255;
     $4236 = ($4235|0)==(255);
     if (!($4236)) {
      $buffer$425 = $4234;$put_bits$264 = $4231;
      break;
     }
     $4237 = (($buffer$424) + 2|0);
     HEAP8[$4234>>0] = 0;
     $buffer$425 = $4237;$put_bits$264 = $4231;
    } else {
     $buffer$425 = $buffer$421$lcssa;$put_bits$264 = $4220;
    }
   } while(0);
   $4238 = (($put_bits$264) + ($4187))|0;
   $4239 = $4222 << $4187;
   $4240 = $4239 | $4219;
   $4241 = ($4238|0)>(15);
   if (!($4241)) {
    $buffer$428 = $buffer$425;$put_bits$266 = $4238;$put_buffer$105 = $4240;$r$105 = 0;
    break;
   }
   $4242 = (($4238) + -8)|0;
   $4243 = $4240 >>> $4242;
   $4244 = $4243&255;
   $4245 = (($buffer$425) + 1|0);
   HEAP8[$buffer$425>>0] = $4244;
   $4246 = $4243 & 255;
   $4247 = ($4246|0)==(255);
   if ($4247) {
    $4248 = (($buffer$425) + 2|0);
    HEAP8[$4245>>0] = 0;
    $buffer$426 = $4248;
   } else {
    $buffer$426 = $4245;
   }
   $4249 = (($4238) + -16)|0;
   $4250 = $4240 >>> $4249;
   $4251 = $4250&255;
   $4252 = (($buffer$426) + 1|0);
   HEAP8[$buffer$426>>0] = $4251;
   $4253 = $4250 & 255;
   $4254 = ($4253|0)==(255);
   if (!($4254)) {
    $buffer$428 = $4252;$put_bits$266 = $4249;$put_buffer$105 = $4240;$r$105 = 0;
    break;
   }
   $4255 = (($buffer$426) + 2|0);
   HEAP8[$4252>>0] = 0;
   $buffer$428 = $4255;$put_bits$266 = $4249;$put_buffer$105 = $4240;$r$105 = 0;
  }
 } while(0);
 $4256 = (($block) + 78|0);
 $4257 = HEAP16[$4256>>1]|0;
 $4258 = $4257 << 16 >> 16;
 $4259 = ($4257<<16>>16)==(0);
 do {
  if ($4259) {
   $4260 = (($r$105) + 1)|0;
   $buffer$436 = $buffer$428;$put_bits$271 = $put_bits$266;$put_buffer$107 = $put_buffer$105;$r$107 = $4260;
  } else {
   $4261 = $4258 >> 31;
   $4262 = $4261 ^ $4258;
   $4263 = (($4262) - ($4261))|0;
   $4264 = (($4261) + ($4258))|0;
   $4265 = (66264 + ($4263)|0);
   $4266 = HEAP8[$4265>>0]|0;
   $4267 = $4266&255;
   $4268 = ($r$105|0)>(15);
   if ($4268) {
    $buffer$429102 = $buffer$428;$put_bits$267100 = $put_bits$266;$put_buffer$106101 = $put_buffer$105;$r$106103 = $r$105;
    while(1) {
     $4269 = (($put_bits$267100) + ($4))|0;
     $4270 = $put_buffer$106101 << $4;
     $4271 = $4270 | $1;
     $4272 = ($4269|0)>(15);
     do {
      if ($4272) {
       $4273 = (($4269) + -8)|0;
       $4274 = $4271 >>> $4273;
       $4275 = $4274&255;
       $4276 = (($buffer$429102) + 1|0);
       HEAP8[$buffer$429102>>0] = $4275;
       $4277 = $4274 & 255;
       $4278 = ($4277|0)==(255);
       if ($4278) {
        $4279 = (($buffer$429102) + 2|0);
        HEAP8[$4276>>0] = 0;
        $buffer$430 = $4279;
       } else {
        $buffer$430 = $4276;
       }
       $4280 = (($4269) + -16)|0;
       $4281 = $4271 >>> $4280;
       $4282 = $4281&255;
       $4283 = (($buffer$430) + 1|0);
       HEAP8[$buffer$430>>0] = $4282;
       $4284 = $4281 & 255;
       $4285 = ($4284|0)==(255);
       if (!($4285)) {
        $buffer$431 = $4283;$put_bits$268 = $4280;
        break;
       }
       $4286 = (($buffer$430) + 2|0);
       HEAP8[$4283>>0] = 0;
       $buffer$431 = $4286;$put_bits$268 = $4280;
      } else {
       $buffer$431 = $buffer$429102;$put_bits$268 = $4269;
      }
     } while(0);
     $4287 = (($r$106103) + -16)|0;
     $4288 = ($4287|0)>(15);
     if ($4288) {
      $buffer$429102 = $buffer$431;$put_bits$267100 = $put_bits$268;$put_buffer$106101 = $4271;$r$106103 = $4287;
     } else {
      break;
     }
    }
    $4289 = $r$105 & 15;
    $buffer$429$lcssa = $buffer$431;$put_bits$267$lcssa = $put_bits$268;$put_buffer$106$lcssa = $4271;$r$106$lcssa = $4289;
   } else {
    $buffer$429$lcssa = $buffer$428;$put_bits$267$lcssa = $put_bits$266;$put_buffer$106$lcssa = $put_buffer$105;$r$106$lcssa = $r$105;
   }
   $4290 = $r$106$lcssa << 4;
   $4291 = (($4290) + ($4267))|0;
   $4292 = (($actbl) + ($4291<<2)|0);
   $4293 = HEAP32[$4292>>2]|0;
   $4294 = ((($actbl) + ($4291)|0) + 1024|0);
   $4295 = HEAP8[$4294>>0]|0;
   $4296 = $4295 << 24 >> 24;
   $4297 = 1 << $4267;
   $4298 = (($4297) + -1)|0;
   $4299 = $4298 & $4264;
   $4300 = (($4296) + ($put_bits$267$lcssa))|0;
   $4301 = $put_buffer$106$lcssa << $4296;
   $4302 = $4301 | $4293;
   $4303 = ($4300|0)>(15);
   do {
    if ($4303) {
     $4304 = (($4300) + -8)|0;
     $4305 = $4302 >>> $4304;
     $4306 = $4305&255;
     $4307 = (($buffer$429$lcssa) + 1|0);
     HEAP8[$buffer$429$lcssa>>0] = $4306;
     $4308 = $4305 & 255;
     $4309 = ($4308|0)==(255);
     if ($4309) {
      $4310 = (($buffer$429$lcssa) + 2|0);
      HEAP8[$4307>>0] = 0;
      $buffer$432 = $4310;
     } else {
      $buffer$432 = $4307;
     }
     $4311 = (($4300) + -16)|0;
     $4312 = $4302 >>> $4311;
     $4313 = $4312&255;
     $4314 = (($buffer$432) + 1|0);
     HEAP8[$buffer$432>>0] = $4313;
     $4315 = $4312 & 255;
     $4316 = ($4315|0)==(255);
     if (!($4316)) {
      $buffer$433 = $4314;$put_bits$269 = $4311;
      break;
     }
     $4317 = (($buffer$432) + 2|0);
     HEAP8[$4314>>0] = 0;
     $buffer$433 = $4317;$put_bits$269 = $4311;
    } else {
     $buffer$433 = $buffer$429$lcssa;$put_bits$269 = $4300;
    }
   } while(0);
   $4318 = (($put_bits$269) + ($4267))|0;
   $4319 = $4302 << $4267;
   $4320 = $4319 | $4299;
   $4321 = ($4318|0)>(15);
   if (!($4321)) {
    $buffer$436 = $buffer$433;$put_bits$271 = $4318;$put_buffer$107 = $4320;$r$107 = 0;
    break;
   }
   $4322 = (($4318) + -8)|0;
   $4323 = $4320 >>> $4322;
   $4324 = $4323&255;
   $4325 = (($buffer$433) + 1|0);
   HEAP8[$buffer$433>>0] = $4324;
   $4326 = $4323 & 255;
   $4327 = ($4326|0)==(255);
   if ($4327) {
    $4328 = (($buffer$433) + 2|0);
    HEAP8[$4325>>0] = 0;
    $buffer$434 = $4328;
   } else {
    $buffer$434 = $4325;
   }
   $4329 = (($4318) + -16)|0;
   $4330 = $4320 >>> $4329;
   $4331 = $4330&255;
   $4332 = (($buffer$434) + 1|0);
   HEAP8[$buffer$434>>0] = $4331;
   $4333 = $4330 & 255;
   $4334 = ($4333|0)==(255);
   if (!($4334)) {
    $buffer$436 = $4332;$put_bits$271 = $4329;$put_buffer$107 = $4320;$r$107 = 0;
    break;
   }
   $4335 = (($buffer$434) + 2|0);
   HEAP8[$4332>>0] = 0;
   $buffer$436 = $4335;$put_bits$271 = $4329;$put_buffer$107 = $4320;$r$107 = 0;
  }
 } while(0);
 $4336 = (($block) + 92|0);
 $4337 = HEAP16[$4336>>1]|0;
 $4338 = $4337 << 16 >> 16;
 $4339 = ($4337<<16>>16)==(0);
 do {
  if ($4339) {
   $4340 = (($r$107) + 1)|0;
   $buffer$444 = $buffer$436;$put_bits$276 = $put_bits$271;$put_buffer$109 = $put_buffer$107;$r$109 = $4340;
  } else {
   $4341 = $4338 >> 31;
   $4342 = $4341 ^ $4338;
   $4343 = (($4342) - ($4341))|0;
   $4344 = (($4341) + ($4338))|0;
   $4345 = (66264 + ($4343)|0);
   $4346 = HEAP8[$4345>>0]|0;
   $4347 = $4346&255;
   $4348 = ($r$107|0)>(15);
   if ($4348) {
    $buffer$43791 = $buffer$436;$put_bits$27289 = $put_bits$271;$put_buffer$10890 = $put_buffer$107;$r$10892 = $r$107;
    while(1) {
     $4349 = (($put_bits$27289) + ($4))|0;
     $4350 = $put_buffer$10890 << $4;
     $4351 = $4350 | $1;
     $4352 = ($4349|0)>(15);
     do {
      if ($4352) {
       $4353 = (($4349) + -8)|0;
       $4354 = $4351 >>> $4353;
       $4355 = $4354&255;
       $4356 = (($buffer$43791) + 1|0);
       HEAP8[$buffer$43791>>0] = $4355;
       $4357 = $4354 & 255;
       $4358 = ($4357|0)==(255);
       if ($4358) {
        $4359 = (($buffer$43791) + 2|0);
        HEAP8[$4356>>0] = 0;
        $buffer$438 = $4359;
       } else {
        $buffer$438 = $4356;
       }
       $4360 = (($4349) + -16)|0;
       $4361 = $4351 >>> $4360;
       $4362 = $4361&255;
       $4363 = (($buffer$438) + 1|0);
       HEAP8[$buffer$438>>0] = $4362;
       $4364 = $4361 & 255;
       $4365 = ($4364|0)==(255);
       if (!($4365)) {
        $buffer$439 = $4363;$put_bits$273 = $4360;
        break;
       }
       $4366 = (($buffer$438) + 2|0);
       HEAP8[$4363>>0] = 0;
       $buffer$439 = $4366;$put_bits$273 = $4360;
      } else {
       $buffer$439 = $buffer$43791;$put_bits$273 = $4349;
      }
     } while(0);
     $4367 = (($r$10892) + -16)|0;
     $4368 = ($4367|0)>(15);
     if ($4368) {
      $buffer$43791 = $buffer$439;$put_bits$27289 = $put_bits$273;$put_buffer$10890 = $4351;$r$10892 = $4367;
     } else {
      break;
     }
    }
    $4369 = $r$107 & 15;
    $buffer$437$lcssa = $buffer$439;$put_bits$272$lcssa = $put_bits$273;$put_buffer$108$lcssa = $4351;$r$108$lcssa = $4369;
   } else {
    $buffer$437$lcssa = $buffer$436;$put_bits$272$lcssa = $put_bits$271;$put_buffer$108$lcssa = $put_buffer$107;$r$108$lcssa = $r$107;
   }
   $4370 = $r$108$lcssa << 4;
   $4371 = (($4370) + ($4347))|0;
   $4372 = (($actbl) + ($4371<<2)|0);
   $4373 = HEAP32[$4372>>2]|0;
   $4374 = ((($actbl) + ($4371)|0) + 1024|0);
   $4375 = HEAP8[$4374>>0]|0;
   $4376 = $4375 << 24 >> 24;
   $4377 = 1 << $4347;
   $4378 = (($4377) + -1)|0;
   $4379 = $4378 & $4344;
   $4380 = (($4376) + ($put_bits$272$lcssa))|0;
   $4381 = $put_buffer$108$lcssa << $4376;
   $4382 = $4381 | $4373;
   $4383 = ($4380|0)>(15);
   do {
    if ($4383) {
     $4384 = (($4380) + -8)|0;
     $4385 = $4382 >>> $4384;
     $4386 = $4385&255;
     $4387 = (($buffer$437$lcssa) + 1|0);
     HEAP8[$buffer$437$lcssa>>0] = $4386;
     $4388 = $4385 & 255;
     $4389 = ($4388|0)==(255);
     if ($4389) {
      $4390 = (($buffer$437$lcssa) + 2|0);
      HEAP8[$4387>>0] = 0;
      $buffer$440 = $4390;
     } else {
      $buffer$440 = $4387;
     }
     $4391 = (($4380) + -16)|0;
     $4392 = $4382 >>> $4391;
     $4393 = $4392&255;
     $4394 = (($buffer$440) + 1|0);
     HEAP8[$buffer$440>>0] = $4393;
     $4395 = $4392 & 255;
     $4396 = ($4395|0)==(255);
     if (!($4396)) {
      $buffer$441 = $4394;$put_bits$274 = $4391;
      break;
     }
     $4397 = (($buffer$440) + 2|0);
     HEAP8[$4394>>0] = 0;
     $buffer$441 = $4397;$put_bits$274 = $4391;
    } else {
     $buffer$441 = $buffer$437$lcssa;$put_bits$274 = $4380;
    }
   } while(0);
   $4398 = (($put_bits$274) + ($4347))|0;
   $4399 = $4382 << $4347;
   $4400 = $4399 | $4379;
   $4401 = ($4398|0)>(15);
   if (!($4401)) {
    $buffer$444 = $buffer$441;$put_bits$276 = $4398;$put_buffer$109 = $4400;$r$109 = 0;
    break;
   }
   $4402 = (($4398) + -8)|0;
   $4403 = $4400 >>> $4402;
   $4404 = $4403&255;
   $4405 = (($buffer$441) + 1|0);
   HEAP8[$buffer$441>>0] = $4404;
   $4406 = $4403 & 255;
   $4407 = ($4406|0)==(255);
   if ($4407) {
    $4408 = (($buffer$441) + 2|0);
    HEAP8[$4405>>0] = 0;
    $buffer$442 = $4408;
   } else {
    $buffer$442 = $4405;
   }
   $4409 = (($4398) + -16)|0;
   $4410 = $4400 >>> $4409;
   $4411 = $4410&255;
   $4412 = (($buffer$442) + 1|0);
   HEAP8[$buffer$442>>0] = $4411;
   $4413 = $4410 & 255;
   $4414 = ($4413|0)==(255);
   if (!($4414)) {
    $buffer$444 = $4412;$put_bits$276 = $4409;$put_buffer$109 = $4400;$r$109 = 0;
    break;
   }
   $4415 = (($buffer$442) + 2|0);
   HEAP8[$4412>>0] = 0;
   $buffer$444 = $4415;$put_bits$276 = $4409;$put_buffer$109 = $4400;$r$109 = 0;
  }
 } while(0);
 $4416 = (($block) + 106|0);
 $4417 = HEAP16[$4416>>1]|0;
 $4418 = $4417 << 16 >> 16;
 $4419 = ($4417<<16>>16)==(0);
 do {
  if ($4419) {
   $4420 = (($r$109) + 1)|0;
   $buffer$452 = $buffer$444;$put_bits$281 = $put_bits$276;$put_buffer$111 = $put_buffer$109;$r$111 = $4420;
  } else {
   $4421 = $4418 >> 31;
   $4422 = $4421 ^ $4418;
   $4423 = (($4422) - ($4421))|0;
   $4424 = (($4421) + ($4418))|0;
   $4425 = (66264 + ($4423)|0);
   $4426 = HEAP8[$4425>>0]|0;
   $4427 = $4426&255;
   $4428 = ($r$109|0)>(15);
   if ($4428) {
    $buffer$44580 = $buffer$444;$put_bits$27778 = $put_bits$276;$put_buffer$11079 = $put_buffer$109;$r$11081 = $r$109;
    while(1) {
     $4429 = (($put_bits$27778) + ($4))|0;
     $4430 = $put_buffer$11079 << $4;
     $4431 = $4430 | $1;
     $4432 = ($4429|0)>(15);
     do {
      if ($4432) {
       $4433 = (($4429) + -8)|0;
       $4434 = $4431 >>> $4433;
       $4435 = $4434&255;
       $4436 = (($buffer$44580) + 1|0);
       HEAP8[$buffer$44580>>0] = $4435;
       $4437 = $4434 & 255;
       $4438 = ($4437|0)==(255);
       if ($4438) {
        $4439 = (($buffer$44580) + 2|0);
        HEAP8[$4436>>0] = 0;
        $buffer$446 = $4439;
       } else {
        $buffer$446 = $4436;
       }
       $4440 = (($4429) + -16)|0;
       $4441 = $4431 >>> $4440;
       $4442 = $4441&255;
       $4443 = (($buffer$446) + 1|0);
       HEAP8[$buffer$446>>0] = $4442;
       $4444 = $4441 & 255;
       $4445 = ($4444|0)==(255);
       if (!($4445)) {
        $buffer$447 = $4443;$put_bits$278 = $4440;
        break;
       }
       $4446 = (($buffer$446) + 2|0);
       HEAP8[$4443>>0] = 0;
       $buffer$447 = $4446;$put_bits$278 = $4440;
      } else {
       $buffer$447 = $buffer$44580;$put_bits$278 = $4429;
      }
     } while(0);
     $4447 = (($r$11081) + -16)|0;
     $4448 = ($4447|0)>(15);
     if ($4448) {
      $buffer$44580 = $buffer$447;$put_bits$27778 = $put_bits$278;$put_buffer$11079 = $4431;$r$11081 = $4447;
     } else {
      break;
     }
    }
    $4449 = $r$109 & 15;
    $buffer$445$lcssa = $buffer$447;$put_bits$277$lcssa = $put_bits$278;$put_buffer$110$lcssa = $4431;$r$110$lcssa = $4449;
   } else {
    $buffer$445$lcssa = $buffer$444;$put_bits$277$lcssa = $put_bits$276;$put_buffer$110$lcssa = $put_buffer$109;$r$110$lcssa = $r$109;
   }
   $4450 = $r$110$lcssa << 4;
   $4451 = (($4450) + ($4427))|0;
   $4452 = (($actbl) + ($4451<<2)|0);
   $4453 = HEAP32[$4452>>2]|0;
   $4454 = ((($actbl) + ($4451)|0) + 1024|0);
   $4455 = HEAP8[$4454>>0]|0;
   $4456 = $4455 << 24 >> 24;
   $4457 = 1 << $4427;
   $4458 = (($4457) + -1)|0;
   $4459 = $4458 & $4424;
   $4460 = (($4456) + ($put_bits$277$lcssa))|0;
   $4461 = $put_buffer$110$lcssa << $4456;
   $4462 = $4461 | $4453;
   $4463 = ($4460|0)>(15);
   do {
    if ($4463) {
     $4464 = (($4460) + -8)|0;
     $4465 = $4462 >>> $4464;
     $4466 = $4465&255;
     $4467 = (($buffer$445$lcssa) + 1|0);
     HEAP8[$buffer$445$lcssa>>0] = $4466;
     $4468 = $4465 & 255;
     $4469 = ($4468|0)==(255);
     if ($4469) {
      $4470 = (($buffer$445$lcssa) + 2|0);
      HEAP8[$4467>>0] = 0;
      $buffer$448 = $4470;
     } else {
      $buffer$448 = $4467;
     }
     $4471 = (($4460) + -16)|0;
     $4472 = $4462 >>> $4471;
     $4473 = $4472&255;
     $4474 = (($buffer$448) + 1|0);
     HEAP8[$buffer$448>>0] = $4473;
     $4475 = $4472 & 255;
     $4476 = ($4475|0)==(255);
     if (!($4476)) {
      $buffer$449 = $4474;$put_bits$279 = $4471;
      break;
     }
     $4477 = (($buffer$448) + 2|0);
     HEAP8[$4474>>0] = 0;
     $buffer$449 = $4477;$put_bits$279 = $4471;
    } else {
     $buffer$449 = $buffer$445$lcssa;$put_bits$279 = $4460;
    }
   } while(0);
   $4478 = (($put_bits$279) + ($4427))|0;
   $4479 = $4462 << $4427;
   $4480 = $4479 | $4459;
   $4481 = ($4478|0)>(15);
   if (!($4481)) {
    $buffer$452 = $buffer$449;$put_bits$281 = $4478;$put_buffer$111 = $4480;$r$111 = 0;
    break;
   }
   $4482 = (($4478) + -8)|0;
   $4483 = $4480 >>> $4482;
   $4484 = $4483&255;
   $4485 = (($buffer$449) + 1|0);
   HEAP8[$buffer$449>>0] = $4484;
   $4486 = $4483 & 255;
   $4487 = ($4486|0)==(255);
   if ($4487) {
    $4488 = (($buffer$449) + 2|0);
    HEAP8[$4485>>0] = 0;
    $buffer$450 = $4488;
   } else {
    $buffer$450 = $4485;
   }
   $4489 = (($4478) + -16)|0;
   $4490 = $4480 >>> $4489;
   $4491 = $4490&255;
   $4492 = (($buffer$450) + 1|0);
   HEAP8[$buffer$450>>0] = $4491;
   $4493 = $4490 & 255;
   $4494 = ($4493|0)==(255);
   if (!($4494)) {
    $buffer$452 = $4492;$put_bits$281 = $4489;$put_buffer$111 = $4480;$r$111 = 0;
    break;
   }
   $4495 = (($buffer$450) + 2|0);
   HEAP8[$4492>>0] = 0;
   $buffer$452 = $4495;$put_bits$281 = $4489;$put_buffer$111 = $4480;$r$111 = 0;
  }
 } while(0);
 $4496 = (($block) + 120|0);
 $4497 = HEAP16[$4496>>1]|0;
 $4498 = $4497 << 16 >> 16;
 $4499 = ($4497<<16>>16)==(0);
 do {
  if ($4499) {
   $4500 = (($r$111) + 1)|0;
   $buffer$460 = $buffer$452;$put_bits$286 = $put_bits$281;$put_buffer$113 = $put_buffer$111;$r$113 = $4500;
  } else {
   $4501 = $4498 >> 31;
   $4502 = $4501 ^ $4498;
   $4503 = (($4502) - ($4501))|0;
   $4504 = (($4501) + ($4498))|0;
   $4505 = (66264 + ($4503)|0);
   $4506 = HEAP8[$4505>>0]|0;
   $4507 = $4506&255;
   $4508 = ($r$111|0)>(15);
   if ($4508) {
    $buffer$45369 = $buffer$452;$put_bits$28267 = $put_bits$281;$put_buffer$11268 = $put_buffer$111;$r$11270 = $r$111;
    while(1) {
     $4509 = (($put_bits$28267) + ($4))|0;
     $4510 = $put_buffer$11268 << $4;
     $4511 = $4510 | $1;
     $4512 = ($4509|0)>(15);
     do {
      if ($4512) {
       $4513 = (($4509) + -8)|0;
       $4514 = $4511 >>> $4513;
       $4515 = $4514&255;
       $4516 = (($buffer$45369) + 1|0);
       HEAP8[$buffer$45369>>0] = $4515;
       $4517 = $4514 & 255;
       $4518 = ($4517|0)==(255);
       if ($4518) {
        $4519 = (($buffer$45369) + 2|0);
        HEAP8[$4516>>0] = 0;
        $buffer$454 = $4519;
       } else {
        $buffer$454 = $4516;
       }
       $4520 = (($4509) + -16)|0;
       $4521 = $4511 >>> $4520;
       $4522 = $4521&255;
       $4523 = (($buffer$454) + 1|0);
       HEAP8[$buffer$454>>0] = $4522;
       $4524 = $4521 & 255;
       $4525 = ($4524|0)==(255);
       if (!($4525)) {
        $buffer$455 = $4523;$put_bits$283 = $4520;
        break;
       }
       $4526 = (($buffer$454) + 2|0);
       HEAP8[$4523>>0] = 0;
       $buffer$455 = $4526;$put_bits$283 = $4520;
      } else {
       $buffer$455 = $buffer$45369;$put_bits$283 = $4509;
      }
     } while(0);
     $4527 = (($r$11270) + -16)|0;
     $4528 = ($4527|0)>(15);
     if ($4528) {
      $buffer$45369 = $buffer$455;$put_bits$28267 = $put_bits$283;$put_buffer$11268 = $4511;$r$11270 = $4527;
     } else {
      break;
     }
    }
    $4529 = $r$111 & 15;
    $buffer$453$lcssa = $buffer$455;$put_bits$282$lcssa = $put_bits$283;$put_buffer$112$lcssa = $4511;$r$112$lcssa = $4529;
   } else {
    $buffer$453$lcssa = $buffer$452;$put_bits$282$lcssa = $put_bits$281;$put_buffer$112$lcssa = $put_buffer$111;$r$112$lcssa = $r$111;
   }
   $4530 = $r$112$lcssa << 4;
   $4531 = (($4530) + ($4507))|0;
   $4532 = (($actbl) + ($4531<<2)|0);
   $4533 = HEAP32[$4532>>2]|0;
   $4534 = ((($actbl) + ($4531)|0) + 1024|0);
   $4535 = HEAP8[$4534>>0]|0;
   $4536 = $4535 << 24 >> 24;
   $4537 = 1 << $4507;
   $4538 = (($4537) + -1)|0;
   $4539 = $4538 & $4504;
   $4540 = (($4536) + ($put_bits$282$lcssa))|0;
   $4541 = $put_buffer$112$lcssa << $4536;
   $4542 = $4541 | $4533;
   $4543 = ($4540|0)>(15);
   do {
    if ($4543) {
     $4544 = (($4540) + -8)|0;
     $4545 = $4542 >>> $4544;
     $4546 = $4545&255;
     $4547 = (($buffer$453$lcssa) + 1|0);
     HEAP8[$buffer$453$lcssa>>0] = $4546;
     $4548 = $4545 & 255;
     $4549 = ($4548|0)==(255);
     if ($4549) {
      $4550 = (($buffer$453$lcssa) + 2|0);
      HEAP8[$4547>>0] = 0;
      $buffer$456 = $4550;
     } else {
      $buffer$456 = $4547;
     }
     $4551 = (($4540) + -16)|0;
     $4552 = $4542 >>> $4551;
     $4553 = $4552&255;
     $4554 = (($buffer$456) + 1|0);
     HEAP8[$buffer$456>>0] = $4553;
     $4555 = $4552 & 255;
     $4556 = ($4555|0)==(255);
     if (!($4556)) {
      $buffer$457 = $4554;$put_bits$284 = $4551;
      break;
     }
     $4557 = (($buffer$456) + 2|0);
     HEAP8[$4554>>0] = 0;
     $buffer$457 = $4557;$put_bits$284 = $4551;
    } else {
     $buffer$457 = $buffer$453$lcssa;$put_bits$284 = $4540;
    }
   } while(0);
   $4558 = (($put_bits$284) + ($4507))|0;
   $4559 = $4542 << $4507;
   $4560 = $4559 | $4539;
   $4561 = ($4558|0)>(15);
   if (!($4561)) {
    $buffer$460 = $buffer$457;$put_bits$286 = $4558;$put_buffer$113 = $4560;$r$113 = 0;
    break;
   }
   $4562 = (($4558) + -8)|0;
   $4563 = $4560 >>> $4562;
   $4564 = $4563&255;
   $4565 = (($buffer$457) + 1|0);
   HEAP8[$buffer$457>>0] = $4564;
   $4566 = $4563 & 255;
   $4567 = ($4566|0)==(255);
   if ($4567) {
    $4568 = (($buffer$457) + 2|0);
    HEAP8[$4565>>0] = 0;
    $buffer$458 = $4568;
   } else {
    $buffer$458 = $4565;
   }
   $4569 = (($4558) + -16)|0;
   $4570 = $4560 >>> $4569;
   $4571 = $4570&255;
   $4572 = (($buffer$458) + 1|0);
   HEAP8[$buffer$458>>0] = $4571;
   $4573 = $4570 & 255;
   $4574 = ($4573|0)==(255);
   if (!($4574)) {
    $buffer$460 = $4572;$put_bits$286 = $4569;$put_buffer$113 = $4560;$r$113 = 0;
    break;
   }
   $4575 = (($buffer$458) + 2|0);
   HEAP8[$4572>>0] = 0;
   $buffer$460 = $4575;$put_bits$286 = $4569;$put_buffer$113 = $4560;$r$113 = 0;
  }
 } while(0);
 $4576 = (($block) + 122|0);
 $4577 = HEAP16[$4576>>1]|0;
 $4578 = $4577 << 16 >> 16;
 $4579 = ($4577<<16>>16)==(0);
 do {
  if ($4579) {
   $4580 = (($r$113) + 1)|0;
   $buffer$468 = $buffer$460;$put_bits$291 = $put_bits$286;$put_buffer$115 = $put_buffer$113;$r$115 = $4580;
  } else {
   $4581 = $4578 >> 31;
   $4582 = $4581 ^ $4578;
   $4583 = (($4582) - ($4581))|0;
   $4584 = (($4581) + ($4578))|0;
   $4585 = (66264 + ($4583)|0);
   $4586 = HEAP8[$4585>>0]|0;
   $4587 = $4586&255;
   $4588 = ($r$113|0)>(15);
   if ($4588) {
    $buffer$46158 = $buffer$460;$put_bits$28756 = $put_bits$286;$put_buffer$11457 = $put_buffer$113;$r$11459 = $r$113;
    while(1) {
     $4589 = (($put_bits$28756) + ($4))|0;
     $4590 = $put_buffer$11457 << $4;
     $4591 = $4590 | $1;
     $4592 = ($4589|0)>(15);
     do {
      if ($4592) {
       $4593 = (($4589) + -8)|0;
       $4594 = $4591 >>> $4593;
       $4595 = $4594&255;
       $4596 = (($buffer$46158) + 1|0);
       HEAP8[$buffer$46158>>0] = $4595;
       $4597 = $4594 & 255;
       $4598 = ($4597|0)==(255);
       if ($4598) {
        $4599 = (($buffer$46158) + 2|0);
        HEAP8[$4596>>0] = 0;
        $buffer$462 = $4599;
       } else {
        $buffer$462 = $4596;
       }
       $4600 = (($4589) + -16)|0;
       $4601 = $4591 >>> $4600;
       $4602 = $4601&255;
       $4603 = (($buffer$462) + 1|0);
       HEAP8[$buffer$462>>0] = $4602;
       $4604 = $4601 & 255;
       $4605 = ($4604|0)==(255);
       if (!($4605)) {
        $buffer$463 = $4603;$put_bits$288 = $4600;
        break;
       }
       $4606 = (($buffer$462) + 2|0);
       HEAP8[$4603>>0] = 0;
       $buffer$463 = $4606;$put_bits$288 = $4600;
      } else {
       $buffer$463 = $buffer$46158;$put_bits$288 = $4589;
      }
     } while(0);
     $4607 = (($r$11459) + -16)|0;
     $4608 = ($4607|0)>(15);
     if ($4608) {
      $buffer$46158 = $buffer$463;$put_bits$28756 = $put_bits$288;$put_buffer$11457 = $4591;$r$11459 = $4607;
     } else {
      break;
     }
    }
    $4609 = $r$113 & 15;
    $buffer$461$lcssa = $buffer$463;$put_bits$287$lcssa = $put_bits$288;$put_buffer$114$lcssa = $4591;$r$114$lcssa = $4609;
   } else {
    $buffer$461$lcssa = $buffer$460;$put_bits$287$lcssa = $put_bits$286;$put_buffer$114$lcssa = $put_buffer$113;$r$114$lcssa = $r$113;
   }
   $4610 = $r$114$lcssa << 4;
   $4611 = (($4610) + ($4587))|0;
   $4612 = (($actbl) + ($4611<<2)|0);
   $4613 = HEAP32[$4612>>2]|0;
   $4614 = ((($actbl) + ($4611)|0) + 1024|0);
   $4615 = HEAP8[$4614>>0]|0;
   $4616 = $4615 << 24 >> 24;
   $4617 = 1 << $4587;
   $4618 = (($4617) + -1)|0;
   $4619 = $4618 & $4584;
   $4620 = (($4616) + ($put_bits$287$lcssa))|0;
   $4621 = $put_buffer$114$lcssa << $4616;
   $4622 = $4621 | $4613;
   $4623 = ($4620|0)>(15);
   do {
    if ($4623) {
     $4624 = (($4620) + -8)|0;
     $4625 = $4622 >>> $4624;
     $4626 = $4625&255;
     $4627 = (($buffer$461$lcssa) + 1|0);
     HEAP8[$buffer$461$lcssa>>0] = $4626;
     $4628 = $4625 & 255;
     $4629 = ($4628|0)==(255);
     if ($4629) {
      $4630 = (($buffer$461$lcssa) + 2|0);
      HEAP8[$4627>>0] = 0;
      $buffer$464 = $4630;
     } else {
      $buffer$464 = $4627;
     }
     $4631 = (($4620) + -16)|0;
     $4632 = $4622 >>> $4631;
     $4633 = $4632&255;
     $4634 = (($buffer$464) + 1|0);
     HEAP8[$buffer$464>>0] = $4633;
     $4635 = $4632 & 255;
     $4636 = ($4635|0)==(255);
     if (!($4636)) {
      $buffer$465 = $4634;$put_bits$289 = $4631;
      break;
     }
     $4637 = (($buffer$464) + 2|0);
     HEAP8[$4634>>0] = 0;
     $buffer$465 = $4637;$put_bits$289 = $4631;
    } else {
     $buffer$465 = $buffer$461$lcssa;$put_bits$289 = $4620;
    }
   } while(0);
   $4638 = (($put_bits$289) + ($4587))|0;
   $4639 = $4622 << $4587;
   $4640 = $4639 | $4619;
   $4641 = ($4638|0)>(15);
   if (!($4641)) {
    $buffer$468 = $buffer$465;$put_bits$291 = $4638;$put_buffer$115 = $4640;$r$115 = 0;
    break;
   }
   $4642 = (($4638) + -8)|0;
   $4643 = $4640 >>> $4642;
   $4644 = $4643&255;
   $4645 = (($buffer$465) + 1|0);
   HEAP8[$buffer$465>>0] = $4644;
   $4646 = $4643 & 255;
   $4647 = ($4646|0)==(255);
   if ($4647) {
    $4648 = (($buffer$465) + 2|0);
    HEAP8[$4645>>0] = 0;
    $buffer$466 = $4648;
   } else {
    $buffer$466 = $4645;
   }
   $4649 = (($4638) + -16)|0;
   $4650 = $4640 >>> $4649;
   $4651 = $4650&255;
   $4652 = (($buffer$466) + 1|0);
   HEAP8[$buffer$466>>0] = $4651;
   $4653 = $4650 & 255;
   $4654 = ($4653|0)==(255);
   if (!($4654)) {
    $buffer$468 = $4652;$put_bits$291 = $4649;$put_buffer$115 = $4640;$r$115 = 0;
    break;
   }
   $4655 = (($buffer$466) + 2|0);
   HEAP8[$4652>>0] = 0;
   $buffer$468 = $4655;$put_bits$291 = $4649;$put_buffer$115 = $4640;$r$115 = 0;
  }
 } while(0);
 $4656 = (($block) + 108|0);
 $4657 = HEAP16[$4656>>1]|0;
 $4658 = $4657 << 16 >> 16;
 $4659 = ($4657<<16>>16)==(0);
 do {
  if ($4659) {
   $4660 = (($r$115) + 1)|0;
   $buffer$476 = $buffer$468;$put_bits$296 = $put_bits$291;$put_buffer$117 = $put_buffer$115;$r$117 = $4660;
  } else {
   $4661 = $4658 >> 31;
   $4662 = $4661 ^ $4658;
   $4663 = (($4662) - ($4661))|0;
   $4664 = (($4661) + ($4658))|0;
   $4665 = (66264 + ($4663)|0);
   $4666 = HEAP8[$4665>>0]|0;
   $4667 = $4666&255;
   $4668 = ($r$115|0)>(15);
   if ($4668) {
    $buffer$46947 = $buffer$468;$put_bits$29245 = $put_bits$291;$put_buffer$11646 = $put_buffer$115;$r$11648 = $r$115;
    while(1) {
     $4669 = (($put_bits$29245) + ($4))|0;
     $4670 = $put_buffer$11646 << $4;
     $4671 = $4670 | $1;
     $4672 = ($4669|0)>(15);
     do {
      if ($4672) {
       $4673 = (($4669) + -8)|0;
       $4674 = $4671 >>> $4673;
       $4675 = $4674&255;
       $4676 = (($buffer$46947) + 1|0);
       HEAP8[$buffer$46947>>0] = $4675;
       $4677 = $4674 & 255;
       $4678 = ($4677|0)==(255);
       if ($4678) {
        $4679 = (($buffer$46947) + 2|0);
        HEAP8[$4676>>0] = 0;
        $buffer$470 = $4679;
       } else {
        $buffer$470 = $4676;
       }
       $4680 = (($4669) + -16)|0;
       $4681 = $4671 >>> $4680;
       $4682 = $4681&255;
       $4683 = (($buffer$470) + 1|0);
       HEAP8[$buffer$470>>0] = $4682;
       $4684 = $4681 & 255;
       $4685 = ($4684|0)==(255);
       if (!($4685)) {
        $buffer$471 = $4683;$put_bits$293 = $4680;
        break;
       }
       $4686 = (($buffer$470) + 2|0);
       HEAP8[$4683>>0] = 0;
       $buffer$471 = $4686;$put_bits$293 = $4680;
      } else {
       $buffer$471 = $buffer$46947;$put_bits$293 = $4669;
      }
     } while(0);
     $4687 = (($r$11648) + -16)|0;
     $4688 = ($4687|0)>(15);
     if ($4688) {
      $buffer$46947 = $buffer$471;$put_bits$29245 = $put_bits$293;$put_buffer$11646 = $4671;$r$11648 = $4687;
     } else {
      break;
     }
    }
    $4689 = $r$115 & 15;
    $buffer$469$lcssa = $buffer$471;$put_bits$292$lcssa = $put_bits$293;$put_buffer$116$lcssa = $4671;$r$116$lcssa = $4689;
   } else {
    $buffer$469$lcssa = $buffer$468;$put_bits$292$lcssa = $put_bits$291;$put_buffer$116$lcssa = $put_buffer$115;$r$116$lcssa = $r$115;
   }
   $4690 = $r$116$lcssa << 4;
   $4691 = (($4690) + ($4667))|0;
   $4692 = (($actbl) + ($4691<<2)|0);
   $4693 = HEAP32[$4692>>2]|0;
   $4694 = ((($actbl) + ($4691)|0) + 1024|0);
   $4695 = HEAP8[$4694>>0]|0;
   $4696 = $4695 << 24 >> 24;
   $4697 = 1 << $4667;
   $4698 = (($4697) + -1)|0;
   $4699 = $4698 & $4664;
   $4700 = (($4696) + ($put_bits$292$lcssa))|0;
   $4701 = $put_buffer$116$lcssa << $4696;
   $4702 = $4701 | $4693;
   $4703 = ($4700|0)>(15);
   do {
    if ($4703) {
     $4704 = (($4700) + -8)|0;
     $4705 = $4702 >>> $4704;
     $4706 = $4705&255;
     $4707 = (($buffer$469$lcssa) + 1|0);
     HEAP8[$buffer$469$lcssa>>0] = $4706;
     $4708 = $4705 & 255;
     $4709 = ($4708|0)==(255);
     if ($4709) {
      $4710 = (($buffer$469$lcssa) + 2|0);
      HEAP8[$4707>>0] = 0;
      $buffer$472 = $4710;
     } else {
      $buffer$472 = $4707;
     }
     $4711 = (($4700) + -16)|0;
     $4712 = $4702 >>> $4711;
     $4713 = $4712&255;
     $4714 = (($buffer$472) + 1|0);
     HEAP8[$buffer$472>>0] = $4713;
     $4715 = $4712 & 255;
     $4716 = ($4715|0)==(255);
     if (!($4716)) {
      $buffer$473 = $4714;$put_bits$294 = $4711;
      break;
     }
     $4717 = (($buffer$472) + 2|0);
     HEAP8[$4714>>0] = 0;
     $buffer$473 = $4717;$put_bits$294 = $4711;
    } else {
     $buffer$473 = $buffer$469$lcssa;$put_bits$294 = $4700;
    }
   } while(0);
   $4718 = (($put_bits$294) + ($4667))|0;
   $4719 = $4702 << $4667;
   $4720 = $4719 | $4699;
   $4721 = ($4718|0)>(15);
   if (!($4721)) {
    $buffer$476 = $buffer$473;$put_bits$296 = $4718;$put_buffer$117 = $4720;$r$117 = 0;
    break;
   }
   $4722 = (($4718) + -8)|0;
   $4723 = $4720 >>> $4722;
   $4724 = $4723&255;
   $4725 = (($buffer$473) + 1|0);
   HEAP8[$buffer$473>>0] = $4724;
   $4726 = $4723 & 255;
   $4727 = ($4726|0)==(255);
   if ($4727) {
    $4728 = (($buffer$473) + 2|0);
    HEAP8[$4725>>0] = 0;
    $buffer$474 = $4728;
   } else {
    $buffer$474 = $4725;
   }
   $4729 = (($4718) + -16)|0;
   $4730 = $4720 >>> $4729;
   $4731 = $4730&255;
   $4732 = (($buffer$474) + 1|0);
   HEAP8[$buffer$474>>0] = $4731;
   $4733 = $4730 & 255;
   $4734 = ($4733|0)==(255);
   if (!($4734)) {
    $buffer$476 = $4732;$put_bits$296 = $4729;$put_buffer$117 = $4720;$r$117 = 0;
    break;
   }
   $4735 = (($buffer$474) + 2|0);
   HEAP8[$4732>>0] = 0;
   $buffer$476 = $4735;$put_bits$296 = $4729;$put_buffer$117 = $4720;$r$117 = 0;
  }
 } while(0);
 $4736 = (($block) + 94|0);
 $4737 = HEAP16[$4736>>1]|0;
 $4738 = $4737 << 16 >> 16;
 $4739 = ($4737<<16>>16)==(0);
 do {
  if ($4739) {
   $4740 = (($r$117) + 1)|0;
   $buffer$484 = $buffer$476;$put_bits$301 = $put_bits$296;$put_buffer$119 = $put_buffer$117;$r$119 = $4740;
  } else {
   $4741 = $4738 >> 31;
   $4742 = $4741 ^ $4738;
   $4743 = (($4742) - ($4741))|0;
   $4744 = (($4741) + ($4738))|0;
   $4745 = (66264 + ($4743)|0);
   $4746 = HEAP8[$4745>>0]|0;
   $4747 = $4746&255;
   $4748 = ($r$117|0)>(15);
   if ($4748) {
    $buffer$47736 = $buffer$476;$put_bits$29734 = $put_bits$296;$put_buffer$11835 = $put_buffer$117;$r$11837 = $r$117;
    while(1) {
     $4749 = (($put_bits$29734) + ($4))|0;
     $4750 = $put_buffer$11835 << $4;
     $4751 = $4750 | $1;
     $4752 = ($4749|0)>(15);
     do {
      if ($4752) {
       $4753 = (($4749) + -8)|0;
       $4754 = $4751 >>> $4753;
       $4755 = $4754&255;
       $4756 = (($buffer$47736) + 1|0);
       HEAP8[$buffer$47736>>0] = $4755;
       $4757 = $4754 & 255;
       $4758 = ($4757|0)==(255);
       if ($4758) {
        $4759 = (($buffer$47736) + 2|0);
        HEAP8[$4756>>0] = 0;
        $buffer$478 = $4759;
       } else {
        $buffer$478 = $4756;
       }
       $4760 = (($4749) + -16)|0;
       $4761 = $4751 >>> $4760;
       $4762 = $4761&255;
       $4763 = (($buffer$478) + 1|0);
       HEAP8[$buffer$478>>0] = $4762;
       $4764 = $4761 & 255;
       $4765 = ($4764|0)==(255);
       if (!($4765)) {
        $buffer$479 = $4763;$put_bits$298 = $4760;
        break;
       }
       $4766 = (($buffer$478) + 2|0);
       HEAP8[$4763>>0] = 0;
       $buffer$479 = $4766;$put_bits$298 = $4760;
      } else {
       $buffer$479 = $buffer$47736;$put_bits$298 = $4749;
      }
     } while(0);
     $4767 = (($r$11837) + -16)|0;
     $4768 = ($4767|0)>(15);
     if ($4768) {
      $buffer$47736 = $buffer$479;$put_bits$29734 = $put_bits$298;$put_buffer$11835 = $4751;$r$11837 = $4767;
     } else {
      break;
     }
    }
    $4769 = $r$117 & 15;
    $buffer$477$lcssa = $buffer$479;$put_bits$297$lcssa = $put_bits$298;$put_buffer$118$lcssa = $4751;$r$118$lcssa = $4769;
   } else {
    $buffer$477$lcssa = $buffer$476;$put_bits$297$lcssa = $put_bits$296;$put_buffer$118$lcssa = $put_buffer$117;$r$118$lcssa = $r$117;
   }
   $4770 = $r$118$lcssa << 4;
   $4771 = (($4770) + ($4747))|0;
   $4772 = (($actbl) + ($4771<<2)|0);
   $4773 = HEAP32[$4772>>2]|0;
   $4774 = ((($actbl) + ($4771)|0) + 1024|0);
   $4775 = HEAP8[$4774>>0]|0;
   $4776 = $4775 << 24 >> 24;
   $4777 = 1 << $4747;
   $4778 = (($4777) + -1)|0;
   $4779 = $4778 & $4744;
   $4780 = (($4776) + ($put_bits$297$lcssa))|0;
   $4781 = $put_buffer$118$lcssa << $4776;
   $4782 = $4781 | $4773;
   $4783 = ($4780|0)>(15);
   do {
    if ($4783) {
     $4784 = (($4780) + -8)|0;
     $4785 = $4782 >>> $4784;
     $4786 = $4785&255;
     $4787 = (($buffer$477$lcssa) + 1|0);
     HEAP8[$buffer$477$lcssa>>0] = $4786;
     $4788 = $4785 & 255;
     $4789 = ($4788|0)==(255);
     if ($4789) {
      $4790 = (($buffer$477$lcssa) + 2|0);
      HEAP8[$4787>>0] = 0;
      $buffer$480 = $4790;
     } else {
      $buffer$480 = $4787;
     }
     $4791 = (($4780) + -16)|0;
     $4792 = $4782 >>> $4791;
     $4793 = $4792&255;
     $4794 = (($buffer$480) + 1|0);
     HEAP8[$buffer$480>>0] = $4793;
     $4795 = $4792 & 255;
     $4796 = ($4795|0)==(255);
     if (!($4796)) {
      $buffer$481 = $4794;$put_bits$299 = $4791;
      break;
     }
     $4797 = (($buffer$480) + 2|0);
     HEAP8[$4794>>0] = 0;
     $buffer$481 = $4797;$put_bits$299 = $4791;
    } else {
     $buffer$481 = $buffer$477$lcssa;$put_bits$299 = $4780;
    }
   } while(0);
   $4798 = (($put_bits$299) + ($4747))|0;
   $4799 = $4782 << $4747;
   $4800 = $4799 | $4779;
   $4801 = ($4798|0)>(15);
   if (!($4801)) {
    $buffer$484 = $buffer$481;$put_bits$301 = $4798;$put_buffer$119 = $4800;$r$119 = 0;
    break;
   }
   $4802 = (($4798) + -8)|0;
   $4803 = $4800 >>> $4802;
   $4804 = $4803&255;
   $4805 = (($buffer$481) + 1|0);
   HEAP8[$buffer$481>>0] = $4804;
   $4806 = $4803 & 255;
   $4807 = ($4806|0)==(255);
   if ($4807) {
    $4808 = (($buffer$481) + 2|0);
    HEAP8[$4805>>0] = 0;
    $buffer$482 = $4808;
   } else {
    $buffer$482 = $4805;
   }
   $4809 = (($4798) + -16)|0;
   $4810 = $4800 >>> $4809;
   $4811 = $4810&255;
   $4812 = (($buffer$482) + 1|0);
   HEAP8[$buffer$482>>0] = $4811;
   $4813 = $4810 & 255;
   $4814 = ($4813|0)==(255);
   if (!($4814)) {
    $buffer$484 = $4812;$put_bits$301 = $4809;$put_buffer$119 = $4800;$r$119 = 0;
    break;
   }
   $4815 = (($buffer$482) + 2|0);
   HEAP8[$4812>>0] = 0;
   $buffer$484 = $4815;$put_bits$301 = $4809;$put_buffer$119 = $4800;$r$119 = 0;
  }
 } while(0);
 $4816 = (($block) + 110|0);
 $4817 = HEAP16[$4816>>1]|0;
 $4818 = $4817 << 16 >> 16;
 $4819 = ($4817<<16>>16)==(0);
 do {
  if ($4819) {
   $4820 = (($r$119) + 1)|0;
   $buffer$492 = $buffer$484;$put_bits$306 = $put_bits$301;$put_buffer$121 = $put_buffer$119;$r$121 = $4820;
  } else {
   $4821 = $4818 >> 31;
   $4822 = $4821 ^ $4818;
   $4823 = (($4822) - ($4821))|0;
   $4824 = (($4821) + ($4818))|0;
   $4825 = (66264 + ($4823)|0);
   $4826 = HEAP8[$4825>>0]|0;
   $4827 = $4826&255;
   $4828 = ($r$119|0)>(15);
   if ($4828) {
    $buffer$48525 = $buffer$484;$put_bits$30223 = $put_bits$301;$put_buffer$12024 = $put_buffer$119;$r$12026 = $r$119;
    while(1) {
     $4829 = (($put_bits$30223) + ($4))|0;
     $4830 = $put_buffer$12024 << $4;
     $4831 = $4830 | $1;
     $4832 = ($4829|0)>(15);
     do {
      if ($4832) {
       $4833 = (($4829) + -8)|0;
       $4834 = $4831 >>> $4833;
       $4835 = $4834&255;
       $4836 = (($buffer$48525) + 1|0);
       HEAP8[$buffer$48525>>0] = $4835;
       $4837 = $4834 & 255;
       $4838 = ($4837|0)==(255);
       if ($4838) {
        $4839 = (($buffer$48525) + 2|0);
        HEAP8[$4836>>0] = 0;
        $buffer$486 = $4839;
       } else {
        $buffer$486 = $4836;
       }
       $4840 = (($4829) + -16)|0;
       $4841 = $4831 >>> $4840;
       $4842 = $4841&255;
       $4843 = (($buffer$486) + 1|0);
       HEAP8[$buffer$486>>0] = $4842;
       $4844 = $4841 & 255;
       $4845 = ($4844|0)==(255);
       if (!($4845)) {
        $buffer$487 = $4843;$put_bits$303 = $4840;
        break;
       }
       $4846 = (($buffer$486) + 2|0);
       HEAP8[$4843>>0] = 0;
       $buffer$487 = $4846;$put_bits$303 = $4840;
      } else {
       $buffer$487 = $buffer$48525;$put_bits$303 = $4829;
      }
     } while(0);
     $4847 = (($r$12026) + -16)|0;
     $4848 = ($4847|0)>(15);
     if ($4848) {
      $buffer$48525 = $buffer$487;$put_bits$30223 = $put_bits$303;$put_buffer$12024 = $4831;$r$12026 = $4847;
     } else {
      break;
     }
    }
    $4849 = $r$119 & 15;
    $buffer$485$lcssa = $buffer$487;$put_bits$302$lcssa = $put_bits$303;$put_buffer$120$lcssa = $4831;$r$120$lcssa = $4849;
   } else {
    $buffer$485$lcssa = $buffer$484;$put_bits$302$lcssa = $put_bits$301;$put_buffer$120$lcssa = $put_buffer$119;$r$120$lcssa = $r$119;
   }
   $4850 = $r$120$lcssa << 4;
   $4851 = (($4850) + ($4827))|0;
   $4852 = (($actbl) + ($4851<<2)|0);
   $4853 = HEAP32[$4852>>2]|0;
   $4854 = ((($actbl) + ($4851)|0) + 1024|0);
   $4855 = HEAP8[$4854>>0]|0;
   $4856 = $4855 << 24 >> 24;
   $4857 = 1 << $4827;
   $4858 = (($4857) + -1)|0;
   $4859 = $4858 & $4824;
   $4860 = (($4856) + ($put_bits$302$lcssa))|0;
   $4861 = $put_buffer$120$lcssa << $4856;
   $4862 = $4861 | $4853;
   $4863 = ($4860|0)>(15);
   do {
    if ($4863) {
     $4864 = (($4860) + -8)|0;
     $4865 = $4862 >>> $4864;
     $4866 = $4865&255;
     $4867 = (($buffer$485$lcssa) + 1|0);
     HEAP8[$buffer$485$lcssa>>0] = $4866;
     $4868 = $4865 & 255;
     $4869 = ($4868|0)==(255);
     if ($4869) {
      $4870 = (($buffer$485$lcssa) + 2|0);
      HEAP8[$4867>>0] = 0;
      $buffer$488 = $4870;
     } else {
      $buffer$488 = $4867;
     }
     $4871 = (($4860) + -16)|0;
     $4872 = $4862 >>> $4871;
     $4873 = $4872&255;
     $4874 = (($buffer$488) + 1|0);
     HEAP8[$buffer$488>>0] = $4873;
     $4875 = $4872 & 255;
     $4876 = ($4875|0)==(255);
     if (!($4876)) {
      $buffer$489 = $4874;$put_bits$304 = $4871;
      break;
     }
     $4877 = (($buffer$488) + 2|0);
     HEAP8[$4874>>0] = 0;
     $buffer$489 = $4877;$put_bits$304 = $4871;
    } else {
     $buffer$489 = $buffer$485$lcssa;$put_bits$304 = $4860;
    }
   } while(0);
   $4878 = (($put_bits$304) + ($4827))|0;
   $4879 = $4862 << $4827;
   $4880 = $4879 | $4859;
   $4881 = ($4878|0)>(15);
   if (!($4881)) {
    $buffer$492 = $buffer$489;$put_bits$306 = $4878;$put_buffer$121 = $4880;$r$121 = 0;
    break;
   }
   $4882 = (($4878) + -8)|0;
   $4883 = $4880 >>> $4882;
   $4884 = $4883&255;
   $4885 = (($buffer$489) + 1|0);
   HEAP8[$buffer$489>>0] = $4884;
   $4886 = $4883 & 255;
   $4887 = ($4886|0)==(255);
   if ($4887) {
    $4888 = (($buffer$489) + 2|0);
    HEAP8[$4885>>0] = 0;
    $buffer$490 = $4888;
   } else {
    $buffer$490 = $4885;
   }
   $4889 = (($4878) + -16)|0;
   $4890 = $4880 >>> $4889;
   $4891 = $4890&255;
   $4892 = (($buffer$490) + 1|0);
   HEAP8[$buffer$490>>0] = $4891;
   $4893 = $4890 & 255;
   $4894 = ($4893|0)==(255);
   if (!($4894)) {
    $buffer$492 = $4892;$put_bits$306 = $4889;$put_buffer$121 = $4880;$r$121 = 0;
    break;
   }
   $4895 = (($buffer$490) + 2|0);
   HEAP8[$4892>>0] = 0;
   $buffer$492 = $4895;$put_bits$306 = $4889;$put_buffer$121 = $4880;$r$121 = 0;
  }
 } while(0);
 $4896 = (($block) + 124|0);
 $4897 = HEAP16[$4896>>1]|0;
 $4898 = $4897 << 16 >> 16;
 $4899 = ($4897<<16>>16)==(0);
 do {
  if ($4899) {
   $4900 = (($r$121) + 1)|0;
   $buffer$500 = $buffer$492;$put_bits$311 = $put_bits$306;$put_buffer$123 = $put_buffer$121;$r$123 = $4900;
  } else {
   $4901 = $4898 >> 31;
   $4902 = $4901 ^ $4898;
   $4903 = (($4902) - ($4901))|0;
   $4904 = (($4901) + ($4898))|0;
   $4905 = (66264 + ($4903)|0);
   $4906 = HEAP8[$4905>>0]|0;
   $4907 = $4906&255;
   $4908 = ($r$121|0)>(15);
   if ($4908) {
    $buffer$49314 = $buffer$492;$put_bits$30712 = $put_bits$306;$put_buffer$12213 = $put_buffer$121;$r$12215 = $r$121;
    while(1) {
     $4909 = (($put_bits$30712) + ($4))|0;
     $4910 = $put_buffer$12213 << $4;
     $4911 = $4910 | $1;
     $4912 = ($4909|0)>(15);
     do {
      if ($4912) {
       $4913 = (($4909) + -8)|0;
       $4914 = $4911 >>> $4913;
       $4915 = $4914&255;
       $4916 = (($buffer$49314) + 1|0);
       HEAP8[$buffer$49314>>0] = $4915;
       $4917 = $4914 & 255;
       $4918 = ($4917|0)==(255);
       if ($4918) {
        $4919 = (($buffer$49314) + 2|0);
        HEAP8[$4916>>0] = 0;
        $buffer$494 = $4919;
       } else {
        $buffer$494 = $4916;
       }
       $4920 = (($4909) + -16)|0;
       $4921 = $4911 >>> $4920;
       $4922 = $4921&255;
       $4923 = (($buffer$494) + 1|0);
       HEAP8[$buffer$494>>0] = $4922;
       $4924 = $4921 & 255;
       $4925 = ($4924|0)==(255);
       if (!($4925)) {
        $buffer$495 = $4923;$put_bits$308 = $4920;
        break;
       }
       $4926 = (($buffer$494) + 2|0);
       HEAP8[$4923>>0] = 0;
       $buffer$495 = $4926;$put_bits$308 = $4920;
      } else {
       $buffer$495 = $buffer$49314;$put_bits$308 = $4909;
      }
     } while(0);
     $4927 = (($r$12215) + -16)|0;
     $4928 = ($4927|0)>(15);
     if ($4928) {
      $buffer$49314 = $buffer$495;$put_bits$30712 = $put_bits$308;$put_buffer$12213 = $4911;$r$12215 = $4927;
     } else {
      break;
     }
    }
    $4929 = $r$121 & 15;
    $buffer$493$lcssa = $buffer$495;$put_bits$307$lcssa = $put_bits$308;$put_buffer$122$lcssa = $4911;$r$122$lcssa = $4929;
   } else {
    $buffer$493$lcssa = $buffer$492;$put_bits$307$lcssa = $put_bits$306;$put_buffer$122$lcssa = $put_buffer$121;$r$122$lcssa = $r$121;
   }
   $4930 = $r$122$lcssa << 4;
   $4931 = (($4930) + ($4907))|0;
   $4932 = (($actbl) + ($4931<<2)|0);
   $4933 = HEAP32[$4932>>2]|0;
   $4934 = ((($actbl) + ($4931)|0) + 1024|0);
   $4935 = HEAP8[$4934>>0]|0;
   $4936 = $4935 << 24 >> 24;
   $4937 = 1 << $4907;
   $4938 = (($4937) + -1)|0;
   $4939 = $4938 & $4904;
   $4940 = (($4936) + ($put_bits$307$lcssa))|0;
   $4941 = $put_buffer$122$lcssa << $4936;
   $4942 = $4941 | $4933;
   $4943 = ($4940|0)>(15);
   do {
    if ($4943) {
     $4944 = (($4940) + -8)|0;
     $4945 = $4942 >>> $4944;
     $4946 = $4945&255;
     $4947 = (($buffer$493$lcssa) + 1|0);
     HEAP8[$buffer$493$lcssa>>0] = $4946;
     $4948 = $4945 & 255;
     $4949 = ($4948|0)==(255);
     if ($4949) {
      $4950 = (($buffer$493$lcssa) + 2|0);
      HEAP8[$4947>>0] = 0;
      $buffer$496 = $4950;
     } else {
      $buffer$496 = $4947;
     }
     $4951 = (($4940) + -16)|0;
     $4952 = $4942 >>> $4951;
     $4953 = $4952&255;
     $4954 = (($buffer$496) + 1|0);
     HEAP8[$buffer$496>>0] = $4953;
     $4955 = $4952 & 255;
     $4956 = ($4955|0)==(255);
     if (!($4956)) {
      $buffer$497 = $4954;$put_bits$309 = $4951;
      break;
     }
     $4957 = (($buffer$496) + 2|0);
     HEAP8[$4954>>0] = 0;
     $buffer$497 = $4957;$put_bits$309 = $4951;
    } else {
     $buffer$497 = $buffer$493$lcssa;$put_bits$309 = $4940;
    }
   } while(0);
   $4958 = (($put_bits$309) + ($4907))|0;
   $4959 = $4942 << $4907;
   $4960 = $4959 | $4939;
   $4961 = ($4958|0)>(15);
   if (!($4961)) {
    $buffer$500 = $buffer$497;$put_bits$311 = $4958;$put_buffer$123 = $4960;$r$123 = 0;
    break;
   }
   $4962 = (($4958) + -8)|0;
   $4963 = $4960 >>> $4962;
   $4964 = $4963&255;
   $4965 = (($buffer$497) + 1|0);
   HEAP8[$buffer$497>>0] = $4964;
   $4966 = $4963 & 255;
   $4967 = ($4966|0)==(255);
   if ($4967) {
    $4968 = (($buffer$497) + 2|0);
    HEAP8[$4965>>0] = 0;
    $buffer$498 = $4968;
   } else {
    $buffer$498 = $4965;
   }
   $4969 = (($4958) + -16)|0;
   $4970 = $4960 >>> $4969;
   $4971 = $4970&255;
   $4972 = (($buffer$498) + 1|0);
   HEAP8[$buffer$498>>0] = $4971;
   $4973 = $4970 & 255;
   $4974 = ($4973|0)==(255);
   if (!($4974)) {
    $buffer$500 = $4972;$put_bits$311 = $4969;$put_buffer$123 = $4960;$r$123 = 0;
    break;
   }
   $4975 = (($buffer$498) + 2|0);
   HEAP8[$4972>>0] = 0;
   $buffer$500 = $4975;$put_bits$311 = $4969;$put_buffer$123 = $4960;$r$123 = 0;
  }
 } while(0);
 $4976 = (($block) + 126|0);
 $4977 = HEAP16[$4976>>1]|0;
 $4978 = $4977 << 16 >> 16;
 $4979 = ($4977<<16>>16)==(0);
 do {
  if ($4979) {
   $phitmp = ($r$123|0)>(-1);
   if (!($phitmp)) {
    $buffer$510 = $buffer$500;$put_bits$317 = $put_bits$311;$put_buffer$126 = $put_buffer$123;
    break;
   }
   $5055 = HEAP32[$actbl>>2]|0;
   $5056 = (($actbl) + 1024|0);
   $5057 = HEAP8[$5056>>0]|0;
   $5058 = $5057 << 24 >> 24;
   $5059 = (($5058) + ($put_bits$311))|0;
   $5060 = $put_buffer$123 << $5058;
   $5061 = $5060 | $5055;
   $5062 = ($5059|0)>(15);
   if (!($5062)) {
    $buffer$510 = $buffer$500;$put_bits$317 = $5059;$put_buffer$126 = $5061;
    break;
   }
   $5063 = (($5059) + -8)|0;
   $5064 = $5061 >>> $5063;
   $5065 = $5064&255;
   $5066 = (($buffer$500) + 1|0);
   HEAP8[$buffer$500>>0] = $5065;
   $5067 = $5064 & 255;
   $5068 = ($5067|0)==(255);
   if ($5068) {
    $5069 = (($buffer$500) + 2|0);
    HEAP8[$5066>>0] = 0;
    $buffer$509 = $5069;
   } else {
    $buffer$509 = $5066;
   }
   $5070 = (($5059) + -16)|0;
   $5071 = $5061 >>> $5070;
   $5072 = $5071&255;
   $5073 = (($buffer$509) + 1|0);
   HEAP8[$buffer$509>>0] = $5072;
   $5074 = $5071 & 255;
   $5075 = ($5074|0)==(255);
   if (!($5075)) {
    $buffer$510 = $5073;$put_bits$317 = $5070;$put_buffer$126 = $5061;
    break;
   }
   $5076 = (($buffer$509) + 2|0);
   HEAP8[$5073>>0] = 0;
   $buffer$510 = $5076;$put_bits$317 = $5070;$put_buffer$126 = $5061;
  } else {
   $4980 = $4978 >> 31;
   $4981 = $4980 ^ $4978;
   $4982 = (($4981) - ($4980))|0;
   $4983 = (($4980) + ($4978))|0;
   $4984 = (66264 + ($4982)|0);
   $4985 = HEAP8[$4984>>0]|0;
   $4986 = $4985&255;
   $4987 = ($r$123|0)>(15);
   if ($4987) {
    $buffer$5015 = $buffer$500;$put_bits$3123 = $put_bits$311;$put_buffer$1244 = $put_buffer$123;$r$1246 = $r$123;
    while(1) {
     $4988 = (($put_bits$3123) + ($4))|0;
     $4989 = $put_buffer$1244 << $4;
     $4990 = $4989 | $1;
     $4991 = ($4988|0)>(15);
     do {
      if ($4991) {
       $4992 = (($4988) + -8)|0;
       $4993 = $4990 >>> $4992;
       $4994 = $4993&255;
       $4995 = (($buffer$5015) + 1|0);
       HEAP8[$buffer$5015>>0] = $4994;
       $4996 = $4993 & 255;
       $4997 = ($4996|0)==(255);
       if ($4997) {
        $4998 = (($buffer$5015) + 2|0);
        HEAP8[$4995>>0] = 0;
        $buffer$502 = $4998;
       } else {
        $buffer$502 = $4995;
       }
       $4999 = (($4988) + -16)|0;
       $5000 = $4990 >>> $4999;
       $5001 = $5000&255;
       $5002 = (($buffer$502) + 1|0);
       HEAP8[$buffer$502>>0] = $5001;
       $5003 = $5000 & 255;
       $5004 = ($5003|0)==(255);
       if (!($5004)) {
        $buffer$503 = $5002;$put_bits$313 = $4999;
        break;
       }
       $5005 = (($buffer$502) + 2|0);
       HEAP8[$5002>>0] = 0;
       $buffer$503 = $5005;$put_bits$313 = $4999;
      } else {
       $buffer$503 = $buffer$5015;$put_bits$313 = $4988;
      }
     } while(0);
     $5006 = (($r$1246) + -16)|0;
     $5007 = ($5006|0)>(15);
     if ($5007) {
      $buffer$5015 = $buffer$503;$put_bits$3123 = $put_bits$313;$put_buffer$1244 = $4990;$r$1246 = $5006;
     } else {
      break;
     }
    }
    $5008 = $r$123 & 15;
    $buffer$501$lcssa = $buffer$503;$put_bits$312$lcssa = $put_bits$313;$put_buffer$124$lcssa = $4990;$r$124$lcssa = $5008;
   } else {
    $buffer$501$lcssa = $buffer$500;$put_bits$312$lcssa = $put_bits$311;$put_buffer$124$lcssa = $put_buffer$123;$r$124$lcssa = $r$123;
   }
   $5009 = $r$124$lcssa << 4;
   $5010 = (($5009) + ($4986))|0;
   $5011 = (($actbl) + ($5010<<2)|0);
   $5012 = HEAP32[$5011>>2]|0;
   $5013 = ((($actbl) + ($5010)|0) + 1024|0);
   $5014 = HEAP8[$5013>>0]|0;
   $5015 = $5014 << 24 >> 24;
   $5016 = 1 << $4986;
   $5017 = (($5016) + -1)|0;
   $5018 = $5017 & $4983;
   $5019 = (($5015) + ($put_bits$312$lcssa))|0;
   $5020 = $put_buffer$124$lcssa << $5015;
   $5021 = $5020 | $5012;
   $5022 = ($5019|0)>(15);
   do {
    if ($5022) {
     $5023 = (($5019) + -8)|0;
     $5024 = $5021 >>> $5023;
     $5025 = $5024&255;
     $5026 = (($buffer$501$lcssa) + 1|0);
     HEAP8[$buffer$501$lcssa>>0] = $5025;
     $5027 = $5024 & 255;
     $5028 = ($5027|0)==(255);
     if ($5028) {
      $5029 = (($buffer$501$lcssa) + 2|0);
      HEAP8[$5026>>0] = 0;
      $buffer$504 = $5029;
     } else {
      $buffer$504 = $5026;
     }
     $5030 = (($5019) + -16)|0;
     $5031 = $5021 >>> $5030;
     $5032 = $5031&255;
     $5033 = (($buffer$504) + 1|0);
     HEAP8[$buffer$504>>0] = $5032;
     $5034 = $5031 & 255;
     $5035 = ($5034|0)==(255);
     if (!($5035)) {
      $buffer$505 = $5033;$put_bits$314 = $5030;
      break;
     }
     $5036 = (($buffer$504) + 2|0);
     HEAP8[$5033>>0] = 0;
     $buffer$505 = $5036;$put_bits$314 = $5030;
    } else {
     $buffer$505 = $buffer$501$lcssa;$put_bits$314 = $5019;
    }
   } while(0);
   $5037 = (($put_bits$314) + ($4986))|0;
   $5038 = $5021 << $4986;
   $5039 = $5038 | $5018;
   $5040 = ($5037|0)>(15);
   if (!($5040)) {
    $buffer$510 = $buffer$505;$put_bits$317 = $5037;$put_buffer$126 = $5039;
    break;
   }
   $5041 = (($5037) + -8)|0;
   $5042 = $5039 >>> $5041;
   $5043 = $5042&255;
   $5044 = (($buffer$505) + 1|0);
   HEAP8[$buffer$505>>0] = $5043;
   $5045 = $5042 & 255;
   $5046 = ($5045|0)==(255);
   if ($5046) {
    $5047 = (($buffer$505) + 2|0);
    HEAP8[$5044>>0] = 0;
    $buffer$506 = $5047;
   } else {
    $buffer$506 = $5044;
   }
   $5048 = (($5037) + -16)|0;
   $5049 = $5039 >>> $5048;
   $5050 = $5049&255;
   $5051 = (($buffer$506) + 1|0);
   HEAP8[$buffer$506>>0] = $5050;
   $5052 = $5049 & 255;
   $5053 = ($5052|0)==(255);
   if (!($5053)) {
    $buffer$510 = $5051;$put_bits$317 = $5048;$put_buffer$126 = $5039;
    break;
   }
   $5054 = (($buffer$506) + 2|0);
   HEAP8[$5051>>0] = 0;
   $buffer$510 = $5054;$put_bits$317 = $5048;$put_buffer$126 = $5039;
  }
 } while(0);
 HEAP32[$5>>2] = $put_buffer$126;
 HEAP32[$7>>2] = $put_bits$317;
 $5077 = ($localbuf$0|0)==(0);
 if ($5077) {
  $5104 = HEAP32[$state>>2]|0;
  $5105 = $buffer$510;
  $5106 = $5104;
  $5107 = HEAP32[$9>>2]|0;
  $5108 = (($5106) - ($5105))|0;
  $5109 = (($5108) + ($5107))|0;
  HEAP32[$9>>2] = $5109;
  HEAP32[$state>>2] = $buffer$510;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $5078 = (($state) + 32|0);
 $5079 = ($buffer$510|0)==($_buffer|0);
 if ($5079) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $5080 = $buffer$510;
 $5081 = $_buffer;
 $5082 = (($5080) - ($5081))|0;
 $buffer$5112 = $_buffer;$bytes$01 = $5082;
 while(1) {
  $5083 = HEAP32[$9>>2]|0;
  $5084 = ($bytes$01>>>0)<($5083>>>0);
  $bytes$0$ = $5084 ? $bytes$01 : $5083;
  $5085 = HEAP32[$state>>2]|0;
  _memcpy(($5085|0),($buffer$5112|0),($bytes$0$|0))|0;
  $5086 = HEAP32[$state>>2]|0;
  $5087 = (($5086) + ($bytes$0$)|0);
  HEAP32[$state>>2] = $5087;
  $5088 = (($buffer$5112) + ($bytes$0$)|0);
  $5089 = HEAP32[$9>>2]|0;
  $5090 = (($5089) - ($bytes$0$))|0;
  HEAP32[$9>>2] = $5090;
  $5091 = ($5089|0)==($bytes$0$|0);
  if ($5091) {
   $5092 = HEAP32[$5078>>2]|0;
   $5093 = (($5092) + 24|0);
   $5094 = HEAP32[$5093>>2]|0;
   $5095 = (($5094) + 12|0);
   $5096 = HEAP32[$5095>>2]|0;
   $5097 = (FUNCTION_TABLE_ii[$5096 & 7]($5092)|0);
   $5098 = ($5097<<24>>24)==(0);
   if ($5098) {
    $$0 = 0;
    label = 1267;
    break;
   }
   $5099 = HEAP32[$5094>>2]|0;
   HEAP32[$state>>2] = $5099;
   $5100 = (($5094) + 4|0);
   $5101 = HEAP32[$5100>>2]|0;
   HEAP32[$9>>2] = $5101;
  }
  $5102 = (($bytes$01) - ($bytes$0$))|0;
  $5103 = ($bytes$01|0)==($bytes$0$|0);
  if ($5103) {
   $$0 = 1;
   label = 1267;
   break;
  } else {
   $buffer$5112 = $5088;$bytes$01 = $5102;
  }
 }
 if ((label|0) == 1267) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _jinit_compress_master($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _jinit_c_master_control($cinfo,0);
 $0 = (($cinfo) + 176|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  _jinit_color_converter($cinfo);
  _jinit_downsampler($cinfo);
  _jinit_c_prep_controller($cinfo,0);
 }
 _jinit_forward_dct($cinfo);
 $3 = (($cinfo) + 177|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 do {
  if ($5) {
   $6 = (($cinfo) + 212|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ($7<<24>>24)==(0);
   if ($8) {
    _jinit_huff_encoder($cinfo);
    break;
   } else {
    _jinit_phuff_encoder($cinfo);
    break;
   }
  } else {
   _jinit_arith_encoder($cinfo);
  }
 } while(0);
 $9 = (($cinfo) + 168|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)>(1);
 if ($11) {
  $23 = 1;
 } else {
  $12 = (($cinfo) + 178|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($cinfo) + 316|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 14|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($18<<24>>24)==(0);
   if ($19) {
    $20 = (($16) + 15|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = ($21<<24>>24)!=(0);
    $phitmp = $22&1;
    $23 = $phitmp;
   } else {
    $23 = 1;
   }
  } else {
   $23 = 1;
  }
 }
 _jinit_c_coef_controller($cinfo,$23);
 _jinit_c_main_controller($cinfo,0);
 _jinit_marker_writer($cinfo);
 $24 = (($cinfo) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 24|0);
 $27 = HEAP32[$26>>2]|0;
 FUNCTION_TABLE_vi[$27 & 63]($cinfo);
 $28 = (($cinfo) + 332|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vi[$30 & 63]($cinfo);
 STACKTOP = sp;return;
}
function _jinit_c_main_controller($cinfo,$need_full_buffer) {
 $cinfo = $cinfo|0;
 $need_full_buffer = $need_full_buffer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ci$01 = 0, $compptr$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 7]($cinfo,1,64)|0);
 $4 = (($cinfo) + 320|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$3>>2] = 6;
 $5 = (($cinfo) + 176|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = ($need_full_buffer<<24>>24)==(0);
 if (!($8)) {
  $9 = HEAP32[$cinfo>>2]|0;
  $10 = (($9) + 20|0);
  HEAP32[$10>>2] = 4;
  $11 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vi[$11 & 63]($cinfo);
  STACKTOP = sp;return;
 }
 $12 = (($cinfo) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)>(0);
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $15 = (($cinfo) + 68|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($3) + 24|0);
 $ci$01 = 0;$compptr$02 = $16;
 while(1) {
  $18 = HEAP32[$0>>2]|0;
  $19 = (($18) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($compptr$02) + 28|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $22 << 3;
  $24 = (($compptr$02) + 12|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $25 << 3;
  $27 = (FUNCTION_TABLE_iiiii[$20 & 3]($cinfo,1,$23,$26)|0);
  $28 = (($17) + ($ci$01<<2)|0);
  HEAP32[$28>>2] = $27;
  $29 = (($ci$01) + 1)|0;
  $30 = (($compptr$02) + 84|0);
  $31 = HEAP32[$12>>2]|0;
  $32 = ($29|0)<($31|0);
  if ($32) {
   $ci$01 = $29;$compptr$02 = $30;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _start_pass_main($cinfo,$pass_mode) {
 $cinfo = $cinfo|0;
 $pass_mode = $pass_mode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pass_mode$c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 320|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 176|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = ($pass_mode|0)==(0);
 if (!($5)) {
  $6 = HEAP32[$cinfo>>2]|0;
  $7 = (($6) + 20|0);
  HEAP32[$7>>2] = 4;
  $8 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vi[$8 & 63]($cinfo);
 }
 $9 = (($1) + 8|0);
 HEAP32[$9>>2] = 0;
 $10 = (($1) + 12|0);
 HEAP32[$10>>2] = 0;
 $11 = (($1) + 16|0);
 HEAP8[$11>>0] = 0;
 $12 = (($1) + 20|0);
 $pass_mode$c = $pass_mode;
 HEAP32[$12>>2] = $pass_mode$c;
 $13 = (($1) + 4|0);
 HEAP32[$13>>2] = 1;
 STACKTOP = sp;return;
}
function _process_data_simple_main($cinfo,$input_buf,$in_row_ctr,$in_rows_avail) {
 $cinfo = $cinfo|0;
 $input_buf = $input_buf|0;
 $in_row_ctr = $in_row_ctr|0;
 $in_rows_avail = $in_rows_avail|0;
 var $$c = 0, $$pr = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 320|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($cinfo) + 224|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = (($1) + 12|0);
 $8 = (($cinfo) + 324|0);
 $9 = (($1) + 24|0);
 $10 = (($cinfo) + 328|0);
 $11 = (($1) + 16|0);
 $$pre = HEAP32[$7>>2]|0;
 $12 = $$pre;
 while(1) {
  $13 = ($12>>>0)<(8);
  if ($13) {
   $14 = HEAP32[$8>>2]|0;
   $15 = (($14) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   FUNCTION_TABLE_viiiiiii[$16 & 3]($cinfo,$input_buf,$in_row_ctr,$in_rows_avail,$9,$7,8);
   $$pr = HEAP32[$7>>2]|0;
   $17 = $$pr;
  } else {
   $17 = $12;
  }
  $18 = ($17|0)==(8);
  if (!($18)) {
   label = 12;
   break;
  }
  $19 = HEAP32[$10>>2]|0;
  $20 = (($19) + 4|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (FUNCTION_TABLE_iii[$21 & 15]($cinfo,$9)|0);
  $23 = ($22<<24>>24)==(0);
  $24 = HEAP8[$11>>0]|0;
  $25 = ($24<<24>>24)!=(0);
  if ($23) {
   label = 7;
   break;
  }
  if ($25) {
   $28 = HEAP32[$in_row_ctr>>2]|0;
   $29 = (($28) + 1)|0;
   HEAP32[$in_row_ctr>>2] = $29;
   HEAP8[$11>>0] = 0;
  }
  HEAP32[$7>>2] = 0;
  $30 = HEAP32[$2>>2]|0;
  $31 = (($30) + 1)|0;
  $$c = $31;
  HEAP32[$2>>2] = $$c;
  $32 = HEAP32[$4>>2]|0;
  $33 = ($31>>>0)<($32>>>0);
  if ($33) {
   $12 = 0;
  } else {
   label = 12;
   break;
  }
 }
 if ((label|0) == 7) {
  if ($25) {
   STACKTOP = sp;return;
  }
  $26 = HEAP32[$in_row_ctr>>2]|0;
  $27 = (($26) + -1)|0;
  HEAP32[$in_row_ctr>>2] = $27;
  HEAP8[$11>>0] = 1;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 12) {
  STACKTOP = sp;return;
 }
}
function _jinit_marker_writer($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 7]($cinfo,1,32)|0);
 $4 = (($cinfo) + 332|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$3>>2] = 13;
 $5 = (($3) + 4|0);
 HEAP32[$5>>2] = 14;
 $6 = (($3) + 8|0);
 HEAP32[$6>>2] = 15;
 $7 = (($3) + 12|0);
 HEAP32[$7>>2] = 16;
 $8 = (($3) + 16|0);
 HEAP32[$8>>2] = 17;
 $9 = (($3) + 20|0);
 HEAP32[$9>>2] = 9;
 $10 = (($3) + 24|0);
 HEAP32[$10>>2] = 7;
 $11 = (($3) + 28|0);
 HEAP32[$11>>2] = 0;
 STACKTOP = sp;return;
}
function _write_file_header($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0;
 var $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0;
 var $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0;
 var $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0;
 var $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0;
 var $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 332|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1|0);
 HEAP32[$3>>2] = $5;
 HEAP8[$4>>0] = -1;
 $6 = (($3) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + -1)|0;
 HEAP32[$6>>2] = $8;
 $9 = ($8|0)==(0);
 if ($9) {
  $10 = (($3) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 7]($cinfo)|0);
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = HEAP32[$cinfo>>2]|0;
   $15 = (($14) + 20|0);
   HEAP32[$15>>2] = 24;
   $16 = HEAP32[$14>>2]|0;
   FUNCTION_TABLE_vi[$16 & 63]($cinfo);
  }
 }
 $17 = HEAP32[$2>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 1|0);
 HEAP32[$17>>2] = $19;
 HEAP8[$18>>0] = -40;
 $20 = (($17) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + -1)|0;
 HEAP32[$20>>2] = $22;
 $23 = ($22|0)==(0);
 if ($23) {
  $24 = (($17) + 12|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (FUNCTION_TABLE_ii[$25 & 7]($cinfo)|0);
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $28 = HEAP32[$cinfo>>2]|0;
   $29 = (($28) + 20|0);
   HEAP32[$29>>2] = 24;
   $30 = HEAP32[$28>>2]|0;
   FUNCTION_TABLE_vi[$30 & 63]($cinfo);
  }
 }
 $31 = (($1) + 28|0);
 HEAP32[$31>>2] = 0;
 $32 = (($cinfo) + 196|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 do {
  if (!($34)) {
   $35 = HEAP32[$2>>2]|0;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 1|0);
   HEAP32[$35>>2] = $37;
   HEAP8[$36>>0] = -1;
   $38 = (($35) + 4|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($39) + -1)|0;
   HEAP32[$38>>2] = $40;
   $41 = ($40|0)==(0);
   if ($41) {
    $42 = (($35) + 12|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (FUNCTION_TABLE_ii[$43 & 7]($cinfo)|0);
    $45 = ($44<<24>>24)==(0);
    if ($45) {
     $46 = HEAP32[$cinfo>>2]|0;
     $47 = (($46) + 20|0);
     HEAP32[$47>>2] = 24;
     $48 = HEAP32[$46>>2]|0;
     FUNCTION_TABLE_vi[$48 & 63]($cinfo);
    }
   }
   $49 = HEAP32[$2>>2]|0;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($50) + 1|0);
   HEAP32[$49>>2] = $51;
   HEAP8[$50>>0] = -32;
   $52 = (($49) + 4|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (($53) + -1)|0;
   HEAP32[$52>>2] = $54;
   $55 = ($54|0)==(0);
   if ($55) {
    $56 = (($49) + 12|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (FUNCTION_TABLE_ii[$57 & 7]($cinfo)|0);
    $59 = ($58<<24>>24)==(0);
    if ($59) {
     $60 = HEAP32[$cinfo>>2]|0;
     $61 = (($60) + 20|0);
     HEAP32[$61>>2] = 24;
     $62 = HEAP32[$60>>2]|0;
     FUNCTION_TABLE_vi[$62 & 63]($cinfo);
    }
   }
   $63 = HEAP32[$2>>2]|0;
   $64 = HEAP32[$63>>2]|0;
   $65 = (($64) + 1|0);
   HEAP32[$63>>2] = $65;
   HEAP8[$64>>0] = 0;
   $66 = (($63) + 4|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($67) + -1)|0;
   HEAP32[$66>>2] = $68;
   $69 = ($68|0)==(0);
   if ($69) {
    $70 = (($63) + 12|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (FUNCTION_TABLE_ii[$71 & 7]($cinfo)|0);
    $73 = ($72<<24>>24)==(0);
    if ($73) {
     $74 = HEAP32[$cinfo>>2]|0;
     $75 = (($74) + 20|0);
     HEAP32[$75>>2] = 24;
     $76 = HEAP32[$74>>2]|0;
     FUNCTION_TABLE_vi[$76 & 63]($cinfo);
    }
   }
   $77 = HEAP32[$2>>2]|0;
   $78 = HEAP32[$77>>2]|0;
   $79 = (($78) + 1|0);
   HEAP32[$77>>2] = $79;
   HEAP8[$78>>0] = 16;
   $80 = (($77) + 4|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (($81) + -1)|0;
   HEAP32[$80>>2] = $82;
   $83 = ($82|0)==(0);
   if ($83) {
    $84 = (($77) + 12|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = (FUNCTION_TABLE_ii[$85 & 7]($cinfo)|0);
    $87 = ($86<<24>>24)==(0);
    if ($87) {
     $88 = HEAP32[$cinfo>>2]|0;
     $89 = (($88) + 20|0);
     HEAP32[$89>>2] = 24;
     $90 = HEAP32[$88>>2]|0;
     FUNCTION_TABLE_vi[$90 & 63]($cinfo);
    }
   }
   $91 = HEAP32[$2>>2]|0;
   $92 = HEAP32[$91>>2]|0;
   $93 = (($92) + 1|0);
   HEAP32[$91>>2] = $93;
   HEAP8[$92>>0] = 74;
   $94 = (($91) + 4|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (($95) + -1)|0;
   HEAP32[$94>>2] = $96;
   $97 = ($96|0)==(0);
   if ($97) {
    $98 = (($91) + 12|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = (FUNCTION_TABLE_ii[$99 & 7]($cinfo)|0);
    $101 = ($100<<24>>24)==(0);
    if ($101) {
     $102 = HEAP32[$cinfo>>2]|0;
     $103 = (($102) + 20|0);
     HEAP32[$103>>2] = 24;
     $104 = HEAP32[$102>>2]|0;
     FUNCTION_TABLE_vi[$104 & 63]($cinfo);
    }
   }
   $105 = HEAP32[$2>>2]|0;
   $106 = HEAP32[$105>>2]|0;
   $107 = (($106) + 1|0);
   HEAP32[$105>>2] = $107;
   HEAP8[$106>>0] = 70;
   $108 = (($105) + 4|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = (($109) + -1)|0;
   HEAP32[$108>>2] = $110;
   $111 = ($110|0)==(0);
   if ($111) {
    $112 = (($105) + 12|0);
    $113 = HEAP32[$112>>2]|0;
    $114 = (FUNCTION_TABLE_ii[$113 & 7]($cinfo)|0);
    $115 = ($114<<24>>24)==(0);
    if ($115) {
     $116 = HEAP32[$cinfo>>2]|0;
     $117 = (($116) + 20|0);
     HEAP32[$117>>2] = 24;
     $118 = HEAP32[$116>>2]|0;
     FUNCTION_TABLE_vi[$118 & 63]($cinfo);
    }
   }
   $119 = HEAP32[$2>>2]|0;
   $120 = HEAP32[$119>>2]|0;
   $121 = (($120) + 1|0);
   HEAP32[$119>>2] = $121;
   HEAP8[$120>>0] = 73;
   $122 = (($119) + 4|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + -1)|0;
   HEAP32[$122>>2] = $124;
   $125 = ($124|0)==(0);
   if ($125) {
    $126 = (($119) + 12|0);
    $127 = HEAP32[$126>>2]|0;
    $128 = (FUNCTION_TABLE_ii[$127 & 7]($cinfo)|0);
    $129 = ($128<<24>>24)==(0);
    if ($129) {
     $130 = HEAP32[$cinfo>>2]|0;
     $131 = (($130) + 20|0);
     HEAP32[$131>>2] = 24;
     $132 = HEAP32[$130>>2]|0;
     FUNCTION_TABLE_vi[$132 & 63]($cinfo);
    }
   }
   $133 = HEAP32[$2>>2]|0;
   $134 = HEAP32[$133>>2]|0;
   $135 = (($134) + 1|0);
   HEAP32[$133>>2] = $135;
   HEAP8[$134>>0] = 70;
   $136 = (($133) + 4|0);
   $137 = HEAP32[$136>>2]|0;
   $138 = (($137) + -1)|0;
   HEAP32[$136>>2] = $138;
   $139 = ($138|0)==(0);
   if ($139) {
    $140 = (($133) + 12|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = (FUNCTION_TABLE_ii[$141 & 7]($cinfo)|0);
    $143 = ($142<<24>>24)==(0);
    if ($143) {
     $144 = HEAP32[$cinfo>>2]|0;
     $145 = (($144) + 20|0);
     HEAP32[$145>>2] = 24;
     $146 = HEAP32[$144>>2]|0;
     FUNCTION_TABLE_vi[$146 & 63]($cinfo);
    }
   }
   $147 = HEAP32[$2>>2]|0;
   $148 = HEAP32[$147>>2]|0;
   $149 = (($148) + 1|0);
   HEAP32[$147>>2] = $149;
   HEAP8[$148>>0] = 0;
   $150 = (($147) + 4|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = (($151) + -1)|0;
   HEAP32[$150>>2] = $152;
   $153 = ($152|0)==(0);
   if ($153) {
    $154 = (($147) + 12|0);
    $155 = HEAP32[$154>>2]|0;
    $156 = (FUNCTION_TABLE_ii[$155 & 7]($cinfo)|0);
    $157 = ($156<<24>>24)==(0);
    if ($157) {
     $158 = HEAP32[$cinfo>>2]|0;
     $159 = (($158) + 20|0);
     HEAP32[$159>>2] = 24;
     $160 = HEAP32[$158>>2]|0;
     FUNCTION_TABLE_vi[$160 & 63]($cinfo);
    }
   }
   $161 = (($cinfo) + 197|0);
   $162 = HEAP8[$161>>0]|0;
   $163 = HEAP32[$2>>2]|0;
   $164 = HEAP32[$163>>2]|0;
   $165 = (($164) + 1|0);
   HEAP32[$163>>2] = $165;
   HEAP8[$164>>0] = $162;
   $166 = (($163) + 4|0);
   $167 = HEAP32[$166>>2]|0;
   $168 = (($167) + -1)|0;
   HEAP32[$166>>2] = $168;
   $169 = ($168|0)==(0);
   if ($169) {
    $170 = (($163) + 12|0);
    $171 = HEAP32[$170>>2]|0;
    $172 = (FUNCTION_TABLE_ii[$171 & 7]($cinfo)|0);
    $173 = ($172<<24>>24)==(0);
    if ($173) {
     $174 = HEAP32[$cinfo>>2]|0;
     $175 = (($174) + 20|0);
     HEAP32[$175>>2] = 24;
     $176 = HEAP32[$174>>2]|0;
     FUNCTION_TABLE_vi[$176 & 63]($cinfo);
    }
   }
   $177 = (($cinfo) + 198|0);
   $178 = HEAP8[$177>>0]|0;
   $179 = HEAP32[$2>>2]|0;
   $180 = HEAP32[$179>>2]|0;
   $181 = (($180) + 1|0);
   HEAP32[$179>>2] = $181;
   HEAP8[$180>>0] = $178;
   $182 = (($179) + 4|0);
   $183 = HEAP32[$182>>2]|0;
   $184 = (($183) + -1)|0;
   HEAP32[$182>>2] = $184;
   $185 = ($184|0)==(0);
   if ($185) {
    $186 = (($179) + 12|0);
    $187 = HEAP32[$186>>2]|0;
    $188 = (FUNCTION_TABLE_ii[$187 & 7]($cinfo)|0);
    $189 = ($188<<24>>24)==(0);
    if ($189) {
     $190 = HEAP32[$cinfo>>2]|0;
     $191 = (($190) + 20|0);
     HEAP32[$191>>2] = 24;
     $192 = HEAP32[$190>>2]|0;
     FUNCTION_TABLE_vi[$192 & 63]($cinfo);
    }
   }
   $193 = (($cinfo) + 199|0);
   $194 = HEAP8[$193>>0]|0;
   $195 = HEAP32[$2>>2]|0;
   $196 = HEAP32[$195>>2]|0;
   $197 = (($196) + 1|0);
   HEAP32[$195>>2] = $197;
   HEAP8[$196>>0] = $194;
   $198 = (($195) + 4|0);
   $199 = HEAP32[$198>>2]|0;
   $200 = (($199) + -1)|0;
   HEAP32[$198>>2] = $200;
   $201 = ($200|0)==(0);
   if ($201) {
    $202 = (($195) + 12|0);
    $203 = HEAP32[$202>>2]|0;
    $204 = (FUNCTION_TABLE_ii[$203 & 7]($cinfo)|0);
    $205 = ($204<<24>>24)==(0);
    if ($205) {
     $206 = HEAP32[$cinfo>>2]|0;
     $207 = (($206) + 20|0);
     HEAP32[$207>>2] = 24;
     $208 = HEAP32[$206>>2]|0;
     FUNCTION_TABLE_vi[$208 & 63]($cinfo);
    }
   }
   $209 = (($cinfo) + 200|0);
   $210 = HEAP16[$209>>1]|0;
   $211 = HEAP32[$2>>2]|0;
   $212 = ($210&65535) >>> 8;
   $213 = $212&255;
   $214 = HEAP32[$211>>2]|0;
   $215 = (($214) + 1|0);
   HEAP32[$211>>2] = $215;
   HEAP8[$214>>0] = $213;
   $216 = (($211) + 4|0);
   $217 = HEAP32[$216>>2]|0;
   $218 = (($217) + -1)|0;
   HEAP32[$216>>2] = $218;
   $219 = ($218|0)==(0);
   if ($219) {
    $220 = (($211) + 12|0);
    $221 = HEAP32[$220>>2]|0;
    $222 = (FUNCTION_TABLE_ii[$221 & 7]($cinfo)|0);
    $223 = ($222<<24>>24)==(0);
    if ($223) {
     $224 = HEAP32[$cinfo>>2]|0;
     $225 = (($224) + 20|0);
     HEAP32[$225>>2] = 24;
     $226 = HEAP32[$224>>2]|0;
     FUNCTION_TABLE_vi[$226 & 63]($cinfo);
    }
   }
   $227 = HEAP32[$2>>2]|0;
   $228 = $210&255;
   $229 = HEAP32[$227>>2]|0;
   $230 = (($229) + 1|0);
   HEAP32[$227>>2] = $230;
   HEAP8[$229>>0] = $228;
   $231 = (($227) + 4|0);
   $232 = HEAP32[$231>>2]|0;
   $233 = (($232) + -1)|0;
   HEAP32[$231>>2] = $233;
   $234 = ($233|0)==(0);
   if ($234) {
    $235 = (($227) + 12|0);
    $236 = HEAP32[$235>>2]|0;
    $237 = (FUNCTION_TABLE_ii[$236 & 7]($cinfo)|0);
    $238 = ($237<<24>>24)==(0);
    if ($238) {
     $239 = HEAP32[$cinfo>>2]|0;
     $240 = (($239) + 20|0);
     HEAP32[$240>>2] = 24;
     $241 = HEAP32[$239>>2]|0;
     FUNCTION_TABLE_vi[$241 & 63]($cinfo);
    }
   }
   $242 = (($cinfo) + 202|0);
   $243 = HEAP16[$242>>1]|0;
   $244 = HEAP32[$2>>2]|0;
   $245 = ($243&65535) >>> 8;
   $246 = $245&255;
   $247 = HEAP32[$244>>2]|0;
   $248 = (($247) + 1|0);
   HEAP32[$244>>2] = $248;
   HEAP8[$247>>0] = $246;
   $249 = (($244) + 4|0);
   $250 = HEAP32[$249>>2]|0;
   $251 = (($250) + -1)|0;
   HEAP32[$249>>2] = $251;
   $252 = ($251|0)==(0);
   do {
    if ($252) {
     $253 = (($244) + 12|0);
     $254 = HEAP32[$253>>2]|0;
     $255 = (FUNCTION_TABLE_ii[$254 & 7]($cinfo)|0);
     $256 = ($255<<24>>24)==(0);
     if (!($256)) {
      break;
     }
     $257 = HEAP32[$cinfo>>2]|0;
     $258 = (($257) + 20|0);
     HEAP32[$258>>2] = 24;
     $259 = HEAP32[$257>>2]|0;
     FUNCTION_TABLE_vi[$259 & 63]($cinfo);
    }
   } while(0);
   $260 = HEAP32[$2>>2]|0;
   $261 = $243&255;
   $262 = HEAP32[$260>>2]|0;
   $263 = (($262) + 1|0);
   HEAP32[$260>>2] = $263;
   HEAP8[$262>>0] = $261;
   $264 = (($260) + 4|0);
   $265 = HEAP32[$264>>2]|0;
   $266 = (($265) + -1)|0;
   HEAP32[$264>>2] = $266;
   $267 = ($266|0)==(0);
   do {
    if ($267) {
     $268 = (($260) + 12|0);
     $269 = HEAP32[$268>>2]|0;
     $270 = (FUNCTION_TABLE_ii[$269 & 7]($cinfo)|0);
     $271 = ($270<<24>>24)==(0);
     if (!($271)) {
      break;
     }
     $272 = HEAP32[$cinfo>>2]|0;
     $273 = (($272) + 20|0);
     HEAP32[$273>>2] = 24;
     $274 = HEAP32[$272>>2]|0;
     FUNCTION_TABLE_vi[$274 & 63]($cinfo);
    }
   } while(0);
   $275 = HEAP32[$2>>2]|0;
   $276 = HEAP32[$275>>2]|0;
   $277 = (($276) + 1|0);
   HEAP32[$275>>2] = $277;
   HEAP8[$276>>0] = 0;
   $278 = (($275) + 4|0);
   $279 = HEAP32[$278>>2]|0;
   $280 = (($279) + -1)|0;
   HEAP32[$278>>2] = $280;
   $281 = ($280|0)==(0);
   do {
    if ($281) {
     $282 = (($275) + 12|0);
     $283 = HEAP32[$282>>2]|0;
     $284 = (FUNCTION_TABLE_ii[$283 & 7]($cinfo)|0);
     $285 = ($284<<24>>24)==(0);
     if (!($285)) {
      break;
     }
     $286 = HEAP32[$cinfo>>2]|0;
     $287 = (($286) + 20|0);
     HEAP32[$287>>2] = 24;
     $288 = HEAP32[$286>>2]|0;
     FUNCTION_TABLE_vi[$288 & 63]($cinfo);
    }
   } while(0);
   $289 = HEAP32[$2>>2]|0;
   $290 = HEAP32[$289>>2]|0;
   $291 = (($290) + 1|0);
   HEAP32[$289>>2] = $291;
   HEAP8[$290>>0] = 0;
   $292 = (($289) + 4|0);
   $293 = HEAP32[$292>>2]|0;
   $294 = (($293) + -1)|0;
   HEAP32[$292>>2] = $294;
   $295 = ($294|0)==(0);
   if (!($295)) {
    break;
   }
   $296 = (($289) + 12|0);
   $297 = HEAP32[$296>>2]|0;
   $298 = (FUNCTION_TABLE_ii[$297 & 7]($cinfo)|0);
   $299 = ($298<<24>>24)==(0);
   if (!($299)) {
    break;
   }
   $300 = HEAP32[$cinfo>>2]|0;
   $301 = (($300) + 20|0);
   HEAP32[$301>>2] = 24;
   $302 = HEAP32[$300>>2]|0;
   FUNCTION_TABLE_vi[$302 & 63]($cinfo);
  }
 } while(0);
 $303 = (($cinfo) + 204|0);
 $304 = HEAP8[$303>>0]|0;
 $305 = ($304<<24>>24)==(0);
 if ($305) {
  STACKTOP = sp;return;
 }
 $306 = HEAP32[$2>>2]|0;
 $307 = HEAP32[$306>>2]|0;
 $308 = (($307) + 1|0);
 HEAP32[$306>>2] = $308;
 HEAP8[$307>>0] = -1;
 $309 = (($306) + 4|0);
 $310 = HEAP32[$309>>2]|0;
 $311 = (($310) + -1)|0;
 HEAP32[$309>>2] = $311;
 $312 = ($311|0)==(0);
 if ($312) {
  $313 = (($306) + 12|0);
  $314 = HEAP32[$313>>2]|0;
  $315 = (FUNCTION_TABLE_ii[$314 & 7]($cinfo)|0);
  $316 = ($315<<24>>24)==(0);
  if ($316) {
   $317 = HEAP32[$cinfo>>2]|0;
   $318 = (($317) + 20|0);
   HEAP32[$318>>2] = 24;
   $319 = HEAP32[$317>>2]|0;
   FUNCTION_TABLE_vi[$319 & 63]($cinfo);
  }
 }
 $320 = HEAP32[$2>>2]|0;
 $321 = HEAP32[$320>>2]|0;
 $322 = (($321) + 1|0);
 HEAP32[$320>>2] = $322;
 HEAP8[$321>>0] = -18;
 $323 = (($320) + 4|0);
 $324 = HEAP32[$323>>2]|0;
 $325 = (($324) + -1)|0;
 HEAP32[$323>>2] = $325;
 $326 = ($325|0)==(0);
 if ($326) {
  $327 = (($320) + 12|0);
  $328 = HEAP32[$327>>2]|0;
  $329 = (FUNCTION_TABLE_ii[$328 & 7]($cinfo)|0);
  $330 = ($329<<24>>24)==(0);
  if ($330) {
   $331 = HEAP32[$cinfo>>2]|0;
   $332 = (($331) + 20|0);
   HEAP32[$332>>2] = 24;
   $333 = HEAP32[$331>>2]|0;
   FUNCTION_TABLE_vi[$333 & 63]($cinfo);
  }
 }
 $334 = HEAP32[$2>>2]|0;
 $335 = HEAP32[$334>>2]|0;
 $336 = (($335) + 1|0);
 HEAP32[$334>>2] = $336;
 HEAP8[$335>>0] = 0;
 $337 = (($334) + 4|0);
 $338 = HEAP32[$337>>2]|0;
 $339 = (($338) + -1)|0;
 HEAP32[$337>>2] = $339;
 $340 = ($339|0)==(0);
 if ($340) {
  $341 = (($334) + 12|0);
  $342 = HEAP32[$341>>2]|0;
  $343 = (FUNCTION_TABLE_ii[$342 & 7]($cinfo)|0);
  $344 = ($343<<24>>24)==(0);
  if ($344) {
   $345 = HEAP32[$cinfo>>2]|0;
   $346 = (($345) + 20|0);
   HEAP32[$346>>2] = 24;
   $347 = HEAP32[$345>>2]|0;
   FUNCTION_TABLE_vi[$347 & 63]($cinfo);
  }
 }
 $348 = HEAP32[$2>>2]|0;
 $349 = HEAP32[$348>>2]|0;
 $350 = (($349) + 1|0);
 HEAP32[$348>>2] = $350;
 HEAP8[$349>>0] = 14;
 $351 = (($348) + 4|0);
 $352 = HEAP32[$351>>2]|0;
 $353 = (($352) + -1)|0;
 HEAP32[$351>>2] = $353;
 $354 = ($353|0)==(0);
 if ($354) {
  $355 = (($348) + 12|0);
  $356 = HEAP32[$355>>2]|0;
  $357 = (FUNCTION_TABLE_ii[$356 & 7]($cinfo)|0);
  $358 = ($357<<24>>24)==(0);
  if ($358) {
   $359 = HEAP32[$cinfo>>2]|0;
   $360 = (($359) + 20|0);
   HEAP32[$360>>2] = 24;
   $361 = HEAP32[$359>>2]|0;
   FUNCTION_TABLE_vi[$361 & 63]($cinfo);
  }
 }
 $362 = HEAP32[$2>>2]|0;
 $363 = HEAP32[$362>>2]|0;
 $364 = (($363) + 1|0);
 HEAP32[$362>>2] = $364;
 HEAP8[$363>>0] = 65;
 $365 = (($362) + 4|0);
 $366 = HEAP32[$365>>2]|0;
 $367 = (($366) + -1)|0;
 HEAP32[$365>>2] = $367;
 $368 = ($367|0)==(0);
 if ($368) {
  $369 = (($362) + 12|0);
  $370 = HEAP32[$369>>2]|0;
  $371 = (FUNCTION_TABLE_ii[$370 & 7]($cinfo)|0);
  $372 = ($371<<24>>24)==(0);
  if ($372) {
   $373 = HEAP32[$cinfo>>2]|0;
   $374 = (($373) + 20|0);
   HEAP32[$374>>2] = 24;
   $375 = HEAP32[$373>>2]|0;
   FUNCTION_TABLE_vi[$375 & 63]($cinfo);
  }
 }
 $376 = HEAP32[$2>>2]|0;
 $377 = HEAP32[$376>>2]|0;
 $378 = (($377) + 1|0);
 HEAP32[$376>>2] = $378;
 HEAP8[$377>>0] = 100;
 $379 = (($376) + 4|0);
 $380 = HEAP32[$379>>2]|0;
 $381 = (($380) + -1)|0;
 HEAP32[$379>>2] = $381;
 $382 = ($381|0)==(0);
 if ($382) {
  $383 = (($376) + 12|0);
  $384 = HEAP32[$383>>2]|0;
  $385 = (FUNCTION_TABLE_ii[$384 & 7]($cinfo)|0);
  $386 = ($385<<24>>24)==(0);
  if ($386) {
   $387 = HEAP32[$cinfo>>2]|0;
   $388 = (($387) + 20|0);
   HEAP32[$388>>2] = 24;
   $389 = HEAP32[$387>>2]|0;
   FUNCTION_TABLE_vi[$389 & 63]($cinfo);
  }
 }
 $390 = HEAP32[$2>>2]|0;
 $391 = HEAP32[$390>>2]|0;
 $392 = (($391) + 1|0);
 HEAP32[$390>>2] = $392;
 HEAP8[$391>>0] = 111;
 $393 = (($390) + 4|0);
 $394 = HEAP32[$393>>2]|0;
 $395 = (($394) + -1)|0;
 HEAP32[$393>>2] = $395;
 $396 = ($395|0)==(0);
 if ($396) {
  $397 = (($390) + 12|0);
  $398 = HEAP32[$397>>2]|0;
  $399 = (FUNCTION_TABLE_ii[$398 & 7]($cinfo)|0);
  $400 = ($399<<24>>24)==(0);
  if ($400) {
   $401 = HEAP32[$cinfo>>2]|0;
   $402 = (($401) + 20|0);
   HEAP32[$402>>2] = 24;
   $403 = HEAP32[$401>>2]|0;
   FUNCTION_TABLE_vi[$403 & 63]($cinfo);
  }
 }
 $404 = HEAP32[$2>>2]|0;
 $405 = HEAP32[$404>>2]|0;
 $406 = (($405) + 1|0);
 HEAP32[$404>>2] = $406;
 HEAP8[$405>>0] = 98;
 $407 = (($404) + 4|0);
 $408 = HEAP32[$407>>2]|0;
 $409 = (($408) + -1)|0;
 HEAP32[$407>>2] = $409;
 $410 = ($409|0)==(0);
 if ($410) {
  $411 = (($404) + 12|0);
  $412 = HEAP32[$411>>2]|0;
  $413 = (FUNCTION_TABLE_ii[$412 & 7]($cinfo)|0);
  $414 = ($413<<24>>24)==(0);
  if ($414) {
   $415 = HEAP32[$cinfo>>2]|0;
   $416 = (($415) + 20|0);
   HEAP32[$416>>2] = 24;
   $417 = HEAP32[$415>>2]|0;
   FUNCTION_TABLE_vi[$417 & 63]($cinfo);
  }
 }
 $418 = HEAP32[$2>>2]|0;
 $419 = HEAP32[$418>>2]|0;
 $420 = (($419) + 1|0);
 HEAP32[$418>>2] = $420;
 HEAP8[$419>>0] = 101;
 $421 = (($418) + 4|0);
 $422 = HEAP32[$421>>2]|0;
 $423 = (($422) + -1)|0;
 HEAP32[$421>>2] = $423;
 $424 = ($423|0)==(0);
 if ($424) {
  $425 = (($418) + 12|0);
  $426 = HEAP32[$425>>2]|0;
  $427 = (FUNCTION_TABLE_ii[$426 & 7]($cinfo)|0);
  $428 = ($427<<24>>24)==(0);
  if ($428) {
   $429 = HEAP32[$cinfo>>2]|0;
   $430 = (($429) + 20|0);
   HEAP32[$430>>2] = 24;
   $431 = HEAP32[$429>>2]|0;
   FUNCTION_TABLE_vi[$431 & 63]($cinfo);
  }
 }
 $432 = HEAP32[$2>>2]|0;
 $433 = HEAP32[$432>>2]|0;
 $434 = (($433) + 1|0);
 HEAP32[$432>>2] = $434;
 HEAP8[$433>>0] = 0;
 $435 = (($432) + 4|0);
 $436 = HEAP32[$435>>2]|0;
 $437 = (($436) + -1)|0;
 HEAP32[$435>>2] = $437;
 $438 = ($437|0)==(0);
 if ($438) {
  $439 = (($432) + 12|0);
  $440 = HEAP32[$439>>2]|0;
  $441 = (FUNCTION_TABLE_ii[$440 & 7]($cinfo)|0);
  $442 = ($441<<24>>24)==(0);
  if ($442) {
   $443 = HEAP32[$cinfo>>2]|0;
   $444 = (($443) + 20|0);
   HEAP32[$444>>2] = 24;
   $445 = HEAP32[$443>>2]|0;
   FUNCTION_TABLE_vi[$445 & 63]($cinfo);
  }
 }
 $446 = HEAP32[$2>>2]|0;
 $447 = HEAP32[$446>>2]|0;
 $448 = (($447) + 1|0);
 HEAP32[$446>>2] = $448;
 HEAP8[$447>>0] = 100;
 $449 = (($446) + 4|0);
 $450 = HEAP32[$449>>2]|0;
 $451 = (($450) + -1)|0;
 HEAP32[$449>>2] = $451;
 $452 = ($451|0)==(0);
 if ($452) {
  $453 = (($446) + 12|0);
  $454 = HEAP32[$453>>2]|0;
  $455 = (FUNCTION_TABLE_ii[$454 & 7]($cinfo)|0);
  $456 = ($455<<24>>24)==(0);
  if ($456) {
   $457 = HEAP32[$cinfo>>2]|0;
   $458 = (($457) + 20|0);
   HEAP32[$458>>2] = 24;
   $459 = HEAP32[$457>>2]|0;
   FUNCTION_TABLE_vi[$459 & 63]($cinfo);
  }
 }
 $460 = HEAP32[$2>>2]|0;
 $461 = HEAP32[$460>>2]|0;
 $462 = (($461) + 1|0);
 HEAP32[$460>>2] = $462;
 HEAP8[$461>>0] = 0;
 $463 = (($460) + 4|0);
 $464 = HEAP32[$463>>2]|0;
 $465 = (($464) + -1)|0;
 HEAP32[$463>>2] = $465;
 $466 = ($465|0)==(0);
 if ($466) {
  $467 = (($460) + 12|0);
  $468 = HEAP32[$467>>2]|0;
  $469 = (FUNCTION_TABLE_ii[$468 & 7]($cinfo)|0);
  $470 = ($469<<24>>24)==(0);
  if ($470) {
   $471 = HEAP32[$cinfo>>2]|0;
   $472 = (($471) + 20|0);
   HEAP32[$472>>2] = 24;
   $473 = HEAP32[$471>>2]|0;
   FUNCTION_TABLE_vi[$473 & 63]($cinfo);
  }
 }
 $474 = HEAP32[$2>>2]|0;
 $475 = HEAP32[$474>>2]|0;
 $476 = (($475) + 1|0);
 HEAP32[$474>>2] = $476;
 HEAP8[$475>>0] = 0;
 $477 = (($474) + 4|0);
 $478 = HEAP32[$477>>2]|0;
 $479 = (($478) + -1)|0;
 HEAP32[$477>>2] = $479;
 $480 = ($479|0)==(0);
 if ($480) {
  $481 = (($474) + 12|0);
  $482 = HEAP32[$481>>2]|0;
  $483 = (FUNCTION_TABLE_ii[$482 & 7]($cinfo)|0);
  $484 = ($483<<24>>24)==(0);
  if ($484) {
   $485 = HEAP32[$cinfo>>2]|0;
   $486 = (($485) + 20|0);
   HEAP32[$486>>2] = 24;
   $487 = HEAP32[$485>>2]|0;
   FUNCTION_TABLE_vi[$487 & 63]($cinfo);
  }
 }
 $488 = HEAP32[$2>>2]|0;
 $489 = HEAP32[$488>>2]|0;
 $490 = (($489) + 1|0);
 HEAP32[$488>>2] = $490;
 HEAP8[$489>>0] = 0;
 $491 = (($488) + 4|0);
 $492 = HEAP32[$491>>2]|0;
 $493 = (($492) + -1)|0;
 HEAP32[$491>>2] = $493;
 $494 = ($493|0)==(0);
 if ($494) {
  $495 = (($488) + 12|0);
  $496 = HEAP32[$495>>2]|0;
  $497 = (FUNCTION_TABLE_ii[$496 & 7]($cinfo)|0);
  $498 = ($497<<24>>24)==(0);
  if ($498) {
   $499 = HEAP32[$cinfo>>2]|0;
   $500 = (($499) + 20|0);
   HEAP32[$500>>2] = 24;
   $501 = HEAP32[$499>>2]|0;
   FUNCTION_TABLE_vi[$501 & 63]($cinfo);
  }
 }
 $502 = HEAP32[$2>>2]|0;
 $503 = HEAP32[$502>>2]|0;
 $504 = (($503) + 1|0);
 HEAP32[$502>>2] = $504;
 HEAP8[$503>>0] = 0;
 $505 = (($502) + 4|0);
 $506 = HEAP32[$505>>2]|0;
 $507 = (($506) + -1)|0;
 HEAP32[$505>>2] = $507;
 $508 = ($507|0)==(0);
 do {
  if ($508) {
   $509 = (($502) + 12|0);
   $510 = HEAP32[$509>>2]|0;
   $511 = (FUNCTION_TABLE_ii[$510 & 7]($cinfo)|0);
   $512 = ($511<<24>>24)==(0);
   if (!($512)) {
    break;
   }
   $513 = HEAP32[$cinfo>>2]|0;
   $514 = (($513) + 20|0);
   HEAP32[$514>>2] = 24;
   $515 = HEAP32[$513>>2]|0;
   FUNCTION_TABLE_vi[$515 & 63]($cinfo);
  }
 } while(0);
 $516 = (($cinfo) + 64|0);
 $517 = HEAP32[$516>>2]|0;
 if ((($517|0) == 5)) {
  $532 = HEAP32[$2>>2]|0;
  $533 = HEAP32[$532>>2]|0;
  $534 = (($533) + 1|0);
  HEAP32[$532>>2] = $534;
  HEAP8[$533>>0] = 2;
  $535 = (($532) + 4|0);
  $536 = HEAP32[$535>>2]|0;
  $537 = (($536) + -1)|0;
  HEAP32[$535>>2] = $537;
  $538 = ($537|0)==(0);
  if (!($538)) {
   STACKTOP = sp;return;
  }
  $539 = (($532) + 12|0);
  $540 = HEAP32[$539>>2]|0;
  $541 = (FUNCTION_TABLE_ii[$540 & 7]($cinfo)|0);
  $542 = ($541<<24>>24)==(0);
  if (!($542)) {
   STACKTOP = sp;return;
  }
  $543 = HEAP32[$cinfo>>2]|0;
  $544 = (($543) + 20|0);
  HEAP32[$544>>2] = 24;
  $545 = HEAP32[$543>>2]|0;
  FUNCTION_TABLE_vi[$545 & 63]($cinfo);
  STACKTOP = sp;return;
 } else if ((($517|0) == 3)) {
  $518 = HEAP32[$2>>2]|0;
  $519 = HEAP32[$518>>2]|0;
  $520 = (($519) + 1|0);
  HEAP32[$518>>2] = $520;
  HEAP8[$519>>0] = 1;
  $521 = (($518) + 4|0);
  $522 = HEAP32[$521>>2]|0;
  $523 = (($522) + -1)|0;
  HEAP32[$521>>2] = $523;
  $524 = ($523|0)==(0);
  if (!($524)) {
   STACKTOP = sp;return;
  }
  $525 = (($518) + 12|0);
  $526 = HEAP32[$525>>2]|0;
  $527 = (FUNCTION_TABLE_ii[$526 & 7]($cinfo)|0);
  $528 = ($527<<24>>24)==(0);
  if (!($528)) {
   STACKTOP = sp;return;
  }
  $529 = HEAP32[$cinfo>>2]|0;
  $530 = (($529) + 20|0);
  HEAP32[$530>>2] = 24;
  $531 = HEAP32[$529>>2]|0;
  FUNCTION_TABLE_vi[$531 & 63]($cinfo);
  STACKTOP = sp;return;
 } else {
  $546 = HEAP32[$2>>2]|0;
  $547 = HEAP32[$546>>2]|0;
  $548 = (($547) + 1|0);
  HEAP32[$546>>2] = $548;
  HEAP8[$547>>0] = 0;
  $549 = (($546) + 4|0);
  $550 = HEAP32[$549>>2]|0;
  $551 = (($550) + -1)|0;
  HEAP32[$549>>2] = $551;
  $552 = ($551|0)==(0);
  if (!($552)) {
   STACKTOP = sp;return;
  }
  $553 = (($546) + 12|0);
  $554 = HEAP32[$553>>2]|0;
  $555 = (FUNCTION_TABLE_ii[$554 & 7]($cinfo)|0);
  $556 = ($555<<24>>24)==(0);
  if (!($556)) {
   STACKTOP = sp;return;
  }
  $557 = HEAP32[$cinfo>>2]|0;
  $558 = (($557) + 20|0);
  HEAP32[$558>>2] = 24;
  $559 = HEAP32[$557>>2]|0;
  FUNCTION_TABLE_vi[$559 & 63]($cinfo);
  STACKTOP = sp;return;
 }
}
function _write_frame_header($cinfo) {
 $cinfo = $cinfo|0;
 var $$phi$trans$insert = 0, $$pr$pre = 0, $$pre = 0, $$pre$i = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ci$015$i = 0, $ci$04 = 0, $ci$11 = 0, $ci$17$i = 0, $ci$25$i = 0, $compptr$06 = 0, $compptr$13 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond20$i = 0, $exitcond21$i = 0, $fin_prec$0$lcssa$i = 0, $fin_prec$016$i = 0, $i$09$i = 0, $i3$04$i = 0;
 var $i3$04$us$i = 0, $is_baseline$0$lcssa = 0, $is_baseline$02 = 0, $is_baseline$1 = 0, $or$cond = 0, $phitmp = 0, $prec$05 = 0, $prec$1 = 0, $prec$i = 0, $seen$i = 0, $size$0$lcssa$i = 0, $size$06$i = 0, $size$1$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $prec$i = sp + 40|0;
 $seen$i = sp;
 dest=$seen$i+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $0 = (($cinfo) + 316|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(720002228);
 $$phi$trans$insert = (($cinfo) + 60|0);
 $$pre14 = HEAP32[$$phi$trans$insert>>2]|0;
 L1: do {
  if ($4) {
   $196 = $$pre14;
   label = 47;
  } else {
   $5 = ($$pre14|0)>(0);
   if ($5) {
    $6 = (($cinfo) + 68|0);
    $7 = HEAP32[$6>>2]|0;
    $ci$015$i = 0;$fin_prec$016$i = 0;
    while(1) {
     $8 = ((($7) + (($ci$015$i*84)|0)|0) + 16|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = ((($cinfo) + ($9<<2)|0) + 72|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($11|0)==(0|0);
     if ($12) {
      $196 = $$pre14;
      label = 47;
      break L1;
     }
     $13 = (($11) + 128|0);
     $14 = HEAP8[$13>>0]|0;
     $15 = ($14<<24>>24)==(1);
     if ($15) {
      $196 = $$pre14;
      label = 47;
      break L1;
     }
     $16 = (($prec$i) + ($ci$015$i<<2)|0);
     HEAP32[$16>>2] = 0;
     $21 = 0;$i$09$i = 0;
     while(1) {
      $17 = (($11) + ($i$09$i<<1)|0);
      $18 = HEAP16[$17>>1]|0;
      $19 = ($18&65535)>(255);
      $20 = $19 << 31 >> 31;
      $22 = ($21|0)!=($20|0);
      $23 = $22&1;
      $24 = (($i$09$i) + 1)|0;
      $exitcond21$i = ($24|0)==(64);
      if ($exitcond21$i) {
       break;
      } else {
       $21 = $23;$i$09$i = $24;
      }
     }
     HEAP32[$16>>2] = $23;
     $25 = (($23) + ($fin_prec$016$i))|0;
     $26 = (($ci$015$i) + 1)|0;
     $27 = ($26|0)<($$pre14|0);
     if ($27) {
      $ci$015$i = $26;$fin_prec$016$i = $25;
     } else {
      $fin_prec$0$lcssa$i = $25;
      break;
     }
    }
   } else {
    $fin_prec$0$lcssa$i = 0;
   }
   $28 = (($cinfo) + 24|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 1|0);
   HEAP32[$29>>2] = $31;
   HEAP8[$30>>0] = -1;
   $32 = (($29) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   HEAP32[$32>>2] = $34;
   $35 = ($34|0)==(0);
   if ($35) {
    $36 = (($29) + 12|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (FUNCTION_TABLE_ii[$37 & 7]($cinfo)|0);
    $39 = ($38<<24>>24)==(0);
    if ($39) {
     $40 = HEAP32[$cinfo>>2]|0;
     $41 = (($40) + 20|0);
     HEAP32[$41>>2] = 24;
     $42 = HEAP32[$40>>2]|0;
     FUNCTION_TABLE_vi[$42 & 63]($cinfo);
    }
   }
   $43 = HEAP32[$28>>2]|0;
   $44 = HEAP32[$43>>2]|0;
   $45 = (($44) + 1|0);
   HEAP32[$43>>2] = $45;
   HEAP8[$44>>0] = -37;
   $46 = (($43) + 4|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($47) + -1)|0;
   HEAP32[$46>>2] = $48;
   $49 = ($48|0)==(0);
   if ($49) {
    $50 = (($43) + 12|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (FUNCTION_TABLE_ii[$51 & 7]($cinfo)|0);
    $53 = ($52<<24>>24)==(0);
    if ($53) {
     $54 = HEAP32[$cinfo>>2]|0;
     $55 = (($54) + 20|0);
     HEAP32[$55>>2] = 24;
     $56 = HEAP32[$54>>2]|0;
     FUNCTION_TABLE_vi[$56 & 63]($cinfo);
    }
   }
   $57 = HEAP32[$$phi$trans$insert>>2]|0;
   $58 = ($57|0)>(0);
   if ($58) {
    $59 = (($cinfo) + 68|0);
    $60 = HEAP32[$59>>2]|0;
    $ci$17$i = 0;$size$06$i = 0;
    while(1) {
     $61 = ((($60) + (($ci$17$i*84)|0)|0) + 16|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = (($seen$i) + ($62<<2)|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = ($64|0)==(0);
     if ($65) {
      $66 = (($prec$i) + ($ci$17$i<<2)|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = $67 << 6;
      $69 = (($size$06$i) + 65)|0;
      $70 = (($69) + ($68))|0;
      HEAP32[$63>>2] = 1;
      $size$1$i = $70;
     } else {
      $size$1$i = $size$06$i;
     }
     $71 = (($ci$17$i) + 1)|0;
     $exitcond = ($71|0)==($57|0);
     if ($exitcond) {
      $size$0$lcssa$i = $size$1$i;
      break;
     } else {
      $ci$17$i = $71;$size$06$i = $size$1$i;
     }
    }
   } else {
    $size$0$lcssa$i = 0;
   }
   $72 = (($size$0$lcssa$i) + 2)|0;
   $73 = $72 >>> 8;
   $74 = HEAP32[$28>>2]|0;
   $75 = $73&255;
   $76 = HEAP32[$74>>2]|0;
   $77 = (($76) + 1|0);
   HEAP32[$74>>2] = $77;
   HEAP8[$76>>0] = $75;
   $78 = (($74) + 4|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = (($79) + -1)|0;
   HEAP32[$78>>2] = $80;
   $81 = ($80|0)==(0);
   if ($81) {
    $82 = (($74) + 12|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (FUNCTION_TABLE_ii[$83 & 7]($cinfo)|0);
    $85 = ($84<<24>>24)==(0);
    if ($85) {
     $86 = HEAP32[$cinfo>>2]|0;
     $87 = (($86) + 20|0);
     HEAP32[$87>>2] = 24;
     $88 = HEAP32[$86>>2]|0;
     FUNCTION_TABLE_vi[$88 & 63]($cinfo);
    }
   }
   $89 = HEAP32[$28>>2]|0;
   $90 = $72&255;
   $91 = HEAP32[$89>>2]|0;
   $92 = (($91) + 1|0);
   HEAP32[$89>>2] = $92;
   HEAP8[$91>>0] = $90;
   $93 = (($89) + 4|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + -1)|0;
   HEAP32[$93>>2] = $95;
   $96 = ($95|0)==(0);
   if ($96) {
    $97 = (($89) + 12|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = (FUNCTION_TABLE_ii[$98 & 7]($cinfo)|0);
    $100 = ($99<<24>>24)==(0);
    if ($100) {
     $101 = HEAP32[$cinfo>>2]|0;
     $102 = (($101) + 20|0);
     HEAP32[$102>>2] = 24;
     $103 = HEAP32[$101>>2]|0;
     FUNCTION_TABLE_vi[$103 & 63]($cinfo);
    }
   }
   $104 = HEAP32[$$phi$trans$insert>>2]|0;
   $105 = ($104|0)>(0);
   if ($105) {
    $106 = (($cinfo) + 68|0);
    $239 = $104;$ci$25$i = 0;
    while(1) {
     $107 = HEAP32[$106>>2]|0;
     $108 = ((($107) + (($ci$25$i*84)|0)|0) + 16|0);
     $109 = HEAP32[$108>>2]|0;
     $110 = ((($cinfo) + ($109<<2)|0) + 72|0);
     $111 = HEAP32[$110>>2]|0;
     $112 = (($111) + 128|0);
     $113 = HEAP8[$112>>0]|0;
     $114 = ($113<<24>>24)==(1);
     if ($114) {
      $193 = $239;
     } else {
      $115 = (($prec$i) + ($ci$25$i<<2)|0);
      $116 = HEAP32[$115>>2]|0;
      $117 = $116 << 4;
      $118 = (($117) + ($109))|0;
      $119 = HEAP32[$28>>2]|0;
      $120 = $118&255;
      $121 = HEAP32[$119>>2]|0;
      $122 = (($121) + 1|0);
      HEAP32[$119>>2] = $122;
      HEAP8[$121>>0] = $120;
      $123 = (($119) + 4|0);
      $124 = HEAP32[$123>>2]|0;
      $125 = (($124) + -1)|0;
      HEAP32[$123>>2] = $125;
      $126 = ($125|0)==(0);
      if ($126) {
       $127 = (($119) + 12|0);
       $128 = HEAP32[$127>>2]|0;
       $129 = (FUNCTION_TABLE_ii[$128 & 7]($cinfo)|0);
       $130 = ($129<<24>>24)==(0);
       if ($130) {
        $131 = HEAP32[$cinfo>>2]|0;
        $132 = (($131) + 20|0);
        HEAP32[$132>>2] = 24;
        $133 = HEAP32[$131>>2]|0;
        FUNCTION_TABLE_vi[$133 & 63]($cinfo);
       }
      }
      $134 = ($116|0)==(0);
      if ($134) {
       $i3$04$us$i = 0;
       while(1) {
        $135 = (142704 + ($i3$04$us$i<<2)|0);
        $136 = HEAP32[$135>>2]|0;
        $137 = (($111) + ($136<<1)|0);
        $138 = HEAP16[$137>>1]|0;
        $139 = HEAP32[$28>>2]|0;
        $140 = $138&255;
        $141 = HEAP32[$139>>2]|0;
        $142 = (($141) + 1|0);
        HEAP32[$139>>2] = $142;
        HEAP8[$141>>0] = $140;
        $143 = (($139) + 4|0);
        $144 = HEAP32[$143>>2]|0;
        $145 = (($144) + -1)|0;
        HEAP32[$143>>2] = $145;
        $146 = ($145|0)==(0);
        if ($146) {
         $147 = (($139) + 12|0);
         $148 = HEAP32[$147>>2]|0;
         $149 = (FUNCTION_TABLE_ii[$148 & 7]($cinfo)|0);
         $150 = ($149<<24>>24)==(0);
         if ($150) {
          $151 = HEAP32[$cinfo>>2]|0;
          $152 = (($151) + 20|0);
          HEAP32[$152>>2] = 24;
          $153 = HEAP32[$151>>2]|0;
          FUNCTION_TABLE_vi[$153 & 63]($cinfo);
         }
        }
        $154 = (($i3$04$us$i) + 1)|0;
        $exitcond20$i = ($154|0)==(64);
        if ($exitcond20$i) {
         break;
        } else {
         $i3$04$us$i = $154;
        }
       }
      } else {
       $i3$04$i = 0;
       while(1) {
        $155 = (142704 + ($i3$04$i<<2)|0);
        $156 = HEAP32[$155>>2]|0;
        $157 = (($111) + ($156<<1)|0);
        $158 = HEAP16[$157>>1]|0;
        $159 = HEAP32[$28>>2]|0;
        $160 = ($158&65535) >>> 8;
        $161 = $160&255;
        $162 = HEAP32[$159>>2]|0;
        $163 = (($162) + 1|0);
        HEAP32[$159>>2] = $163;
        HEAP8[$162>>0] = $161;
        $164 = (($159) + 4|0);
        $165 = HEAP32[$164>>2]|0;
        $166 = (($165) + -1)|0;
        HEAP32[$164>>2] = $166;
        $167 = ($166|0)==(0);
        if ($167) {
         $168 = (($159) + 12|0);
         $169 = HEAP32[$168>>2]|0;
         $170 = (FUNCTION_TABLE_ii[$169 & 7]($cinfo)|0);
         $171 = ($170<<24>>24)==(0);
         if ($171) {
          $172 = HEAP32[$cinfo>>2]|0;
          $173 = (($172) + 20|0);
          HEAP32[$173>>2] = 24;
          $174 = HEAP32[$172>>2]|0;
          FUNCTION_TABLE_vi[$174 & 63]($cinfo);
         }
        }
        $175 = HEAP32[$28>>2]|0;
        $176 = $158&255;
        $177 = HEAP32[$175>>2]|0;
        $178 = (($177) + 1|0);
        HEAP32[$175>>2] = $178;
        HEAP8[$177>>0] = $176;
        $179 = (($175) + 4|0);
        $180 = HEAP32[$179>>2]|0;
        $181 = (($180) + -1)|0;
        HEAP32[$179>>2] = $181;
        $182 = ($181|0)==(0);
        do {
         if ($182) {
          $183 = (($175) + 12|0);
          $184 = HEAP32[$183>>2]|0;
          $185 = (FUNCTION_TABLE_ii[$184 & 7]($cinfo)|0);
          $186 = ($185<<24>>24)==(0);
          if (!($186)) {
           break;
          }
          $187 = HEAP32[$cinfo>>2]|0;
          $188 = (($187) + 20|0);
          HEAP32[$188>>2] = 24;
          $189 = HEAP32[$187>>2]|0;
          FUNCTION_TABLE_vi[$189 & 63]($cinfo);
         }
        } while(0);
        $190 = (($i3$04$i) + 1)|0;
        $exitcond$i = ($190|0)==(64);
        if ($exitcond$i) {
         break;
        } else {
         $i3$04$i = $190;
        }
       }
      }
      HEAP8[$112>>0] = 1;
      $$pre$i = HEAP32[$$phi$trans$insert>>2]|0;
      $193 = $$pre$i;
     }
     $191 = (($ci$25$i) + 1)|0;
     $192 = ($191|0)<($193|0);
     if ($192) {
      $239 = $193;$ci$25$i = $191;
     } else {
      $238 = $193;
      break;
     }
    }
   } else {
    $238 = $104;
   }
   $194 = ($fin_prec$0$lcssa$i|0)==(-1);
   if ($194) {
    $196 = $238;
    label = 47;
   } else {
    $217 = $238;$prec$1 = $fin_prec$0$lcssa$i;
   }
  }
 } while(0);
 if ((label|0) == 47) {
  $195 = (($cinfo) + 60|0);
  $197 = ($196|0)>(0);
  if ($197) {
   $198 = (($cinfo) + 68|0);
   $199 = HEAP32[$198>>2]|0;
   $ci$04 = 0;$compptr$06 = $199;$prec$05 = 0;
   while(1) {
    $200 = (($compptr$06) + 16|0);
    $201 = HEAP32[$200>>2]|0;
    $202 = (_emit_dqt($cinfo,$201)|0);
    $203 = (($202) + ($prec$05))|0;
    $204 = (($ci$04) + 1)|0;
    $205 = (($compptr$06) + 84|0);
    $206 = HEAP32[$195>>2]|0;
    $207 = ($204|0)<($206|0);
    if ($207) {
     $ci$04 = $204;$compptr$06 = $205;$prec$05 = $203;
    } else {
     $217 = $206;$prec$1 = $203;
     break;
    }
   }
  } else {
   $217 = $196;$prec$1 = 0;
  }
 }
 $208 = (($cinfo) + 177|0);
 $209 = HEAP8[$208>>0]|0;
 $210 = ($209<<24>>24)==(0);
 $211 = (($cinfo) + 212|0);
 $212 = HEAP8[$211>>0]|0;
 $213 = ($212<<24>>24)==(0);
 L73: do {
  if ($210) {
   L75: do {
    if ($213) {
     $214 = (($cinfo) + 56|0);
     $215 = HEAP32[$214>>2]|0;
     $216 = ($215|0)==(8);
     do {
      if ($216) {
       $218 = ($217|0)>(0);
       if ($218) {
        $219 = (($cinfo) + 68|0);
        $220 = HEAP32[$219>>2]|0;
        $ci$11 = 0;$compptr$13 = $220;$is_baseline$02 = 1;
        while(1) {
         $221 = (($compptr$13) + 20|0);
         $222 = HEAP32[$221>>2]|0;
         $223 = ($222|0)>(1);
         if ($223) {
          label = 58;
         } else {
          $224 = (($compptr$13) + 24|0);
          $225 = HEAP32[$224>>2]|0;
          $226 = ($225|0)>(1);
          if ($226) {
           label = 58;
          } else {
           $is_baseline$1 = $is_baseline$02;
          }
         }
         if ((label|0) == 58) {
          label = 0;
          $is_baseline$1 = 0;
         }
         $227 = (($ci$11) + 1)|0;
         $228 = (($compptr$13) + 84|0);
         $229 = ($227|0)<($217|0);
         if ($229) {
          $ci$11 = $227;$compptr$13 = $228;$is_baseline$02 = $is_baseline$1;
         } else {
          $is_baseline$0$lcssa = $is_baseline$1;
          break;
         }
        }
       } else {
        $is_baseline$0$lcssa = 1;
       }
       $230 = ($prec$1|0)==(0);
       $231 = ($is_baseline$0$lcssa<<24>>24)==(0);
       $or$cond = $230 | $231;
       if ($or$cond) {
        $237 = ($is_baseline$0$lcssa<<24>>24)==(0);
        if ($237) {
         break;
        }
        _emit_sof($cinfo,192);
        STACKTOP = sp;return;
       } else {
        $232 = HEAP32[$cinfo>>2]|0;
        $233 = (($232) + 20|0);
        HEAP32[$233>>2] = 75;
        $234 = (($232) + 4|0);
        $235 = HEAP32[$234>>2]|0;
        FUNCTION_TABLE_vii[$235 & 15]($cinfo,0);
        $$pr$pre = HEAP8[$208>>0]|0;
        $$pre = HEAP8[$211>>0]|0;
        $phitmp = ($$pr$pre<<24>>24)==(0);
        $236 = ($$pre<<24>>24)!=(0);
        if ($phitmp) {
         if ($236) {
          break L75;
         } else {
          break;
         }
        } else {
         if ($236) {
          label = 63;
          break L73;
         } else {
          label = 64;
          break L73;
         }
        }
       }
      }
     } while(0);
     _emit_sof($cinfo,193);
     STACKTOP = sp;return;
    }
   } while(0);
   _emit_sof($cinfo,194);
   STACKTOP = sp;return;
  } else {
   if ($213) {
    label = 64;
   } else {
    label = 63;
   }
  }
 } while(0);
 if ((label|0) == 63) {
  _emit_sof($cinfo,202);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 64) {
  _emit_sof($cinfo,201);
  STACKTOP = sp;return;
 }
}
function _write_scan_header($cinfo) {
 $cinfo = $cinfo|0;
 var $$c = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $$pre38 = 0, $$promoted$i = 0, $$promoted26$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0;
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0;
 var $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0;
 var $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0;
 var $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0;
 var $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0;
 var $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0;
 var $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0;
 var $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0;
 var $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0;
 var $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0;
 var $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0;
 var $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0;
 var $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0;
 var $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0;
 var $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0;
 var $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0;
 var $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0;
 var $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0;
 var $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0;
 var $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0;
 var $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0;
 var $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0;
 var $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0;
 var $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0;
 var $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0;
 var $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0;
 var $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0;
 var $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0;
 var $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0;
 var $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ac_in_use$i = 0, $aclens$i = 0, $acseen$i = 0, $dc_in_use$i = 0, $dclens$i = 0, $dcseen$i = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i6 = 0, $exitcond13$i = 0, $exitcond31 = 0, $exitcond32 = 0, $exitcond33 = 0, $exitcond36$i = 0;
 var $i$026 = 0, $i$031$i = 0, $i$07$i = 0, $i$111$i = 0, $i$111$us$i = 0, $i$115$i = 0, $i$28$i = 0, $i$35$i = 0, $j$47$i = 0, $j$58$i = 0, $j$610$i = 0, $j$711$i = 0, $length$0$lcssa51$i = 0, $length$030$i = 0, $length$09$i = 0, $length$1$i = 0, $length$2$i = 0, $phitmp$i = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $dclens$i = sp + 48|0;
 $aclens$i = sp + 32|0;
 $dcseen$i = sp + 16|0;
 $acseen$i = sp;
 $dc_in_use$i = sp + 80|0;
 $ac_in_use$i = sp + 64|0;
 $0 = (($cinfo) + 332|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 177|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 L1: do {
  if ($4) {
   ;HEAP32[$dclens$i+0>>2]=0|0;HEAP32[$dclens$i+4>>2]=0|0;HEAP32[$dclens$i+8>>2]=0|0;HEAP32[$dclens$i+12>>2]=0|0;
   ;HEAP32[$aclens$i+0>>2]=0|0;HEAP32[$aclens$i+4>>2]=0|0;HEAP32[$aclens$i+8>>2]=0|0;HEAP32[$aclens$i+12>>2]=0|0;
   ;HEAP32[$dcseen$i+0>>2]=0|0;HEAP32[$dcseen$i+4>>2]=0|0;HEAP32[$dcseen$i+8>>2]=0|0;HEAP32[$dcseen$i+12>>2]=0|0;
   ;HEAP32[$acseen$i+0>>2]=0|0;HEAP32[$acseen$i+4>>2]=0|0;HEAP32[$acseen$i+8>>2]=0|0;HEAP32[$acseen$i+12>>2]=0|0;
   $181 = (($cinfo) + 316|0);
   $182 = HEAP32[$181>>2]|0;
   $183 = (($182) + 4120|0);
   $184 = HEAP32[$183>>2]|0;
   $185 = ($184|0)==(720002228);
   $$phi$trans$insert = (($cinfo) + 228|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   do {
    if ($185) {
     $402 = $$pre;
    } else {
     $186 = ($$pre|0)>(0);
     if ($186) {
      $187 = (($cinfo) + 300|0);
      $188 = (($cinfo) + 308|0);
      $189 = (($cinfo) + 304|0);
      $190 = (($dcseen$i) + 4|0);
      $191 = (($dcseen$i) + 8|0);
      $192 = (($dcseen$i) + 12|0);
      $193 = (($acseen$i) + 4|0);
      $194 = (($acseen$i) + 8|0);
      $195 = (($acseen$i) + 12|0);
      $i$031$i = 0;$length$030$i = 2;
      while(1) {
       $196 = ((($cinfo) + ($i$031$i<<2)|0) + 232|0);
       $197 = HEAP32[$196>>2]|0;
       $198 = (($197) + 20|0);
       $199 = HEAP32[$198>>2]|0;
       $200 = (($197) + 24|0);
       $201 = HEAP32[$200>>2]|0;
       $202 = ((($cinfo) + ($199<<2)|0) + 88|0);
       $203 = HEAP32[$202>>2]|0;
       $204 = ((($cinfo) + ($201<<2)|0) + 104|0);
       $205 = HEAP32[$204>>2]|0;
       $206 = HEAP32[$187>>2]|0;
       $207 = ($206|0)==(0);
       if ($207) {
        $208 = HEAP32[$188>>2]|0;
        $209 = ($208|0)==(0);
        if ($209) {
         $210 = ($203|0)==(0|0);
         if ($210) {
          $211 = HEAP32[$cinfo>>2]|0;
          $212 = (($211) + 20|0);
          HEAP32[$212>>2] = 50;
          $213 = (($211) + 24|0);
          HEAP32[$213>>2] = $199;
          $214 = HEAP32[$211>>2]|0;
          FUNCTION_TABLE_vi[$214 & 63]($cinfo);
         }
         $215 = (($203) + 273|0);
         $216 = HEAP8[$215>>0]|0;
         $217 = ($216<<24>>24)==(0);
         if ($217) {
          $218 = HEAP32[$dcseen$i>>2]|0;
          $219 = ($203|0)==($218|0);
          $220 = $219&1;
          $221 = HEAP32[$190>>2]|0;
          $222 = ($203|0)==($221|0);
          $223 = $222&1;
          $224 = (($223) + ($220))|0;
          $225 = HEAP32[$191>>2]|0;
          $226 = ($203|0)==($225|0);
          $227 = $226&1;
          $228 = (($227) + ($224))|0;
          $229 = HEAP32[$192>>2]|0;
          $230 = ($203|0)==($229|0);
          $231 = $230&1;
          $232 = (0 - ($228))|0;
          $233 = ($231|0)==($232|0);
          if ($233) {
           $234 = (($dcseen$i) + ($i$031$i<<2)|0);
           HEAP32[$234>>2] = $203;
           $235 = (($dclens$i) + ($i$031$i<<2)|0);
           $$promoted$i = HEAP32[$235>>2]|0;
           $236 = (($203) + 1|0);
           $237 = HEAP8[$236>>0]|0;
           $238 = $237&255;
           $239 = (($238) + ($$promoted$i))|0;
           $240 = (($203) + 2|0);
           $241 = HEAP8[$240>>0]|0;
           $242 = $241&255;
           $243 = (($239) + ($242))|0;
           $244 = (($203) + 3|0);
           $245 = HEAP8[$244>>0]|0;
           $246 = $245&255;
           $247 = (($243) + ($246))|0;
           $248 = (($203) + 4|0);
           $249 = HEAP8[$248>>0]|0;
           $250 = $249&255;
           $251 = (($247) + ($250))|0;
           $252 = (($203) + 5|0);
           $253 = HEAP8[$252>>0]|0;
           $254 = $253&255;
           $255 = (($251) + ($254))|0;
           $256 = (($203) + 6|0);
           $257 = HEAP8[$256>>0]|0;
           $258 = $257&255;
           $259 = (($255) + ($258))|0;
           $260 = (($203) + 7|0);
           $261 = HEAP8[$260>>0]|0;
           $262 = $261&255;
           $263 = (($259) + ($262))|0;
           $264 = (($203) + 8|0);
           $265 = HEAP8[$264>>0]|0;
           $266 = $265&255;
           $267 = (($263) + ($266))|0;
           $268 = (($203) + 9|0);
           $269 = HEAP8[$268>>0]|0;
           $270 = $269&255;
           $271 = (($267) + ($270))|0;
           $272 = (($203) + 10|0);
           $273 = HEAP8[$272>>0]|0;
           $274 = $273&255;
           $275 = (($271) + ($274))|0;
           $276 = (($203) + 11|0);
           $277 = HEAP8[$276>>0]|0;
           $278 = $277&255;
           $279 = (($275) + ($278))|0;
           $280 = (($203) + 12|0);
           $281 = HEAP8[$280>>0]|0;
           $282 = $281&255;
           $283 = (($279) + ($282))|0;
           $284 = (($203) + 13|0);
           $285 = HEAP8[$284>>0]|0;
           $286 = $285&255;
           $287 = (($283) + ($286))|0;
           $288 = (($203) + 14|0);
           $289 = HEAP8[$288>>0]|0;
           $290 = $289&255;
           $291 = (($287) + ($290))|0;
           $292 = (($203) + 15|0);
           $293 = HEAP8[$292>>0]|0;
           $294 = $293&255;
           $295 = (($291) + ($294))|0;
           $296 = (($203) + 16|0);
           $297 = HEAP8[$296>>0]|0;
           $298 = $297&255;
           $299 = (($295) + ($298))|0;
           HEAP32[$235>>2] = $299;
           $300 = (($length$030$i) + 17)|0;
           $301 = (($300) + ($299))|0;
           $length$1$i = $301;
           label = 53;
          } else {
           $length$2$i = $length$030$i;
          }
         } else {
          $length$2$i = $length$030$i;
         }
        } else {
         $length$1$i = $length$030$i;
         label = 53;
        }
       } else {
        $length$1$i = $length$030$i;
        label = 53;
       }
       if ((label|0) == 53) {
        label = 0;
        $302 = HEAP32[$189>>2]|0;
        $303 = ($302|0)==(0);
        if ($303) {
         $length$2$i = $length$1$i;
        } else {
         $304 = ($205|0)==(0|0);
         if ($304) {
          $305 = HEAP32[$cinfo>>2]|0;
          $306 = (($305) + 20|0);
          HEAP32[$306>>2] = 50;
          $307 = (($201) + 16)|0;
          $308 = (($305) + 24|0);
          HEAP32[$308>>2] = $307;
          $309 = HEAP32[$305>>2]|0;
          FUNCTION_TABLE_vi[$309 & 63]($cinfo);
         }
         $310 = (($205) + 273|0);
         $311 = HEAP8[$310>>0]|0;
         $312 = ($311<<24>>24)==(0);
         if ($312) {
          $313 = HEAP32[$acseen$i>>2]|0;
          $314 = ($205|0)==($313|0);
          $315 = $314&1;
          $316 = HEAP32[$193>>2]|0;
          $317 = ($205|0)==($316|0);
          $318 = $317&1;
          $319 = (($318) + ($315))|0;
          $320 = HEAP32[$194>>2]|0;
          $321 = ($205|0)==($320|0);
          $322 = $321&1;
          $323 = (($322) + ($319))|0;
          $324 = HEAP32[$195>>2]|0;
          $325 = ($205|0)==($324|0);
          $326 = $325&1;
          $327 = (0 - ($323))|0;
          $328 = ($326|0)==($327|0);
          if ($328) {
           $329 = (($acseen$i) + ($i$031$i<<2)|0);
           HEAP32[$329>>2] = $205;
           $330 = (($aclens$i) + ($i$031$i<<2)|0);
           $$promoted26$i = HEAP32[$330>>2]|0;
           $331 = (($205) + 1|0);
           $332 = HEAP8[$331>>0]|0;
           $333 = $332&255;
           $334 = (($333) + ($$promoted26$i))|0;
           $335 = (($205) + 2|0);
           $336 = HEAP8[$335>>0]|0;
           $337 = $336&255;
           $338 = (($334) + ($337))|0;
           $339 = (($205) + 3|0);
           $340 = HEAP8[$339>>0]|0;
           $341 = $340&255;
           $342 = (($338) + ($341))|0;
           $343 = (($205) + 4|0);
           $344 = HEAP8[$343>>0]|0;
           $345 = $344&255;
           $346 = (($342) + ($345))|0;
           $347 = (($205) + 5|0);
           $348 = HEAP8[$347>>0]|0;
           $349 = $348&255;
           $350 = (($346) + ($349))|0;
           $351 = (($205) + 6|0);
           $352 = HEAP8[$351>>0]|0;
           $353 = $352&255;
           $354 = (($350) + ($353))|0;
           $355 = (($205) + 7|0);
           $356 = HEAP8[$355>>0]|0;
           $357 = $356&255;
           $358 = (($354) + ($357))|0;
           $359 = (($205) + 8|0);
           $360 = HEAP8[$359>>0]|0;
           $361 = $360&255;
           $362 = (($358) + ($361))|0;
           $363 = (($205) + 9|0);
           $364 = HEAP8[$363>>0]|0;
           $365 = $364&255;
           $366 = (($362) + ($365))|0;
           $367 = (($205) + 10|0);
           $368 = HEAP8[$367>>0]|0;
           $369 = $368&255;
           $370 = (($366) + ($369))|0;
           $371 = (($205) + 11|0);
           $372 = HEAP8[$371>>0]|0;
           $373 = $372&255;
           $374 = (($370) + ($373))|0;
           $375 = (($205) + 12|0);
           $376 = HEAP8[$375>>0]|0;
           $377 = $376&255;
           $378 = (($374) + ($377))|0;
           $379 = (($205) + 13|0);
           $380 = HEAP8[$379>>0]|0;
           $381 = $380&255;
           $382 = (($378) + ($381))|0;
           $383 = (($205) + 14|0);
           $384 = HEAP8[$383>>0]|0;
           $385 = $384&255;
           $386 = (($382) + ($385))|0;
           $387 = (($205) + 15|0);
           $388 = HEAP8[$387>>0]|0;
           $389 = $388&255;
           $390 = (($386) + ($389))|0;
           $391 = (($205) + 16|0);
           $392 = HEAP8[$391>>0]|0;
           $393 = $392&255;
           $394 = (($390) + ($393))|0;
           HEAP32[$330>>2] = $394;
           $395 = (($length$1$i) + 17)|0;
           $396 = (($395) + ($394))|0;
           $length$2$i = $396;
          } else {
           $length$2$i = $length$1$i;
          }
         } else {
          $length$2$i = $length$1$i;
         }
        }
       }
       $397 = (($i$031$i) + 1)|0;
       $398 = HEAP32[$$phi$trans$insert>>2]|0;
       $399 = ($397|0)<($398|0);
       if ($399) {
        $i$031$i = $397;$length$030$i = $length$2$i;
       } else {
        break;
       }
      }
      $400 = ($length$2$i|0)>(65535);
      if ($400) {
       $402 = $398;
       break;
      } else {
       $length$0$lcssa51$i = $length$2$i;
      }
     } else {
      $length$0$lcssa51$i = 2;
     }
     $407 = (($cinfo) + 24|0);
     $408 = HEAP32[$407>>2]|0;
     $409 = HEAP32[$408>>2]|0;
     $410 = (($409) + 1|0);
     HEAP32[$408>>2] = $410;
     HEAP8[$409>>0] = -1;
     $411 = (($408) + 4|0);
     $412 = HEAP32[$411>>2]|0;
     $413 = (($412) + -1)|0;
     HEAP32[$411>>2] = $413;
     $414 = ($413|0)==(0);
     if ($414) {
      $415 = (($408) + 12|0);
      $416 = HEAP32[$415>>2]|0;
      $417 = (FUNCTION_TABLE_ii[$416 & 7]($cinfo)|0);
      $418 = ($417<<24>>24)==(0);
      if ($418) {
       $419 = HEAP32[$cinfo>>2]|0;
       $420 = (($419) + 20|0);
       HEAP32[$420>>2] = 24;
       $421 = HEAP32[$419>>2]|0;
       FUNCTION_TABLE_vi[$421 & 63]($cinfo);
      }
     }
     $422 = HEAP32[$407>>2]|0;
     $423 = HEAP32[$422>>2]|0;
     $424 = (($423) + 1|0);
     HEAP32[$422>>2] = $424;
     HEAP8[$423>>0] = -60;
     $425 = (($422) + 4|0);
     $426 = HEAP32[$425>>2]|0;
     $427 = (($426) + -1)|0;
     HEAP32[$425>>2] = $427;
     $428 = ($427|0)==(0);
     if ($428) {
      $429 = (($422) + 12|0);
      $430 = HEAP32[$429>>2]|0;
      $431 = (FUNCTION_TABLE_ii[$430 & 7]($cinfo)|0);
      $432 = ($431<<24>>24)==(0);
      if ($432) {
       $433 = HEAP32[$cinfo>>2]|0;
       $434 = (($433) + 20|0);
       HEAP32[$434>>2] = 24;
       $435 = HEAP32[$433>>2]|0;
       FUNCTION_TABLE_vi[$435 & 63]($cinfo);
      }
     }
     $436 = $length$0$lcssa51$i >>> 8;
     $437 = HEAP32[$407>>2]|0;
     $438 = $436&255;
     $439 = HEAP32[$437>>2]|0;
     $440 = (($439) + 1|0);
     HEAP32[$437>>2] = $440;
     HEAP8[$439>>0] = $438;
     $441 = (($437) + 4|0);
     $442 = HEAP32[$441>>2]|0;
     $443 = (($442) + -1)|0;
     HEAP32[$441>>2] = $443;
     $444 = ($443|0)==(0);
     if ($444) {
      $445 = (($437) + 12|0);
      $446 = HEAP32[$445>>2]|0;
      $447 = (FUNCTION_TABLE_ii[$446 & 7]($cinfo)|0);
      $448 = ($447<<24>>24)==(0);
      if ($448) {
       $449 = HEAP32[$cinfo>>2]|0;
       $450 = (($449) + 20|0);
       HEAP32[$450>>2] = 24;
       $451 = HEAP32[$449>>2]|0;
       FUNCTION_TABLE_vi[$451 & 63]($cinfo);
      }
     }
     $452 = HEAP32[$407>>2]|0;
     $453 = $length$0$lcssa51$i&255;
     $454 = HEAP32[$452>>2]|0;
     $455 = (($454) + 1|0);
     HEAP32[$452>>2] = $455;
     HEAP8[$454>>0] = $453;
     $456 = (($452) + 4|0);
     $457 = HEAP32[$456>>2]|0;
     $458 = (($457) + -1)|0;
     HEAP32[$456>>2] = $458;
     $459 = ($458|0)==(0);
     if ($459) {
      $460 = (($452) + 12|0);
      $461 = HEAP32[$460>>2]|0;
      $462 = (FUNCTION_TABLE_ii[$461 & 7]($cinfo)|0);
      $463 = ($462<<24>>24)==(0);
      if ($463) {
       $464 = HEAP32[$cinfo>>2]|0;
       $465 = (($464) + 20|0);
       HEAP32[$465>>2] = 24;
       $466 = HEAP32[$464>>2]|0;
       FUNCTION_TABLE_vi[$466 & 63]($cinfo);
      }
     }
     $467 = HEAP32[$$phi$trans$insert>>2]|0;
     $468 = ($467|0)>(0);
     if (!($468)) {
      break L1;
     }
     $469 = (($cinfo) + 300|0);
     $470 = (($cinfo) + 308|0);
     $471 = (($cinfo) + 304|0);
     $i$115$i = 0;
     while(1) {
      $472 = ((($cinfo) + ($i$115$i<<2)|0) + 232|0);
      $473 = HEAP32[$472>>2]|0;
      $474 = (($473) + 20|0);
      $475 = HEAP32[$474>>2]|0;
      $476 = (($473) + 24|0);
      $477 = HEAP32[$476>>2]|0;
      $478 = ((($cinfo) + ($475<<2)|0) + 88|0);
      $479 = HEAP32[$478>>2]|0;
      $480 = ((($cinfo) + ($477<<2)|0) + 104|0);
      $481 = HEAP32[$480>>2]|0;
      $482 = (($477) + 16)|0;
      $483 = HEAP32[$469>>2]|0;
      $484 = ($483|0)==(0);
      if ($484) {
       $485 = HEAP32[$470>>2]|0;
       $486 = ($485|0)==(0);
       if ($486) {
        $487 = (($479) + 273|0);
        $488 = HEAP8[$487>>0]|0;
        $489 = ($488<<24>>24)==(0);
        if ($489) {
         $490 = HEAP32[$407>>2]|0;
         $491 = $475&255;
         $492 = HEAP32[$490>>2]|0;
         $493 = (($492) + 1|0);
         HEAP32[$490>>2] = $493;
         HEAP8[$492>>0] = $491;
         $494 = (($490) + 4|0);
         $495 = HEAP32[$494>>2]|0;
         $496 = (($495) + -1)|0;
         HEAP32[$494>>2] = $496;
         $497 = ($496|0)==(0);
         if ($497) {
          $498 = (($490) + 12|0);
          $499 = HEAP32[$498>>2]|0;
          $500 = (FUNCTION_TABLE_ii[$499 & 7]($cinfo)|0);
          $501 = ($500<<24>>24)==(0);
          if ($501) {
           $502 = HEAP32[$cinfo>>2]|0;
           $503 = (($502) + 20|0);
           HEAP32[$503>>2] = 24;
           $504 = HEAP32[$502>>2]|0;
           FUNCTION_TABLE_vi[$504 & 63]($cinfo);
           $j$47$i = 1;
          } else {
           $j$47$i = 1;
          }
         } else {
          $j$47$i = 1;
         }
         while(1) {
          $505 = (($479) + ($j$47$i)|0);
          $506 = HEAP8[$505>>0]|0;
          $507 = HEAP32[$407>>2]|0;
          $508 = HEAP32[$507>>2]|0;
          $509 = (($508) + 1|0);
          HEAP32[$507>>2] = $509;
          HEAP8[$508>>0] = $506;
          $510 = (($507) + 4|0);
          $511 = HEAP32[$510>>2]|0;
          $512 = (($511) + -1)|0;
          HEAP32[$510>>2] = $512;
          $513 = ($512|0)==(0);
          if ($513) {
           $514 = (($507) + 12|0);
           $515 = HEAP32[$514>>2]|0;
           $516 = (FUNCTION_TABLE_ii[$515 & 7]($cinfo)|0);
           $517 = ($516<<24>>24)==(0);
           if ($517) {
            $518 = HEAP32[$cinfo>>2]|0;
            $519 = (($518) + 20|0);
            HEAP32[$519>>2] = 24;
            $520 = HEAP32[$518>>2]|0;
            FUNCTION_TABLE_vi[$520 & 63]($cinfo);
           }
          }
          $521 = (($j$47$i) + 1)|0;
          $exitcond$i6 = ($521|0)==(17);
          if ($exitcond$i6) {
           break;
          } else {
           $j$47$i = $521;
          }
         }
         $522 = (($dclens$i) + ($i$115$i<<2)|0);
         $523 = HEAP32[$522>>2]|0;
         $524 = ($523|0)>(0);
         if ($524) {
          $j$58$i = 0;
          while(1) {
           $525 = ((($479) + ($j$58$i)|0) + 17|0);
           $526 = HEAP8[$525>>0]|0;
           $527 = HEAP32[$407>>2]|0;
           $528 = HEAP32[$527>>2]|0;
           $529 = (($528) + 1|0);
           HEAP32[$527>>2] = $529;
           HEAP8[$528>>0] = $526;
           $530 = (($527) + 4|0);
           $531 = HEAP32[$530>>2]|0;
           $532 = (($531) + -1)|0;
           HEAP32[$530>>2] = $532;
           $533 = ($532|0)==(0);
           do {
            if ($533) {
             $534 = (($527) + 12|0);
             $535 = HEAP32[$534>>2]|0;
             $536 = (FUNCTION_TABLE_ii[$535 & 7]($cinfo)|0);
             $537 = ($536<<24>>24)==(0);
             if (!($537)) {
              break;
             }
             $538 = HEAP32[$cinfo>>2]|0;
             $539 = (($538) + 20|0);
             HEAP32[$539>>2] = 24;
             $540 = HEAP32[$538>>2]|0;
             FUNCTION_TABLE_vi[$540 & 63]($cinfo);
            }
           } while(0);
           $541 = (($j$58$i) + 1)|0;
           $exitcond = ($541|0)==($523|0);
           if ($exitcond) {
            break;
           } else {
            $j$58$i = $541;
           }
          }
         }
         HEAP8[$487>>0] = 1;
        }
       }
      }
      $542 = HEAP32[$471>>2]|0;
      $543 = ($542|0)==(0);
      if (!($543)) {
       $544 = (($481) + 273|0);
       $545 = HEAP8[$544>>0]|0;
       $546 = ($545<<24>>24)==(0);
       if ($546) {
        $547 = HEAP32[$407>>2]|0;
        $548 = $482&255;
        $549 = HEAP32[$547>>2]|0;
        $550 = (($549) + 1|0);
        HEAP32[$547>>2] = $550;
        HEAP8[$549>>0] = $548;
        $551 = (($547) + 4|0);
        $552 = HEAP32[$551>>2]|0;
        $553 = (($552) + -1)|0;
        HEAP32[$551>>2] = $553;
        $554 = ($553|0)==(0);
        if ($554) {
         $555 = (($547) + 12|0);
         $556 = HEAP32[$555>>2]|0;
         $557 = (FUNCTION_TABLE_ii[$556 & 7]($cinfo)|0);
         $558 = ($557<<24>>24)==(0);
         if ($558) {
          $559 = HEAP32[$cinfo>>2]|0;
          $560 = (($559) + 20|0);
          HEAP32[$560>>2] = 24;
          $561 = HEAP32[$559>>2]|0;
          FUNCTION_TABLE_vi[$561 & 63]($cinfo);
          $j$610$i = 1;
         } else {
          $j$610$i = 1;
         }
        } else {
         $j$610$i = 1;
        }
        while(1) {
         $562 = (($481) + ($j$610$i)|0);
         $563 = HEAP8[$562>>0]|0;
         $564 = HEAP32[$407>>2]|0;
         $565 = HEAP32[$564>>2]|0;
         $566 = (($565) + 1|0);
         HEAP32[$564>>2] = $566;
         HEAP8[$565>>0] = $563;
         $567 = (($564) + 4|0);
         $568 = HEAP32[$567>>2]|0;
         $569 = (($568) + -1)|0;
         HEAP32[$567>>2] = $569;
         $570 = ($569|0)==(0);
         if ($570) {
          $571 = (($564) + 12|0);
          $572 = HEAP32[$571>>2]|0;
          $573 = (FUNCTION_TABLE_ii[$572 & 7]($cinfo)|0);
          $574 = ($573<<24>>24)==(0);
          if ($574) {
           $575 = HEAP32[$cinfo>>2]|0;
           $576 = (($575) + 20|0);
           HEAP32[$576>>2] = 24;
           $577 = HEAP32[$575>>2]|0;
           FUNCTION_TABLE_vi[$577 & 63]($cinfo);
          }
         }
         $578 = (($j$610$i) + 1)|0;
         $exitcond36$i = ($578|0)==(17);
         if ($exitcond36$i) {
          break;
         } else {
          $j$610$i = $578;
         }
        }
        $579 = (($aclens$i) + ($i$115$i<<2)|0);
        $580 = HEAP32[$579>>2]|0;
        $581 = ($580|0)>(0);
        if ($581) {
         $j$711$i = 0;
         while(1) {
          $582 = ((($481) + ($j$711$i)|0) + 17|0);
          $583 = HEAP8[$582>>0]|0;
          $584 = HEAP32[$407>>2]|0;
          $585 = HEAP32[$584>>2]|0;
          $586 = (($585) + 1|0);
          HEAP32[$584>>2] = $586;
          HEAP8[$585>>0] = $583;
          $587 = (($584) + 4|0);
          $588 = HEAP32[$587>>2]|0;
          $589 = (($588) + -1)|0;
          HEAP32[$587>>2] = $589;
          $590 = ($589|0)==(0);
          do {
           if ($590) {
            $591 = (($584) + 12|0);
            $592 = HEAP32[$591>>2]|0;
            $593 = (FUNCTION_TABLE_ii[$592 & 7]($cinfo)|0);
            $594 = ($593<<24>>24)==(0);
            if (!($594)) {
             break;
            }
            $595 = HEAP32[$cinfo>>2]|0;
            $596 = (($595) + 20|0);
            HEAP32[$596>>2] = 24;
            $597 = HEAP32[$595>>2]|0;
            FUNCTION_TABLE_vi[$597 & 63]($cinfo);
           }
          } while(0);
          $598 = (($j$711$i) + 1)|0;
          $exitcond31 = ($598|0)==($580|0);
          if ($exitcond31) {
           break;
          } else {
           $j$711$i = $598;
          }
         }
        }
        HEAP8[$544>>0] = 1;
       }
      }
      $599 = (($i$115$i) + 1)|0;
      $600 = HEAP32[$$phi$trans$insert>>2]|0;
      $601 = ($599|0)<($600|0);
      if ($601) {
       $i$115$i = $599;
      } else {
       break L1;
      }
     }
    }
   } while(0);
   $401 = (($cinfo) + 228|0);
   $403 = ($402|0)>(0);
   if ($403) {
    $404 = (($cinfo) + 300|0);
    $405 = (($cinfo) + 308|0);
    $406 = (($cinfo) + 304|0);
    $i$026 = 0;
    while(1) {
     $602 = ((($cinfo) + ($i$026<<2)|0) + 232|0);
     $603 = HEAP32[$602>>2]|0;
     $604 = HEAP32[$404>>2]|0;
     $605 = ($604|0)==(0);
     if ($605) {
      $606 = HEAP32[$405>>2]|0;
      $607 = ($606|0)==(0);
      if ($607) {
       $608 = (($603) + 20|0);
       $609 = HEAP32[$608>>2]|0;
       _emit_dht($cinfo,$609,0);
      }
     }
     $610 = HEAP32[$406>>2]|0;
     $611 = ($610|0)==(0);
     if (!($611)) {
      $612 = (($603) + 24|0);
      $613 = HEAP32[$612>>2]|0;
      _emit_dht($cinfo,$613,1);
     }
     $614 = (($i$026) + 1)|0;
     $615 = HEAP32[$401>>2]|0;
     $616 = ($614|0)<($615|0);
     if ($616) {
      $i$026 = $614;
     } else {
      break;
     }
    }
   }
  } else {
   dest=$ac_in_use$i+0|0; stop=dest+16|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   dest=$dc_in_use$i+0|0; stop=dest+16|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   $5 = (($cinfo) + 228|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)>(0);
   L3: do {
    if ($7) {
     $8 = (($cinfo) + 300|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = ($9|0)==(0);
     $11 = (($cinfo) + 304|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = ($12|0)==(0);
     if (!($10)) {
      $i$111$i = 0;
      while(1) {
       if (!($13)) {
        $26 = ((($cinfo) + ($i$111$i<<2)|0) + 232|0);
        $27 = HEAP32[$26>>2]|0;
        $28 = (($27) + 24|0);
        $29 = HEAP32[$28>>2]|0;
        $30 = (($ac_in_use$i) + ($29)|0);
        HEAP8[$30>>0] = 1;
       }
       $31 = (($i$111$i) + 1)|0;
       $exitcond33 = ($31|0)==($6|0);
       if ($exitcond33) {
        $i$28$i = 0;$length$09$i = 0;
        break L3;
       } else {
        $i$111$i = $31;
       }
      }
     }
     $14 = (($cinfo) + 308|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($15|0)==(0);
     $i$111$us$i = 0;
     while(1) {
      $17 = ((($cinfo) + ($i$111$us$i<<2)|0) + 232|0);
      $18 = HEAP32[$17>>2]|0;
      if ($16) {
       $19 = (($18) + 20|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = (($dc_in_use$i) + ($20)|0);
       HEAP8[$21>>0] = 1;
      }
      if (!($13)) {
       $22 = (($18) + 24|0);
       $23 = HEAP32[$22>>2]|0;
       $24 = (($ac_in_use$i) + ($23)|0);
       HEAP8[$24>>0] = 1;
      }
      $25 = (($i$111$us$i) + 1)|0;
      $exitcond32 = ($25|0)==($6|0);
      if ($exitcond32) {
       $i$28$i = 0;$length$09$i = 0;
       break;
      } else {
       $i$111$us$i = $25;
      }
     }
    } else {
     $i$28$i = 0;$length$09$i = 0;
    }
   } while(0);
   while(1) {
    $32 = (($dc_in_use$i) + ($i$28$i)|0);
    $33 = HEAP8[$32>>0]|0;
    $34 = $33 << 24 >> 24;
    $35 = (($ac_in_use$i) + ($i$28$i)|0);
    $36 = HEAP8[$35>>0]|0;
    $37 = $36 << 24 >> 24;
    $38 = (($34) + ($length$09$i))|0;
    $39 = (($38) + ($37))|0;
    $40 = (($i$28$i) + 1)|0;
    $exitcond13$i = ($40|0)==(16);
    if ($exitcond13$i) {
     break;
    } else {
     $i$28$i = $40;$length$09$i = $39;
    }
   }
   $41 = ($39|0)==(0);
   if (!($41)) {
    $42 = (($cinfo) + 24|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = HEAP32[$43>>2]|0;
    $45 = (($44) + 1|0);
    HEAP32[$43>>2] = $45;
    HEAP8[$44>>0] = -1;
    $46 = (($43) + 4|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($47) + -1)|0;
    HEAP32[$46>>2] = $48;
    $49 = ($48|0)==(0);
    if ($49) {
     $50 = (($43) + 12|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = (FUNCTION_TABLE_ii[$51 & 7]($cinfo)|0);
     $53 = ($52<<24>>24)==(0);
     if ($53) {
      $54 = HEAP32[$cinfo>>2]|0;
      $55 = (($54) + 20|0);
      HEAP32[$55>>2] = 24;
      $56 = HEAP32[$54>>2]|0;
      FUNCTION_TABLE_vi[$56 & 63]($cinfo);
     }
    }
    $57 = HEAP32[$42>>2]|0;
    $58 = HEAP32[$57>>2]|0;
    $59 = (($58) + 1|0);
    HEAP32[$57>>2] = $59;
    HEAP8[$58>>0] = -52;
    $60 = (($57) + 4|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = (($61) + -1)|0;
    HEAP32[$60>>2] = $62;
    $63 = ($62|0)==(0);
    if ($63) {
     $64 = (($57) + 12|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = (FUNCTION_TABLE_ii[$65 & 7]($cinfo)|0);
     $67 = ($66<<24>>24)==(0);
     if ($67) {
      $68 = HEAP32[$cinfo>>2]|0;
      $69 = (($68) + 20|0);
      HEAP32[$69>>2] = 24;
      $70 = HEAP32[$68>>2]|0;
      FUNCTION_TABLE_vi[$70 & 63]($cinfo);
     }
    }
    $71 = $39 << 1;
    $72 = (($71) + 2)|0;
    $73 = $72 >>> 8;
    $74 = HEAP32[$42>>2]|0;
    $75 = $73&255;
    $76 = HEAP32[$74>>2]|0;
    $77 = (($76) + 1|0);
    HEAP32[$74>>2] = $77;
    HEAP8[$76>>0] = $75;
    $78 = (($74) + 4|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = (($79) + -1)|0;
    HEAP32[$78>>2] = $80;
    $81 = ($80|0)==(0);
    if ($81) {
     $82 = (($74) + 12|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = (FUNCTION_TABLE_ii[$83 & 7]($cinfo)|0);
     $85 = ($84<<24>>24)==(0);
     if ($85) {
      $86 = HEAP32[$cinfo>>2]|0;
      $87 = (($86) + 20|0);
      HEAP32[$87>>2] = 24;
      $88 = HEAP32[$86>>2]|0;
      FUNCTION_TABLE_vi[$88 & 63]($cinfo);
     }
    }
    $89 = HEAP32[$42>>2]|0;
    $90 = $72&255;
    $91 = HEAP32[$89>>2]|0;
    $92 = (($91) + 1|0);
    HEAP32[$89>>2] = $92;
    HEAP8[$91>>0] = $90;
    $93 = (($89) + 4|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = (($94) + -1)|0;
    HEAP32[$93>>2] = $95;
    $96 = ($95|0)==(0);
    if ($96) {
     $97 = (($89) + 12|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = (FUNCTION_TABLE_ii[$98 & 7]($cinfo)|0);
     $100 = ($99<<24>>24)==(0);
     if ($100) {
      $101 = HEAP32[$cinfo>>2]|0;
      $102 = (($101) + 20|0);
      HEAP32[$102>>2] = 24;
      $103 = HEAP32[$101>>2]|0;
      FUNCTION_TABLE_vi[$103 & 63]($cinfo);
     }
    }
    $i$35$i = 0;
    while(1) {
     $104 = (($dc_in_use$i) + ($i$35$i)|0);
     $105 = HEAP8[$104>>0]|0;
     $106 = ($105<<24>>24)==(0);
     if (!($106)) {
      $107 = HEAP32[$42>>2]|0;
      $108 = $i$35$i&255;
      $109 = HEAP32[$107>>2]|0;
      $110 = (($109) + 1|0);
      HEAP32[$107>>2] = $110;
      HEAP8[$109>>0] = $108;
      $111 = (($107) + 4|0);
      $112 = HEAP32[$111>>2]|0;
      $113 = (($112) + -1)|0;
      HEAP32[$111>>2] = $113;
      $114 = ($113|0)==(0);
      if ($114) {
       $115 = (($107) + 12|0);
       $116 = HEAP32[$115>>2]|0;
       $117 = (FUNCTION_TABLE_ii[$116 & 7]($cinfo)|0);
       $118 = ($117<<24>>24)==(0);
       if ($118) {
        $119 = HEAP32[$cinfo>>2]|0;
        $120 = (($119) + 20|0);
        HEAP32[$120>>2] = 24;
        $121 = HEAP32[$119>>2]|0;
        FUNCTION_TABLE_vi[$121 & 63]($cinfo);
       }
      }
      $122 = ((($cinfo) + ($i$35$i)|0) + 120|0);
      $123 = HEAP8[$122>>0]|0;
      $124 = $123&255;
      $125 = ((($cinfo) + ($i$35$i)|0) + 136|0);
      $126 = HEAP8[$125>>0]|0;
      $127 = $126&255;
      $128 = $127 << 4;
      $129 = (($128) + ($124))|0;
      $130 = HEAP32[$42>>2]|0;
      $131 = $129&255;
      $132 = HEAP32[$130>>2]|0;
      $133 = (($132) + 1|0);
      HEAP32[$130>>2] = $133;
      HEAP8[$132>>0] = $131;
      $134 = (($130) + 4|0);
      $135 = HEAP32[$134>>2]|0;
      $136 = (($135) + -1)|0;
      HEAP32[$134>>2] = $136;
      $137 = ($136|0)==(0);
      if ($137) {
       $138 = (($130) + 12|0);
       $139 = HEAP32[$138>>2]|0;
       $140 = (FUNCTION_TABLE_ii[$139 & 7]($cinfo)|0);
       $141 = ($140<<24>>24)==(0);
       if ($141) {
        $142 = HEAP32[$cinfo>>2]|0;
        $143 = (($142) + 20|0);
        HEAP32[$143>>2] = 24;
        $144 = HEAP32[$142>>2]|0;
        FUNCTION_TABLE_vi[$144 & 63]($cinfo);
       }
      }
     }
     $145 = (($ac_in_use$i) + ($i$35$i)|0);
     $146 = HEAP8[$145>>0]|0;
     $147 = ($146<<24>>24)==(0);
     if (!($147)) {
      $148 = (($i$35$i) + 16)|0;
      $149 = HEAP32[$42>>2]|0;
      $150 = $148&255;
      $151 = HEAP32[$149>>2]|0;
      $152 = (($151) + 1|0);
      HEAP32[$149>>2] = $152;
      HEAP8[$151>>0] = $150;
      $153 = (($149) + 4|0);
      $154 = HEAP32[$153>>2]|0;
      $155 = (($154) + -1)|0;
      HEAP32[$153>>2] = $155;
      $156 = ($155|0)==(0);
      if ($156) {
       $157 = (($149) + 12|0);
       $158 = HEAP32[$157>>2]|0;
       $159 = (FUNCTION_TABLE_ii[$158 & 7]($cinfo)|0);
       $160 = ($159<<24>>24)==(0);
       if ($160) {
        $161 = HEAP32[$cinfo>>2]|0;
        $162 = (($161) + 20|0);
        HEAP32[$162>>2] = 24;
        $163 = HEAP32[$161>>2]|0;
        FUNCTION_TABLE_vi[$163 & 63]($cinfo);
       }
      }
      $164 = ((($cinfo) + ($i$35$i)|0) + 152|0);
      $165 = HEAP8[$164>>0]|0;
      $166 = HEAP32[$42>>2]|0;
      $167 = HEAP32[$166>>2]|0;
      $168 = (($167) + 1|0);
      HEAP32[$166>>2] = $168;
      HEAP8[$167>>0] = $165;
      $169 = (($166) + 4|0);
      $170 = HEAP32[$169>>2]|0;
      $171 = (($170) + -1)|0;
      HEAP32[$169>>2] = $171;
      $172 = ($171|0)==(0);
      if ($172) {
       $173 = (($166) + 12|0);
       $174 = HEAP32[$173>>2]|0;
       $175 = (FUNCTION_TABLE_ii[$174 & 7]($cinfo)|0);
       $176 = ($175<<24>>24)==(0);
       if ($176) {
        $177 = HEAP32[$cinfo>>2]|0;
        $178 = (($177) + 20|0);
        HEAP32[$178>>2] = 24;
        $179 = HEAP32[$177>>2]|0;
        FUNCTION_TABLE_vi[$179 & 63]($cinfo);
       }
      }
     }
     $180 = (($i$35$i) + 1)|0;
     $exitcond$i = ($180|0)==(16);
     if ($exitcond$i) {
      break;
     } else {
      $i$35$i = $180;
     }
    }
   }
  }
 } while(0);
 $617 = (($cinfo) + 188|0);
 $618 = HEAP32[$617>>2]|0;
 $619 = (($1) + 28|0);
 $620 = HEAP32[$619>>2]|0;
 $621 = ($618|0)==($620|0);
 $$pre38 = (($cinfo) + 24|0);
 if (!($621)) {
  $622 = HEAP32[$$pre38>>2]|0;
  $623 = HEAP32[$622>>2]|0;
  $624 = (($623) + 1|0);
  HEAP32[$622>>2] = $624;
  HEAP8[$623>>0] = -1;
  $625 = (($622) + 4|0);
  $626 = HEAP32[$625>>2]|0;
  $627 = (($626) + -1)|0;
  HEAP32[$625>>2] = $627;
  $628 = ($627|0)==(0);
  if ($628) {
   $629 = (($622) + 12|0);
   $630 = HEAP32[$629>>2]|0;
   $631 = (FUNCTION_TABLE_ii[$630 & 7]($cinfo)|0);
   $632 = ($631<<24>>24)==(0);
   if ($632) {
    $633 = HEAP32[$cinfo>>2]|0;
    $634 = (($633) + 20|0);
    HEAP32[$634>>2] = 24;
    $635 = HEAP32[$633>>2]|0;
    FUNCTION_TABLE_vi[$635 & 63]($cinfo);
   }
  }
  $636 = HEAP32[$$pre38>>2]|0;
  $637 = HEAP32[$636>>2]|0;
  $638 = (($637) + 1|0);
  HEAP32[$636>>2] = $638;
  HEAP8[$637>>0] = -35;
  $639 = (($636) + 4|0);
  $640 = HEAP32[$639>>2]|0;
  $641 = (($640) + -1)|0;
  HEAP32[$639>>2] = $641;
  $642 = ($641|0)==(0);
  if ($642) {
   $643 = (($636) + 12|0);
   $644 = HEAP32[$643>>2]|0;
   $645 = (FUNCTION_TABLE_ii[$644 & 7]($cinfo)|0);
   $646 = ($645<<24>>24)==(0);
   if ($646) {
    $647 = HEAP32[$cinfo>>2]|0;
    $648 = (($647) + 20|0);
    HEAP32[$648>>2] = 24;
    $649 = HEAP32[$647>>2]|0;
    FUNCTION_TABLE_vi[$649 & 63]($cinfo);
   }
  }
  $650 = HEAP32[$$pre38>>2]|0;
  $651 = HEAP32[$650>>2]|0;
  $652 = (($651) + 1|0);
  HEAP32[$650>>2] = $652;
  HEAP8[$651>>0] = 0;
  $653 = (($650) + 4|0);
  $654 = HEAP32[$653>>2]|0;
  $655 = (($654) + -1)|0;
  HEAP32[$653>>2] = $655;
  $656 = ($655|0)==(0);
  if ($656) {
   $657 = (($650) + 12|0);
   $658 = HEAP32[$657>>2]|0;
   $659 = (FUNCTION_TABLE_ii[$658 & 7]($cinfo)|0);
   $660 = ($659<<24>>24)==(0);
   if ($660) {
    $661 = HEAP32[$cinfo>>2]|0;
    $662 = (($661) + 20|0);
    HEAP32[$662>>2] = 24;
    $663 = HEAP32[$661>>2]|0;
    FUNCTION_TABLE_vi[$663 & 63]($cinfo);
   }
  }
  $664 = HEAP32[$$pre38>>2]|0;
  $665 = HEAP32[$664>>2]|0;
  $666 = (($665) + 1|0);
  HEAP32[$664>>2] = $666;
  HEAP8[$665>>0] = 4;
  $667 = (($664) + 4|0);
  $668 = HEAP32[$667>>2]|0;
  $669 = (($668) + -1)|0;
  HEAP32[$667>>2] = $669;
  $670 = ($669|0)==(0);
  if ($670) {
   $671 = (($664) + 12|0);
   $672 = HEAP32[$671>>2]|0;
   $673 = (FUNCTION_TABLE_ii[$672 & 7]($cinfo)|0);
   $674 = ($673<<24>>24)==(0);
   if ($674) {
    $675 = HEAP32[$cinfo>>2]|0;
    $676 = (($675) + 20|0);
    HEAP32[$676>>2] = 24;
    $677 = HEAP32[$675>>2]|0;
    FUNCTION_TABLE_vi[$677 & 63]($cinfo);
   }
  }
  $678 = HEAP32[$617>>2]|0;
  $679 = $678 >>> 8;
  $680 = HEAP32[$$pre38>>2]|0;
  $681 = $679&255;
  $682 = HEAP32[$680>>2]|0;
  $683 = (($682) + 1|0);
  HEAP32[$680>>2] = $683;
  HEAP8[$682>>0] = $681;
  $684 = (($680) + 4|0);
  $685 = HEAP32[$684>>2]|0;
  $686 = (($685) + -1)|0;
  HEAP32[$684>>2] = $686;
  $687 = ($686|0)==(0);
  if ($687) {
   $688 = (($680) + 12|0);
   $689 = HEAP32[$688>>2]|0;
   $690 = (FUNCTION_TABLE_ii[$689 & 7]($cinfo)|0);
   $691 = ($690<<24>>24)==(0);
   if ($691) {
    $692 = HEAP32[$cinfo>>2]|0;
    $693 = (($692) + 20|0);
    HEAP32[$693>>2] = 24;
    $694 = HEAP32[$692>>2]|0;
    FUNCTION_TABLE_vi[$694 & 63]($cinfo);
   }
  }
  $695 = HEAP32[$$pre38>>2]|0;
  $696 = $678&255;
  $697 = HEAP32[$695>>2]|0;
  $698 = (($697) + 1|0);
  HEAP32[$695>>2] = $698;
  HEAP8[$697>>0] = $696;
  $699 = (($695) + 4|0);
  $700 = HEAP32[$699>>2]|0;
  $701 = (($700) + -1)|0;
  HEAP32[$699>>2] = $701;
  $702 = ($701|0)==(0);
  if ($702) {
   $703 = (($695) + 12|0);
   $704 = HEAP32[$703>>2]|0;
   $705 = (FUNCTION_TABLE_ii[$704 & 7]($cinfo)|0);
   $706 = ($705<<24>>24)==(0);
   if ($706) {
    $707 = HEAP32[$cinfo>>2]|0;
    $708 = (($707) + 20|0);
    HEAP32[$708>>2] = 24;
    $709 = HEAP32[$707>>2]|0;
    FUNCTION_TABLE_vi[$709 & 63]($cinfo);
   }
  }
  $710 = HEAP32[$617>>2]|0;
  $$c = $710;
  HEAP32[$619>>2] = $$c;
 }
 $711 = HEAP32[$$pre38>>2]|0;
 $712 = HEAP32[$711>>2]|0;
 $713 = (($712) + 1|0);
 HEAP32[$711>>2] = $713;
 HEAP8[$712>>0] = -1;
 $714 = (($711) + 4|0);
 $715 = HEAP32[$714>>2]|0;
 $716 = (($715) + -1)|0;
 HEAP32[$714>>2] = $716;
 $717 = ($716|0)==(0);
 if ($717) {
  $718 = (($711) + 12|0);
  $719 = HEAP32[$718>>2]|0;
  $720 = (FUNCTION_TABLE_ii[$719 & 7]($cinfo)|0);
  $721 = ($720<<24>>24)==(0);
  if ($721) {
   $722 = HEAP32[$cinfo>>2]|0;
   $723 = (($722) + 20|0);
   HEAP32[$723>>2] = 24;
   $724 = HEAP32[$722>>2]|0;
   FUNCTION_TABLE_vi[$724 & 63]($cinfo);
  }
 }
 $725 = HEAP32[$$pre38>>2]|0;
 $726 = HEAP32[$725>>2]|0;
 $727 = (($726) + 1|0);
 HEAP32[$725>>2] = $727;
 HEAP8[$726>>0] = -38;
 $728 = (($725) + 4|0);
 $729 = HEAP32[$728>>2]|0;
 $730 = (($729) + -1)|0;
 HEAP32[$728>>2] = $730;
 $731 = ($730|0)==(0);
 if ($731) {
  $732 = (($725) + 12|0);
  $733 = HEAP32[$732>>2]|0;
  $734 = (FUNCTION_TABLE_ii[$733 & 7]($cinfo)|0);
  $735 = ($734<<24>>24)==(0);
  if ($735) {
   $736 = HEAP32[$cinfo>>2]|0;
   $737 = (($736) + 20|0);
   HEAP32[$737>>2] = 24;
   $738 = HEAP32[$736>>2]|0;
   FUNCTION_TABLE_vi[$738 & 63]($cinfo);
  }
 }
 $739 = (($cinfo) + 228|0);
 $740 = HEAP32[$739>>2]|0;
 $741 = $740 << 1;
 $742 = (($741) + 6)|0;
 $743 = $742 >>> 8;
 $744 = HEAP32[$$pre38>>2]|0;
 $745 = $743&255;
 $746 = HEAP32[$744>>2]|0;
 $747 = (($746) + 1|0);
 HEAP32[$744>>2] = $747;
 HEAP8[$746>>0] = $745;
 $748 = (($744) + 4|0);
 $749 = HEAP32[$748>>2]|0;
 $750 = (($749) + -1)|0;
 HEAP32[$748>>2] = $750;
 $751 = ($750|0)==(0);
 if ($751) {
  $752 = (($744) + 12|0);
  $753 = HEAP32[$752>>2]|0;
  $754 = (FUNCTION_TABLE_ii[$753 & 7]($cinfo)|0);
  $755 = ($754<<24>>24)==(0);
  if ($755) {
   $756 = HEAP32[$cinfo>>2]|0;
   $757 = (($756) + 20|0);
   HEAP32[$757>>2] = 24;
   $758 = HEAP32[$756>>2]|0;
   FUNCTION_TABLE_vi[$758 & 63]($cinfo);
  }
 }
 $759 = HEAP32[$$pre38>>2]|0;
 $760 = $742&255;
 $761 = HEAP32[$759>>2]|0;
 $762 = (($761) + 1|0);
 HEAP32[$759>>2] = $762;
 HEAP8[$761>>0] = $760;
 $763 = (($759) + 4|0);
 $764 = HEAP32[$763>>2]|0;
 $765 = (($764) + -1)|0;
 HEAP32[$763>>2] = $765;
 $766 = ($765|0)==(0);
 if ($766) {
  $767 = (($759) + 12|0);
  $768 = HEAP32[$767>>2]|0;
  $769 = (FUNCTION_TABLE_ii[$768 & 7]($cinfo)|0);
  $770 = ($769<<24>>24)==(0);
  if ($770) {
   $771 = HEAP32[$cinfo>>2]|0;
   $772 = (($771) + 20|0);
   HEAP32[$772>>2] = 24;
   $773 = HEAP32[$771>>2]|0;
   FUNCTION_TABLE_vi[$773 & 63]($cinfo);
  }
 }
 $774 = HEAP32[$739>>2]|0;
 $775 = HEAP32[$$pre38>>2]|0;
 $776 = $774&255;
 $777 = HEAP32[$775>>2]|0;
 $778 = (($777) + 1|0);
 HEAP32[$775>>2] = $778;
 HEAP8[$777>>0] = $776;
 $779 = (($775) + 4|0);
 $780 = HEAP32[$779>>2]|0;
 $781 = (($780) + -1)|0;
 HEAP32[$779>>2] = $781;
 $782 = ($781|0)==(0);
 if ($782) {
  $783 = (($775) + 12|0);
  $784 = HEAP32[$783>>2]|0;
  $785 = (FUNCTION_TABLE_ii[$784 & 7]($cinfo)|0);
  $786 = ($785<<24>>24)==(0);
  if ($786) {
   $787 = HEAP32[$cinfo>>2]|0;
   $788 = (($787) + 20|0);
   HEAP32[$788>>2] = 24;
   $789 = HEAP32[$787>>2]|0;
   FUNCTION_TABLE_vi[$789 & 63]($cinfo);
  }
 }
 $790 = HEAP32[$739>>2]|0;
 $791 = ($790|0)>(0);
 if ($791) {
  $792 = (($cinfo) + 300|0);
  $793 = (($cinfo) + 308|0);
  $794 = (($cinfo) + 304|0);
  $i$07$i = 0;
  while(1) {
   $795 = ((($cinfo) + ($i$07$i<<2)|0) + 232|0);
   $796 = HEAP32[$795>>2]|0;
   $797 = HEAP32[$796>>2]|0;
   $798 = HEAP32[$$pre38>>2]|0;
   $799 = $797&255;
   $800 = HEAP32[$798>>2]|0;
   $801 = (($800) + 1|0);
   HEAP32[$798>>2] = $801;
   HEAP8[$800>>0] = $799;
   $802 = (($798) + 4|0);
   $803 = HEAP32[$802>>2]|0;
   $804 = (($803) + -1)|0;
   HEAP32[$802>>2] = $804;
   $805 = ($804|0)==(0);
   if ($805) {
    $806 = (($798) + 12|0);
    $807 = HEAP32[$806>>2]|0;
    $808 = (FUNCTION_TABLE_ii[$807 & 7]($cinfo)|0);
    $809 = ($808<<24>>24)==(0);
    if ($809) {
     $810 = HEAP32[$cinfo>>2]|0;
     $811 = (($810) + 20|0);
     HEAP32[$811>>2] = 24;
     $812 = HEAP32[$810>>2]|0;
     FUNCTION_TABLE_vi[$812 & 63]($cinfo);
    }
   }
   $813 = HEAP32[$792>>2]|0;
   $814 = ($813|0)==(0);
   if ($814) {
    $815 = HEAP32[$793>>2]|0;
    $816 = ($815|0)==(0);
    if ($816) {
     $817 = (($796) + 20|0);
     $818 = HEAP32[$817>>2]|0;
     $phitmp$i = $818 << 4;
     $824 = $phitmp$i;
    } else {
     $824 = 0;
    }
   } else {
    $824 = 0;
   }
   $819 = HEAP32[$794>>2]|0;
   $820 = ($819|0)==(0);
   if ($820) {
    $825 = 0;
   } else {
    $821 = (($796) + 24|0);
    $822 = HEAP32[$821>>2]|0;
    $825 = $822;
   }
   $823 = (($825) + ($824))|0;
   $826 = HEAP32[$$pre38>>2]|0;
   $827 = $823&255;
   $828 = HEAP32[$826>>2]|0;
   $829 = (($828) + 1|0);
   HEAP32[$826>>2] = $829;
   HEAP8[$828>>0] = $827;
   $830 = (($826) + 4|0);
   $831 = HEAP32[$830>>2]|0;
   $832 = (($831) + -1)|0;
   HEAP32[$830>>2] = $832;
   $833 = ($832|0)==(0);
   if ($833) {
    $834 = (($826) + 12|0);
    $835 = HEAP32[$834>>2]|0;
    $836 = (FUNCTION_TABLE_ii[$835 & 7]($cinfo)|0);
    $837 = ($836<<24>>24)==(0);
    if ($837) {
     $838 = HEAP32[$cinfo>>2]|0;
     $839 = (($838) + 20|0);
     HEAP32[$839>>2] = 24;
     $840 = HEAP32[$838>>2]|0;
     FUNCTION_TABLE_vi[$840 & 63]($cinfo);
    }
   }
   $841 = (($i$07$i) + 1)|0;
   $842 = HEAP32[$739>>2]|0;
   $843 = ($841|0)<($842|0);
   if ($843) {
    $i$07$i = $841;
   } else {
    $$pre$phi$iZ2D = $792;
    break;
   }
  }
 } else {
  $$pre$i = (($cinfo) + 300|0);
  $$pre$phi$iZ2D = $$pre$i;
 }
 $844 = HEAP32[$$pre$phi$iZ2D>>2]|0;
 $845 = HEAP32[$$pre38>>2]|0;
 $846 = $844&255;
 $847 = HEAP32[$845>>2]|0;
 $848 = (($847) + 1|0);
 HEAP32[$845>>2] = $848;
 HEAP8[$847>>0] = $846;
 $849 = (($845) + 4|0);
 $850 = HEAP32[$849>>2]|0;
 $851 = (($850) + -1)|0;
 HEAP32[$849>>2] = $851;
 $852 = ($851|0)==(0);
 if ($852) {
  $853 = (($845) + 12|0);
  $854 = HEAP32[$853>>2]|0;
  $855 = (FUNCTION_TABLE_ii[$854 & 7]($cinfo)|0);
  $856 = ($855<<24>>24)==(0);
  if ($856) {
   $857 = HEAP32[$cinfo>>2]|0;
   $858 = (($857) + 20|0);
   HEAP32[$858>>2] = 24;
   $859 = HEAP32[$857>>2]|0;
   FUNCTION_TABLE_vi[$859 & 63]($cinfo);
  }
 }
 $860 = (($cinfo) + 304|0);
 $861 = HEAP32[$860>>2]|0;
 $862 = HEAP32[$$pre38>>2]|0;
 $863 = $861&255;
 $864 = HEAP32[$862>>2]|0;
 $865 = (($864) + 1|0);
 HEAP32[$862>>2] = $865;
 HEAP8[$864>>0] = $863;
 $866 = (($862) + 4|0);
 $867 = HEAP32[$866>>2]|0;
 $868 = (($867) + -1)|0;
 HEAP32[$866>>2] = $868;
 $869 = ($868|0)==(0);
 if ($869) {
  $870 = (($862) + 12|0);
  $871 = HEAP32[$870>>2]|0;
  $872 = (FUNCTION_TABLE_ii[$871 & 7]($cinfo)|0);
  $873 = ($872<<24>>24)==(0);
  if ($873) {
   $874 = HEAP32[$cinfo>>2]|0;
   $875 = (($874) + 20|0);
   HEAP32[$875>>2] = 24;
   $876 = HEAP32[$874>>2]|0;
   FUNCTION_TABLE_vi[$876 & 63]($cinfo);
  }
 }
 $877 = (($cinfo) + 308|0);
 $878 = HEAP32[$877>>2]|0;
 $879 = $878 << 4;
 $880 = (($cinfo) + 312|0);
 $881 = HEAP32[$880>>2]|0;
 $882 = (($879) + ($881))|0;
 $883 = HEAP32[$$pre38>>2]|0;
 $884 = $882&255;
 $885 = HEAP32[$883>>2]|0;
 $886 = (($885) + 1|0);
 HEAP32[$883>>2] = $886;
 HEAP8[$885>>0] = $884;
 $887 = (($883) + 4|0);
 $888 = HEAP32[$887>>2]|0;
 $889 = (($888) + -1)|0;
 HEAP32[$887>>2] = $889;
 $890 = ($889|0)==(0);
 if (!($890)) {
  STACKTOP = sp;return;
 }
 $891 = (($883) + 12|0);
 $892 = HEAP32[$891>>2]|0;
 $893 = (FUNCTION_TABLE_ii[$892 & 7]($cinfo)|0);
 $894 = ($893<<24>>24)==(0);
 if (!($894)) {
  STACKTOP = sp;return;
 }
 $895 = HEAP32[$cinfo>>2]|0;
 $896 = (($895) + 20|0);
 HEAP32[$896>>2] = 24;
 $897 = HEAP32[$895>>2]|0;
 FUNCTION_TABLE_vi[$897 & 63]($cinfo);
 STACKTOP = sp;return;
}
function _write_file_trailer($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 HEAP32[$1>>2] = $3;
 HEAP8[$2>>0] = -1;
 $4 = (($1) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + -1)|0;
 HEAP32[$4>>2] = $6;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($1) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (FUNCTION_TABLE_ii[$9 & 7]($cinfo)|0);
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = HEAP32[$cinfo>>2]|0;
   $13 = (($12) + 20|0);
   HEAP32[$13>>2] = 24;
   $14 = HEAP32[$12>>2]|0;
   FUNCTION_TABLE_vi[$14 & 63]($cinfo);
  }
 }
 $15 = HEAP32[$0>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 1|0);
 HEAP32[$15>>2] = $17;
 HEAP8[$16>>0] = -39;
 $18 = (($15) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + -1)|0;
 HEAP32[$18>>2] = $20;
 $21 = ($20|0)==(0);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 $22 = (($15) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (FUNCTION_TABLE_ii[$23 & 7]($cinfo)|0);
 $25 = ($24<<24>>24)==(0);
 if (!($25)) {
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$cinfo>>2]|0;
 $27 = (($26) + 20|0);
 HEAP32[$27>>2] = 24;
 $28 = HEAP32[$26>>2]|0;
 FUNCTION_TABLE_vi[$28 & 63]($cinfo);
 STACKTOP = sp;return;
}
function _write_tables_only($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 HEAP32[$1>>2] = $3;
 HEAP8[$2>>0] = -1;
 $4 = (($1) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + -1)|0;
 HEAP32[$4>>2] = $6;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($1) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (FUNCTION_TABLE_ii[$9 & 7]($cinfo)|0);
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = HEAP32[$cinfo>>2]|0;
   $13 = (($12) + 20|0);
   HEAP32[$13>>2] = 24;
   $14 = HEAP32[$12>>2]|0;
   FUNCTION_TABLE_vi[$14 & 63]($cinfo);
  }
 }
 $15 = HEAP32[$0>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 1|0);
 HEAP32[$15>>2] = $17;
 HEAP8[$16>>0] = -40;
 $18 = (($15) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + -1)|0;
 HEAP32[$18>>2] = $20;
 $21 = ($20|0)==(0);
 if ($21) {
  $22 = (($15) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (FUNCTION_TABLE_ii[$23 & 7]($cinfo)|0);
  $25 = ($24<<24>>24)==(0);
  if ($25) {
   $26 = HEAP32[$cinfo>>2]|0;
   $27 = (($26) + 20|0);
   HEAP32[$27>>2] = 24;
   $28 = HEAP32[$26>>2]|0;
   FUNCTION_TABLE_vi[$28 & 63]($cinfo);
  }
 }
 $29 = (($cinfo) + 72|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if (!($31)) {
  (_emit_dqt($cinfo,0)|0);
 }
 $32 = (($cinfo) + 76|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  (_emit_dqt($cinfo,1)|0);
 }
 $87 = (($cinfo) + 80|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ($88|0)==(0|0);
 if (!($89)) {
  (_emit_dqt($cinfo,2)|0);
 }
 $90 = (($cinfo) + 84|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = ($91|0)==(0|0);
 if (!($92)) {
  (_emit_dqt($cinfo,3)|0);
 }
 $93 = (($cinfo) + 177|0);
 $94 = HEAP8[$93>>0]|0;
 $95 = ($94<<24>>24)==(0);
 if ($95) {
  $35 = (($cinfo) + 88|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0|0);
  if (!($37)) {
   _emit_dht($cinfo,0,0);
  }
  $38 = (($cinfo) + 104|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)==(0|0);
  if (!($40)) {
   _emit_dht($cinfo,0,1);
  }
  $41 = (($cinfo) + 92|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0|0);
  if (!($43)) {
   _emit_dht($cinfo,1,0);
  }
  $72 = (($cinfo) + 108|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = ($73|0)==(0|0);
  if (!($74)) {
   _emit_dht($cinfo,1,1);
  }
  $75 = (($cinfo) + 96|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = ($76|0)==(0|0);
  if (!($77)) {
   _emit_dht($cinfo,2,0);
  }
  $78 = (($cinfo) + 112|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = ($79|0)==(0|0);
  if (!($80)) {
   _emit_dht($cinfo,2,1);
  }
  $81 = (($cinfo) + 100|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = ($82|0)==(0|0);
  if (!($83)) {
   _emit_dht($cinfo,3,0);
  }
  $84 = (($cinfo) + 116|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = ($85|0)==(0|0);
  if (!($86)) {
   _emit_dht($cinfo,3,1);
  }
 }
 $44 = HEAP32[$0>>2]|0;
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + 1|0);
 HEAP32[$44>>2] = $46;
 HEAP8[$45>>0] = -1;
 $47 = (($44) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + -1)|0;
 HEAP32[$47>>2] = $49;
 $50 = ($49|0)==(0);
 if ($50) {
  $51 = (($44) + 12|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (FUNCTION_TABLE_ii[$52 & 7]($cinfo)|0);
  $54 = ($53<<24>>24)==(0);
  if ($54) {
   $55 = HEAP32[$cinfo>>2]|0;
   $56 = (($55) + 20|0);
   HEAP32[$56>>2] = 24;
   $57 = HEAP32[$55>>2]|0;
   FUNCTION_TABLE_vi[$57 & 63]($cinfo);
  }
 }
 $58 = HEAP32[$0>>2]|0;
 $59 = HEAP32[$58>>2]|0;
 $60 = (($59) + 1|0);
 HEAP32[$58>>2] = $60;
 HEAP8[$59>>0] = -39;
 $61 = (($58) + 4|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($62) + -1)|0;
 HEAP32[$61>>2] = $63;
 $64 = ($63|0)==(0);
 if (!($64)) {
  STACKTOP = sp;return;
 }
 $65 = (($58) + 12|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (FUNCTION_TABLE_ii[$66 & 7]($cinfo)|0);
 $68 = ($67<<24>>24)==(0);
 if (!($68)) {
  STACKTOP = sp;return;
 }
 $69 = HEAP32[$cinfo>>2]|0;
 $70 = (($69) + 20|0);
 HEAP32[$70>>2] = 24;
 $71 = HEAP32[$69>>2]|0;
 FUNCTION_TABLE_vi[$71 & 63]($cinfo);
 STACKTOP = sp;return;
}
function _write_marker_header($cinfo,$marker,$datalen) {
 $cinfo = $cinfo|0;
 $marker = $marker|0;
 $datalen = $datalen|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($datalen>>>0)>(65533);
 if ($0) {
  $1 = HEAP32[$cinfo>>2]|0;
  $2 = (($1) + 20|0);
  HEAP32[$2>>2] = 11;
  $3 = HEAP32[$1>>2]|0;
  FUNCTION_TABLE_vi[$3 & 63]($cinfo);
 }
 $4 = (($cinfo) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 1|0);
 HEAP32[$5>>2] = $7;
 HEAP8[$6>>0] = -1;
 $8 = (($5) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + -1)|0;
 HEAP32[$8>>2] = $10;
 $11 = ($10|0)==(0);
 if ($11) {
  $12 = (($5) + 12|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_ii[$13 & 7]($cinfo)|0);
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   $16 = HEAP32[$cinfo>>2]|0;
   $17 = (($16) + 20|0);
   HEAP32[$17>>2] = 24;
   $18 = HEAP32[$16>>2]|0;
   FUNCTION_TABLE_vi[$18 & 63]($cinfo);
  }
 }
 $19 = HEAP32[$4>>2]|0;
 $20 = $marker&255;
 $21 = HEAP32[$19>>2]|0;
 $22 = (($21) + 1|0);
 HEAP32[$19>>2] = $22;
 HEAP8[$21>>0] = $20;
 $23 = (($19) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + -1)|0;
 HEAP32[$23>>2] = $25;
 $26 = ($25|0)==(0);
 if ($26) {
  $27 = (($19) + 12|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (FUNCTION_TABLE_ii[$28 & 7]($cinfo)|0);
  $30 = ($29<<24>>24)==(0);
  if ($30) {
   $31 = HEAP32[$cinfo>>2]|0;
   $32 = (($31) + 20|0);
   HEAP32[$32>>2] = 24;
   $33 = HEAP32[$31>>2]|0;
   FUNCTION_TABLE_vi[$33 & 63]($cinfo);
  }
 }
 $34 = (($datalen) + 2)|0;
 $35 = $34 >>> 8;
 $36 = HEAP32[$4>>2]|0;
 $37 = $35&255;
 $38 = HEAP32[$36>>2]|0;
 $39 = (($38) + 1|0);
 HEAP32[$36>>2] = $39;
 HEAP8[$38>>0] = $37;
 $40 = (($36) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + -1)|0;
 HEAP32[$40>>2] = $42;
 $43 = ($42|0)==(0);
 if ($43) {
  $44 = (($36) + 12|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (FUNCTION_TABLE_ii[$45 & 7]($cinfo)|0);
  $47 = ($46<<24>>24)==(0);
  if ($47) {
   $48 = HEAP32[$cinfo>>2]|0;
   $49 = (($48) + 20|0);
   HEAP32[$49>>2] = 24;
   $50 = HEAP32[$48>>2]|0;
   FUNCTION_TABLE_vi[$50 & 63]($cinfo);
  }
 }
 $51 = HEAP32[$4>>2]|0;
 $52 = $34&255;
 $53 = HEAP32[$51>>2]|0;
 $54 = (($53) + 1|0);
 HEAP32[$51>>2] = $54;
 HEAP8[$53>>0] = $52;
 $55 = (($51) + 4|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + -1)|0;
 HEAP32[$55>>2] = $57;
 $58 = ($57|0)==(0);
 if (!($58)) {
  STACKTOP = sp;return;
 }
 $59 = (($51) + 12|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (FUNCTION_TABLE_ii[$60 & 7]($cinfo)|0);
 $62 = ($61<<24>>24)==(0);
 if (!($62)) {
  STACKTOP = sp;return;
 }
 $63 = HEAP32[$cinfo>>2]|0;
 $64 = (($63) + 20|0);
 HEAP32[$64>>2] = 24;
 $65 = HEAP32[$63>>2]|0;
 FUNCTION_TABLE_vi[$65 & 63]($cinfo);
 STACKTOP = sp;return;
}
function _write_marker_byte($cinfo,$val) {
 $cinfo = $cinfo|0;
 $val = $val|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $val&255;
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 1|0);
 HEAP32[$1>>2] = $4;
 HEAP8[$3>>0] = $2;
 $5 = (($1) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + -1)|0;
 HEAP32[$5>>2] = $7;
 $8 = ($7|0)==(0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($1) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 7]($cinfo)|0);
 $12 = ($11<<24>>24)==(0);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = HEAP32[$cinfo>>2]|0;
 $14 = (($13) + 20|0);
 HEAP32[$14>>2] = 24;
 $15 = HEAP32[$13>>2]|0;
 FUNCTION_TABLE_vi[$15 & 63]($cinfo);
 STACKTOP = sp;return;
}
function _emit_dqt($cinfo,$index) {
 $cinfo = $cinfo|0;
 $index = $index|0;
 var $$prec$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond10 = 0, $exitcond9 = 0, $i$06 = 0, $i$14 = 0, $i$14$us = 0, $prec$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($cinfo) + ($index<<2)|0) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[$cinfo>>2]|0;
  $4 = (($3) + 20|0);
  HEAP32[$4>>2] = 52;
  $5 = (($3) + 24|0);
  HEAP32[$5>>2] = $index;
  $6 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$6 & 63]($cinfo);
  $i$06 = 0;$prec$07 = 0;
 } else {
  $i$06 = 0;$prec$07 = 0;
 }
 while(1) {
  $7 = (($1) + ($i$06<<1)|0);
  $8 = HEAP16[$7>>1]|0;
  $9 = ($8&65535)>(255);
  $$prec$0 = $9 ? 1 : $prec$07;
  $10 = (($i$06) + 1)|0;
  $exitcond9 = ($10|0)==(64);
  if ($exitcond9) {
   break;
  } else {
   $i$06 = $10;$prec$07 = $$prec$0;
  }
 }
 $11 = (($1) + 128|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if (!($13)) {
  STACKTOP = sp;return ($$prec$0|0);
 }
 $14 = (($cinfo) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 1|0);
 HEAP32[$15>>2] = $17;
 HEAP8[$16>>0] = -1;
 $18 = (($15) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + -1)|0;
 HEAP32[$18>>2] = $20;
 $21 = ($20|0)==(0);
 if ($21) {
  $22 = (($15) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (FUNCTION_TABLE_ii[$23 & 7]($cinfo)|0);
  $25 = ($24<<24>>24)==(0);
  if ($25) {
   $26 = HEAP32[$cinfo>>2]|0;
   $27 = (($26) + 20|0);
   HEAP32[$27>>2] = 24;
   $28 = HEAP32[$26>>2]|0;
   FUNCTION_TABLE_vi[$28 & 63]($cinfo);
  }
 }
 $29 = HEAP32[$14>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 1|0);
 HEAP32[$29>>2] = $31;
 HEAP8[$30>>0] = -37;
 $32 = (($29) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + -1)|0;
 HEAP32[$32>>2] = $34;
 $35 = ($34|0)==(0);
 if ($35) {
  $36 = (($29) + 12|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (FUNCTION_TABLE_ii[$37 & 7]($cinfo)|0);
  $39 = ($38<<24>>24)==(0);
  if ($39) {
   $40 = HEAP32[$cinfo>>2]|0;
   $41 = (($40) + 20|0);
   HEAP32[$41>>2] = 24;
   $42 = HEAP32[$40>>2]|0;
   FUNCTION_TABLE_vi[$42 & 63]($cinfo);
  }
 }
 $43 = ($$prec$0|0)!=(0);
 $44 = HEAP32[$14>>2]|0;
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + 1|0);
 HEAP32[$44>>2] = $46;
 HEAP8[$45>>0] = 0;
 $47 = (($44) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + -1)|0;
 HEAP32[$47>>2] = $49;
 $50 = ($49|0)==(0);
 if ($50) {
  $51 = (($44) + 12|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (FUNCTION_TABLE_ii[$52 & 7]($cinfo)|0);
  $54 = ($53<<24>>24)==(0);
  if ($54) {
   $55 = HEAP32[$cinfo>>2]|0;
   $56 = (($55) + 20|0);
   HEAP32[$56>>2] = 24;
   $57 = HEAP32[$55>>2]|0;
   FUNCTION_TABLE_vi[$57 & 63]($cinfo);
  }
 }
 $58 = HEAP32[$14>>2]|0;
 $59 = $43 ? -125 : 67;
 $60 = HEAP32[$58>>2]|0;
 $61 = (($60) + 1|0);
 HEAP32[$58>>2] = $61;
 HEAP8[$60>>0] = $59;
 $62 = (($58) + 4|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($63) + -1)|0;
 HEAP32[$62>>2] = $64;
 $65 = ($64|0)==(0);
 if ($65) {
  $66 = (($58) + 12|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (FUNCTION_TABLE_ii[$67 & 7]($cinfo)|0);
  $69 = ($68<<24>>24)==(0);
  if ($69) {
   $70 = HEAP32[$cinfo>>2]|0;
   $71 = (($70) + 20|0);
   HEAP32[$71>>2] = 24;
   $72 = HEAP32[$70>>2]|0;
   FUNCTION_TABLE_vi[$72 & 63]($cinfo);
  }
 }
 $73 = $$prec$0 << 4;
 $74 = (($73) + ($index))|0;
 $75 = HEAP32[$14>>2]|0;
 $76 = $74&255;
 $77 = HEAP32[$75>>2]|0;
 $78 = (($77) + 1|0);
 HEAP32[$75>>2] = $78;
 HEAP8[$77>>0] = $76;
 $79 = (($75) + 4|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = (($80) + -1)|0;
 HEAP32[$79>>2] = $81;
 $82 = ($81|0)==(0);
 if ($82) {
  $83 = (($75) + 12|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (FUNCTION_TABLE_ii[$84 & 7]($cinfo)|0);
  $86 = ($85<<24>>24)==(0);
  if ($86) {
   $87 = HEAP32[$cinfo>>2]|0;
   $88 = (($87) + 20|0);
   HEAP32[$88>>2] = 24;
   $89 = HEAP32[$87>>2]|0;
   FUNCTION_TABLE_vi[$89 & 63]($cinfo);
  }
 }
 if ($43) {
  $i$14$us = 0;
  while(1) {
   $90 = (142704 + ($i$14$us<<2)|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = (($1) + ($91<<1)|0);
   $93 = HEAP16[$92>>1]|0;
   $94 = HEAP32[$14>>2]|0;
   $95 = ($93&65535) >>> 8;
   $96 = $95&255;
   $97 = HEAP32[$94>>2]|0;
   $98 = (($97) + 1|0);
   HEAP32[$94>>2] = $98;
   HEAP8[$97>>0] = $96;
   $99 = (($94) + 4|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = (($100) + -1)|0;
   HEAP32[$99>>2] = $101;
   $102 = ($101|0)==(0);
   if ($102) {
    $103 = (($94) + 12|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = (FUNCTION_TABLE_ii[$104 & 7]($cinfo)|0);
    $106 = ($105<<24>>24)==(0);
    if ($106) {
     $107 = HEAP32[$cinfo>>2]|0;
     $108 = (($107) + 20|0);
     HEAP32[$108>>2] = 24;
     $109 = HEAP32[$107>>2]|0;
     FUNCTION_TABLE_vi[$109 & 63]($cinfo);
    }
   }
   $110 = HEAP32[$14>>2]|0;
   $111 = $93&255;
   $112 = HEAP32[$110>>2]|0;
   $113 = (($112) + 1|0);
   HEAP32[$110>>2] = $113;
   HEAP8[$112>>0] = $111;
   $114 = (($110) + 4|0);
   $115 = HEAP32[$114>>2]|0;
   $116 = (($115) + -1)|0;
   HEAP32[$114>>2] = $116;
   $117 = ($116|0)==(0);
   if ($117) {
    $118 = (($110) + 12|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = (FUNCTION_TABLE_ii[$119 & 7]($cinfo)|0);
    $121 = ($120<<24>>24)==(0);
    if ($121) {
     $122 = HEAP32[$cinfo>>2]|0;
     $123 = (($122) + 20|0);
     HEAP32[$123>>2] = 24;
     $124 = HEAP32[$122>>2]|0;
     FUNCTION_TABLE_vi[$124 & 63]($cinfo);
    }
   }
   $125 = (($i$14$us) + 1)|0;
   $exitcond10 = ($125|0)==(64);
   if ($exitcond10) {
    break;
   } else {
    $i$14$us = $125;
   }
  }
 } else {
  $i$14 = 0;
  while(1) {
   $126 = (142704 + ($i$14<<2)|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = (($1) + ($127<<1)|0);
   $129 = HEAP16[$128>>1]|0;
   $130 = HEAP32[$14>>2]|0;
   $131 = $129&255;
   $132 = HEAP32[$130>>2]|0;
   $133 = (($132) + 1|0);
   HEAP32[$130>>2] = $133;
   HEAP8[$132>>0] = $131;
   $134 = (($130) + 4|0);
   $135 = HEAP32[$134>>2]|0;
   $136 = (($135) + -1)|0;
   HEAP32[$134>>2] = $136;
   $137 = ($136|0)==(0);
   if ($137) {
    $138 = (($130) + 12|0);
    $139 = HEAP32[$138>>2]|0;
    $140 = (FUNCTION_TABLE_ii[$139 & 7]($cinfo)|0);
    $141 = ($140<<24>>24)==(0);
    if ($141) {
     $142 = HEAP32[$cinfo>>2]|0;
     $143 = (($142) + 20|0);
     HEAP32[$143>>2] = 24;
     $144 = HEAP32[$142>>2]|0;
     FUNCTION_TABLE_vi[$144 & 63]($cinfo);
    }
   }
   $145 = (($i$14) + 1)|0;
   $exitcond = ($145|0)==(64);
   if ($exitcond) {
    break;
   } else {
    $i$14 = $145;
   }
  }
 }
 HEAP8[$11>>0] = 1;
 STACKTOP = sp;return ($$prec$0|0);
}
function _emit_dht($cinfo,$index,$is_ac) {
 $cinfo = $cinfo|0;
 $index = $index|0;
 $is_ac = $is_ac|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond8 = 0, $htbl$0 = 0, $htbl$0$in = 0, $i$15 = 0, $i$24 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($is_ac<<24>>24)==(0);
 if ($0) {
  $3 = ((($cinfo) + ($index<<2)|0) + 88|0);
  $$0 = $index;$htbl$0$in = $3;
 } else {
  $1 = ((($cinfo) + ($index<<2)|0) + 104|0);
  $2 = (($index) + 16)|0;
  $$0 = $2;$htbl$0$in = $1;
 }
 $htbl$0 = HEAP32[$htbl$0$in>>2]|0;
 $4 = ($htbl$0|0)==(0|0);
 if ($4) {
  $5 = HEAP32[$cinfo>>2]|0;
  $6 = (($5) + 20|0);
  HEAP32[$6>>2] = 50;
  $7 = (($5) + 24|0);
  HEAP32[$7>>2] = $$0;
  $8 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vi[$8 & 63]($cinfo);
 }
 $9 = (($htbl$0) + 273|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = (($cinfo) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 1|0);
 HEAP32[$13>>2] = $15;
 HEAP8[$14>>0] = -1;
 $16 = (($13) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + -1)|0;
 HEAP32[$16>>2] = $18;
 $19 = ($18|0)==(0);
 if ($19) {
  $20 = (($13) + 12|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (FUNCTION_TABLE_ii[$21 & 7]($cinfo)|0);
  $23 = ($22<<24>>24)==(0);
  if ($23) {
   $24 = HEAP32[$cinfo>>2]|0;
   $25 = (($24) + 20|0);
   HEAP32[$25>>2] = 24;
   $26 = HEAP32[$24>>2]|0;
   FUNCTION_TABLE_vi[$26 & 63]($cinfo);
  }
 }
 $27 = HEAP32[$12>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 1|0);
 HEAP32[$27>>2] = $29;
 HEAP8[$28>>0] = -60;
 $30 = (($27) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + -1)|0;
 HEAP32[$30>>2] = $32;
 $33 = ($32|0)==(0);
 if ($33) {
  $34 = (($27) + 12|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (FUNCTION_TABLE_ii[$35 & 7]($cinfo)|0);
  $37 = ($36<<24>>24)==(0);
  if ($37) {
   $38 = HEAP32[$cinfo>>2]|0;
   $39 = (($38) + 20|0);
   HEAP32[$39>>2] = 24;
   $40 = HEAP32[$38>>2]|0;
   FUNCTION_TABLE_vi[$40 & 63]($cinfo);
  }
 }
 $41 = (($htbl$0) + 1|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = $42&255;
 $44 = (($htbl$0) + 2|0);
 $45 = HEAP8[$44>>0]|0;
 $46 = $45&255;
 $47 = (($46) + ($43))|0;
 $48 = (($htbl$0) + 3|0);
 $49 = HEAP8[$48>>0]|0;
 $50 = $49&255;
 $51 = (($50) + ($47))|0;
 $52 = (($htbl$0) + 4|0);
 $53 = HEAP8[$52>>0]|0;
 $54 = $53&255;
 $55 = (($54) + ($51))|0;
 $56 = (($htbl$0) + 5|0);
 $57 = HEAP8[$56>>0]|0;
 $58 = $57&255;
 $59 = (($58) + ($55))|0;
 $60 = (($htbl$0) + 6|0);
 $61 = HEAP8[$60>>0]|0;
 $62 = $61&255;
 $63 = (($62) + ($59))|0;
 $64 = (($htbl$0) + 7|0);
 $65 = HEAP8[$64>>0]|0;
 $66 = $65&255;
 $67 = (($66) + ($63))|0;
 $68 = (($htbl$0) + 8|0);
 $69 = HEAP8[$68>>0]|0;
 $70 = $69&255;
 $71 = (($70) + ($67))|0;
 $72 = (($htbl$0) + 9|0);
 $73 = HEAP8[$72>>0]|0;
 $74 = $73&255;
 $75 = (($74) + ($71))|0;
 $76 = (($htbl$0) + 10|0);
 $77 = HEAP8[$76>>0]|0;
 $78 = $77&255;
 $79 = (($78) + ($75))|0;
 $80 = (($htbl$0) + 11|0);
 $81 = HEAP8[$80>>0]|0;
 $82 = $81&255;
 $83 = (($82) + ($79))|0;
 $84 = (($htbl$0) + 12|0);
 $85 = HEAP8[$84>>0]|0;
 $86 = $85&255;
 $87 = (($86) + ($83))|0;
 $88 = (($htbl$0) + 13|0);
 $89 = HEAP8[$88>>0]|0;
 $90 = $89&255;
 $91 = (($90) + ($87))|0;
 $92 = (($htbl$0) + 14|0);
 $93 = HEAP8[$92>>0]|0;
 $94 = $93&255;
 $95 = (($94) + ($91))|0;
 $96 = (($htbl$0) + 15|0);
 $97 = HEAP8[$96>>0]|0;
 $98 = $97&255;
 $99 = (($98) + ($95))|0;
 $100 = (($htbl$0) + 16|0);
 $101 = HEAP8[$100>>0]|0;
 $102 = $101&255;
 $103 = (($102) + ($99))|0;
 $104 = (($103) + 19)|0;
 $105 = $104 >>> 8;
 $106 = HEAP32[$12>>2]|0;
 $107 = $105&255;
 $108 = HEAP32[$106>>2]|0;
 $109 = (($108) + 1|0);
 HEAP32[$106>>2] = $109;
 HEAP8[$108>>0] = $107;
 $110 = (($106) + 4|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = (($111) + -1)|0;
 HEAP32[$110>>2] = $112;
 $113 = ($112|0)==(0);
 if ($113) {
  $114 = (($106) + 12|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = (FUNCTION_TABLE_ii[$115 & 7]($cinfo)|0);
  $117 = ($116<<24>>24)==(0);
  if ($117) {
   $118 = HEAP32[$cinfo>>2]|0;
   $119 = (($118) + 20|0);
   HEAP32[$119>>2] = 24;
   $120 = HEAP32[$118>>2]|0;
   FUNCTION_TABLE_vi[$120 & 63]($cinfo);
  }
 }
 $121 = HEAP32[$12>>2]|0;
 $122 = $104&255;
 $123 = HEAP32[$121>>2]|0;
 $124 = (($123) + 1|0);
 HEAP32[$121>>2] = $124;
 HEAP8[$123>>0] = $122;
 $125 = (($121) + 4|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = (($126) + -1)|0;
 HEAP32[$125>>2] = $127;
 $128 = ($127|0)==(0);
 if ($128) {
  $129 = (($121) + 12|0);
  $130 = HEAP32[$129>>2]|0;
  $131 = (FUNCTION_TABLE_ii[$130 & 7]($cinfo)|0);
  $132 = ($131<<24>>24)==(0);
  if ($132) {
   $133 = HEAP32[$cinfo>>2]|0;
   $134 = (($133) + 20|0);
   HEAP32[$134>>2] = 24;
   $135 = HEAP32[$133>>2]|0;
   FUNCTION_TABLE_vi[$135 & 63]($cinfo);
  }
 }
 $136 = HEAP32[$12>>2]|0;
 $137 = $$0&255;
 $138 = HEAP32[$136>>2]|0;
 $139 = (($138) + 1|0);
 HEAP32[$136>>2] = $139;
 HEAP8[$138>>0] = $137;
 $140 = (($136) + 4|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = (($141) + -1)|0;
 HEAP32[$140>>2] = $142;
 $143 = ($142|0)==(0);
 if ($143) {
  $144 = (($136) + 12|0);
  $145 = HEAP32[$144>>2]|0;
  $146 = (FUNCTION_TABLE_ii[$145 & 7]($cinfo)|0);
  $147 = ($146<<24>>24)==(0);
  if ($147) {
   $148 = HEAP32[$cinfo>>2]|0;
   $149 = (($148) + 20|0);
   HEAP32[$149>>2] = 24;
   $150 = HEAP32[$148>>2]|0;
   FUNCTION_TABLE_vi[$150 & 63]($cinfo);
  }
 }
 $i$15 = 1;
 while(1) {
  $152 = (($htbl$0) + ($i$15)|0);
  $153 = HEAP8[$152>>0]|0;
  $154 = HEAP32[$12>>2]|0;
  $155 = HEAP32[$154>>2]|0;
  $156 = (($155) + 1|0);
  HEAP32[$154>>2] = $156;
  HEAP8[$155>>0] = $153;
  $157 = (($154) + 4|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = (($158) + -1)|0;
  HEAP32[$157>>2] = $159;
  $160 = ($159|0)==(0);
  if ($160) {
   $161 = (($154) + 12|0);
   $162 = HEAP32[$161>>2]|0;
   $163 = (FUNCTION_TABLE_ii[$162 & 7]($cinfo)|0);
   $164 = ($163<<24>>24)==(0);
   if ($164) {
    $165 = HEAP32[$cinfo>>2]|0;
    $166 = (($165) + 20|0);
    HEAP32[$166>>2] = 24;
    $167 = HEAP32[$165>>2]|0;
    FUNCTION_TABLE_vi[$167 & 63]($cinfo);
   }
  }
  $168 = (($i$15) + 1)|0;
  $exitcond8 = ($168|0)==(17);
  if ($exitcond8) {
   break;
  } else {
   $i$15 = $168;
  }
 }
 $151 = ($103|0)>(0);
 if ($151) {
  $i$24 = 0;
  while(1) {
   $169 = ((($htbl$0) + ($i$24)|0) + 17|0);
   $170 = HEAP8[$169>>0]|0;
   $171 = HEAP32[$12>>2]|0;
   $172 = HEAP32[$171>>2]|0;
   $173 = (($172) + 1|0);
   HEAP32[$171>>2] = $173;
   HEAP8[$172>>0] = $170;
   $174 = (($171) + 4|0);
   $175 = HEAP32[$174>>2]|0;
   $176 = (($175) + -1)|0;
   HEAP32[$174>>2] = $176;
   $177 = ($176|0)==(0);
   if ($177) {
    $178 = (($171) + 12|0);
    $179 = HEAP32[$178>>2]|0;
    $180 = (FUNCTION_TABLE_ii[$179 & 7]($cinfo)|0);
    $181 = ($180<<24>>24)==(0);
    if ($181) {
     $182 = HEAP32[$cinfo>>2]|0;
     $183 = (($182) + 20|0);
     HEAP32[$183>>2] = 24;
     $184 = HEAP32[$182>>2]|0;
     FUNCTION_TABLE_vi[$184 & 63]($cinfo);
    }
   }
   $185 = (($i$24) + 1)|0;
   $exitcond = ($185|0)==($103|0);
   if ($exitcond) {
    break;
   } else {
    $i$24 = $185;
   }
  }
 }
 HEAP8[$9>>0] = 1;
 STACKTOP = sp;return;
}
function _emit_sof($cinfo,$code) {
 $cinfo = $cinfo|0;
 $code = $code|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ci$010 = 0, $compptr$011 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 HEAP32[$1>>2] = $3;
 HEAP8[$2>>0] = -1;
 $4 = (($1) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + -1)|0;
 HEAP32[$4>>2] = $6;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($1) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (FUNCTION_TABLE_ii[$9 & 7]($cinfo)|0);
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = HEAP32[$cinfo>>2]|0;
   $13 = (($12) + 20|0);
   HEAP32[$13>>2] = 24;
   $14 = HEAP32[$12>>2]|0;
   FUNCTION_TABLE_vi[$14 & 63]($cinfo);
  }
 }
 $15 = HEAP32[$0>>2]|0;
 $16 = $code&255;
 $17 = HEAP32[$15>>2]|0;
 $18 = (($17) + 1|0);
 HEAP32[$15>>2] = $18;
 HEAP8[$17>>0] = $16;
 $19 = (($15) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + -1)|0;
 HEAP32[$19>>2] = $21;
 $22 = ($21|0)==(0);
 if ($22) {
  $23 = (($15) + 12|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (FUNCTION_TABLE_ii[$24 & 7]($cinfo)|0);
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $27 = HEAP32[$cinfo>>2]|0;
   $28 = (($27) + 20|0);
   HEAP32[$28>>2] = 24;
   $29 = HEAP32[$27>>2]|0;
   FUNCTION_TABLE_vi[$29 & 63]($cinfo);
  }
 }
 $30 = (($cinfo) + 60|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31*3)|0;
 $33 = (($32) + 8)|0;
 $34 = $33 >>> 8;
 $35 = HEAP32[$0>>2]|0;
 $36 = $34&255;
 $37 = HEAP32[$35>>2]|0;
 $38 = (($37) + 1|0);
 HEAP32[$35>>2] = $38;
 HEAP8[$37>>0] = $36;
 $39 = (($35) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + -1)|0;
 HEAP32[$39>>2] = $41;
 $42 = ($41|0)==(0);
 if ($42) {
  $43 = (($35) + 12|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (FUNCTION_TABLE_ii[$44 & 7]($cinfo)|0);
  $46 = ($45<<24>>24)==(0);
  if ($46) {
   $47 = HEAP32[$cinfo>>2]|0;
   $48 = (($47) + 20|0);
   HEAP32[$48>>2] = 24;
   $49 = HEAP32[$47>>2]|0;
   FUNCTION_TABLE_vi[$49 & 63]($cinfo);
  }
 }
 $50 = HEAP32[$0>>2]|0;
 $51 = $33&255;
 $52 = HEAP32[$50>>2]|0;
 $53 = (($52) + 1|0);
 HEAP32[$50>>2] = $53;
 HEAP8[$52>>0] = $51;
 $54 = (($50) + 4|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + -1)|0;
 HEAP32[$54>>2] = $56;
 $57 = ($56|0)==(0);
 if ($57) {
  $58 = (($50) + 12|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = (FUNCTION_TABLE_ii[$59 & 7]($cinfo)|0);
  $61 = ($60<<24>>24)==(0);
  if ($61) {
   $62 = HEAP32[$cinfo>>2]|0;
   $63 = (($62) + 20|0);
   HEAP32[$63>>2] = 24;
   $64 = HEAP32[$62>>2]|0;
   FUNCTION_TABLE_vi[$64 & 63]($cinfo);
  }
 }
 $65 = (($cinfo) + 32|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)>(65535);
 if ($67) {
  label = 15;
 } else {
  $68 = (($cinfo) + 28|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ($69|0)>(65535);
  if ($70) {
   label = 15;
  }
 }
 if ((label|0) == 15) {
  $71 = HEAP32[$cinfo>>2]|0;
  $72 = (($71) + 20|0);
  HEAP32[$72>>2] = 41;
  $73 = (($71) + 24|0);
  HEAP32[$73>>2] = 65535;
  $74 = HEAP32[$71>>2]|0;
  FUNCTION_TABLE_vi[$74 & 63]($cinfo);
 }
 $75 = (($cinfo) + 56|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = HEAP32[$0>>2]|0;
 $78 = $76&255;
 $79 = HEAP32[$77>>2]|0;
 $80 = (($79) + 1|0);
 HEAP32[$77>>2] = $80;
 HEAP8[$79>>0] = $78;
 $81 = (($77) + 4|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (($82) + -1)|0;
 HEAP32[$81>>2] = $83;
 $84 = ($83|0)==(0);
 if ($84) {
  $85 = (($77) + 12|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = (FUNCTION_TABLE_ii[$86 & 7]($cinfo)|0);
  $88 = ($87<<24>>24)==(0);
  if ($88) {
   $89 = HEAP32[$cinfo>>2]|0;
   $90 = (($89) + 20|0);
   HEAP32[$90>>2] = 24;
   $91 = HEAP32[$89>>2]|0;
   FUNCTION_TABLE_vi[$91 & 63]($cinfo);
  }
 }
 $92 = HEAP32[$65>>2]|0;
 $93 = $92 >>> 8;
 $94 = HEAP32[$0>>2]|0;
 $95 = $93&255;
 $96 = HEAP32[$94>>2]|0;
 $97 = (($96) + 1|0);
 HEAP32[$94>>2] = $97;
 HEAP8[$96>>0] = $95;
 $98 = (($94) + 4|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = (($99) + -1)|0;
 HEAP32[$98>>2] = $100;
 $101 = ($100|0)==(0);
 if ($101) {
  $102 = (($94) + 12|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = (FUNCTION_TABLE_ii[$103 & 7]($cinfo)|0);
  $105 = ($104<<24>>24)==(0);
  if ($105) {
   $106 = HEAP32[$cinfo>>2]|0;
   $107 = (($106) + 20|0);
   HEAP32[$107>>2] = 24;
   $108 = HEAP32[$106>>2]|0;
   FUNCTION_TABLE_vi[$108 & 63]($cinfo);
  }
 }
 $109 = HEAP32[$0>>2]|0;
 $110 = $92&255;
 $111 = HEAP32[$109>>2]|0;
 $112 = (($111) + 1|0);
 HEAP32[$109>>2] = $112;
 HEAP8[$111>>0] = $110;
 $113 = (($109) + 4|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = (($114) + -1)|0;
 HEAP32[$113>>2] = $115;
 $116 = ($115|0)==(0);
 if ($116) {
  $117 = (($109) + 12|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = (FUNCTION_TABLE_ii[$118 & 7]($cinfo)|0);
  $120 = ($119<<24>>24)==(0);
  if ($120) {
   $121 = HEAP32[$cinfo>>2]|0;
   $122 = (($121) + 20|0);
   HEAP32[$122>>2] = 24;
   $123 = HEAP32[$121>>2]|0;
   FUNCTION_TABLE_vi[$123 & 63]($cinfo);
  }
 }
 $124 = (($cinfo) + 28|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = $125 >>> 8;
 $127 = HEAP32[$0>>2]|0;
 $128 = $126&255;
 $129 = HEAP32[$127>>2]|0;
 $130 = (($129) + 1|0);
 HEAP32[$127>>2] = $130;
 HEAP8[$129>>0] = $128;
 $131 = (($127) + 4|0);
 $132 = HEAP32[$131>>2]|0;
 $133 = (($132) + -1)|0;
 HEAP32[$131>>2] = $133;
 $134 = ($133|0)==(0);
 if ($134) {
  $135 = (($127) + 12|0);
  $136 = HEAP32[$135>>2]|0;
  $137 = (FUNCTION_TABLE_ii[$136 & 7]($cinfo)|0);
  $138 = ($137<<24>>24)==(0);
  if ($138) {
   $139 = HEAP32[$cinfo>>2]|0;
   $140 = (($139) + 20|0);
   HEAP32[$140>>2] = 24;
   $141 = HEAP32[$139>>2]|0;
   FUNCTION_TABLE_vi[$141 & 63]($cinfo);
  }
 }
 $142 = HEAP32[$0>>2]|0;
 $143 = $125&255;
 $144 = HEAP32[$142>>2]|0;
 $145 = (($144) + 1|0);
 HEAP32[$142>>2] = $145;
 HEAP8[$144>>0] = $143;
 $146 = (($142) + 4|0);
 $147 = HEAP32[$146>>2]|0;
 $148 = (($147) + -1)|0;
 HEAP32[$146>>2] = $148;
 $149 = ($148|0)==(0);
 if ($149) {
  $150 = (($142) + 12|0);
  $151 = HEAP32[$150>>2]|0;
  $152 = (FUNCTION_TABLE_ii[$151 & 7]($cinfo)|0);
  $153 = ($152<<24>>24)==(0);
  if ($153) {
   $154 = HEAP32[$cinfo>>2]|0;
   $155 = (($154) + 20|0);
   HEAP32[$155>>2] = 24;
   $156 = HEAP32[$154>>2]|0;
   FUNCTION_TABLE_vi[$156 & 63]($cinfo);
  }
 }
 $157 = HEAP32[$30>>2]|0;
 $158 = HEAP32[$0>>2]|0;
 $159 = $157&255;
 $160 = HEAP32[$158>>2]|0;
 $161 = (($160) + 1|0);
 HEAP32[$158>>2] = $161;
 HEAP8[$160>>0] = $159;
 $162 = (($158) + 4|0);
 $163 = HEAP32[$162>>2]|0;
 $164 = (($163) + -1)|0;
 HEAP32[$162>>2] = $164;
 $165 = ($164|0)==(0);
 if ($165) {
  $166 = (($158) + 12|0);
  $167 = HEAP32[$166>>2]|0;
  $168 = (FUNCTION_TABLE_ii[$167 & 7]($cinfo)|0);
  $169 = ($168<<24>>24)==(0);
  if ($169) {
   $170 = HEAP32[$cinfo>>2]|0;
   $171 = (($170) + 20|0);
   HEAP32[$171>>2] = 24;
   $172 = HEAP32[$170>>2]|0;
   FUNCTION_TABLE_vi[$172 & 63]($cinfo);
  }
 }
 $173 = HEAP32[$30>>2]|0;
 $174 = ($173|0)>(0);
 if (!($174)) {
  STACKTOP = sp;return;
 }
 $175 = (($cinfo) + 68|0);
 $176 = HEAP32[$175>>2]|0;
 $ci$010 = 0;$compptr$011 = $176;
 while(1) {
  $177 = HEAP32[$compptr$011>>2]|0;
  $178 = HEAP32[$0>>2]|0;
  $179 = $177&255;
  $180 = HEAP32[$178>>2]|0;
  $181 = (($180) + 1|0);
  HEAP32[$178>>2] = $181;
  HEAP8[$180>>0] = $179;
  $182 = (($178) + 4|0);
  $183 = HEAP32[$182>>2]|0;
  $184 = (($183) + -1)|0;
  HEAP32[$182>>2] = $184;
  $185 = ($184|0)==(0);
  if ($185) {
   $186 = (($178) + 12|0);
   $187 = HEAP32[$186>>2]|0;
   $188 = (FUNCTION_TABLE_ii[$187 & 7]($cinfo)|0);
   $189 = ($188<<24>>24)==(0);
   if ($189) {
    $190 = HEAP32[$cinfo>>2]|0;
    $191 = (($190) + 20|0);
    HEAP32[$191>>2] = 24;
    $192 = HEAP32[$190>>2]|0;
    FUNCTION_TABLE_vi[$192 & 63]($cinfo);
   }
  }
  $193 = (($compptr$011) + 8|0);
  $194 = HEAP32[$193>>2]|0;
  $195 = $194 << 4;
  $196 = (($compptr$011) + 12|0);
  $197 = HEAP32[$196>>2]|0;
  $198 = (($195) + ($197))|0;
  $199 = HEAP32[$0>>2]|0;
  $200 = $198&255;
  $201 = HEAP32[$199>>2]|0;
  $202 = (($201) + 1|0);
  HEAP32[$199>>2] = $202;
  HEAP8[$201>>0] = $200;
  $203 = (($199) + 4|0);
  $204 = HEAP32[$203>>2]|0;
  $205 = (($204) + -1)|0;
  HEAP32[$203>>2] = $205;
  $206 = ($205|0)==(0);
  if ($206) {
   $207 = (($199) + 12|0);
   $208 = HEAP32[$207>>2]|0;
   $209 = (FUNCTION_TABLE_ii[$208 & 7]($cinfo)|0);
   $210 = ($209<<24>>24)==(0);
   if ($210) {
    $211 = HEAP32[$cinfo>>2]|0;
    $212 = (($211) + 20|0);
    HEAP32[$212>>2] = 24;
    $213 = HEAP32[$211>>2]|0;
    FUNCTION_TABLE_vi[$213 & 63]($cinfo);
   }
  }
  $214 = (($compptr$011) + 16|0);
  $215 = HEAP32[$214>>2]|0;
  $216 = HEAP32[$0>>2]|0;
  $217 = $215&255;
  $218 = HEAP32[$216>>2]|0;
  $219 = (($218) + 1|0);
  HEAP32[$216>>2] = $219;
  HEAP8[$218>>0] = $217;
  $220 = (($216) + 4|0);
  $221 = HEAP32[$220>>2]|0;
  $222 = (($221) + -1)|0;
  HEAP32[$220>>2] = $222;
  $223 = ($222|0)==(0);
  if ($223) {
   $224 = (($216) + 12|0);
   $225 = HEAP32[$224>>2]|0;
   $226 = (FUNCTION_TABLE_ii[$225 & 7]($cinfo)|0);
   $227 = ($226<<24>>24)==(0);
   if ($227) {
    $228 = HEAP32[$cinfo>>2]|0;
    $229 = (($228) + 20|0);
    HEAP32[$229>>2] = 24;
    $230 = HEAP32[$228>>2]|0;
    FUNCTION_TABLE_vi[$230 & 63]($cinfo);
   }
  }
  $231 = (($ci$010) + 1)|0;
  $232 = (($compptr$011) + 84|0);
  $233 = HEAP32[$30>>2]|0;
  $234 = ($231|0)<($233|0);
  if ($234) {
   $ci$010 = $231;$compptr$011 = $232;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _jinit_c_master_control($cinfo,$transcode_only) {
 $cinfo = $cinfo|0;
 $transcode_only = $transcode_only|0;
 var $$$i = 0, $$c = 0, $$c1 = 0, $$c2 = 0, $$off$i = 0, $$off$i3 = 0, $$off2$i = 0, $$op = 0, $$pre = 0, $$pre$i = 0, $$pre$i4 = 0, $$pre$phiZ2D = 0, $$pre10$i = 0, $$pre11$i = 0, $$pre12$i = 0, $$pre13$i = 0, $$pre14 = 0, $$pre14$i = 0, $$pre15$i = 0, $$pre16 = 0;
 var $$pre18$pre$i$pre$pre = 0, $$pre19$pre$i = 0, $$pre67$i = 0, $$pre68$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ci$06$i = 0, $ci$14$i = 0, $ci$225$i = 0, $ci$334$i = 0, $ci$438$i = 0, $ci$522$i = 0, $ci$619$i = 0, $coefi$1$ph$i = 0, $coefi$128$i = 0, $coefi$128$us$i = 0, $coefi$128$us$us$i = 0, $coefi$128$us31$i = 0;
 var $component_sent$i = 0, $compptr$05$i = 0, $compptr$13$i = 0, $exitcond$i = 0, $exitcond61$i = 0, $exitcond62$i = 0, $last_bitpos$i = 0, $or$cond$i = 0, $or$cond13$i = 0, $or$cond16$i = 0, $or$cond17$i = 0, $or$cond18$i = 0, $or$cond5$i = 0, $scanno$041$i = 0, $scanptr$045$i = 0, $scevgep = 0, $smax$i = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2576|0;
 $component_sent$i = sp + 2560|0;
 $last_bitpos$i = sp;
 $0 = (($cinfo) + 316|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$1>>2] = 18;
 $2 = (($1) + 4|0);
 HEAP32[$2>>2] = 19;
 $3 = (($1) + 8|0);
 HEAP32[$3>>2] = 20;
 $4 = (($1) + 13|0);
 HEAP8[$4>>0] = 0;
 $5 = (($1) + 12|0);
 HEAP8[$5>>0] = 0;
 $6 = (($cinfo) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 $$pre18$pre$i$pre$pre = (($cinfo) + 28|0);
 if ($8) {
  label = 5;
 } else {
  $9 = HEAP32[$$pre18$pre$i$pre$pre>>2]|0;
  $10 = ($9|0)==(0);
  if ($10) {
   label = 5;
  } else {
   $11 = (($cinfo) + 60|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)<(1);
   if ($13) {
    label = 5;
   } else {
    $14 = (($cinfo) + 36|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)<(1);
    if ($16) {
     label = 5;
    } else {
     $20 = $7;
    }
   }
  }
 }
 if ((label|0) == 5) {
  $17 = HEAP32[$cinfo>>2]|0;
  $18 = (($17) + 20|0);
  HEAP32[$18>>2] = 32;
  $19 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_vi[$19 & 63]($cinfo);
  $$pre$i = HEAP32[$6>>2]|0;
  $20 = $$pre$i;
 }
 $21 = ($20|0)>(65500);
 if ($21) {
  label = 8;
 } else {
  $22 = HEAP32[$$pre18$pre$i$pre$pre>>2]|0;
  $23 = ($22|0)>(65500);
  if ($23) {
   label = 8;
  }
 }
 if ((label|0) == 8) {
  $24 = HEAP32[$cinfo>>2]|0;
  $25 = (($24) + 20|0);
  HEAP32[$25>>2] = 41;
  $26 = (($24) + 24|0);
  HEAP32[$26>>2] = 65500;
  $27 = HEAP32[$24>>2]|0;
  FUNCTION_TABLE_vi[$27 & 63]($cinfo);
 }
 $28 = (($cinfo) + 56|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(8);
 if (!($30)) {
  $31 = HEAP32[$cinfo>>2]|0;
  $32 = (($31) + 20|0);
  HEAP32[$32>>2] = 15;
  $33 = HEAP32[$28>>2]|0;
  $34 = (($31) + 24|0);
  HEAP32[$34>>2] = $33;
  $35 = HEAP32[$31>>2]|0;
  FUNCTION_TABLE_vi[$35 & 63]($cinfo);
 }
 $36 = (($cinfo) + 60|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)>(10);
 if ($38) {
  $39 = HEAP32[$cinfo>>2]|0;
  $40 = (($39) + 20|0);
  HEAP32[$40>>2] = 26;
  $41 = HEAP32[$36>>2]|0;
  $42 = (($39) + 24|0);
  HEAP32[$42>>2] = $41;
  $43 = (($39) + 28|0);
  HEAP32[$43>>2] = 10;
  $44 = HEAP32[$39>>2]|0;
  FUNCTION_TABLE_vi[$44 & 63]($cinfo);
  $$pre10$i = HEAP32[$36>>2]|0;
  $48 = $$pre10$i;
 } else {
  $48 = $37;
 }
 $45 = (($cinfo) + 216|0);
 HEAP32[$45>>2] = 1;
 $46 = (($cinfo) + 220|0);
 HEAP32[$46>>2] = 1;
 $47 = (($cinfo) + 68|0);
 $49 = ($48|0)>(0);
 if ($49) {
  $50 = HEAP32[$47>>2]|0;
  $357 = $48;$358 = 1;$359 = 1;$ci$06$i = 0;$compptr$05$i = $50;
  while(1) {
   $51 = (($compptr$05$i) + 8|0);
   $52 = HEAP32[$51>>2]|0;
   $$off$i = (($52) + -1)|0;
   $53 = ($$off$i>>>0)>(3);
   $$pre19$pre$i = (($compptr$05$i) + 12|0);
   if ($53) {
    label = 17;
   } else {
    $54 = HEAP32[$$pre19$pre$i>>2]|0;
    $$off2$i = (($54) + -1)|0;
    $55 = ($$off2$i>>>0)>(3);
    if ($55) {
     label = 17;
    } else {
     $59 = $359;$61 = $52;$63 = $358;$69 = $357;
    }
   }
   if ((label|0) == 17) {
    label = 0;
    $56 = HEAP32[$cinfo>>2]|0;
    $57 = (($56) + 20|0);
    HEAP32[$57>>2] = 18;
    $58 = HEAP32[$56>>2]|0;
    FUNCTION_TABLE_vi[$58 & 63]($cinfo);
    $$pre12$i = HEAP32[$45>>2]|0;
    $$pre13$i = HEAP32[$51>>2]|0;
    $$pre14$i = HEAP32[$46>>2]|0;
    $$pre15$i = HEAP32[$36>>2]|0;
    $59 = $$pre12$i;$61 = $$pre13$i;$63 = $$pre14$i;$69 = $$pre15$i;
   }
   $60 = ($59|0)>($61|0);
   $$$i = $60 ? $59 : $61;
   HEAP32[$45>>2] = $$$i;
   $62 = HEAP32[$$pre19$pre$i>>2]|0;
   $64 = ($63|0)>($62|0);
   $65 = $64 ? $63 : $62;
   HEAP32[$46>>2] = $65;
   $66 = (($ci$06$i) + 1)|0;
   $67 = (($compptr$05$i) + 84|0);
   $68 = ($66|0)<($69|0);
   if ($68) {
    $357 = $69;$358 = $65;$359 = $$$i;$ci$06$i = $66;$compptr$05$i = $67;
   } else {
    break;
   }
  }
  $70 = ($69|0)>(0);
  if ($70) {
   $71 = HEAP32[$47>>2]|0;
   $ci$14$i = 0;$compptr$13$i = $71;
   while(1) {
    $72 = (($compptr$13$i) + 4|0);
    HEAP32[$72>>2] = $ci$14$i;
    $73 = (($compptr$13$i) + 36|0);
    HEAP32[$73>>2] = 8;
    $74 = HEAP32[$$pre18$pre$i$pre$pre>>2]|0;
    $75 = (($compptr$13$i) + 8|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = Math_imul($76, $74)|0;
    $78 = HEAP32[$45>>2]|0;
    $79 = $78 << 3;
    $80 = (_jdiv_round_up($77,$79)|0);
    $81 = (($compptr$13$i) + 28|0);
    HEAP32[$81>>2] = $80;
    $82 = HEAP32[$6>>2]|0;
    $83 = (($compptr$13$i) + 12|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = Math_imul($84, $82)|0;
    $86 = HEAP32[$46>>2]|0;
    $87 = $86 << 3;
    $88 = (_jdiv_round_up($85,$87)|0);
    $89 = (($compptr$13$i) + 32|0);
    HEAP32[$89>>2] = $88;
    $90 = HEAP32[$$pre18$pre$i$pre$pre>>2]|0;
    $91 = HEAP32[$75>>2]|0;
    $92 = Math_imul($91, $90)|0;
    $93 = HEAP32[$45>>2]|0;
    $94 = (_jdiv_round_up($92,$93)|0);
    $95 = (($compptr$13$i) + 40|0);
    HEAP32[$95>>2] = $94;
    $96 = HEAP32[$6>>2]|0;
    $97 = HEAP32[$83>>2]|0;
    $98 = Math_imul($97, $96)|0;
    $99 = HEAP32[$46>>2]|0;
    $100 = (_jdiv_round_up($98,$99)|0);
    $101 = (($compptr$13$i) + 44|0);
    HEAP32[$101>>2] = $100;
    $102 = (($compptr$13$i) + 48|0);
    HEAP8[$102>>0] = 1;
    $103 = (($ci$14$i) + 1)|0;
    $104 = (($compptr$13$i) + 84|0);
    $105 = HEAP32[$36>>2]|0;
    $106 = ($103|0)<($105|0);
    if ($106) {
     $ci$14$i = $103;$compptr$13$i = $104;
    } else {
     break;
    }
   }
   $$pre11$i = HEAP32[$46>>2]|0;
   $109 = $$pre11$i;
  } else {
   $109 = $65;
  }
 } else {
  $109 = 1;
 }
 $107 = HEAP32[$6>>2]|0;
 $108 = $109 << 3;
 $110 = (_jdiv_round_up($107,$108)|0);
 $111 = (($cinfo) + 224|0);
 HEAP32[$111>>2] = $110;
 $112 = (($cinfo) + 172|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = ($113|0)==(0|0);
 do {
  if ($114) {
   $299 = (($cinfo) + 212|0);
   HEAP8[$299>>0] = 0;
   $300 = (($cinfo) + 168|0);
   HEAP32[$300>>2] = 1;
  } else {
   $115 = HEAP32[$0>>2]|0;
   $116 = (($115) + 14|0);
   $117 = HEAP8[$116>>0]|0;
   $118 = ($117<<24>>24)==(0);
   if (!($118)) {
    $119 = (($cinfo) + 212|0);
    HEAP8[$119>>0] = 1;
    break;
   }
   $120 = (($cinfo) + 168|0);
   $121 = HEAP32[$120>>2]|0;
   $122 = ($121|0)<(1);
   if ($122) {
    $123 = HEAP32[$cinfo>>2]|0;
    $124 = (($123) + 20|0);
    HEAP32[$124>>2] = 19;
    $125 = (($123) + 24|0);
    HEAP32[$125>>2] = 0;
    $126 = HEAP32[$123>>2]|0;
    FUNCTION_TABLE_vi[$126 & 63]($cinfo);
    $$pre = HEAP32[$112>>2]|0;
    $128 = $$pre;
   } else {
    $128 = $113;
   }
   $127 = (($128) + 20|0);
   $129 = HEAP32[$127>>2]|0;
   $130 = ($129|0)==(0);
   if ($130) {
    $131 = (($128) + 24|0);
    $132 = HEAP32[$131>>2]|0;
    $133 = ($132|0)==(63);
    if ($133) {
     $141 = (($cinfo) + 212|0);
     HEAP8[$141>>0] = 0;
     $142 = HEAP32[$36>>2]|0;
     $143 = ($142|0)>(0);
     if ($143) {
      $144 = ($142|0)>(1);
      $smax$i = $144 ? $142 : 1;
      _memset(($component_sent$i|0),0,($smax$i|0))|0;
      $360 = $142;$361 = 0;
     } else {
      $360 = $142;$361 = 0;
     }
    } else {
     label = 30;
    }
   } else {
    label = 30;
   }
   if ((label|0) == 30) {
    $134 = (($cinfo) + 212|0);
    HEAP8[$134>>0] = 1;
    $135 = HEAP32[$36>>2]|0;
    $136 = ($135|0)>(0);
    if ($136) {
     $137 = $135 << 8;
     _memset(($last_bitpos$i|0),-1,($137|0))|0;
     $360 = $135;$361 = 1;
    } else {
     $360 = $135;$361 = 1;
    }
   }
   $138 = HEAP32[$120>>2]|0;
   $139 = ($138|0)<(1);
   if ($139) {
    $277 = $361;$279 = $360;
   } else {
    $140 = (($cinfo) + 212|0);
    $scanno$041$i = 1;$scanptr$045$i = $128;
    while(1) {
     $145 = HEAP32[$scanptr$045$i>>2]|0;
     $$off$i3 = (($145) + -1)|0;
     $146 = ($$off$i3>>>0)>(3);
     if ($146) {
      $147 = HEAP32[$cinfo>>2]|0;
      $148 = (($147) + 20|0);
      HEAP32[$148>>2] = 26;
      $149 = (($147) + 24|0);
      HEAP32[$149>>2] = $145;
      $150 = (($147) + 28|0);
      HEAP32[$150>>2] = 4;
      $151 = HEAP32[$147>>2]|0;
      FUNCTION_TABLE_vi[$151 & 63]($cinfo);
     }
     $152 = ($145|0)>(0);
     if ($152) {
      $ci$225$i = 0;
      while(1) {
       $153 = ((($scanptr$045$i) + ($ci$225$i<<2)|0) + 4|0);
       $154 = HEAP32[$153>>2]|0;
       $155 = ($154|0)<(0);
       if ($155) {
        label = 41;
       } else {
        $156 = HEAP32[$36>>2]|0;
        $157 = ($154|0)<($156|0);
        if (!($157)) {
         label = 41;
        }
       }
       if ((label|0) == 41) {
        label = 0;
        $158 = HEAP32[$cinfo>>2]|0;
        $159 = (($158) + 20|0);
        HEAP32[$159>>2] = 19;
        $160 = (($158) + 24|0);
        HEAP32[$160>>2] = $scanno$041$i;
        $161 = HEAP32[$158>>2]|0;
        FUNCTION_TABLE_vi[$161 & 63]($cinfo);
       }
       $162 = ($ci$225$i|0)>(0);
       do {
        if ($162) {
         $163 = (($ci$225$i) + -1)|0;
         $164 = ((($scanptr$045$i) + ($163<<2)|0) + 4|0);
         $165 = HEAP32[$164>>2]|0;
         $166 = ($154|0)>($165|0);
         if ($166) {
          break;
         }
         $167 = HEAP32[$cinfo>>2]|0;
         $168 = (($167) + 20|0);
         HEAP32[$168>>2] = 19;
         $169 = (($167) + 24|0);
         HEAP32[$169>>2] = $scanno$041$i;
         $170 = HEAP32[$167>>2]|0;
         FUNCTION_TABLE_vi[$170 & 63]($cinfo);
        }
       } while(0);
       $171 = (($ci$225$i) + 1)|0;
       $exitcond$i = ($171|0)==($145|0);
       if ($exitcond$i) {
        break;
       } else {
        $ci$225$i = $171;
       }
      }
     }
     $172 = (($scanptr$045$i) + 20|0);
     $173 = HEAP32[$172>>2]|0;
     $174 = (($scanptr$045$i) + 24|0);
     $175 = HEAP32[$174>>2]|0;
     $176 = (($scanptr$045$i) + 28|0);
     $177 = HEAP32[$176>>2]|0;
     $178 = (($scanptr$045$i) + 32|0);
     $179 = HEAP32[$178>>2]|0;
     $180 = HEAP8[$140>>0]|0;
     $181 = ($180<<24>>24)==(0);
     if ($181) {
      $255 = ($173|0)==(0);
      $256 = ($175|0)==(63);
      $or$cond16$i = $255 & $256;
      $257 = ($177|0)==(0);
      $or$cond17$i = $or$cond16$i & $257;
      $258 = ($179|0)==(0);
      $or$cond18$i = $or$cond17$i & $258;
      if (!($or$cond18$i)) {
       $259 = HEAP32[$cinfo>>2]|0;
       $260 = (($259) + 20|0);
       HEAP32[$260>>2] = 17;
       $261 = (($259) + 24|0);
       HEAP32[$261>>2] = $scanno$041$i;
       $262 = HEAP32[$259>>2]|0;
       FUNCTION_TABLE_vi[$262 & 63]($cinfo);
      }
      if ($152) {
       $ci$438$i = 0;
       while(1) {
        $263 = ((($scanptr$045$i) + ($ci$438$i<<2)|0) + 4|0);
        $264 = HEAP32[$263>>2]|0;
        $265 = (($component_sent$i) + ($264)|0);
        $266 = HEAP8[$265>>0]|0;
        $267 = ($266<<24>>24)==(0);
        if (!($267)) {
         $268 = HEAP32[$cinfo>>2]|0;
         $269 = (($268) + 20|0);
         HEAP32[$269>>2] = 19;
         $270 = (($268) + 24|0);
         HEAP32[$270>>2] = $scanno$041$i;
         $271 = HEAP32[$268>>2]|0;
         FUNCTION_TABLE_vi[$271 & 63]($cinfo);
        }
        HEAP8[$265>>0] = 1;
        $272 = (($ci$438$i) + 1)|0;
        $exitcond62$i = ($272|0)==($145|0);
        if ($exitcond62$i) {
         break;
        } else {
         $ci$438$i = $272;
        }
       }
      }
     } else {
      $182 = ($173>>>0)>(63);
      if ($182) {
       label = 49;
      } else {
       $183 = ($175|0)<($173|0);
       $184 = ($175|0)>(63);
       $or$cond5$i = $183 | $184;
       $185 = ($177>>>0)>(10);
       $or$cond$i = $or$cond5$i | $185;
       $186 = ($179>>>0)>(10);
       $or$cond13$i = $or$cond$i | $186;
       if ($or$cond13$i) {
        label = 49;
       }
      }
      if ((label|0) == 49) {
       label = 0;
       $187 = HEAP32[$cinfo>>2]|0;
       $188 = (($187) + 20|0);
       HEAP32[$188>>2] = 17;
       $189 = (($187) + 24|0);
       HEAP32[$189>>2] = $scanno$041$i;
       $190 = HEAP32[$187>>2]|0;
       FUNCTION_TABLE_vi[$190 & 63]($cinfo);
      }
      $191 = ($173|0)==(0);
      do {
       if ($191) {
        $192 = ($175|0)==(0);
        if ($192) {
         break;
        }
        $193 = HEAP32[$cinfo>>2]|0;
        $194 = (($193) + 20|0);
        HEAP32[$194>>2] = 17;
        $195 = (($193) + 24|0);
        HEAP32[$195>>2] = $scanno$041$i;
        $196 = HEAP32[$193>>2]|0;
        FUNCTION_TABLE_vi[$196 & 63]($cinfo);
       } else {
        $197 = ($145|0)==(1);
        if ($197) {
         break;
        }
        $198 = HEAP32[$cinfo>>2]|0;
        $199 = (($198) + 20|0);
        HEAP32[$199>>2] = 17;
        $200 = (($198) + 24|0);
        HEAP32[$200>>2] = $scanno$041$i;
        $201 = HEAP32[$198>>2]|0;
        FUNCTION_TABLE_vi[$201 & 63]($cinfo);
       }
      } while(0);
      if ($152) {
       $202 = ($177|0)==(0);
       $203 = (($177) + -1)|0;
       $204 = ($179|0)==($203|0);
       $ci$334$i = 0;
       while(1) {
        $205 = ((($scanptr$045$i) + ($ci$334$i<<2)|0) + 4|0);
        $206 = HEAP32[$205>>2]|0;
        do {
         if ($191) {
          $coefi$1$ph$i = 0;
         } else {
          $207 = (($last_bitpos$i) + ($206<<8)|0);
          $208 = HEAP32[$207>>2]|0;
          $209 = ($208|0)<(0);
          if (!($209)) {
           $coefi$1$ph$i = $173;
           break;
          }
          $210 = HEAP32[$cinfo>>2]|0;
          $211 = (($210) + 20|0);
          HEAP32[$211>>2] = 17;
          $212 = (($210) + 24|0);
          HEAP32[$212>>2] = $scanno$041$i;
          $213 = HEAP32[$210>>2]|0;
          FUNCTION_TABLE_vi[$213 & 63]($cinfo);
          $coefi$1$ph$i = $173;
         }
        } while(0);
        $214 = ($coefi$1$ph$i|0)>($175|0);
        L99: do {
         if (!($214)) {
          if (!($204)) {
           if ($202) {
            $coefi$128$us31$i = $coefi$1$ph$i;
           } else {
            $coefi$128$i = $coefi$1$ph$i;
            while(1) {
             $247 = ((($last_bitpos$i) + ($206<<8)|0) + ($coefi$128$i<<2)|0);
             $248 = HEAP32[$cinfo>>2]|0;
             $249 = (($248) + 20|0);
             HEAP32[$249>>2] = 17;
             $250 = (($248) + 24|0);
             HEAP32[$250>>2] = $scanno$041$i;
             $251 = HEAP32[$248>>2]|0;
             FUNCTION_TABLE_vi[$251 & 63]($cinfo);
             HEAP32[$247>>2] = $179;
             $252 = (($coefi$128$i) + 1)|0;
             $253 = ($coefi$128$i|0)<($175|0);
             if ($253) {
              $coefi$128$i = $252;
             } else {
              break L99;
             }
            }
           }
           while(1) {
            $238 = ((($last_bitpos$i) + ($206<<8)|0) + ($coefi$128$us31$i<<2)|0);
            $239 = HEAP32[$238>>2]|0;
            $240 = ($239|0)<(0);
            if (!($240)) {
             $241 = HEAP32[$cinfo>>2]|0;
             $242 = (($241) + 20|0);
             HEAP32[$242>>2] = 17;
             $243 = (($241) + 24|0);
             HEAP32[$243>>2] = $scanno$041$i;
             $244 = HEAP32[$241>>2]|0;
             FUNCTION_TABLE_vi[$244 & 63]($cinfo);
            }
            HEAP32[$238>>2] = $179;
            $245 = (($coefi$128$us31$i) + 1)|0;
            $246 = ($coefi$128$us31$i|0)<($175|0);
            if ($246) {
             $coefi$128$us31$i = $245;
            } else {
             break L99;
            }
           }
          }
          if ($202) {
           $coefi$128$us$us$i = $coefi$1$ph$i;
           while(1) {
            $215 = ((($last_bitpos$i) + ($206<<8)|0) + ($coefi$128$us$us$i<<2)|0);
            $216 = HEAP32[$215>>2]|0;
            $217 = ($216|0)<(1);
            if (!($217)) {
             $218 = HEAP32[$cinfo>>2]|0;
             $219 = (($218) + 20|0);
             HEAP32[$219>>2] = 17;
             $220 = (($218) + 24|0);
             HEAP32[$220>>2] = $scanno$041$i;
             $221 = HEAP32[$218>>2]|0;
             FUNCTION_TABLE_vi[$221 & 63]($cinfo);
            }
            HEAP32[$215>>2] = $179;
            $222 = (($coefi$128$us$us$i) + 1)|0;
            $223 = ($coefi$128$us$us$i|0)<($175|0);
            if ($223) {
             $coefi$128$us$us$i = $222;
            } else {
             break L99;
            }
           }
          } else {
           $coefi$128$us$i = $coefi$1$ph$i;
          }
          while(1) {
           $224 = ((($last_bitpos$i) + ($206<<8)|0) + ($coefi$128$us$i<<2)|0);
           $225 = HEAP32[$224>>2]|0;
           $226 = ($225|0)<(0);
           do {
            if ($226) {
             $232 = HEAP32[$cinfo>>2]|0;
             $233 = (($232) + 20|0);
             HEAP32[$233>>2] = 17;
             $234 = (($232) + 24|0);
             HEAP32[$234>>2] = $scanno$041$i;
             $235 = HEAP32[$232>>2]|0;
             FUNCTION_TABLE_vi[$235 & 63]($cinfo);
            } else {
             $227 = ($177|0)==($225|0);
             if ($227) {
              break;
             }
             $228 = HEAP32[$cinfo>>2]|0;
             $229 = (($228) + 20|0);
             HEAP32[$229>>2] = 17;
             $230 = (($228) + 24|0);
             HEAP32[$230>>2] = $scanno$041$i;
             $231 = HEAP32[$228>>2]|0;
             FUNCTION_TABLE_vi[$231 & 63]($cinfo);
            }
           } while(0);
           HEAP32[$224>>2] = $179;
           $236 = (($coefi$128$us$i) + 1)|0;
           $237 = ($coefi$128$us$i|0)<($175|0);
           if ($237) {
            $coefi$128$us$i = $236;
           } else {
            break;
           }
          }
         }
        } while(0);
        $254 = (($ci$334$i) + 1)|0;
        $exitcond61$i = ($254|0)==($145|0);
        if ($exitcond61$i) {
         break;
        } else {
         $ci$334$i = $254;
        }
       }
      }
     }
     $273 = (($scanptr$045$i) + 36|0);
     $274 = (($scanno$041$i) + 1)|0;
     $275 = HEAP32[$120>>2]|0;
     $276 = ($scanno$041$i|0)<($275|0);
     if ($276) {
      $scanno$041$i = $274;$scanptr$045$i = $273;
     } else {
      break;
     }
    }
    $$pre$i4 = HEAP8[$140>>0]|0;
    $$pre14 = HEAP32[$36>>2]|0;
    $277 = $$pre$i4;$279 = $$pre14;
   }
   $278 = ($277<<24>>24)==(0);
   $280 = ($279|0)>(0);
   if ($278) {
    if (!($280)) {
     break;
    }
    $363 = $279;$ci$619$i = 0;
    while(1) {
     $290 = (($component_sent$i) + ($ci$619$i)|0);
     $291 = HEAP8[$290>>0]|0;
     $292 = ($291<<24>>24)==(0);
     if ($292) {
      $293 = HEAP32[$cinfo>>2]|0;
      $294 = (($293) + 20|0);
      HEAP32[$294>>2] = 45;
      $295 = HEAP32[$293>>2]|0;
      FUNCTION_TABLE_vi[$295 & 63]($cinfo);
      $$pre67$i = HEAP32[$36>>2]|0;
      $298 = $$pre67$i;
     } else {
      $298 = $363;
     }
     $296 = (($ci$619$i) + 1)|0;
     $297 = ($296|0)<($298|0);
     if ($297) {
      $363 = $298;$ci$619$i = $296;
     } else {
      break;
     }
    }
   } else {
    if (!($280)) {
     break;
    }
    $362 = $279;$ci$522$i = 0;
    while(1) {
     $281 = (($last_bitpos$i) + ($ci$522$i<<8)|0);
     $282 = HEAP32[$281>>2]|0;
     $283 = ($282|0)<(0);
     if ($283) {
      $284 = HEAP32[$cinfo>>2]|0;
      $285 = (($284) + 20|0);
      HEAP32[$285>>2] = 45;
      $286 = HEAP32[$284>>2]|0;
      FUNCTION_TABLE_vi[$286 & 63]($cinfo);
      $$pre68$i = HEAP32[$36>>2]|0;
      $289 = $$pre68$i;
     } else {
      $289 = $362;
     }
     $287 = (($ci$522$i) + 1)|0;
     $288 = ($287|0)<($289|0);
     if ($288) {
      $362 = $289;$ci$522$i = $287;
     } else {
      break;
     }
    }
   }
  }
 } while(0);
 $301 = (($cinfo) + 212|0);
 $302 = HEAP8[$301>>0]|0;
 $303 = ($302<<24>>24)==(0);
 if (!($303)) {
  $304 = (($cinfo) + 177|0);
  $305 = HEAP8[$304>>0]|0;
  $306 = ($305<<24>>24)==(0);
  if ($306) {
   $307 = (($cinfo) + 178|0);
   HEAP8[$307>>0] = 1;
  }
 }
 $308 = ($transcode_only<<24>>24)==(0);
 do {
  if ($308) {
   $313 = (($1) + 4176|0);
   HEAP32[$313>>2] = 0;
   $$pre16 = (($cinfo) + 178|0);
   $$pre$phiZ2D = $$pre16;
  } else {
   $309 = (($cinfo) + 178|0);
   $310 = HEAP8[$309>>0]|0;
   $311 = ($310<<24>>24)==(0);
   $312 = (($1) + 4176|0);
   if ($311) {
    HEAP32[$312>>2] = (2);
    $$pre$phiZ2D = $309;
    break;
   } else {
    HEAP32[$312>>2] = (1);
    $$pre$phiZ2D = $309;
    break;
   }
  }
 } while(0);
 $314 = (($1) + 4188|0);
 HEAP32[$314>>2] = 0;
 $315 = (($1) + 4180|0);
 HEAP32[$315>>2] = 0;
 $316 = HEAP8[$$pre$phiZ2D>>0]|0;
 $317 = ($316<<24>>24)==(0);
 $318 = (($cinfo) + 168|0);
 $319 = HEAP32[$318>>2]|0;
 if ($317) {
  $322 = (($1) + 4184|0);
  $$c = $319;
  HEAP32[$322>>2] = $$c;
  $348 = $319;
 } else {
  $320 = $319 << 1;
  $321 = (($1) + 4184|0);
  $$c2 = $320;
  HEAP32[$321>>2] = $$c2;
  $348 = $320;
 }
 $323 = (($1) + 4192|0);
 HEAP32[$323>>2] = 0;
 $324 = HEAP32[$0>>2]|0;
 $325 = (($324) + 15|0);
 $326 = HEAP8[$325>>0]|0;
 $327 = ($326<<24>>24)==(0);
 if (!($327)) {
  $328 = HEAP8[$$pre$phiZ2D>>0]|0;
  $329 = ($328<<24>>24)==(0);
  $330 = (($324) + 19|0);
  $331 = HEAP8[$330>>0]|0;
  $332 = ($331<<24>>24)!=(0);
  if ($329) {
   $339 = $332 ? 2 : 1;
   $340 = HEAP32[$36>>2]|0;
   $341 = Math_imul($340, $339)|0;
   $342 = (($324) + 4136|0);
   $343 = HEAP32[$342>>2]|0;
   $344 = Math_imul($341, $343)|0;
   $345 = (($344) + 1)|0;
   $storemerge = $345;
  } else {
   $333 = $332 ? 4 : 2;
   $334 = HEAP32[$36>>2]|0;
   $335 = Math_imul($334, $333)|0;
   $336 = (($324) + 4136|0);
   $337 = HEAP32[$336>>2]|0;
   $338 = Math_imul($335, $337)|0;
   $storemerge = $338;
  }
  HEAP32[$323>>2] = $storemerge;
  $346 = (($1) + 4184|0);
  $347 = (($348) + ($storemerge))|0;
  $$c1 = $347;
  HEAP32[$346>>2] = $$c1;
 }
 $349 = (($324) + 14|0);
 $350 = HEAP8[$349>>0]|0;
 $351 = ($350<<24>>24)==(0);
 if ($351) {
  STACKTOP = sp;return;
 }
 $352 = (($1) + 4980|0);
 HEAP32[$352>>2] = 0;
 $353 = HEAP32[$318>>2]|0;
 $354 = ($353|0)>(0);
 if (!($354)) {
  STACKTOP = sp;return;
 }
 $scevgep = (($1) + 4196|0);
 $355 = ($353|0)>(1);
 $$op = $353 << 2;
 $356 = $355 ? $$op : 4;
 _memset(($scevgep|0),0,($356|0))|0;
 STACKTOP = sp;return;
}
function _prepare_for_pass($cinfo) {
 $cinfo = $cinfo|0;
 var $$c = 0, $$pre = 0, $$pre$phi9Z2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond$1 = 0, $exitcond$2 = 0, $exitcond$3 = 0, $j$01 = 0, $j$01$1 = 0, $j$01$2 = 0, $j$01$3 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 316|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4180|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4192|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)<($5|0);
 $7 = $6&1;
 $8 = (($1) + 20|0);
 HEAP8[$8>>0] = $7;
 $9 = (($1) + 4176|0);
 $10 = HEAP32[$9>>2]|0;
 do {
  if ((($10|0) == 1)) {
   _select_scan_parameters($cinfo);
   _per_scan_setup($cinfo);
   $58 = (($cinfo) + 300|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59|0)==(0);
   if ($60) {
    $61 = (($cinfo) + 308|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = ($62|0)==(0);
    if (!($63)) {
     $64 = (($cinfo) + 177|0);
     $65 = HEAP8[$64>>0]|0;
     $66 = ($65<<24>>24)==(0);
     if ($66) {
      HEAP32[$9>>2] = (2);
      $74 = HEAP32[$2>>2]|0;
      $75 = (($74) + 1)|0;
      $$c = $75;
      HEAP32[$2>>2] = $$c;
      label = 16;
      break;
     }
    }
   }
   $67 = (($cinfo) + 348|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = HEAP32[$68>>2]|0;
   FUNCTION_TABLE_vii[$69 & 15]($cinfo,1);
   $70 = (($cinfo) + 328|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = HEAP32[$71>>2]|0;
   FUNCTION_TABLE_vii[$72 & 15]($cinfo,2);
   $73 = (($1) + 12|0);
   HEAP8[$73>>0] = 0;
  } else if ((($10|0) == 2)) {
   label = 16;
  } else if ((($10|0) == 3)) {
   $112 = (($cinfo) + 60|0);
   $113 = HEAP32[$112>>2]|0;
   $114 = HEAP32[$0>>2]|0;
   $115 = (($114) + 19|0);
   $116 = HEAP8[$115>>0]|0;
   $117 = ($116<<24>>24)!=(0);
   $118 = $117 ? 4 : 2;
   $119 = Math_imul($118, $113)|0;
   $120 = (($3|0) % ($119|0))&-1;
   $121 = ($120|0)==(1);
   if ($121) {
    $122 = (($114) + 21|0);
    $123 = HEAP8[$122>>0]|0;
    $124 = ($123<<24>>24)==(0);
    if (!($124)) {
     $j$01 = 1;
     while(1) {
      $125 = ((($114) + ($j$01<<3)|0) + 24|0);
      HEAPF64[$125>>3] = 0.0;
      $126 = ((($114) + ($j$01<<3)|0) + 2072|0);
      HEAPF64[$126>>3] = 0.0;
      $127 = (($j$01) + 1)|0;
      $exitcond = ($127|0)==(64);
      if ($exitcond) {
       $j$01$1 = 1;
       break;
      } else {
       $j$01 = $127;
      }
     }
     while(1) {
      $155 = ((($114) + ($j$01$1<<3)|0) + 536|0);
      HEAPF64[$155>>3] = 0.0;
      $156 = ((($114) + ($j$01$1<<3)|0) + 2584|0);
      HEAPF64[$156>>3] = 0.0;
      $157 = (($j$01$1) + 1)|0;
      $exitcond$1 = ($157|0)==(64);
      if ($exitcond$1) {
       $j$01$2 = 1;
       break;
      } else {
       $j$01$1 = $157;
      }
     }
     while(1) {
      $158 = ((($114) + ($j$01$2<<3)|0) + 1048|0);
      HEAPF64[$158>>3] = 0.0;
      $159 = ((($114) + ($j$01$2<<3)|0) + 3096|0);
      HEAPF64[$159>>3] = 0.0;
      $160 = (($j$01$2) + 1)|0;
      $exitcond$2 = ($160|0)==(64);
      if ($exitcond$2) {
       $j$01$3 = 1;
       break;
      } else {
       $j$01$2 = $160;
      }
     }
     while(1) {
      $161 = ((($114) + ($j$01$3<<3)|0) + 1560|0);
      HEAPF64[$161>>3] = 0.0;
      $162 = ((($114) + ($j$01$3<<3)|0) + 3608|0);
      HEAPF64[$162>>3] = 0.0;
      $163 = (($j$01$3) + 1)|0;
      $exitcond$3 = ($163|0)==(64);
      if ($exitcond$3) {
       break;
      } else {
       $j$01$3 = $163;
      }
     }
    }
   }
   $128 = (($cinfo) + 348|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = HEAP32[$129>>2]|0;
   $131 = (($cinfo) + 177|0);
   $132 = HEAP8[$131>>0]|0;
   $133 = ($132<<24>>24)==(0);
   $134 = $133&1;
   FUNCTION_TABLE_vii[$130 & 15]($cinfo,$134);
   $135 = (($cinfo) + 328|0);
   $136 = HEAP32[$135>>2]|0;
   $137 = HEAP32[$136>>2]|0;
   FUNCTION_TABLE_vii[$137 & 15]($cinfo,4);
   $138 = (($1) + 12|0);
   HEAP8[$138>>0] = 0;
  } else if ((($10|0) == 0)) {
   _select_scan_parameters($cinfo);
   _per_scan_setup($cinfo);
   $11 = (($cinfo) + 176|0);
   $12 = HEAP8[$11>>0]|0;
   $13 = ($12<<24>>24)==(0);
   if ($13) {
    $14 = (($cinfo) + 336|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = HEAP32[$15>>2]|0;
    FUNCTION_TABLE_vi[$16 & 63]($cinfo);
    $17 = (($cinfo) + 340|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    FUNCTION_TABLE_vi[$19 & 63]($cinfo);
    $20 = (($cinfo) + 324|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$21>>2]|0;
    FUNCTION_TABLE_vii[$22 & 15]($cinfo,0);
   }
   $23 = (($cinfo) + 344|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = HEAP32[$24>>2]|0;
   FUNCTION_TABLE_vi[$25 & 63]($cinfo);
   $26 = (($cinfo) + 348|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$27>>2]|0;
   $29 = (($cinfo) + 178|0);
   $30 = HEAP8[$29>>0]|0;
   $31 = ($30<<24>>24)==(0);
   if ($31) {
    $32 = HEAP32[$0>>2]|0;
    $33 = (($32) + 15|0);
    $34 = HEAP8[$33>>0]|0;
    $35 = ($34<<24>>24)==(0);
    if ($35) {
     $39 = 0;
    } else {
     label = 6;
    }
   } else {
    label = 6;
   }
   if ((label|0) == 6) {
    $36 = (($cinfo) + 177|0);
    $37 = HEAP8[$36>>0]|0;
    $38 = ($37<<24>>24)==(0);
    $phitmp = $38&1;
    $39 = $phitmp;
   }
   FUNCTION_TABLE_vii[$28 & 15]($cinfo,$39);
   $40 = (($cinfo) + 328|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = HEAP32[$41>>2]|0;
   $43 = (($1) + 4184|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44|0)>(1);
   $46 = $45 ? 3 : 0;
   FUNCTION_TABLE_vii[$42 & 15]($cinfo,$46);
   $47 = (($cinfo) + 320|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = HEAP32[$48>>2]|0;
   FUNCTION_TABLE_vii[$49 & 15]($cinfo,0);
   $50 = HEAP8[$29>>0]|0;
   $51 = ($50<<24>>24)==(0);
   if ($51) {
    $52 = HEAP32[$0>>2]|0;
    $53 = (($52) + 15|0);
    $54 = HEAP8[$53>>0]|0;
    $55 = ($54<<24>>24)==(0);
    if ($55) {
     $57 = (($1) + 12|0);
     HEAP8[$57>>0] = 1;
     break;
    }
   }
   $56 = (($1) + 12|0);
   HEAP8[$56>>0] = 0;
  } else {
   $139 = HEAP32[$cinfo>>2]|0;
   $140 = (($139) + 20|0);
   HEAP32[$140>>2] = 48;
   $141 = HEAP32[$139>>2]|0;
   FUNCTION_TABLE_vi[$141 & 63]($cinfo);
  }
 } while(0);
 if ((label|0) == 16) {
  $76 = (($cinfo) + 178|0);
  $77 = HEAP8[$76>>0]|0;
  $78 = ($77<<24>>24)==(0);
  if ($78) {
   _select_scan_parameters($cinfo);
   _per_scan_setup($cinfo);
  }
  $79 = HEAP32[$0>>2]|0;
  $80 = (($79) + 14|0);
  $81 = HEAP8[$80>>0]|0;
  $82 = ($81<<24>>24)==(0);
  if ($82) {
   $$pre = (($1) + 4188|0);
   $$pre$phi9Z2D = $$pre;
  } else {
   $83 = (($cinfo) + 24|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($1) + 4988|0);
   HEAP32[$85>>2] = $84;
   HEAP32[$83>>2] = 0;
   $86 = (($1) + 4188|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = ((($1) + ($87<<2)|0) + 4452|0);
   HEAP32[$88>>2] = 0;
   $89 = HEAP32[$86>>2]|0;
   $90 = (($1) + 4196|0);
   $91 = (($90) + ($89<<2)|0);
   $92 = ((($1) + ($89<<2)|0) + 4452|0);
   _jpeg_mem_dest($cinfo,$91,$92);
   $93 = HEAP32[$83>>2]|0;
   $94 = (($93) + 8|0);
   $95 = HEAP32[$94>>2]|0;
   FUNCTION_TABLE_vi[$95 & 63]($cinfo);
   $$pre$phi9Z2D = $86;
  }
  $96 = (($cinfo) + 348|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = HEAP32[$97>>2]|0;
  FUNCTION_TABLE_vii[$98 & 15]($cinfo,0);
  $99 = (($cinfo) + 328|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = HEAP32[$100>>2]|0;
  FUNCTION_TABLE_vii[$101 & 15]($cinfo,2);
  $102 = HEAP32[$$pre$phi9Z2D>>2]|0;
  $103 = ($102|0)==(0);
  $104 = (($cinfo) + 332|0);
  if ($103) {
   $105 = HEAP32[$104>>2]|0;
   $106 = (($105) + 4|0);
   $107 = HEAP32[$106>>2]|0;
   FUNCTION_TABLE_vi[$107 & 63]($cinfo);
  }
  $108 = HEAP32[$104>>2]|0;
  $109 = (($108) + 8|0);
  $110 = HEAP32[$109>>2]|0;
  FUNCTION_TABLE_vi[$110 & 63]($cinfo);
  $111 = (($1) + 12|0);
  HEAP8[$111>>0] = 0;
 }
 $142 = HEAP32[$2>>2]|0;
 $143 = (($1) + 4184|0);
 $144 = HEAP32[$143>>2]|0;
 $145 = (($144) + -1)|0;
 $146 = ($142|0)==($145|0);
 $147 = $146&1;
 $148 = (($1) + 13|0);
 HEAP8[$148>>0] = $147;
 $149 = (($cinfo) + 8|0);
 $150 = HEAP32[$149>>2]|0;
 $151 = ($150|0)==(0|0);
 if ($151) {
  STACKTOP = sp;return;
 }
 $152 = (($150) + 12|0);
 HEAP32[$152>>2] = $142;
 $153 = HEAP32[$143>>2]|0;
 $154 = (($150) + 16|0);
 HEAP32[$154>>2] = $153;
 STACKTOP = sp;return;
}
function _pass_startup($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 316|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 12|0);
 HEAP8[$2>>0] = 0;
 $3 = (($cinfo) + 332|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vi[$6 & 63]($cinfo);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vi[$9 & 63]($cinfo);
 STACKTOP = sp;return;
}
function _finish_pass_master($cinfo) {
 $cinfo = $cinfo|0;
 var $$ = 0, $$$1 = 0, $$$2 = 0, $$$3 = 0, $$$i = 0, $$c = 0, $$c$i = 0, $$c1 = 0, $$c1$i = 0, $$c2 = 0, $$c2$i = 0, $$c4$i = 0, $$not$i = 0, $$not9$i = 0, $$off$i = 0, $$off3$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre$phi28Z2D = 0;
 var $$pre26 = 0, $$pre53$i = 0, $$pre54$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0.0, $381 = 0, $382 = 0, $383 = 0.0;
 var $384 = 0.0, $385 = 0.0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0.0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0.0, $403 = 0.0, $404 = 0.0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0.0, $416 = 0, $417 = 0, $418 = 0.0, $419 = 0.0;
 var $42 = 0, $420 = 0.0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0.0, $432 = 0, $433 = 0, $434 = 0.0, $435 = 0.0, $436 = 0.0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $Al8$020$i = 0, $Al8$020$in$i = 0, $Al8$117$i = 0, $Al8$117$in$i = 0, $Al8$213$i = 0, $Al8$213$in$i = 0, $base_scan_idx$0$i = 0, $base_scan_idx$1$i = 0, $base_scan_idx$2$i = 0, $cost$0$lcssa$i = 0, $cost$027$i = 0;
 var $cost4$0$lcssa$i = 0, $cost4$023$i = 0, $exitcond = 0, $exitcond$1 = 0, $exitcond$2 = 0, $exitcond$3 = 0, $i$028$i = 0, $i3$022$i = 0, $i7$011$i = 0, $j$04 = 0, $j$04$1 = 0, $j$04$2 = 0, $j$04$3 = 0, $or$cond$i = 0, $or$cond10$i = 0, $or$cond5$i = 0, $or$cond6$i = 0, $or$cond8$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 316|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 348|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 63]($cinfo);
 $6 = (($1) + 4176|0);
 $7 = HEAP32[$6>>2]|0;
 if ((($7|0) == 1)) {
  $18 = (($1) + 4180|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($1) + 4192|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + -1)|0;
  $23 = ($19|0)<($22|0);
  $$c2 = $23 ? (3) : (2);
  HEAP32[$6>>2] = $$c2;
  $395 = (($1) + 4180|0);
  $396 = HEAP32[$395>>2]|0;
  $397 = (($396) + 1)|0;
  $$c1 = $397;
  HEAP32[$395>>2] = $$c1;
  STACKTOP = sp;return;
 } else if ((($7|0) == 2)) {
  $24 = (($cinfo) + 178|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if (!($26)) {
   HEAP32[$6>>2] = (1);
  }
  $27 = HEAP32[$0>>2]|0;
  $28 = (($27) + 14|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = ($29<<24>>24)==(0);
  if ($30) {
   $$pre26 = (($1) + 4188|0);
   $$pre$phi28Z2D = $$pre26;
  } else {
   $31 = (($cinfo) + 24|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32) + 16|0);
   $34 = HEAP32[$33>>2]|0;
   FUNCTION_TABLE_vi[$34 & 63]($cinfo);
   $35 = (($1) + 4988|0);
   $36 = HEAP32[$35>>2]|0;
   HEAP32[$31>>2] = $36;
   $37 = (($1) + 4188|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (($38) + 1)|0;
   $40 = HEAP32[$0>>2]|0;
   $41 = (($40) + 4144|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($40) + 4156|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44*3)|0;
   $46 = (($45) + ($42))|0;
   $47 = (($46) + 2)|0;
   $48 = (($40) + 4140|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($40) + 4148|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($40) + 4160|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ($53*6)|0;
   $55 = (($49) + 4)|0;
   $56 = (($55) + ($51))|0;
   $57 = (($56) + ($54))|0;
   $58 = HEAP8[$24>>0]|0;
   $59 = ($58<<24>>24)!=(0);
   $60 = $59 ? 2 : 1;
   $61 = ($39|0)<(2);
   $62 = ($47|0)<($39|0);
   $or$cond$i = $61 | $62;
   do {
    if ($or$cond$i) {
     $$not$i = $62 ^ 1;
     $92 = ($49|0)<($39|0);
     $or$cond8$i = $92 | $$not$i;
     if (!($or$cond8$i)) {
      $93 = ($47|0)==($38|0);
      if ($93) {
       $94 = (($40) + 4968|0);
       HEAP32[$94>>2] = 0;
       $95 = ((($40) + ($38<<2)|0) + 4452|0);
       $96 = HEAP32[$95>>2]|0;
       $97 = (($40) + 4964|0);
       HEAP32[$97>>2] = $96;
       $base_scan_idx$0$i = 0;
       break;
      }
      $98 = (($39) - ($47))|0;
      $99 = (($98|0) % 2)&-1;
      $100 = ($99|0)==(1);
      if (!($100)) {
       $base_scan_idx$0$i = 0;
       break;
      }
      $101 = $98 >> 1;
      $102 = (($38) + -1)|0;
      $103 = ((($40) + ($102<<2)|0) + 4452|0);
      $104 = HEAP32[$103>>2]|0;
      $105 = ((($40) + ($38<<2)|0) + 4452|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + ($104))|0;
      $108 = (($40) + 4964|0);
      $109 = HEAP32[$108>>2]|0;
      $110 = ($107>>>0)<($109>>>0);
      if ($110) {
       HEAP32[$108>>2] = $107;
       $111 = (($40) + 4968|0);
       HEAP32[$111>>2] = $101;
      }
      if ((($101|0) == 4)) {
       $118 = (($40) + 4968|0);
       $119 = HEAP32[$118>>2]|0;
       $120 = ($119|0)==(4);
       if ($120) {
        $base_scan_idx$0$i = 0;
        break;
       }
      } else if ((($101|0) == 3)) {
       $115 = (($40) + 4968|0);
       $116 = HEAP32[$115>>2]|0;
       $117 = ($116|0)==(2);
       if ($117) {
        $base_scan_idx$0$i = 0;
        break;
       }
      } else if ((($101|0) == 2)) {
       $112 = (($40) + 4968|0);
       $113 = HEAP32[$112>>2]|0;
       $114 = ($113|0)==(0);
       if (!($114)) {
        $base_scan_idx$0$i = 0;
        break;
       }
      } else {
       $base_scan_idx$0$i = 0;
       break;
      }
      $121 = (($49) + -1)|0;
      $122 = (($40) + 4188|0);
      HEAP32[$122>>2] = $121;
      $123 = Math_imul($60, $49)|0;
      $124 = (($123) + -1)|0;
      $125 = (($40) + 4192|0);
      $126 = HEAP32[$125>>2]|0;
      $127 = (($124) + ($126))|0;
      $128 = (($40) + 4180|0);
      $$c2$i = $127;
      HEAP32[$128>>2] = $$c2$i;
      $129 = (($40) + 4184|0);
      $130 = HEAP32[$129>>2]|0;
      $131 = (($130) + -1)|0;
      $132 = ($127|0)==($131|0);
      $133 = $132&1;
      $134 = (($40) + 13|0);
      HEAP8[$134>>0] = $133;
      $base_scan_idx$0$i = 0;
      break;
     }
     $135 = (($cinfo) + 168|0);
     $136 = HEAP32[$135>>2]|0;
     $137 = ($136|0)>($49|0);
     if ($137) {
      $138 = (($51) + ($49))|0;
      $139 = ($138|0)==($39|0);
      if ($139) {
       $140 = ((($40) + ($49<<2)|0) + 4452|0);
       $141 = HEAP32[$140>>2]|0;
       $142 = (($49) + 1)|0;
       $143 = ((($40) + ($142<<2)|0) + 4452|0);
       $144 = HEAP32[$143>>2]|0;
       $145 = (($49) + 2)|0;
       $146 = ((($40) + ($145<<2)|0) + 4452|0);
       $147 = HEAP32[$146>>2]|0;
       $148 = (($147) + ($144))|0;
       $149 = ($141>>>0)<=($148>>>0);
       $150 = $149&1;
       $151 = (($40) + 4984|0);
       HEAP8[$151>>0] = $150;
       $base_scan_idx$0$i = $49;
       break;
      }
      $152 = ($138|0)>=($39|0);
      $153 = ($57|0)<($39|0);
      $or$cond5$i = $152 | $153;
      if (!($or$cond5$i)) {
       $154 = (($39) - ($138))|0;
       $155 = (($154|0) % 6)&-1;
       $156 = ($155|0)==(4);
       if (!($156)) {
        $base_scan_idx$0$i = $138;
        break;
       }
       $157 = (($154|0) / 6)&-1;
       $158 = (($38) + -3)|0;
       $159 = ((($40) + ($158<<2)|0) + 4452|0);
       $160 = HEAP32[$159>>2]|0;
       $161 = (($38) + -2)|0;
       $162 = ((($40) + ($161<<2)|0) + 4452|0);
       $163 = HEAP32[$162>>2]|0;
       $164 = (($163) + ($160))|0;
       $165 = (($38) + -1)|0;
       $166 = ((($40) + ($165<<2)|0) + 4452|0);
       $167 = HEAP32[$166>>2]|0;
       $168 = (($164) + ($167))|0;
       $169 = ((($40) + ($38<<2)|0) + 4452|0);
       $170 = HEAP32[$169>>2]|0;
       $171 = (($168) + ($170))|0;
       $172 = ($154|0)>(5);
       if ($172) {
        $173 = (($138) + 4)|0;
        $174 = (($138) + 5)|0;
        $cost4$023$i = $171;$i3$022$i = 0;
        while(1) {
         $175 = ($i3$022$i*6)|0;
         $176 = (($173) + ($175))|0;
         $177 = ((($40) + ($176<<2)|0) + 4452|0);
         $178 = HEAP32[$177>>2]|0;
         $179 = (($178) + ($cost4$023$i))|0;
         $180 = (($174) + ($175))|0;
         $181 = ((($40) + ($180<<2)|0) + 4452|0);
         $182 = HEAP32[$181>>2]|0;
         $183 = (($179) + ($182))|0;
         $184 = (($i3$022$i) + 1)|0;
         $185 = ($184|0)<($157|0);
         if ($185) {
          $cost4$023$i = $183;$i3$022$i = $184;
         } else {
          $cost4$0$lcssa$i = $183;
          break;
         }
        }
       } else {
        $cost4$0$lcssa$i = $171;
       }
       $$off$i = (($154) + 5)|0;
       $186 = ($$off$i>>>0)<(11);
       $$pre53$i = (($40) + 4964|0);
       if (!($186)) {
        $187 = HEAP32[$$pre53$i>>2]|0;
        $188 = ($cost4$0$lcssa$i>>>0)<($187>>>0);
        if (!($188)) {
         $190 = (($57) + -1)|0;
         $191 = (($40) + 4188|0);
         HEAP32[$191>>2] = $190;
         $192 = Math_imul($60, $57)|0;
         $193 = (($192) + -1)|0;
         $194 = (($40) + 4192|0);
         $195 = HEAP32[$194>>2]|0;
         $196 = (($193) + ($195))|0;
         $197 = (($40) + 4180|0);
         $$c1$i = $196;
         HEAP32[$197>>2] = $$c1$i;
         $base_scan_idx$0$i = $138;
         break;
        }
       }
       HEAP32[$$pre53$i>>2] = $cost4$0$lcssa$i;
       $189 = (($40) + 4980|0);
       HEAP32[$189>>2] = $157;
       $base_scan_idx$0$i = $138;
       break;
      }
      $$not9$i = $153 ^ 1;
      $198 = ($136|0)<($39|0);
      $or$cond10$i = $198 | $$not9$i;
      if ($or$cond10$i) {
       $base_scan_idx$0$i = 0;
      } else {
       $199 = (($57) + 1)|0;
       $200 = ($199|0)==($38|0);
       if ($200) {
        $201 = (($40) + 4972|0);
        HEAP32[$201>>2] = 0;
        $202 = (($38) + -1)|0;
        $203 = ((($40) + ($202<<2)|0) + 4452|0);
        $204 = HEAP32[$203>>2]|0;
        $205 = (($40) + 4964|0);
        HEAP32[$205>>2] = $204;
        $206 = ((($40) + ($38<<2)|0) + 4452|0);
        $207 = HEAP32[$206>>2]|0;
        $208 = (($207) + ($204))|0;
        HEAP32[$205>>2] = $208;
        $base_scan_idx$0$i = 0;
        break;
       }
       $209 = (($39) - ($57))|0;
       $210 = (($209|0) % 4)&-1;
       $211 = ($210|0)==(2);
       if ($211) {
        $212 = $209 >> 2;
        $213 = (($38) + -3)|0;
        $214 = ((($40) + ($213<<2)|0) + 4452|0);
        $215 = HEAP32[$214>>2]|0;
        $216 = (($38) + -2)|0;
        $217 = ((($40) + ($216<<2)|0) + 4452|0);
        $218 = HEAP32[$217>>2]|0;
        $219 = (($218) + ($215))|0;
        $220 = (($38) + -1)|0;
        $221 = ((($40) + ($220<<2)|0) + 4452|0);
        $222 = HEAP32[$221>>2]|0;
        $223 = (($219) + ($222))|0;
        $224 = ((($40) + ($38<<2)|0) + 4452|0);
        $225 = HEAP32[$224>>2]|0;
        $226 = (($223) + ($225))|0;
        $227 = (($40) + 4964|0);
        $228 = HEAP32[$227>>2]|0;
        $229 = ($226>>>0)<($228>>>0);
        if ($229) {
         HEAP32[$227>>2] = $226;
         $230 = (($40) + 4972|0);
         HEAP32[$230>>2] = $212;
        }
        if ((($212|0) == 2)) {
         $231 = (($40) + 4972|0);
         $232 = HEAP32[$231>>2]|0;
         $233 = ($232|0)==(0);
         if (!($233)) {
          $base_scan_idx$0$i = 0;
          break;
         }
        } else if ((($212|0) == 3)) {
         $234 = (($40) + 4972|0);
         $235 = HEAP32[$234>>2]|0;
         $236 = ($235|0)==(2);
         if ($236) {
          $base_scan_idx$0$i = 0;
          break;
         }
        } else if ((($212|0) == 4)) {
         $237 = (($40) + 4972|0);
         $238 = HEAP32[$237>>2]|0;
         $239 = ($238|0)==(4);
         if ($239) {
          $base_scan_idx$0$i = 0;
          break;
         }
        } else {
         $base_scan_idx$0$i = 0;
         break;
        }
        $240 = HEAP32[$135>>2]|0;
        $241 = (($240) + -1)|0;
        $242 = (($40) + 4188|0);
        HEAP32[$242>>2] = $241;
        $243 = Math_imul($240, $60)|0;
        $244 = (($243) + -1)|0;
        $245 = (($40) + 4192|0);
        $246 = HEAP32[$245>>2]|0;
        $247 = (($244) + ($246))|0;
        $248 = (($40) + 4180|0);
        $$c$i = $247;
        HEAP32[$248>>2] = $$c$i;
        $249 = (($40) + 4184|0);
        $250 = HEAP32[$249>>2]|0;
        $251 = (($250) + -1)|0;
        $252 = ($247|0)==($251|0);
        $253 = $252&1;
        $254 = (($40) + 13|0);
        HEAP8[$254>>0] = $253;
        $base_scan_idx$0$i = 0;
       } else {
        $base_scan_idx$0$i = 0;
       }
      }
     } else {
      $base_scan_idx$0$i = 0;
     }
    } else {
     $63 = (($38|0) % 3)&-1;
     $64 = ($63|0)==(2);
     if ($64) {
      $65 = (($38|0) / 3)&-1;
      $66 = (($38) + -1)|0;
      $67 = ((($40) + ($66<<2)|0) + 4452|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = ((($40) + ($38<<2)|0) + 4452|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = (($70) + ($68))|0;
      $72 = ($38|0)>(2);
      if ($72) {
       $cost$027$i = $71;$i$028$i = 0;
       while(1) {
        $73 = ($i$028$i*3)|0;
        $74 = (($73) + 3)|0;
        $75 = ((($40) + ($74<<2)|0) + 4452|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = (($76) + ($cost$027$i))|0;
        $78 = (($i$028$i) + 1)|0;
        $79 = ($78|0)<($65|0);
        if ($79) {
         $cost$027$i = $77;$i$028$i = $78;
        } else {
         $cost$0$lcssa$i = $77;
         break;
        }
       }
      } else {
       $cost$0$lcssa$i = $71;
      }
      $$off3$i = (($38) + 2)|0;
      $80 = ($$off3$i>>>0)<(5);
      $$pre54$i = (($40) + 4964|0);
      if (!($80)) {
       $81 = HEAP32[$$pre54$i>>2]|0;
       $82 = ($cost$0$lcssa$i>>>0)<($81>>>0);
       if (!($82)) {
        $84 = (($46) + 1)|0;
        $85 = (($40) + 4188|0);
        HEAP32[$85>>2] = $84;
        $86 = Math_imul($60, $47)|0;
        $87 = (($86) + -1)|0;
        $88 = (($40) + 4192|0);
        $89 = HEAP32[$88>>2]|0;
        $90 = (($87) + ($89))|0;
        $91 = (($40) + 4180|0);
        $$c4$i = $90;
        HEAP32[$91>>2] = $$c4$i;
        $base_scan_idx$0$i = 0;
        break;
       }
      }
      HEAP32[$$pre54$i>>2] = $cost$0$lcssa$i;
      $83 = (($40) + 4976|0);
      HEAP32[$83>>2] = $65;
      $base_scan_idx$0$i = 0;
     } else {
      $base_scan_idx$0$i = 0;
     }
    }
   } while(0);
   $255 = (($40) + 4188|0);
   $256 = HEAP32[$255>>2]|0;
   $257 = (($cinfo) + 168|0);
   $258 = HEAP32[$257>>2]|0;
   $259 = (($258) + -1)|0;
   $260 = ($256|0)==($259|0);
   if ($260) {
    $261 = (($40) + 4976|0);
    $262 = HEAP32[$261>>2]|0;
    $263 = (($40) + 4980|0);
    $264 = HEAP32[$263>>2]|0;
    $265 = ($262|0)<($264|0);
    $$$i = $265 ? $262 : $264;
    _copy_buffer($cinfo,0);
    $266 = HEAP32[$257>>2]|0;
    $267 = HEAP32[$0>>2]|0;
    $268 = (($267) + 4140|0);
    $269 = HEAP32[$268>>2]|0;
    $270 = ($266|0)>($269|0);
    do {
     if ($270) {
      $271 = (($267) + 4124|0);
      $272 = HEAP32[$271>>2]|0;
      $273 = ($272|0)==(0);
      if ($273) {
       $base_scan_idx$1$i = $base_scan_idx$0$i;
      } else {
       $274 = (($40) + 4984|0);
       $275 = HEAP8[$274>>0]|0;
       $276 = ($275<<24>>24)==(0);
       $277 = ($272|0)==(1);
       $or$cond6$i = $276 | $277;
       if ($or$cond6$i) {
        $278 = (($269) + 1)|0;
        _copy_buffer($cinfo,$278);
        $279 = (($269) + 2)|0;
        _copy_buffer($cinfo,$279);
        $base_scan_idx$1$i = $269;
        break;
       } else {
        _copy_buffer($cinfo,$269);
        $base_scan_idx$1$i = $269;
        break;
       }
      }
     } else {
      $base_scan_idx$1$i = $base_scan_idx$0$i;
     }
    } while(0);
    $280 = (($40) + 4968|0);
    $281 = HEAP32[$280>>2]|0;
    $282 = ($281|0)==(0);
    if ($282) {
     _copy_buffer($cinfo,$47);
    } else {
     $283 = $281 << 1;
     $284 = (($46) + 1)|0;
     $285 = (($284) + ($283))|0;
     _copy_buffer($cinfo,$285);
     $286 = HEAP32[$280>>2]|0;
     $287 = $286 << 1;
     $288 = (($287) + ($47))|0;
     _copy_buffer($cinfo,$288);
    }
    $289 = HEAP32[$261>>2]|0;
    $290 = ($289|0)>($$$i|0);
    if ($290) {
     $Al8$020$in$i = $289;
     while(1) {
      $Al8$020$i = (($Al8$020$in$i) + -1)|0;
      $291 = ($Al8$020$i*3)|0;
      $292 = (($291) + 3)|0;
      _copy_buffer($cinfo,$292);
      $293 = ($Al8$020$i|0)>($$$i|0);
      if ($293) {
       $Al8$020$in$i = $Al8$020$i;
      } else {
       break;
      }
     }
    }
    $294 = HEAP32[$257>>2]|0;
    $295 = HEAP32[$0>>2]|0;
    $296 = (($295) + 4140|0);
    $297 = HEAP32[$296>>2]|0;
    $298 = ($294|0)>($297|0);
    if ($298) {
     $299 = (($40) + 4972|0);
     $300 = HEAP32[$299>>2]|0;
     $301 = ($300|0)==(0);
     if ($301) {
      _copy_buffer($cinfo,$57);
      $302 = (($57) + 1)|0;
      _copy_buffer($cinfo,$302);
     } else {
      $303 = $300 << 2;
      $304 = (($57) + -2)|0;
      $305 = (($304) + ($303))|0;
      _copy_buffer($cinfo,$305);
      $306 = HEAP32[$299>>2]|0;
      $307 = $306 << 2;
      $308 = (($57) + -1)|0;
      $309 = (($308) + ($307))|0;
      _copy_buffer($cinfo,$309);
      $310 = HEAP32[$299>>2]|0;
      $311 = $310 << 2;
      $312 = (($311) + ($57))|0;
      _copy_buffer($cinfo,$312);
      $313 = HEAP32[$299>>2]|0;
      $314 = $313 << 2;
      $315 = (($57) + 1)|0;
      $316 = (($315) + ($314))|0;
      _copy_buffer($cinfo,$316);
     }
     $317 = HEAP32[$0>>2]|0;
     $318 = (($317) + 4140|0);
     $319 = HEAP32[$318>>2]|0;
     $320 = (($317) + 4148|0);
     $321 = HEAP32[$320>>2]|0;
     $322 = (($321) + ($319))|0;
     $323 = HEAP32[$263>>2]|0;
     $324 = ($323|0)>($$$i|0);
     if ($324) {
      $Al8$117$in$i = $323;
      while(1) {
       $Al8$117$i = (($Al8$117$in$i) + -1)|0;
       $325 = ($Al8$117$i*6)|0;
       $326 = (($325) + ($322))|0;
       $327 = (($326) + 4)|0;
       _copy_buffer($cinfo,$327);
       $328 = (($326) + 5)|0;
       _copy_buffer($cinfo,$328);
       $329 = ($Al8$117$i|0)>($$$i|0);
       if ($329) {
        $Al8$117$in$i = $Al8$117$i;
       } else {
        $base_scan_idx$2$i = $322;
        break;
       }
      }
     } else {
      $base_scan_idx$2$i = $322;
     }
    } else {
     $base_scan_idx$2$i = $base_scan_idx$1$i;
    }
    $330 = ($$$i|0)>(0);
    if ($330) {
     $Al8$213$in$i = $$$i;
     while(1) {
      $Al8$213$i = (($Al8$213$in$i) + -1)|0;
      $334 = ($Al8$213$i*3)|0;
      $335 = (($334) + 3)|0;
      _copy_buffer($cinfo,$335);
      $336 = HEAP32[$257>>2]|0;
      $337 = HEAP32[$0>>2]|0;
      $338 = (($337) + 4140|0);
      $339 = HEAP32[$338>>2]|0;
      $340 = ($336|0)>($339|0);
      if ($340) {
       $342 = ($Al8$213$i*6)|0;
       $343 = (($342) + ($base_scan_idx$2$i))|0;
       $344 = (($343) + 4)|0;
       _copy_buffer($cinfo,$344);
       $345 = (($343) + 5)|0;
       _copy_buffer($cinfo,$345);
      }
      $341 = ($Al8$213$i|0)>(0);
      if ($341) {
       $Al8$213$in$i = $Al8$213$i;
      } else {
       break;
      }
     }
    }
    $331 = HEAP32[$257>>2]|0;
    $332 = ($331|0)>(0);
    if ($332) {
     $333 = (($40) + 4196|0);
     $445 = $331;$i7$011$i = 0;
     while(1) {
      $346 = (($333) + ($i7$011$i<<2)|0);
      $347 = HEAP32[$346>>2]|0;
      $348 = ($347|0)==(0|0);
      if ($348) {
       $351 = $445;
      } else {
       _free($347);
       $$pre$i = HEAP32[$257>>2]|0;
       $351 = $$pre$i;
      }
      $349 = (($i7$011$i) + 1)|0;
      $350 = ($349|0)<($351|0);
      if ($350) {
       $445 = $351;$i7$011$i = $349;
      } else {
       $$pre$phi28Z2D = $37;
       break;
      }
     }
    } else {
     $$pre$phi28Z2D = $37;
    }
   } else {
    $$pre$phi28Z2D = $37;
   }
  }
  $352 = HEAP32[$$pre$phi28Z2D>>2]|0;
  $353 = (($352) + 1)|0;
  HEAP32[$$pre$phi28Z2D>>2] = $353;
  $395 = (($1) + 4180|0);
  $396 = HEAP32[$395>>2]|0;
  $397 = (($396) + 1)|0;
  $$c1 = $397;
  HEAP32[$395>>2] = $$c1;
  STACKTOP = sp;return;
 } else if ((($7|0) == 3)) {
  $354 = (($cinfo) + 178|0);
  $355 = HEAP8[$354>>0]|0;
  $356 = ($355<<24>>24)==(0);
  if ($356) {
   $357 = (($1) + 4180|0);
   $358 = HEAP32[$357>>2]|0;
   $359 = (($1) + 4192|0);
   $360 = HEAP32[$359>>2]|0;
   $361 = (($360) + -1)|0;
   $362 = ($358|0)<($361|0);
   $$c = $362 ? (3) : (2);
   HEAP32[$6>>2] = $$c;
   $364 = $358;
  } else {
   HEAP32[$6>>2] = (1);
   $$phi$trans$insert = (($1) + 4180|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $364 = $$pre;
  }
  $363 = (($364) + 1)|0;
  $365 = (($cinfo) + 60|0);
  $366 = HEAP32[$365>>2]|0;
  $367 = HEAP32[$0>>2]|0;
  $368 = (($367) + 19|0);
  $369 = HEAP8[$368>>0]|0;
  $370 = ($369<<24>>24)!=(0);
  $371 = $370 ? 4 : 2;
  $372 = Math_imul($371, $366)|0;
  $373 = (($363|0) % ($372|0))&-1;
  $374 = ($373|0)==(0);
  if (!($374)) {
   $395 = (($1) + 4180|0);
   $396 = HEAP32[$395>>2]|0;
   $397 = (($396) + 1)|0;
   $$c1 = $397;
   HEAP32[$395>>2] = $$c1;
   STACKTOP = sp;return;
  }
  $375 = (($367) + 21|0);
  $376 = HEAP8[$375>>0]|0;
  $377 = ($376<<24>>24)==(0);
  if ($377) {
   $395 = (($1) + 4180|0);
   $396 = HEAP32[$395>>2]|0;
   $397 = (($396) + 1)|0;
   $$c1 = $397;
   HEAP32[$395>>2] = $$c1;
   STACKTOP = sp;return;
  }
  $378 = (($cinfo) + 72|0);
  $j$04 = 1;
  while(1) {
   $379 = ((($367) + ($j$04<<3)|0) + 2072|0);
   $380 = +HEAPF64[$379>>3];
   $381 = $380 != 0.0;
   if ($381) {
    $382 = ((($367) + ($j$04<<3)|0) + 24|0);
    $383 = +HEAPF64[$382>>3];
    $384 = $383 / $380;
    $385 = $384 + 0.5;
    $386 = (~~(($385)));
    $387 = ($386|0)>(254);
    $$ = $387 ? 254 : $386;
    $388 = ($$|0)<(1);
    $389 = $$&65535;
    $390 = $388 ? 1 : $389;
    $391 = HEAP32[$378>>2]|0;
    $392 = (($391) + ($j$04<<1)|0);
    HEAP16[$392>>1] = $390;
   }
   $393 = (($j$04) + 1)|0;
   $exitcond = ($393|0)==(64);
   if ($exitcond) {
    break;
   } else {
    $j$04 = $393;
   }
  }
  $394 = (($cinfo) + 76|0);
  $j$04$1 = 1;
  while(1) {
   $398 = ((($367) + ($j$04$1<<3)|0) + 2584|0);
   $399 = +HEAPF64[$398>>3];
   $400 = $399 != 0.0;
   if ($400) {
    $401 = ((($367) + ($j$04$1<<3)|0) + 536|0);
    $402 = +HEAPF64[$401>>3];
    $403 = $402 / $399;
    $404 = $403 + 0.5;
    $405 = (~~(($404)));
    $406 = ($405|0)>(254);
    $$$1 = $406 ? 254 : $405;
    $407 = ($$$1|0)<(1);
    $408 = $$$1&65535;
    $409 = $407 ? 1 : $408;
    $410 = HEAP32[$394>>2]|0;
    $411 = (($410) + ($j$04$1<<1)|0);
    HEAP16[$411>>1] = $409;
   }
   $412 = (($j$04$1) + 1)|0;
   $exitcond$1 = ($412|0)==(64);
   if ($exitcond$1) {
    break;
   } else {
    $j$04$1 = $412;
   }
  }
  $413 = (($cinfo) + 80|0);
  $j$04$2 = 1;
  while(1) {
   $414 = ((($367) + ($j$04$2<<3)|0) + 3096|0);
   $415 = +HEAPF64[$414>>3];
   $416 = $415 != 0.0;
   if ($416) {
    $417 = ((($367) + ($j$04$2<<3)|0) + 1048|0);
    $418 = +HEAPF64[$417>>3];
    $419 = $418 / $415;
    $420 = $419 + 0.5;
    $421 = (~~(($420)));
    $422 = ($421|0)>(254);
    $$$2 = $422 ? 254 : $421;
    $423 = ($$$2|0)<(1);
    $424 = $$$2&65535;
    $425 = $423 ? 1 : $424;
    $426 = HEAP32[$413>>2]|0;
    $427 = (($426) + ($j$04$2<<1)|0);
    HEAP16[$427>>1] = $425;
   }
   $428 = (($j$04$2) + 1)|0;
   $exitcond$2 = ($428|0)==(64);
   if ($exitcond$2) {
    break;
   } else {
    $j$04$2 = $428;
   }
  }
  $429 = (($cinfo) + 84|0);
  $j$04$3 = 1;
  while(1) {
   $430 = ((($367) + ($j$04$3<<3)|0) + 3608|0);
   $431 = +HEAPF64[$430>>3];
   $432 = $431 != 0.0;
   if ($432) {
    $433 = ((($367) + ($j$04$3<<3)|0) + 1560|0);
    $434 = +HEAPF64[$433>>3];
    $435 = $434 / $431;
    $436 = $435 + 0.5;
    $437 = (~~(($436)));
    $438 = ($437|0)>(254);
    $$$3 = $438 ? 254 : $437;
    $439 = ($$$3|0)<(1);
    $440 = $$$3&65535;
    $441 = $439 ? 1 : $440;
    $442 = HEAP32[$429>>2]|0;
    $443 = (($442) + ($j$04$3<<1)|0);
    HEAP16[$443>>1] = $441;
   }
   $444 = (($j$04$3) + 1)|0;
   $exitcond$3 = ($444|0)==(64);
   if ($exitcond$3) {
    break;
   } else {
    $j$04$3 = $444;
   }
  }
  $395 = (($1) + 4180|0);
  $396 = HEAP32[$395>>2]|0;
  $397 = (($396) + 1)|0;
  $$c1 = $397;
  HEAP32[$395>>2] = $$c1;
  STACKTOP = sp;return;
 } else if ((($7|0) == 0)) {
  $8 = HEAP32[$0>>2]|0;
  $9 = (($8) + 15|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if (!($11)) {
   HEAP32[$6>>2] = (3);
   $395 = (($1) + 4180|0);
   $396 = HEAP32[$395>>2]|0;
   $397 = (($396) + 1)|0;
   $$c1 = $397;
   HEAP32[$395>>2] = $$c1;
   STACKTOP = sp;return;
  }
  HEAP32[$6>>2] = (2);
  $12 = (($cinfo) + 178|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if (!($14)) {
   $395 = (($1) + 4180|0);
   $396 = HEAP32[$395>>2]|0;
   $397 = (($396) + 1)|0;
   $$c1 = $397;
   HEAP32[$395>>2] = $$c1;
   STACKTOP = sp;return;
  }
  $15 = (($1) + 4188|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 1)|0;
  HEAP32[$15>>2] = $17;
  $395 = (($1) + 4180|0);
  $396 = HEAP32[$395>>2]|0;
  $397 = (($396) + 1)|0;
  $$c1 = $397;
  HEAP32[$395>>2] = $$c1;
  STACKTOP = sp;return;
 } else {
  $395 = (($1) + 4180|0);
  $396 = HEAP32[$395>>2]|0;
  $397 = (($396) + 1)|0;
  $$c1 = $397;
  HEAP32[$395>>2] = $$c1;
  STACKTOP = sp;return;
 }
}
function _copy_buffer($cinfo,$scan_idx) {
 $cinfo = $cinfo|0;
 $scan_idx = $scan_idx|0;
 var $$lcssa1 = 0, $$lcssa8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $i$010 = 0, $size$0$lcssa = 0, $size$02 = 0, $src$0$lcssa = 0, $src$03 = 0, $vararg_buffer6 = 0;
 var $vararg_ptr1 = 0, $vararg_ptr5 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer6 = sp;
 $0 = (($cinfo) + 316|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1) + ($scan_idx<<2)|0) + 4452|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4196|0);
 $5 = (($4) + ($scan_idx<<2)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$cinfo>>2]|0;
 $8 = (($7) + 104|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)>(0);
 if ($10) {
  $11 = HEAP32[_stderr>>2]|0;
  (_fwrite((131800|0),5,1,($11|0))|0);
  $12 = (($cinfo) + 172|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + (($scan_idx*36)|0)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)>(0);
  if ($16) {
   $20 = $13;$i$010 = 0;
   while(1) {
    $17 = ($i$010|0)==(0);
    $18 = $17 ? 131816 : 131824;
    $19 = (((($20) + (($scan_idx*36)|0)|0) + ($i$010<<2)|0) + 4|0);
    $21 = HEAP32[$19>>2]|0;
    HEAP32[$vararg_buffer6>>2] = $18;
    $vararg_ptr1 = (($vararg_buffer6) + 4|0);
    HEAP32[$vararg_ptr1>>2] = $21;
    (_fprintf(($11|0),(131808|0),($vararg_buffer6|0))|0);
    $22 = (($i$010) + 1)|0;
    $23 = HEAP32[$12>>2]|0;
    $24 = (($23) + (($scan_idx*36)|0)|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($22|0)<($25|0);
    if ($26) {
     $20 = $23;$i$010 = $22;
    } else {
     $$lcssa8 = $23;
     break;
    }
   }
  } else {
   $$lcssa8 = $13;
  }
  $27 = ((($$lcssa8) + (($scan_idx*36)|0)|0) + 20|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ((($$lcssa8) + (($scan_idx*36)|0)|0) + 24|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$vararg_buffer6>>2] = $28;
  $vararg_ptr5 = (($vararg_buffer6) + 4|0);
  HEAP32[$vararg_ptr5>>2] = $30;
  (_fprintf(($11|0),(131832|0),($vararg_buffer6|0))|0);
  $31 = HEAP32[$12>>2]|0;
  $32 = ((($31) + (($scan_idx*36)|0)|0) + 28|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ((($1) + ($scan_idx<<2)|0) + 4708|0);
  $35 = HEAP32[$34>>2]|0;
  HEAP32[$vararg_buffer6>>2] = $33;
  $vararg_ptr9 = (($vararg_buffer6) + 4|0);
  HEAP32[$vararg_ptr9>>2] = $35;
  (_fprintf(($11|0),(131840|0),($vararg_buffer6|0))|0);
  (_fputc(10,($11|0))|0);
 }
 $36 = (($cinfo) + 24|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 4|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($3>>>0)<($39>>>0);
 $41 = HEAP32[$37>>2]|0;
 if ($40) {
  $$lcssa1 = $41;$size$0$lcssa = $3;$src$0$lcssa = $6;
  _memcpy(($$lcssa1|0),($src$0$lcssa|0),($size$0$lcssa|0))|0;
  $65 = HEAP32[$36>>2]|0;
  $66 = HEAP32[$65>>2]|0;
  $67 = (($66) + ($size$0$lcssa)|0);
  HEAP32[$65>>2] = $67;
  $68 = HEAP32[$36>>2]|0;
  $69 = (($68) + 4|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (($70) - ($size$0$lcssa))|0;
  HEAP32[$69>>2] = $71;
  STACKTOP = sp;return;
 }
 $42 = $41;$43 = $39;$size$02 = $3;$src$03 = $6;
 while(1) {
  _memcpy(($42|0),($src$03|0),($43|0))|0;
  $44 = HEAP32[$36>>2]|0;
  $45 = (($44) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($src$03) + ($46)|0);
  $48 = (($size$02) - ($46))|0;
  $49 = HEAP32[$44>>2]|0;
  $50 = (($49) + ($46)|0);
  HEAP32[$44>>2] = $50;
  $51 = HEAP32[$36>>2]|0;
  $52 = (($51) + 4|0);
  HEAP32[$52>>2] = 0;
  $53 = (($51) + 12|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = (FUNCTION_TABLE_ii[$54 & 7]($cinfo)|0);
  $56 = ($55<<24>>24)==(0);
  if ($56) {
   $57 = HEAP32[$cinfo>>2]|0;
   $58 = (($57) + 20|0);
   HEAP32[$58>>2] = 129;
   $59 = HEAP32[$57>>2]|0;
   FUNCTION_TABLE_vi[$59 & 63]($cinfo);
  }
  $60 = HEAP32[$36>>2]|0;
  $61 = (($60) + 4|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ($48>>>0)<($62>>>0);
  $64 = HEAP32[$60>>2]|0;
  if ($63) {
   $$lcssa1 = $64;$size$0$lcssa = $48;$src$0$lcssa = $47;
   break;
  } else {
   $42 = $64;$43 = $62;$size$02 = $48;$src$03 = $47;
  }
 }
 _memcpy(($$lcssa1|0),($src$0$lcssa|0),($size$0$lcssa|0))|0;
 $65 = HEAP32[$36>>2]|0;
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + ($size$0$lcssa)|0);
 HEAP32[$65>>2] = $67;
 $68 = HEAP32[$36>>2]|0;
 $69 = (($68) + 4|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (($70) - ($size$0$lcssa))|0;
 HEAP32[$69>>2] = $71;
 STACKTOP = sp;return;
}
function _select_scan_parameters($cinfo) {
 $cinfo = $cinfo|0;
 var $$pre = 0, $$pre10 = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ci$02 = 0, $ci$11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 316|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4180|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4192|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)<($5|0);
 if ($6) {
  $7 = (($cinfo) + 228|0);
  HEAP32[$7>>2] = 1;
  $8 = (($1) + 19|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($9<<24>>24)==(0);
  $11 = HEAP32[$2>>2]|0;
  $12 = (($1) + 4136|0);
  $13 = HEAP32[$12>>2]|0;
  if ($10) {
   $34 = $13 << 1;
   $35 = (($11|0) / ($34|0))&-1;
   $36 = (($cinfo) + 68|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($37) + (($35*84)|0)|0);
   $39 = (($cinfo) + 232|0);
   HEAP32[$39>>2] = $38;
   $40 = (($cinfo) + 300|0);
   HEAP32[$40>>2] = 1;
   $41 = (($cinfo) + 304|0);
   HEAP32[$41>>2] = 63;
   STACKTOP = sp;return;
  }
  $14 = $13 << 2;
  $15 = (($11|0) / ($14|0))&-1;
  $16 = (($cinfo) + 68|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + (($15*84)|0)|0);
  $19 = (($cinfo) + 232|0);
  HEAP32[$19>>2] = $18;
  $20 = (($11|0) % 4)&-1;
  $21 = ($20|0)<(2);
  if ($21) {
   $26 = 1;
  } else {
   $22 = (($1) + 4132|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + 1)|0;
   $26 = $24;
  }
  $25 = (($cinfo) + 300|0);
  HEAP32[$25>>2] = $26;
  $27 = HEAP32[$2>>2]|0;
  $28 = (($27|0) % 4)&-1;
  $29 = ($28|0)<(2);
  if ($29) {
   $30 = (($1) + 4132|0);
   $31 = HEAP32[$30>>2]|0;
   $33 = $31;
  } else {
   $33 = 63;
  }
  $32 = (($cinfo) + 304|0);
  HEAP32[$32>>2] = $33;
  STACKTOP = sp;return;
 }
 $42 = (($cinfo) + 172|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 if ($44) {
  $108 = (($cinfo) + 60|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = ($109|0)>(4);
  if ($110) {
   $111 = HEAP32[$cinfo>>2]|0;
   $112 = (($111) + 20|0);
   HEAP32[$112>>2] = 26;
   $113 = HEAP32[$108>>2]|0;
   $114 = (($111) + 24|0);
   HEAP32[$114>>2] = $113;
   $115 = (($111) + 28|0);
   HEAP32[$115>>2] = 4;
   $116 = HEAP32[$111>>2]|0;
   FUNCTION_TABLE_vi[$116 & 63]($cinfo);
   $$pre = HEAP32[$108>>2]|0;
   $118 = $$pre;
  } else {
   $118 = $109;
  }
  $117 = (($cinfo) + 228|0);
  HEAP32[$117>>2] = $118;
  $119 = ($118|0)>(0);
  if ($119) {
   $120 = (($cinfo) + 68|0);
   $ci$11 = 0;
   while(1) {
    $121 = HEAP32[$120>>2]|0;
    $122 = (($121) + (($ci$11*84)|0)|0);
    $123 = ((($cinfo) + ($ci$11<<2)|0) + 232|0);
    HEAP32[$123>>2] = $122;
    $124 = (($ci$11) + 1)|0;
    $125 = HEAP32[$108>>2]|0;
    $126 = ($124|0)<($125|0);
    if ($126) {
     $ci$11 = $124;
    } else {
     break;
    }
   }
  }
  $127 = (($cinfo) + 300|0);
  HEAP32[$127>>2] = 0;
  $128 = (($cinfo) + 304|0);
  HEAP32[$128>>2] = 63;
  $129 = (($cinfo) + 308|0);
  HEAP32[$129>>2] = 0;
  $130 = (($cinfo) + 312|0);
  HEAP32[$130>>2] = 0;
  STACKTOP = sp;return;
 }
 $45 = (($1) + 4188|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($43) + (($46*36)|0)|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($cinfo) + 228|0);
 HEAP32[$49>>2] = $48;
 $50 = HEAP32[$47>>2]|0;
 $51 = ($50|0)>(0);
 if ($51) {
  $52 = (($cinfo) + 68|0);
  $ci$02 = 0;
  while(1) {
   $53 = (((($43) + (($46*36)|0)|0) + ($ci$02<<2)|0) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = HEAP32[$52>>2]|0;
   $56 = (($55) + (($54*84)|0)|0);
   $57 = ((($cinfo) + ($ci$02<<2)|0) + 232|0);
   HEAP32[$57>>2] = $56;
   $58 = (($ci$02) + 1)|0;
   $59 = ($58|0)<($50|0);
   if ($59) {
    $ci$02 = $58;
   } else {
    break;
   }
  }
  $$pre6 = HEAP32[$0>>2]|0;
  $73 = $$pre6;
 } else {
  $73 = $1;
 }
 $60 = ((($43) + (($46*36)|0)|0) + 20|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($cinfo) + 300|0);
 HEAP32[$62>>2] = $61;
 $63 = ((($43) + (($46*36)|0)|0) + 24|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($cinfo) + 304|0);
 HEAP32[$65>>2] = $64;
 $66 = ((($43) + (($46*36)|0)|0) + 28|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($cinfo) + 308|0);
 HEAP32[$68>>2] = $67;
 $69 = ((($43) + (($46*36)|0)|0) + 32|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (($cinfo) + 312|0);
 HEAP32[$71>>2] = $70;
 $72 = (($73) + 14|0);
 $74 = HEAP8[$72>>0]|0;
 $75 = ($74<<24>>24)==(0);
 if ($75) {
  $107 = $70;
 } else {
  $76 = HEAP32[$45>>2]|0;
  $77 = (($73) + 4144|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (($73) + 4156|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = ($80*3)|0;
  $82 = (($78) + 2)|0;
  $83 = (($82) + ($81))|0;
  $84 = ($76|0)<($83|0);
  $$pre10 = (($73) + 4140|0);
  if ($84) {
   $131 = $70;$98 = $76;
  } else {
   $85 = HEAP32[$$pre10>>2]|0;
   $86 = ($76|0)<($85|0);
   if ($86) {
    $87 = (($1) + 4976|0);
    $88 = HEAP32[$87>>2]|0;
    HEAP32[$71>>2] = $88;
    $$pre7 = HEAP32[$45>>2]|0;
    $131 = $88;$98 = $$pre7;
   } else {
    $131 = $70;$98 = $76;
   }
  }
  $89 = HEAP32[$$pre10>>2]|0;
  $90 = (($73) + 4148|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = (($73) + 4160|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = ($93*6)|0;
  $95 = (($89) + 4)|0;
  $96 = (($95) + ($91))|0;
  $97 = (($96) + ($94))|0;
  $99 = ($98|0)<($97|0);
  if ($99) {
   $107 = $131;
  } else {
   $100 = (($cinfo) + 168|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = ($98|0)<($101|0);
   if ($102) {
    $103 = (($1) + 4980|0);
    $104 = HEAP32[$103>>2]|0;
    HEAP32[$71>>2] = $104;
    $107 = $104;
   } else {
    $107 = $131;
   }
  }
 }
 $105 = HEAP32[$45>>2]|0;
 $106 = ((($1) + ($105<<2)|0) + 4708|0);
 HEAP32[$106>>2] = $107;
 STACKTOP = sp;return;
}
function _per_scan_setup($cinfo) {
 $cinfo = $cinfo|0;
 var $$ = 0, $$1 = 0, $$off = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $ci$03 = 0, $mcublks$02 = 0, $tmp$2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 228|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1);
 if ($2) {
  $3 = (($cinfo) + 232|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 28|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($cinfo) + 248|0);
  HEAP32[$7>>2] = $6;
  $8 = (($4) + 32|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($cinfo) + 252|0);
  HEAP32[$10>>2] = $9;
  $11 = (($4) + 52|0);
  HEAP32[$11>>2] = 1;
  $12 = (($4) + 56|0);
  HEAP32[$12>>2] = 1;
  $13 = (($4) + 60|0);
  HEAP32[$13>>2] = 1;
  $14 = (($4) + 64|0);
  HEAP32[$14>>2] = 8;
  $15 = (($4) + 68|0);
  HEAP32[$15>>2] = 1;
  $16 = HEAP32[$8>>2]|0;
  $17 = (($4) + 12|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($16>>>0) % ($18>>>0))&-1;
  $20 = ($19|0)==(0);
  $$ = $20 ? $18 : $19;
  $21 = (($4) + 72|0);
  HEAP32[$21>>2] = $$;
  $22 = (($cinfo) + 256|0);
  HEAP32[$22>>2] = 1;
  $23 = (($cinfo) + 260|0);
  HEAP32[$23>>2] = 0;
 } else {
  $$off = (($1) + -1)|0;
  $24 = ($$off>>>0)>(3);
  if ($24) {
   $25 = HEAP32[$cinfo>>2]|0;
   $26 = (($25) + 20|0);
   HEAP32[$26>>2] = 26;
   $27 = HEAP32[$0>>2]|0;
   $28 = (($25) + 24|0);
   HEAP32[$28>>2] = $27;
   $29 = (($25) + 28|0);
   HEAP32[$29>>2] = 4;
   $30 = HEAP32[$25>>2]|0;
   FUNCTION_TABLE_vi[$30 & 63]($cinfo);
  }
  $31 = (($cinfo) + 28|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($cinfo) + 216|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = $34 << 3;
  $36 = (_jdiv_round_up($32,$35)|0);
  $37 = (($cinfo) + 248|0);
  HEAP32[$37>>2] = $36;
  $38 = (($cinfo) + 32|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($cinfo) + 220|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = $41 << 3;
  $43 = (_jdiv_round_up($39,$42)|0);
  $44 = (($cinfo) + 252|0);
  HEAP32[$44>>2] = $43;
  $45 = (($cinfo) + 256|0);
  HEAP32[$45>>2] = 0;
  $46 = HEAP32[$0>>2]|0;
  $47 = ($46|0)>(0);
  if ($47) {
   $ci$03 = 0;
   while(1) {
    $48 = ((($cinfo) + ($ci$03<<2)|0) + 232|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($49) + 8|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($49) + 52|0);
    HEAP32[$52>>2] = $51;
    $53 = (($49) + 12|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($49) + 56|0);
    HEAP32[$55>>2] = $54;
    $56 = Math_imul($51, $54)|0;
    $57 = (($49) + 60|0);
    HEAP32[$57>>2] = $56;
    $58 = $51 << 3;
    $59 = (($49) + 64|0);
    HEAP32[$59>>2] = $58;
    $60 = (($49) + 28|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = (($61>>>0) % ($51>>>0))&-1;
    $63 = ($62|0)==(0);
    $$1 = $63 ? $51 : $62;
    $64 = (($49) + 68|0);
    HEAP32[$64>>2] = $$1;
    $65 = (($49) + 32|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = (($66>>>0) % ($54>>>0))&-1;
    $68 = ($67|0)==(0);
    $tmp$2 = $68 ? $54 : $67;
    $69 = (($49) + 72|0);
    HEAP32[$69>>2] = $tmp$2;
    $70 = HEAP32[$45>>2]|0;
    $71 = (($70) + ($56))|0;
    $72 = ($71|0)>(10);
    if ($72) {
     $73 = HEAP32[$cinfo>>2]|0;
     $74 = (($73) + 20|0);
     HEAP32[$74>>2] = 13;
     $75 = HEAP32[$73>>2]|0;
     FUNCTION_TABLE_vi[$75 & 63]($cinfo);
    }
    $76 = ($56|0)>(0);
    if ($76) {
     $mcublks$02 = $56;
     while(1) {
      $77 = (($mcublks$02) + -1)|0;
      $78 = HEAP32[$45>>2]|0;
      $79 = (($78) + 1)|0;
      HEAP32[$45>>2] = $79;
      $80 = ((($cinfo) + ($78<<2)|0) + 260|0);
      HEAP32[$80>>2] = $ci$03;
      $81 = ($77|0)>(0);
      if ($81) {
       $mcublks$02 = $77;
      } else {
       break;
      }
     }
    }
    $82 = (($ci$03) + 1)|0;
    $83 = HEAP32[$0>>2]|0;
    $84 = ($82|0)<($83|0);
    if ($84) {
     $ci$03 = $82;
    } else {
     break;
    }
   }
  }
 }
 $85 = (($cinfo) + 192|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = ($86|0)>(0);
 if (!($87)) {
  STACKTOP = sp;return;
 }
 $88 = (($cinfo) + 248|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = Math_imul($89, $86)|0;
 $91 = ($90|0)<(65535);
 $92 = $91 ? $90 : 65535;
 $93 = (($cinfo) + 188|0);
 HEAP32[$93>>2] = $92;
 STACKTOP = sp;return;
}
function _jpeg_abort($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($1) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 15]($cinfo,1);
 $5 = (($cinfo) + 16|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 $8 = (($cinfo) + 20|0);
 if ($7) {
  HEAP32[$8>>2] = 100;
  STACKTOP = sp;return;
 } else {
  HEAP32[$8>>2] = 200;
  $9 = (($cinfo) + 268|0);
  HEAP32[$9>>2] = 0;
  STACKTOP = sp;return;
 }
}
function _jpeg_destroy($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 40|0);
  $4 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$4 & 63]($cinfo);
 }
 HEAP32[$0>>2] = 0;
 $5 = (($cinfo) + 20|0);
 HEAP32[$5>>2] = 0;
 STACKTOP = sp;return;
}
function _jpeg_alloc_quant_table($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 7]($cinfo,0,130)|0);
 $4 = (($3) + 128|0);
 HEAP8[$4>>0] = 0;
 STACKTOP = sp;return ($3|0);
}
function _jpeg_alloc_huff_table($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 7]($cinfo,0,274)|0);
 $4 = (($3) + 273|0);
 HEAP8[$4>>0] = 0;
 STACKTOP = sp;return ($3|0);
}
function _jpeg_set_linear_quality($cinfo,$scale_factor,$force_baseline) {
 $cinfo = $cinfo|0;
 $scale_factor = $scale_factor|0;
 $force_baseline = $force_baseline|0;
 var $$$$us$i = 0, $$$$us$i4 = 0, $$$i = 0, $$$i8 = 0, $$$us$i = 0, $$$us$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $exitcond$i = 0, $exitcond$i9 = 0, $exitcond3$i = 0, $exitcond3$i5 = 0, $i$02$i = 0, $i$02$i7 = 0, $i$02$us$i = 0, $i$02$us$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 316|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4128|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($cinfo) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(100);
 if (!($6)) {
  $7 = HEAP32[$cinfo>>2]|0;
  $8 = (($7) + 20|0);
  HEAP32[$8>>2] = 20;
  $9 = HEAP32[$4>>2]|0;
  $10 = (($7) + 24|0);
  HEAP32[$10>>2] = $9;
  $11 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_vi[$11 & 63]($cinfo);
 }
 $12 = (($cinfo) + 72|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $15 = (_jpeg_alloc_quant_table($cinfo)|0);
  HEAP32[$12>>2] = $15;
  $28 = $15;
 } else {
  $28 = $13;
 }
 $16 = ($force_baseline<<24>>24)==(0);
 if ($16) {
  $i$02$i = 0;
  while(1) {
   $30 = ((131848 + ($3<<8)|0) + ($i$02$i<<2)|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = Math_imul($31, $scale_factor)|0;
   $33 = (($32) + 50)|0;
   $34 = (($33|0) / 100)&-1;
   $35 = ($34|0)<(1);
   $$$i = $35 ? 1 : $34;
   $36 = ($$$i|0)>(32767);
   $37 = $$$i&65535;
   $38 = $36 ? 32767 : $37;
   $39 = (($28) + ($i$02$i<<1)|0);
   HEAP16[$39>>1] = $38;
   $40 = (($i$02$i) + 1)|0;
   $exitcond$i = ($40|0)==(64);
   if ($exitcond$i) {
    break;
   } else {
    $i$02$i = $40;
   }
  }
 } else {
  $i$02$us$i = 0;
  while(1) {
   $17 = ((131848 + ($3<<8)|0) + ($i$02$us$i<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = Math_imul($18, $scale_factor)|0;
   $20 = (($19) + 50)|0;
   $21 = (($20|0) / 100)&-1;
   $22 = ($21|0)<(1);
   $$$us$i = $22 ? 1 : $21;
   $23 = ($$$us$i|0)>(32767);
   $$$$us$i = $23 ? 32767 : $$$us$i;
   $24 = ($$$$us$i|0)>(255);
   $25 = $$$$us$i&65535;
   $26 = $24 ? 255 : $25;
   $27 = (($28) + ($i$02$us$i<<1)|0);
   HEAP16[$27>>1] = $26;
   $29 = (($i$02$us$i) + 1)|0;
   $exitcond3$i = ($29|0)==(64);
   if ($exitcond3$i) {
    break;
   } else {
    $i$02$us$i = $29;
   }
  }
 }
 $41 = (($28) + 128|0);
 HEAP8[$41>>0] = 0;
 $42 = HEAP32[$0>>2]|0;
 $43 = (($42) + 4128|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = HEAP32[$4>>2]|0;
 $46 = ($45|0)==(100);
 if (!($46)) {
  $47 = HEAP32[$cinfo>>2]|0;
  $48 = (($47) + 20|0);
  HEAP32[$48>>2] = 20;
  $49 = HEAP32[$4>>2]|0;
  $50 = (($47) + 24|0);
  HEAP32[$50>>2] = $49;
  $51 = HEAP32[$47>>2]|0;
  FUNCTION_TABLE_vi[$51 & 63]($cinfo);
 }
 $52 = (($cinfo) + 76|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53|0)==(0|0);
 if ($54) {
  $55 = (_jpeg_alloc_quant_table($cinfo)|0);
  HEAP32[$52>>2] = $55;
  $67 = $55;
 } else {
  $67 = $53;
 }
 if ($16) {
  $i$02$i7 = 0;
  while(1) {
   $69 = ((134152 + ($44<<8)|0) + ($i$02$i7<<2)|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = Math_imul($70, $scale_factor)|0;
   $72 = (($71) + 50)|0;
   $73 = (($72|0) / 100)&-1;
   $74 = ($73|0)<(1);
   $$$i8 = $74 ? 1 : $73;
   $75 = ($$$i8|0)>(32767);
   $76 = $$$i8&65535;
   $77 = $75 ? 32767 : $76;
   $78 = (($67) + ($i$02$i7<<1)|0);
   HEAP16[$78>>1] = $77;
   $79 = (($i$02$i7) + 1)|0;
   $exitcond$i9 = ($79|0)==(64);
   if ($exitcond$i9) {
    break;
   } else {
    $i$02$i7 = $79;
   }
  }
  $80 = (($67) + 128|0);
  HEAP8[$80>>0] = 0;
  STACKTOP = sp;return;
 } else {
  $i$02$us$i2 = 0;
  while(1) {
   $56 = ((134152 + ($44<<8)|0) + ($i$02$us$i2<<2)|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = Math_imul($57, $scale_factor)|0;
   $59 = (($58) + 50)|0;
   $60 = (($59|0) / 100)&-1;
   $61 = ($60|0)<(1);
   $$$us$i3 = $61 ? 1 : $60;
   $62 = ($$$us$i3|0)>(32767);
   $$$$us$i4 = $62 ? 32767 : $$$us$i3;
   $63 = ($$$$us$i4|0)>(255);
   $64 = $$$$us$i4&65535;
   $65 = $63 ? 255 : $64;
   $66 = (($67) + ($i$02$us$i2<<1)|0);
   HEAP16[$66>>1] = $65;
   $68 = (($i$02$us$i2) + 1)|0;
   $exitcond3$i5 = ($68|0)==(64);
   if ($exitcond3$i5) {
    break;
   } else {
    $i$02$us$i2 = $68;
   }
  }
  $80 = (($67) + 128|0);
  HEAP8[$80>>0] = 0;
  STACKTOP = sp;return;
 }
}
function _jpeg_set_quality($cinfo,$quality,$force_baseline) {
 $cinfo = $cinfo|0;
 $quality = $quality|0;
 $force_baseline = $force_baseline|0;
 var $$0$i$i = 0.0, $$1$i$i = 0.0, $$2$i$i = 0.0, $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+($quality|0));
 $1 = !($0 <= 0.0);
 $$0$i$i = $1 ? $0 : 1.0;
 $2 = $$0$i$i > 100.0;
 $$1$i$i = $2 ? 100.0 : $$0$i$i;
 $3 = $$1$i$i < 50.0;
 if ($3) {
  $4 = 5000.0 / $$1$i$i;
  $$2$i$i = $4;
 } else {
  $5 = $$1$i$i * 2.0;
  $6 = 200.0 - $5;
  $$2$i$i = $6;
 }
 $7 = (~~(($$2$i$i)));
 _jpeg_set_linear_quality($cinfo,$7,$force_baseline);
 STACKTOP = sp;return;
}
function _jpeg_set_defaults($cinfo) {
 $cinfo = $cinfo|0;
 var $$ = 0, $$$ = 0, $$pre = 0, $$pre$phi3Z2D = 0, $$pre$phi5Z2D = 0, $$pre$phiZ2D = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ac_huff_tbl_ptrs$0$in$i = 0, $dc_huff_tbl_ptrs$0$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(100);
 if (!($2)) {
  $3 = HEAP32[$cinfo>>2]|0;
  $4 = (($3) + 20|0);
  HEAP32[$4>>2] = 20;
  $5 = HEAP32[$0>>2]|0;
  $6 = (($3) + 24|0);
  HEAP32[$6>>2] = $5;
  $7 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$7 & 63]($cinfo);
 }
 $8 = (($cinfo) + 68|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $11 = (($cinfo) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_iiii[$13 & 7]($cinfo,0,840)|0);
  HEAP32[$8>>2] = $14;
  $$pre$phi5Z2D = $cinfo;
 } else {
  $$pre$phi5Z2D = $cinfo;
 }
 $15 = (($cinfo) + 56|0);
 HEAP32[$15>>2] = 8;
 _jpeg_set_linear_quality($cinfo,50,1);
 $16 = (($cinfo) + 16|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17<<24>>24)==(0);
 if ($18) {
  $21 = (($cinfo) + 88|0);
  $22 = (($cinfo) + 104|0);
  $$pre = (($cinfo) + 160|0);
  $$pre2 = (($cinfo) + 176|0);
  $$pre$phi3Z2D = $$pre2;$$pre$phiZ2D = $$pre;$ac_huff_tbl_ptrs$0$in$i = $22;$dc_huff_tbl_ptrs$0$in$i = $21;
 } else {
  $19 = (($cinfo) + 160|0);
  $20 = (($cinfo) + 176|0);
  $$pre$phi3Z2D = $20;$$pre$phiZ2D = $19;$ac_huff_tbl_ptrs$0$in$i = $20;$dc_huff_tbl_ptrs$0$in$i = $19;
 }
 _add_huff_table($$pre$phi5Z2D,$dc_huff_tbl_ptrs$0$in$i,136480,136504);
 _add_huff_table($$pre$phi5Z2D,$ac_huff_tbl_ptrs$0$in$i,136560,136584);
 $23 = (($dc_huff_tbl_ptrs$0$in$i) + 4|0);
 _add_huff_table($$pre$phi5Z2D,$23,136520,136544);
 $24 = (($ac_huff_tbl_ptrs$0$in$i) + 4|0);
 _add_huff_table($$pre$phi5Z2D,$24,136752,136776);
 $25 = (($cinfo) + 120|0);
 HEAP8[$25>>0] = 0;
 $26 = (($cinfo) + 136|0);
 HEAP8[$26>>0] = 1;
 $27 = (($cinfo) + 152|0);
 HEAP8[$27>>0] = 5;
 $28 = (($cinfo) + 121|0);
 HEAP8[$28>>0] = 0;
 $29 = (($cinfo) + 137|0);
 HEAP8[$29>>0] = 1;
 $30 = (($cinfo) + 153|0);
 HEAP8[$30>>0] = 5;
 $31 = (($cinfo) + 122|0);
 HEAP8[$31>>0] = 0;
 $32 = (($cinfo) + 138|0);
 HEAP8[$32>>0] = 1;
 $33 = (($cinfo) + 154|0);
 HEAP8[$33>>0] = 5;
 $34 = (($cinfo) + 123|0);
 HEAP8[$34>>0] = 0;
 $35 = (($cinfo) + 139|0);
 HEAP8[$35>>0] = 1;
 $36 = (($cinfo) + 155|0);
 HEAP8[$36>>0] = 5;
 $37 = (($cinfo) + 124|0);
 HEAP8[$37>>0] = 0;
 $38 = (($cinfo) + 140|0);
 HEAP8[$38>>0] = 1;
 $39 = (($cinfo) + 156|0);
 HEAP8[$39>>0] = 5;
 $40 = (($cinfo) + 125|0);
 HEAP8[$40>>0] = 0;
 $41 = (($cinfo) + 141|0);
 HEAP8[$41>>0] = 1;
 $42 = (($cinfo) + 157|0);
 HEAP8[$42>>0] = 5;
 $43 = (($cinfo) + 126|0);
 HEAP8[$43>>0] = 0;
 $44 = (($cinfo) + 142|0);
 HEAP8[$44>>0] = 1;
 $45 = (($cinfo) + 158|0);
 HEAP8[$45>>0] = 5;
 $46 = (($cinfo) + 127|0);
 HEAP8[$46>>0] = 0;
 $47 = (($cinfo) + 143|0);
 HEAP8[$47>>0] = 1;
 $48 = (($cinfo) + 159|0);
 HEAP8[$48>>0] = 5;
 $49 = (($cinfo) + 128|0);
 HEAP8[$49>>0] = 0;
 $50 = (($cinfo) + 144|0);
 HEAP8[$50>>0] = 1;
 HEAP8[$$pre$phiZ2D>>0] = 5;
 $51 = (($cinfo) + 129|0);
 HEAP8[$51>>0] = 0;
 $52 = (($cinfo) + 145|0);
 HEAP8[$52>>0] = 1;
 $53 = (($cinfo) + 161|0);
 HEAP8[$53>>0] = 5;
 $54 = (($cinfo) + 130|0);
 HEAP8[$54>>0] = 0;
 $55 = (($cinfo) + 146|0);
 HEAP8[$55>>0] = 1;
 $56 = (($cinfo) + 162|0);
 HEAP8[$56>>0] = 5;
 $57 = (($cinfo) + 131|0);
 HEAP8[$57>>0] = 0;
 $58 = (($cinfo) + 147|0);
 HEAP8[$58>>0] = 1;
 $59 = (($cinfo) + 163|0);
 HEAP8[$59>>0] = 5;
 $60 = (($cinfo) + 132|0);
 HEAP8[$60>>0] = 0;
 $61 = (($cinfo) + 148|0);
 HEAP8[$61>>0] = 1;
 $62 = (($cinfo) + 164|0);
 HEAP8[$62>>0] = 5;
 $63 = (($cinfo) + 133|0);
 HEAP8[$63>>0] = 0;
 $64 = (($cinfo) + 149|0);
 HEAP8[$64>>0] = 1;
 $65 = (($cinfo) + 165|0);
 HEAP8[$65>>0] = 5;
 $66 = (($cinfo) + 134|0);
 HEAP8[$66>>0] = 0;
 $67 = (($cinfo) + 150|0);
 HEAP8[$67>>0] = 1;
 $68 = (($cinfo) + 166|0);
 HEAP8[$68>>0] = 5;
 $69 = (($cinfo) + 135|0);
 HEAP8[$69>>0] = 0;
 $70 = (($cinfo) + 151|0);
 HEAP8[$70>>0] = 1;
 $71 = (($cinfo) + 167|0);
 HEAP8[$71>>0] = 5;
 $72 = (($cinfo) + 172|0);
 HEAP32[$72>>2] = 0;
 $73 = (($cinfo) + 168|0);
 HEAP32[$73>>2] = 0;
 HEAP8[$$pre$phi3Z2D>>0] = 0;
 $74 = (($cinfo) + 177|0);
 HEAP8[$74>>0] = 0;
 $75 = (($cinfo) + 316|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + 4120|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ($78|0)==(1560820397);
 $80 = (($cinfo) + 178|0);
 $$ = $79&1;
 $81 = HEAP32[$15>>2]|0;
 $82 = ($81|0)>(8);
 $$$ = $82 ? 1 : $$;
 HEAP8[$80>>0] = $$$;
 $83 = (($cinfo) + 179|0);
 HEAP8[$83>>0] = 0;
 $84 = HEAP32[$77>>2]|0;
 $85 = ($84|0)==(1560820397);
 $86 = $85&1;
 $87 = (($76) + 22|0);
 HEAP8[$87>>0] = $86;
 $88 = (($cinfo) + 180|0);
 $89 = (($cinfo) + 197|0);
 ;HEAP32[$88+0>>2]=0|0;HEAP32[$88+4>>2]=0|0;HEAP32[$88+8>>2]=0|0;HEAP32[$88+12>>2]=0|0;
 HEAP8[$89>>0] = 1;
 $90 = (($cinfo) + 198|0);
 HEAP8[$90>>0] = 1;
 $91 = (($cinfo) + 199|0);
 HEAP8[$91>>0] = 0;
 $92 = (($cinfo) + 200|0);
 HEAP16[$92>>1] = 1;
 $93 = (($cinfo) + 202|0);
 HEAP16[$93>>1] = 1;
 _jpeg_default_colorspace($cinfo);
 $94 = HEAP32[$75>>2]|0;
 $95 = (($94) + 4124|0);
 HEAP32[$95>>2] = 1;
 $96 = (($94) + 4120|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = ($97|0)==(1560820397);
 $99 = (($94) + 14|0);
 if ($98) {
  HEAP8[$99>>0] = 1;
  _jpeg_simple_progression($cinfo);
  $100 = HEAP32[$75>>2]|0;
  $101 = (($100) + 4120|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = ($102|0)==(1560820397);
  $104 = $103&1;
  $105 = (($100) + 15|0);
  HEAP8[$105>>0] = $104;
  $106 = HEAP32[$75>>2]|0;
  $107 = (($106) + 4164|0);
  HEAPF32[$107>>2] = 14.75;
  $108 = (($106) + 4168|0);
  HEAPF32[$108>>2] = 16.5;
  $109 = (($106) + 4120|0);
  $110 = HEAP32[$109>>2]|0;
  $111 = ($110|0)==(1560820397);
  $112 = $111 ? 3 : 0;
  $113 = (($106) + 4128|0);
  HEAP32[$113>>2] = $112;
  $114 = (($106) + 18|0);
  HEAP8[$114>>0] = 1;
  $115 = HEAP32[$75>>2]|0;
  $116 = (($115) + 19|0);
  HEAP8[$116>>0] = 0;
  $117 = HEAP32[$75>>2]|0;
  $118 = (($117) + 4132|0);
  HEAP32[$118>>2] = 8;
  $119 = (($117) + 4136|0);
  HEAP32[$119>>2] = 1;
  $120 = (($117) + 21|0);
  HEAP8[$120>>0] = 0;
  $121 = HEAP32[$75>>2]|0;
  $122 = (($121) + 16|0);
  HEAP8[$122>>0] = 1;
  $123 = HEAP32[$75>>2]|0;
  $124 = (($123) + 4172|0);
  HEAPF32[$124>>2] = 0.0;
  STACKTOP = sp;return;
 } else {
  HEAP8[$99>>0] = 0;
  $100 = HEAP32[$75>>2]|0;
  $101 = (($100) + 4120|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = ($102|0)==(1560820397);
  $104 = $103&1;
  $105 = (($100) + 15|0);
  HEAP8[$105>>0] = $104;
  $106 = HEAP32[$75>>2]|0;
  $107 = (($106) + 4164|0);
  HEAPF32[$107>>2] = 14.75;
  $108 = (($106) + 4168|0);
  HEAPF32[$108>>2] = 16.5;
  $109 = (($106) + 4120|0);
  $110 = HEAP32[$109>>2]|0;
  $111 = ($110|0)==(1560820397);
  $112 = $111 ? 3 : 0;
  $113 = (($106) + 4128|0);
  HEAP32[$113>>2] = $112;
  $114 = (($106) + 18|0);
  HEAP8[$114>>0] = 1;
  $115 = HEAP32[$75>>2]|0;
  $116 = (($115) + 19|0);
  HEAP8[$116>>0] = 0;
  $117 = HEAP32[$75>>2]|0;
  $118 = (($117) + 4132|0);
  HEAP32[$118>>2] = 8;
  $119 = (($117) + 4136|0);
  HEAP32[$119>>2] = 1;
  $120 = (($117) + 21|0);
  HEAP8[$120>>0] = 0;
  $121 = HEAP32[$75>>2]|0;
  $122 = (($121) + 16|0);
  HEAP8[$122>>0] = 1;
  $123 = HEAP32[$75>>2]|0;
  $124 = (($123) + 4172|0);
  HEAPF32[$124>>2] = 0.0;
  STACKTOP = sp;return;
 }
}
function _jpeg_default_colorspace($cinfo) {
 $cinfo = $cinfo|0;
 var $$off$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ci$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 switch ($1|0) {
 case 1:  {
  $2 = (($cinfo) + 20|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(100);
  if (!($4)) {
   $5 = HEAP32[$cinfo>>2]|0;
   $6 = (($5) + 20|0);
   HEAP32[$6>>2] = 20;
   $7 = HEAP32[$2>>2]|0;
   $8 = (($5) + 24|0);
   HEAP32[$8>>2] = $7;
   $9 = HEAP32[$5>>2]|0;
   FUNCTION_TABLE_vi[$9 & 63]($cinfo);
  }
  $10 = (($cinfo) + 64|0);
  HEAP32[$10>>2] = 1;
  $11 = (($cinfo) + 196|0);
  $12 = (($cinfo) + 204|0);
  HEAP8[$12>>0] = 0;
  HEAP8[$11>>0] = 1;
  $13 = (($cinfo) + 60|0);
  HEAP32[$13>>2] = 1;
  $14 = (($cinfo) + 68|0);
  $15 = HEAP32[$14>>2]|0;
  HEAP32[$15>>2] = 1;
  $16 = (($15) + 8|0);
  HEAP32[$16>>2] = 1;
  $17 = (($15) + 12|0);
  HEAP32[$17>>2] = 1;
  $18 = (($15) + 16|0);
  HEAP32[$18>>2] = 0;
  $19 = (($15) + 20|0);
  HEAP32[$19>>2] = 0;
  $20 = (($15) + 24|0);
  HEAP32[$20>>2] = 0;
  STACKTOP = sp;return;
  break;
 }
 case 15: case 14: case 13: case 12: case 11: case 10: case 9: case 8: case 7: case 6: case 2:  {
  $21 = (($cinfo) + 20|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(100);
  if (!($23)) {
   $24 = HEAP32[$cinfo>>2]|0;
   $25 = (($24) + 20|0);
   HEAP32[$25>>2] = 20;
   $26 = HEAP32[$21>>2]|0;
   $27 = (($24) + 24|0);
   HEAP32[$27>>2] = $26;
   $28 = HEAP32[$24>>2]|0;
   FUNCTION_TABLE_vi[$28 & 63]($cinfo);
  }
  $29 = (($cinfo) + 64|0);
  HEAP32[$29>>2] = 3;
  $30 = (($cinfo) + 196|0);
  $31 = (($cinfo) + 204|0);
  HEAP8[$31>>0] = 0;
  HEAP8[$30>>0] = 1;
  $32 = (($cinfo) + 60|0);
  HEAP32[$32>>2] = 3;
  $33 = (($cinfo) + 68|0);
  $34 = HEAP32[$33>>2]|0;
  HEAP32[$34>>2] = 1;
  $35 = (($34) + 8|0);
  HEAP32[$35>>2] = 2;
  $36 = (($34) + 12|0);
  HEAP32[$36>>2] = 2;
  $37 = (($34) + 16|0);
  HEAP32[$37>>2] = 0;
  $38 = (($34) + 20|0);
  HEAP32[$38>>2] = 0;
  $39 = (($34) + 24|0);
  HEAP32[$39>>2] = 0;
  $40 = (($34) + 84|0);
  HEAP32[$40>>2] = 2;
  $41 = (($34) + 92|0);
  HEAP32[$41>>2] = 1;
  $42 = (($34) + 96|0);
  HEAP32[$42>>2] = 1;
  $43 = (($34) + 100|0);
  HEAP32[$43>>2] = 1;
  $44 = (($34) + 104|0);
  HEAP32[$44>>2] = 1;
  $45 = (($34) + 108|0);
  HEAP32[$45>>2] = 1;
  $46 = (($34) + 168|0);
  HEAP32[$46>>2] = 3;
  $47 = (($34) + 176|0);
  HEAP32[$47>>2] = 1;
  $48 = (($34) + 180|0);
  HEAP32[$48>>2] = 1;
  $49 = (($34) + 184|0);
  HEAP32[$49>>2] = 1;
  $50 = (($34) + 188|0);
  HEAP32[$50>>2] = 1;
  $51 = (($34) + 192|0);
  HEAP32[$51>>2] = 1;
  STACKTOP = sp;return;
  break;
 }
 case 5:  {
  $120 = (($cinfo) + 20|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = ($121|0)==(100);
  if (!($122)) {
   $123 = HEAP32[$cinfo>>2]|0;
   $124 = (($123) + 20|0);
   HEAP32[$124>>2] = 20;
   $125 = HEAP32[$120>>2]|0;
   $126 = (($123) + 24|0);
   HEAP32[$126>>2] = $125;
   $127 = HEAP32[$123>>2]|0;
   FUNCTION_TABLE_vi[$127 & 63]($cinfo);
  }
  $128 = (($cinfo) + 64|0);
  HEAP32[$128>>2] = 5;
  $129 = (($cinfo) + 196|0);
  HEAP8[$129>>0] = 0;
  $130 = (($cinfo) + 204|0);
  HEAP8[$130>>0] = 1;
  $131 = (($cinfo) + 60|0);
  HEAP32[$131>>2] = 4;
  $132 = (($cinfo) + 68|0);
  $133 = HEAP32[$132>>2]|0;
  HEAP32[$133>>2] = 1;
  $134 = (($133) + 8|0);
  HEAP32[$134>>2] = 2;
  $135 = (($133) + 12|0);
  HEAP32[$135>>2] = 2;
  $136 = (($133) + 16|0);
  HEAP32[$136>>2] = 0;
  $137 = (($133) + 20|0);
  HEAP32[$137>>2] = 0;
  $138 = (($133) + 24|0);
  HEAP32[$138>>2] = 0;
  $139 = (($133) + 84|0);
  HEAP32[$139>>2] = 2;
  $140 = (($133) + 92|0);
  HEAP32[$140>>2] = 1;
  $141 = (($133) + 96|0);
  HEAP32[$141>>2] = 1;
  $142 = (($133) + 100|0);
  HEAP32[$142>>2] = 1;
  $143 = (($133) + 104|0);
  HEAP32[$143>>2] = 1;
  $144 = (($133) + 108|0);
  HEAP32[$144>>2] = 1;
  $145 = (($133) + 168|0);
  HEAP32[$145>>2] = 3;
  $146 = (($133) + 176|0);
  HEAP32[$146>>2] = 1;
  $147 = (($133) + 180|0);
  HEAP32[$147>>2] = 1;
  $148 = (($133) + 184|0);
  HEAP32[$148>>2] = 1;
  $149 = (($133) + 188|0);
  HEAP32[$149>>2] = 1;
  $150 = (($133) + 192|0);
  HEAP32[$150>>2] = 1;
  $151 = (($133) + 252|0);
  HEAP32[$151>>2] = 4;
  $152 = (($133) + 260|0);
  HEAP32[$152>>2] = 2;
  $153 = (($133) + 264|0);
  HEAP32[$153>>2] = 2;
  $154 = (($133) + 268|0);
  HEAP32[$154>>2] = 0;
  $155 = (($133) + 272|0);
  HEAP32[$155>>2] = 0;
  $156 = (($133) + 276|0);
  HEAP32[$156>>2] = 0;
  STACKTOP = sp;return;
  break;
 }
 case 4:  {
  $83 = (($cinfo) + 20|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = ($84|0)==(100);
  if (!($85)) {
   $86 = HEAP32[$cinfo>>2]|0;
   $87 = (($86) + 20|0);
   HEAP32[$87>>2] = 20;
   $88 = HEAP32[$83>>2]|0;
   $89 = (($86) + 24|0);
   HEAP32[$89>>2] = $88;
   $90 = HEAP32[$86>>2]|0;
   FUNCTION_TABLE_vi[$90 & 63]($cinfo);
  }
  $91 = (($cinfo) + 64|0);
  HEAP32[$91>>2] = 4;
  $92 = (($cinfo) + 196|0);
  HEAP8[$92>>0] = 0;
  $93 = (($cinfo) + 204|0);
  HEAP8[$93>>0] = 1;
  $94 = (($cinfo) + 60|0);
  HEAP32[$94>>2] = 4;
  $95 = (($cinfo) + 68|0);
  $96 = HEAP32[$95>>2]|0;
  HEAP32[$96>>2] = 67;
  $97 = (($96) + 8|0);
  HEAP32[$97>>2] = 1;
  $98 = (($96) + 12|0);
  HEAP32[$98>>2] = 1;
  $99 = (($96) + 16|0);
  HEAP32[$99>>2] = 0;
  $100 = (($96) + 20|0);
  HEAP32[$100>>2] = 0;
  $101 = (($96) + 24|0);
  HEAP32[$101>>2] = 0;
  $102 = (($96) + 84|0);
  HEAP32[$102>>2] = 77;
  $103 = (($96) + 92|0);
  HEAP32[$103>>2] = 1;
  $104 = (($96) + 96|0);
  HEAP32[$104>>2] = 1;
  $105 = (($96) + 100|0);
  HEAP32[$105>>2] = 0;
  $106 = (($96) + 104|0);
  HEAP32[$106>>2] = 0;
  $107 = (($96) + 108|0);
  HEAP32[$107>>2] = 0;
  $108 = (($96) + 168|0);
  HEAP32[$108>>2] = 89;
  $109 = (($96) + 176|0);
  HEAP32[$109>>2] = 1;
  $110 = (($96) + 180|0);
  HEAP32[$110>>2] = 1;
  $111 = (($96) + 184|0);
  HEAP32[$111>>2] = 0;
  $112 = (($96) + 188|0);
  HEAP32[$112>>2] = 0;
  $113 = (($96) + 192|0);
  HEAP32[$113>>2] = 0;
  $114 = (($96) + 252|0);
  HEAP32[$114>>2] = 75;
  $115 = (($96) + 260|0);
  HEAP32[$115>>2] = 1;
  $116 = (($96) + 264|0);
  HEAP32[$116>>2] = 1;
  $117 = (($96) + 268|0);
  HEAP32[$117>>2] = 0;
  $118 = (($96) + 272|0);
  HEAP32[$118>>2] = 0;
  $119 = (($96) + 276|0);
  HEAP32[$119>>2] = 0;
  STACKTOP = sp;return;
  break;
 }
 case 0:  {
  $157 = (($cinfo) + 20|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = ($158|0)==(100);
  if (!($159)) {
   $160 = HEAP32[$cinfo>>2]|0;
   $161 = (($160) + 20|0);
   HEAP32[$161>>2] = 20;
   $162 = HEAP32[$157>>2]|0;
   $163 = (($160) + 24|0);
   HEAP32[$163>>2] = $162;
   $164 = HEAP32[$160>>2]|0;
   FUNCTION_TABLE_vi[$164 & 63]($cinfo);
  }
  $165 = (($cinfo) + 64|0);
  HEAP32[$165>>2] = 0;
  $166 = (($cinfo) + 196|0);
  HEAP8[$166>>0] = 0;
  $167 = (($cinfo) + 204|0);
  HEAP8[$167>>0] = 0;
  $168 = (($cinfo) + 36|0);
  $169 = HEAP32[$168>>2]|0;
  $170 = (($cinfo) + 60|0);
  HEAP32[$170>>2] = $169;
  $$off$i = (($169) + -1)|0;
  $171 = ($$off$i>>>0)>(9);
  if ($171) {
   $172 = HEAP32[$cinfo>>2]|0;
   $173 = (($172) + 20|0);
   HEAP32[$173>>2] = 26;
   $174 = HEAP32[$170>>2]|0;
   $175 = (($172) + 24|0);
   HEAP32[$175>>2] = $174;
   $176 = (($172) + 28|0);
   HEAP32[$176>>2] = 10;
   $177 = HEAP32[$172>>2]|0;
   FUNCTION_TABLE_vi[$177 & 63]($cinfo);
   $$pre$i = HEAP32[$170>>2]|0;
   $178 = $$pre$i;
  } else {
   $178 = $169;
  }
  $179 = ($178|0)>(0);
  if (!($179)) {
   STACKTOP = sp;return;
  }
  $180 = (($cinfo) + 68|0);
  $181 = HEAP32[$180>>2]|0;
  $ci$01$i = 0;
  while(1) {
   $182 = (($181) + (($ci$01$i*84)|0)|0);
   HEAP32[$182>>2] = $ci$01$i;
   $183 = ((($181) + (($ci$01$i*84)|0)|0) + 8|0);
   HEAP32[$183>>2] = 1;
   $184 = ((($181) + (($ci$01$i*84)|0)|0) + 12|0);
   HEAP32[$184>>2] = 1;
   $185 = ((($181) + (($ci$01$i*84)|0)|0) + 16|0);
   HEAP32[$185>>2] = 0;
   $186 = ((($181) + (($ci$01$i*84)|0)|0) + 20|0);
   HEAP32[$186>>2] = 0;
   $187 = ((($181) + (($ci$01$i*84)|0)|0) + 24|0);
   HEAP32[$187>>2] = 0;
   $188 = (($ci$01$i) + 1)|0;
   $189 = HEAP32[$170>>2]|0;
   $190 = ($188|0)<($189|0);
   if ($190) {
    $ci$01$i = $188;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 3:  {
  $52 = (($cinfo) + 20|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(100);
  if (!($54)) {
   $55 = HEAP32[$cinfo>>2]|0;
   $56 = (($55) + 20|0);
   HEAP32[$56>>2] = 20;
   $57 = HEAP32[$52>>2]|0;
   $58 = (($55) + 24|0);
   HEAP32[$58>>2] = $57;
   $59 = HEAP32[$55>>2]|0;
   FUNCTION_TABLE_vi[$59 & 63]($cinfo);
  }
  $60 = (($cinfo) + 64|0);
  HEAP32[$60>>2] = 3;
  $61 = (($cinfo) + 196|0);
  $62 = (($cinfo) + 204|0);
  HEAP8[$62>>0] = 0;
  HEAP8[$61>>0] = 1;
  $63 = (($cinfo) + 60|0);
  HEAP32[$63>>2] = 3;
  $64 = (($cinfo) + 68|0);
  $65 = HEAP32[$64>>2]|0;
  HEAP32[$65>>2] = 1;
  $66 = (($65) + 8|0);
  HEAP32[$66>>2] = 2;
  $67 = (($65) + 12|0);
  HEAP32[$67>>2] = 2;
  $68 = (($65) + 16|0);
  HEAP32[$68>>2] = 0;
  $69 = (($65) + 20|0);
  HEAP32[$69>>2] = 0;
  $70 = (($65) + 24|0);
  HEAP32[$70>>2] = 0;
  $71 = (($65) + 84|0);
  HEAP32[$71>>2] = 2;
  $72 = (($65) + 92|0);
  HEAP32[$72>>2] = 1;
  $73 = (($65) + 96|0);
  HEAP32[$73>>2] = 1;
  $74 = (($65) + 100|0);
  HEAP32[$74>>2] = 1;
  $75 = (($65) + 104|0);
  HEAP32[$75>>2] = 1;
  $76 = (($65) + 108|0);
  HEAP32[$76>>2] = 1;
  $77 = (($65) + 168|0);
  HEAP32[$77>>2] = 3;
  $78 = (($65) + 176|0);
  HEAP32[$78>>2] = 1;
  $79 = (($65) + 180|0);
  HEAP32[$79>>2] = 1;
  $80 = (($65) + 184|0);
  HEAP32[$80>>2] = 1;
  $81 = (($65) + 188|0);
  HEAP32[$81>>2] = 1;
  $82 = (($65) + 192|0);
  HEAP32[$82>>2] = 1;
  STACKTOP = sp;return;
  break;
 }
 default: {
  $191 = HEAP32[$cinfo>>2]|0;
  $192 = (($191) + 20|0);
  HEAP32[$192>>2] = 9;
  $193 = HEAP32[$191>>2]|0;
  FUNCTION_TABLE_vi[$193 & 63]($cinfo);
  STACKTOP = sp;return;
 }
 }
}
function _jpeg_simple_progression($cinfo) {
 $cinfo = $cinfo|0;
 var $$0$i19 = 0, $$0$i55 = 0, $$0$i99 = 0, $$0$lcssa$i27 = 0, $$01$i = 0, $$01$i$i$i = 0, $$01$i$i14 = 0, $$01$i$i50 = 0, $$01$i$i94 = 0, $$01$i22 = 0, $$01$i30 = 0, $$01$i38 = 0, $$01$i58 = 0, $$01$i66 = 0, $$01$i74 = 0, $$01$i82 = 0, $$lcssa$i = 0, $$lcssa25$i = 0, $$pre = 0, $$pre$i = 0;
 var $$pre$phiZ2D = 0, $$pre146 = 0, $$sink$lcssa$i = 0, $$sink$pn$lcssa$i = 0, $$sink$pn16$i = 0, $$sink$pn16$i$phi = 0, $$sink26$i = 0, $$sink7$lcssa$i = 0, $$sink710$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0;
 var $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0;
 var $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0;
 var $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0;
 var $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0;
 var $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0;
 var $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0;
 var $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0;
 var $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0;
 var $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0;
 var $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0;
 var $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0;
 var $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $Al$027$i = 0, $Al$111$i = 0, $ci$01$i = 0, $ci$01$i$i = 0, $ci$01$i101 = 0, $ci$01$i113 = 0, $ci$01$i45 = 0, $ci$01$i89 = 0, $ci$01$i9 = 0, $ci$02$i = 0, $ci$02$i$i$i = 0, $ci$02$i$i13 = 0, $ci$02$i$i49 = 0, $ci$02$i$i93 = 0;
 var $ci$02$i21 = 0, $ci$02$i29 = 0, $ci$02$i37 = 0, $ci$02$i57 = 0, $ci$02$i65 = 0, $ci$02$i73 = 0, $ci$02$i81 = 0, $exitcond$i = 0, $exitcond$i$i = 0, $exitcond$i$i$i = 0, $exitcond$i$i15 = 0, $exitcond$i$i51 = 0, $exitcond$i$i95 = 0, $exitcond$i10 = 0, $exitcond$i102 = 0, $exitcond$i114 = 0, $exitcond$i23 = 0, $exitcond$i31 = 0, $exitcond$i39 = 0, $exitcond$i46 = 0;
 var $exitcond$i59 = 0, $exitcond$i6 = 0, $exitcond$i67 = 0, $exitcond$i75 = 0, $exitcond$i83 = 0, $exitcond$i90 = 0, $i$017$i = 0, $i$19$i = 0, $nscans$0 = 0, $nscans$0$i = 0, $scanptr$0 = 0, $scanptr$0$i = 0, $scanptr$2$i = 0, $scanptr$2$lcssa$i = 0, $scanptr$215$i = 0, $scanptr$218$i = 0, $scanptr$48$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i17 = 0, $scevgep$i$i53 = 0;
 var $scevgep$i$i97 = 0, $scevgep$i25 = 0, $scevgep$i33 = 0, $scevgep$i33$sum = 0, $scevgep$i41 = 0, $scevgep$i41$sum = 0, $scevgep$i69 = 0, $scevgep$i77 = 0, $scevgep$i77$sum = 0, $scevgep$i85 = 0, $scevgep$i85$sum = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 316|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 14|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 do {
  if ($4) {
   $$pre = (($cinfo) + 20|0);
   $$pre$phiZ2D = $$pre;
  } else {
   $5 = (($cinfo) + 60|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($cinfo) + 20|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(100);
   if (!($9)) {
    $10 = HEAP32[$cinfo>>2]|0;
    $11 = (($10) + 20|0);
    HEAP32[$11>>2] = 20;
    $12 = HEAP32[$7>>2]|0;
    $13 = (($10) + 24|0);
    HEAP32[$13>>2] = $12;
    $14 = HEAP32[$10>>2]|0;
    FUNCTION_TABLE_vi[$14 & 63]($cinfo);
   }
   if ((($6|0) == 3)) {
    $15 = (($cinfo) + 64|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(3);
    if ($17) {
     $nscans$0$i = 64;
    } else {
     label = 29;
    }
   } else if ((($6|0) == 1)) {
    $nscans$0$i = 23;
   } else {
    label = 29;
   }
   if ((label|0) == 29) {
    $238 = HEAP32[$0>>2]|0;
    $239 = (($238) + 4140|0);
    HEAP32[$239>>2] = 0;
    $$pre$phiZ2D = $7;
    break;
   }
   $18 = (($cinfo) + 352|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0|0);
   $$pre$i = (($cinfo) + 356|0);
   if ($20) {
    label = 9;
   } else {
    $21 = HEAP32[$$pre$i>>2]|0;
    $22 = ($21|0)<($nscans$0$i|0);
    if ($22) {
     label = 9;
    } else {
     $28 = $19;
    }
   }
   if ((label|0) == 9) {
    HEAP32[$$pre$i>>2] = 64;
    $23 = (($cinfo) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = HEAP32[$24>>2]|0;
    $26 = (FUNCTION_TABLE_iiii[$25 & 7]($cinfo,0,2304)|0);
    HEAP32[$18>>2] = $26;
    $28 = $26;
   }
   $27 = (($cinfo) + 172|0);
   HEAP32[$27>>2] = $28;
   $29 = (($cinfo) + 168|0);
   HEAP32[$29>>2] = $nscans$0$i;
   $30 = HEAP32[$0>>2]|0;
   $31 = (($30) + 4156|0);
   HEAP32[$31>>2] = 3;
   $32 = (($30) + 4144|0);
   HEAP32[$32>>2] = 1;
   $33 = (($30) + 4152|0);
   HEAP32[$33>>2] = 5;
   $34 = (($30) + 4140|0);
   HEAP32[$34>>2] = 23;
   $35 = (($30) + 4124|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==(0);
   do {
    if ($37) {
     $38 = ($6|0)<(5);
     if (!($38)) {
      $$01$i$i$i = $28;$ci$02$i$i$i = 0;
      while(1) {
       HEAP32[$$01$i$i$i>>2] = 1;
       $44 = (($$01$i$i$i) + 4|0);
       HEAP32[$44>>2] = $ci$02$i$i$i;
       $45 = (($$01$i$i$i) + 20|0);
       $46 = (($$01$i$i$i) + 36|0);
       $47 = (($ci$02$i$i$i) + 1)|0;
       $exitcond$i$i$i = ($47|0)==($6|0);
       ;HEAP32[$45+0>>2]=0|0;HEAP32[$45+4>>2]=0|0;HEAP32[$45+8>>2]=0|0;HEAP32[$45+12>>2]=0|0;
       if ($exitcond$i$i$i) {
        break;
       } else {
        $$01$i$i$i = $46;$ci$02$i$i$i = $47;
       }
      }
      $scevgep$i$i$i = (($28) + (($6*36)|0)|0);
      $scanptr$0$i = $scevgep$i$i$i;
      break;
     }
     HEAP32[$28>>2] = $6;
     $39 = ($6|0)>(0);
     if ($39) {
      $ci$01$i$i = 0;
      while(1) {
       $40 = ((($28) + ($ci$01$i$i<<2)|0) + 4|0);
       HEAP32[$40>>2] = $ci$01$i$i;
       $41 = (($ci$01$i$i) + 1)|0;
       $exitcond$i$i = ($41|0)==($6|0);
       if ($exitcond$i$i) {
        break;
       } else {
        $ci$01$i$i = $41;
       }
      }
     }
     $42 = (($28) + 20|0);
     $43 = (($28) + 36|0);
     ;HEAP32[$42+0>>2]=0|0;HEAP32[$42+4>>2]=0|0;HEAP32[$42+8>>2]=0|0;HEAP32[$42+12>>2]=0|0;
     $scanptr$0$i = $43;
    } else {
     HEAP32[$28>>2] = 1;
     $48 = (($28) + 4|0);
     HEAP32[$48>>2] = 0;
     $49 = (($28) + 20|0);
     $50 = (($28) + 36|0);
     ;HEAP32[$49+0>>2]=0|0;HEAP32[$49+4>>2]=0|0;HEAP32[$49+8>>2]=0|0;HEAP32[$49+12>>2]=0|0;
     $scanptr$0$i = $50;
    }
   } while(0);
   HEAP32[$scanptr$0$i>>2] = 1;
   $51 = (($scanptr$0$i) + 4|0);
   HEAP32[$51>>2] = 0;
   $52 = (($scanptr$0$i) + 20|0);
   HEAP32[$52>>2] = 1;
   $53 = (($scanptr$0$i) + 24|0);
   HEAP32[$53>>2] = 8;
   $54 = (($scanptr$0$i) + 28|0);
   HEAP32[$54>>2] = 0;
   $55 = (($scanptr$0$i) + 32|0);
   HEAP32[$55>>2] = 0;
   $56 = (($scanptr$0$i) + 36|0);
   HEAP32[$56>>2] = 1;
   $57 = (($scanptr$0$i) + 40|0);
   HEAP32[$57>>2] = 0;
   $58 = (($scanptr$0$i) + 56|0);
   HEAP32[$58>>2] = 9;
   $59 = (($scanptr$0$i) + 60|0);
   HEAP32[$59>>2] = 63;
   $60 = (($scanptr$0$i) + 64|0);
   HEAP32[$60>>2] = 0;
   $61 = (($scanptr$0$i) + 68|0);
   HEAP32[$61>>2] = 0;
   $62 = (($scanptr$0$i) + 72|0);
   $63 = HEAP32[$31>>2]|0;
   $64 = ($63|0)>(0);
   if ($64) {
    $$sink26$i = $56;$66 = $62;$Al$027$i = 0;
    while(1) {
     $65 = (($Al$027$i) + 1)|0;
     HEAP32[$66>>2] = 1;
     $67 = (($$sink26$i) + 40|0);
     HEAP32[$67>>2] = 0;
     $68 = (($$sink26$i) + 56|0);
     HEAP32[$68>>2] = 1;
     $69 = (($$sink26$i) + 60|0);
     HEAP32[$69>>2] = 63;
     $70 = (($$sink26$i) + 64|0);
     HEAP32[$70>>2] = $65;
     $71 = (($$sink26$i) + 68|0);
     HEAP32[$71>>2] = $Al$027$i;
     $72 = (($$sink26$i) + 72|0);
     HEAP32[$72>>2] = 1;
     $73 = (($$sink26$i) + 76|0);
     HEAP32[$73>>2] = 0;
     $74 = (($$sink26$i) + 92|0);
     HEAP32[$74>>2] = 1;
     $75 = (($$sink26$i) + 96|0);
     HEAP32[$75>>2] = 8;
     $76 = (($$sink26$i) + 100|0);
     HEAP32[$76>>2] = 0;
     $77 = (($$sink26$i) + 104|0);
     HEAP32[$77>>2] = $65;
     $78 = (($$sink26$i) + 108|0);
     HEAP32[$78>>2] = 1;
     $79 = (($$sink26$i) + 112|0);
     HEAP32[$79>>2] = 0;
     $80 = (($$sink26$i) + 128|0);
     HEAP32[$80>>2] = 9;
     $81 = (($$sink26$i) + 132|0);
     HEAP32[$81>>2] = 63;
     $82 = (($$sink26$i) + 136|0);
     HEAP32[$82>>2] = 0;
     $83 = (($$sink26$i) + 140|0);
     HEAP32[$83>>2] = $65;
     $84 = (($$sink26$i) + 144|0);
     $85 = HEAP32[$31>>2]|0;
     $86 = ($65|0)<($85|0);
     if ($86) {
      $$sink26$i = $78;$66 = $84;$Al$027$i = $65;
     } else {
      $$lcssa25$i = $84;$$sink$lcssa$i = $78;
      break;
     }
    }
   } else {
    $$lcssa25$i = $62;$$sink$lcssa$i = $56;
   }
   HEAP32[$$lcssa25$i>>2] = 1;
   $87 = (($$sink$lcssa$i) + 40|0);
   HEAP32[$87>>2] = 0;
   $88 = (($$sink$lcssa$i) + 56|0);
   HEAP32[$88>>2] = 1;
   $89 = (($$sink$lcssa$i) + 60|0);
   HEAP32[$89>>2] = 63;
   $90 = (($$sink$lcssa$i) + 64|0);
   HEAP32[$90>>2] = 0;
   $91 = (($$sink$lcssa$i) + 68|0);
   HEAP32[$91>>2] = 0;
   $scanptr$215$i = (($$sink$lcssa$i) + 72|0);
   $92 = HEAP32[$33>>2]|0;
   $93 = ($92|0)>(0);
   if ($93) {
    $$sink$pn16$i = $$sink$lcssa$i;$i$017$i = 0;$scanptr$218$i = $scanptr$215$i;
    while(1) {
     $94 = (136456 + ($i$017$i<<2)|0);
     $95 = HEAP32[$94>>2]|0;
     HEAP32[$scanptr$218$i>>2] = 1;
     $96 = (($$sink$pn16$i) + 76|0);
     HEAP32[$96>>2] = 0;
     $97 = (($$sink$pn16$i) + 92|0);
     HEAP32[$97>>2] = 1;
     $98 = (($$sink$pn16$i) + 96|0);
     HEAP32[$98>>2] = $95;
     $99 = (($$sink$pn16$i) + 100|0);
     HEAP32[$99>>2] = 0;
     $100 = (($$sink$pn16$i) + 104|0);
     HEAP32[$100>>2] = 0;
     $101 = (($95) + 1)|0;
     $102 = (($$sink$pn16$i) + 108|0);
     HEAP32[$102>>2] = 1;
     $103 = (($$sink$pn16$i) + 112|0);
     HEAP32[$103>>2] = 0;
     $104 = (($$sink$pn16$i) + 128|0);
     HEAP32[$104>>2] = $101;
     $105 = (($$sink$pn16$i) + 132|0);
     HEAP32[$105>>2] = 63;
     $106 = (($$sink$pn16$i) + 136|0);
     HEAP32[$106>>2] = 0;
     $107 = (($$sink$pn16$i) + 140|0);
     HEAP32[$107>>2] = 0;
     $108 = (($i$017$i) + 1)|0;
     $scanptr$2$i = (($scanptr$218$i) + 72|0);
     $109 = HEAP32[$33>>2]|0;
     $110 = ($108|0)<($109|0);
     if ($110) {
      $$sink$pn16$i$phi = $scanptr$218$i;$i$017$i = $108;$scanptr$218$i = $scanptr$2$i;$$sink$pn16$i = $$sink$pn16$i$phi;
     } else {
      $$sink$pn$lcssa$i = $scanptr$218$i;$scanptr$2$lcssa$i = $scanptr$2$i;
      break;
     }
    }
   } else {
    $$sink$pn$lcssa$i = $$sink$lcssa$i;$scanptr$2$lcssa$i = $scanptr$215$i;
   }
   $111 = ($6|0)==(1);
   $112 = (($30) + 4160|0);
   if ($111) {
    HEAP32[$112>>2] = 0;
    $113 = (($30) + 4148|0);
    HEAP32[$113>>2] = 0;
    STACKTOP = sp;return;
   }
   HEAP32[$112>>2] = 2;
   $114 = (($30) + 4148|0);
   HEAP32[$114>>2] = 3;
   HEAP32[$scanptr$2$lcssa$i>>2] = 2;
   $115 = (($$sink$pn$lcssa$i) + 76|0);
   HEAP32[$115>>2] = 1;
   $116 = (($$sink$pn$lcssa$i) + 80|0);
   HEAP32[$116>>2] = 2;
   $117 = (($$sink$pn$lcssa$i) + 92|0);
   ;HEAP32[$117+0>>2]=0|0;HEAP32[$117+4>>2]=0|0;HEAP32[$117+8>>2]=0|0;HEAP32[$117+12>>2]=0|0;
   $118 = (($$sink$pn$lcssa$i) + 108|0);
   HEAP32[$118>>2] = 1;
   $119 = (($$sink$pn$lcssa$i) + 112|0);
   HEAP32[$119>>2] = 1;
   $120 = (($$sink$pn$lcssa$i) + 128|0);
   $121 = (($$sink$pn$lcssa$i) + 144|0);
   ;HEAP32[$120+0>>2]=0|0;HEAP32[$120+4>>2]=0|0;HEAP32[$120+8>>2]=0|0;HEAP32[$120+12>>2]=0|0;
   HEAP32[$121>>2] = 1;
   $122 = (($$sink$pn$lcssa$i) + 148|0);
   HEAP32[$122>>2] = 2;
   $123 = (($$sink$pn$lcssa$i) + 164|0);
   $124 = (($$sink$pn$lcssa$i) + 180|0);
   ;HEAP32[$123+0>>2]=0|0;HEAP32[$123+4>>2]=0|0;HEAP32[$123+8>>2]=0|0;HEAP32[$123+12>>2]=0|0;
   HEAP32[$124>>2] = 1;
   $125 = (($$sink$pn$lcssa$i) + 184|0);
   HEAP32[$125>>2] = 1;
   $126 = (($$sink$pn$lcssa$i) + 200|0);
   HEAP32[$126>>2] = 1;
   $127 = (($$sink$pn$lcssa$i) + 204|0);
   HEAP32[$127>>2] = 8;
   $128 = (($$sink$pn$lcssa$i) + 208|0);
   HEAP32[$128>>2] = 0;
   $129 = (($$sink$pn$lcssa$i) + 212|0);
   HEAP32[$129>>2] = 0;
   $130 = (($$sink$pn$lcssa$i) + 216|0);
   HEAP32[$130>>2] = 1;
   $131 = (($$sink$pn$lcssa$i) + 220|0);
   HEAP32[$131>>2] = 1;
   $132 = (($$sink$pn$lcssa$i) + 236|0);
   HEAP32[$132>>2] = 9;
   $133 = (($$sink$pn$lcssa$i) + 240|0);
   HEAP32[$133>>2] = 63;
   $134 = (($$sink$pn$lcssa$i) + 244|0);
   HEAP32[$134>>2] = 0;
   $135 = (($$sink$pn$lcssa$i) + 248|0);
   HEAP32[$135>>2] = 0;
   $136 = (($$sink$pn$lcssa$i) + 252|0);
   HEAP32[$136>>2] = 1;
   $137 = (($$sink$pn$lcssa$i) + 256|0);
   HEAP32[$137>>2] = 2;
   $138 = (($$sink$pn$lcssa$i) + 272|0);
   HEAP32[$138>>2] = 1;
   $139 = (($$sink$pn$lcssa$i) + 276|0);
   HEAP32[$139>>2] = 8;
   $140 = (($$sink$pn$lcssa$i) + 280|0);
   HEAP32[$140>>2] = 0;
   $141 = (($$sink$pn$lcssa$i) + 284|0);
   HEAP32[$141>>2] = 0;
   $142 = (($$sink$pn$lcssa$i) + 288|0);
   HEAP32[$142>>2] = 1;
   $143 = (($$sink$pn$lcssa$i) + 292|0);
   HEAP32[$143>>2] = 2;
   $144 = (($$sink$pn$lcssa$i) + 308|0);
   HEAP32[$144>>2] = 9;
   $145 = (($$sink$pn$lcssa$i) + 312|0);
   HEAP32[$145>>2] = 63;
   $146 = (($$sink$pn$lcssa$i) + 316|0);
   HEAP32[$146>>2] = 0;
   $147 = (($$sink$pn$lcssa$i) + 320|0);
   HEAP32[$147>>2] = 0;
   $148 = (($$sink$pn$lcssa$i) + 324|0);
   $149 = HEAP32[$0>>2]|0;
   $150 = (($149) + 4160|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = ($151|0)>(0);
   if ($152) {
    $$sink710$i = $142;$154 = $148;$Al$111$i = 0;
    while(1) {
     $153 = (($Al$111$i) + 1)|0;
     HEAP32[$154>>2] = 1;
     $155 = (($$sink710$i) + 40|0);
     HEAP32[$155>>2] = 1;
     $156 = (($$sink710$i) + 56|0);
     HEAP32[$156>>2] = 1;
     $157 = (($$sink710$i) + 60|0);
     HEAP32[$157>>2] = 63;
     $158 = (($$sink710$i) + 64|0);
     HEAP32[$158>>2] = $153;
     $159 = (($$sink710$i) + 68|0);
     HEAP32[$159>>2] = $Al$111$i;
     $160 = (($$sink710$i) + 72|0);
     HEAP32[$160>>2] = 1;
     $161 = (($$sink710$i) + 76|0);
     HEAP32[$161>>2] = 2;
     $162 = (($$sink710$i) + 92|0);
     HEAP32[$162>>2] = 1;
     $163 = (($$sink710$i) + 96|0);
     HEAP32[$163>>2] = 63;
     $164 = (($$sink710$i) + 100|0);
     HEAP32[$164>>2] = $153;
     $165 = (($$sink710$i) + 104|0);
     HEAP32[$165>>2] = $Al$111$i;
     $166 = (($$sink710$i) + 108|0);
     HEAP32[$166>>2] = 1;
     $167 = (($$sink710$i) + 112|0);
     HEAP32[$167>>2] = 1;
     $168 = (($$sink710$i) + 128|0);
     HEAP32[$168>>2] = 1;
     $169 = (($$sink710$i) + 132|0);
     HEAP32[$169>>2] = 8;
     $170 = (($$sink710$i) + 136|0);
     HEAP32[$170>>2] = 0;
     $171 = (($$sink710$i) + 140|0);
     HEAP32[$171>>2] = $153;
     $172 = (($$sink710$i) + 144|0);
     HEAP32[$172>>2] = 1;
     $173 = (($$sink710$i) + 148|0);
     HEAP32[$173>>2] = 1;
     $174 = (($$sink710$i) + 164|0);
     HEAP32[$174>>2] = 9;
     $175 = (($$sink710$i) + 168|0);
     HEAP32[$175>>2] = 63;
     $176 = (($$sink710$i) + 172|0);
     HEAP32[$176>>2] = 0;
     $177 = (($$sink710$i) + 176|0);
     HEAP32[$177>>2] = $153;
     $178 = (($$sink710$i) + 180|0);
     HEAP32[$178>>2] = 1;
     $179 = (($$sink710$i) + 184|0);
     HEAP32[$179>>2] = 2;
     $180 = (($$sink710$i) + 200|0);
     HEAP32[$180>>2] = 1;
     $181 = (($$sink710$i) + 204|0);
     HEAP32[$181>>2] = 8;
     $182 = (($$sink710$i) + 208|0);
     HEAP32[$182>>2] = 0;
     $183 = (($$sink710$i) + 212|0);
     HEAP32[$183>>2] = $153;
     $184 = (($$sink710$i) + 216|0);
     HEAP32[$184>>2] = 1;
     $185 = (($$sink710$i) + 220|0);
     HEAP32[$185>>2] = 2;
     $186 = (($$sink710$i) + 236|0);
     HEAP32[$186>>2] = 9;
     $187 = (($$sink710$i) + 240|0);
     HEAP32[$187>>2] = 63;
     $188 = (($$sink710$i) + 244|0);
     HEAP32[$188>>2] = 0;
     $189 = (($$sink710$i) + 248|0);
     HEAP32[$189>>2] = $153;
     $190 = (($$sink710$i) + 252|0);
     $191 = HEAP32[$150>>2]|0;
     $192 = ($153|0)<($191|0);
     if ($192) {
      $$sink710$i = $184;$154 = $190;$Al$111$i = $153;
     } else {
      $$lcssa$i = $190;$$sink7$lcssa$i = $184;
      break;
     }
    }
   } else {
    $$lcssa$i = $148;$$sink7$lcssa$i = $142;
   }
   HEAP32[$$lcssa$i>>2] = 1;
   $193 = (($$sink7$lcssa$i) + 40|0);
   HEAP32[$193>>2] = 1;
   $194 = (($$sink7$lcssa$i) + 56|0);
   HEAP32[$194>>2] = 1;
   $195 = (($$sink7$lcssa$i) + 60|0);
   HEAP32[$195>>2] = 63;
   $196 = (($$sink7$lcssa$i) + 64|0);
   HEAP32[$196>>2] = 0;
   $197 = (($$sink7$lcssa$i) + 68|0);
   HEAP32[$197>>2] = 0;
   $198 = (($$sink7$lcssa$i) + 72|0);
   HEAP32[$198>>2] = 1;
   $199 = (($$sink7$lcssa$i) + 76|0);
   HEAP32[$199>>2] = 2;
   $200 = (($$sink7$lcssa$i) + 92|0);
   HEAP32[$200>>2] = 1;
   $201 = (($$sink7$lcssa$i) + 96|0);
   HEAP32[$201>>2] = 63;
   $202 = (($$sink7$lcssa$i) + 100|0);
   HEAP32[$202>>2] = 0;
   $203 = (($$sink7$lcssa$i) + 104|0);
   HEAP32[$203>>2] = 0;
   $204 = (($149) + 4152|0);
   $205 = HEAP32[$204>>2]|0;
   $206 = ($205|0)>(0);
   if (!($206)) {
    STACKTOP = sp;return;
   }
   $207 = (($$sink7$lcssa$i) + 108|0);
   $i$19$i = 0;$scanptr$48$i = $207;
   while(1) {
    $208 = (136456 + ($i$19$i<<2)|0);
    $209 = HEAP32[$208>>2]|0;
    HEAP32[$scanptr$48$i>>2] = 1;
    $210 = (($scanptr$48$i) + 4|0);
    HEAP32[$210>>2] = 1;
    $211 = (($scanptr$48$i) + 20|0);
    HEAP32[$211>>2] = 1;
    $212 = (($scanptr$48$i) + 24|0);
    HEAP32[$212>>2] = $209;
    $213 = (($scanptr$48$i) + 28|0);
    HEAP32[$213>>2] = 0;
    $214 = (($scanptr$48$i) + 32|0);
    HEAP32[$214>>2] = 0;
    $215 = (($209) + 1)|0;
    $216 = (($scanptr$48$i) + 36|0);
    HEAP32[$216>>2] = 1;
    $217 = (($scanptr$48$i) + 40|0);
    HEAP32[$217>>2] = 1;
    $218 = (($scanptr$48$i) + 56|0);
    HEAP32[$218>>2] = $215;
    $219 = (($scanptr$48$i) + 60|0);
    HEAP32[$219>>2] = 63;
    $220 = (($scanptr$48$i) + 64|0);
    HEAP32[$220>>2] = 0;
    $221 = (($scanptr$48$i) + 68|0);
    HEAP32[$221>>2] = 0;
    $222 = (($scanptr$48$i) + 72|0);
    HEAP32[$222>>2] = 1;
    $223 = (($scanptr$48$i) + 76|0);
    HEAP32[$223>>2] = 2;
    $224 = (($scanptr$48$i) + 92|0);
    HEAP32[$224>>2] = 1;
    $225 = (($scanptr$48$i) + 96|0);
    HEAP32[$225>>2] = $209;
    $226 = (($scanptr$48$i) + 100|0);
    HEAP32[$226>>2] = 0;
    $227 = (($scanptr$48$i) + 104|0);
    HEAP32[$227>>2] = 0;
    $228 = (($scanptr$48$i) + 108|0);
    HEAP32[$228>>2] = 1;
    $229 = (($scanptr$48$i) + 112|0);
    HEAP32[$229>>2] = 2;
    $230 = (($scanptr$48$i) + 128|0);
    HEAP32[$230>>2] = $215;
    $231 = (($scanptr$48$i) + 132|0);
    HEAP32[$231>>2] = 63;
    $232 = (($scanptr$48$i) + 136|0);
    HEAP32[$232>>2] = 0;
    $233 = (($scanptr$48$i) + 140|0);
    HEAP32[$233>>2] = 0;
    $234 = (($scanptr$48$i) + 144|0);
    $235 = (($i$19$i) + 1)|0;
    $236 = HEAP32[$204>>2]|0;
    $237 = ($235|0)<($236|0);
    if ($237) {
     $i$19$i = $235;$scanptr$48$i = $234;
    } else {
     break;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $240 = HEAP32[$$pre$phiZ2D>>2]|0;
 $241 = ($240|0)==(100);
 if (!($241)) {
  $242 = HEAP32[$cinfo>>2]|0;
  $243 = (($242) + 20|0);
  HEAP32[$243>>2] = 20;
  $244 = HEAP32[$$pre$phiZ2D>>2]|0;
  $245 = (($242) + 24|0);
  HEAP32[$245>>2] = $244;
  $246 = HEAP32[$242>>2]|0;
  FUNCTION_TABLE_vi[$246 & 63]($cinfo);
 }
 $247 = (($cinfo) + 60|0);
 $248 = HEAP32[$247>>2]|0;
 $249 = ($248|0)==(3);
 if ($249) {
  $250 = (($cinfo) + 64|0);
  $251 = HEAP32[$250>>2]|0;
  $252 = ($251|0)==(3);
  if ($252) {
   $nscans$0 = 10;
  } else {
   label = 34;
  }
 } else {
  label = 34;
 }
 do {
  if ((label|0) == 34) {
   $253 = HEAP32[$0>>2]|0;
   $254 = (($253) + 4120|0);
   $255 = HEAP32[$254>>2]|0;
   $256 = ($255|0)==(1560820397);
   $257 = ($248|0)>(4);
   if ($256) {
    if ($257) {
     $258 = ($248*5)|0;
     $nscans$0 = $258;
     break;
    } else {
     $259 = $248 << 2;
     $260 = $259 | 1;
     $nscans$0 = $260;
     break;
    }
   } else {
    if ($257) {
     $261 = ($248*6)|0;
     $nscans$0 = $261;
     break;
    } else {
     $262 = $248 << 2;
     $263 = $262 | 2;
     $nscans$0 = $263;
     break;
    }
   }
  }
 } while(0);
 $264 = (($cinfo) + 352|0);
 $265 = HEAP32[$264>>2]|0;
 $266 = ($265|0)==(0|0);
 $$pre146 = (($cinfo) + 356|0);
 if ($266) {
  label = 43;
 } else {
  $267 = HEAP32[$$pre146>>2]|0;
  $268 = ($267|0)<($nscans$0|0);
  if ($268) {
   label = 43;
  } else {
   $277 = $265;
  }
 }
 if ((label|0) == 43) {
  $269 = ($nscans$0|0)>(10);
  $270 = $269 ? $nscans$0 : 10;
  HEAP32[$$pre146>>2] = $270;
  $271 = (($cinfo) + 4|0);
  $272 = HEAP32[$271>>2]|0;
  $273 = HEAP32[$272>>2]|0;
  $274 = ($270*36)|0;
  $275 = (FUNCTION_TABLE_iiii[$273 & 7]($cinfo,0,$274)|0);
  HEAP32[$264>>2] = $275;
  $277 = $275;
 }
 $276 = (($cinfo) + 172|0);
 HEAP32[$276>>2] = $277;
 $278 = (($cinfo) + 168|0);
 HEAP32[$278>>2] = $nscans$0;
 if ($249) {
  $279 = (($cinfo) + 64|0);
  $280 = HEAP32[$279>>2]|0;
  $281 = ($280|0)==(3);
  if ($281) {
   $282 = HEAP32[$0>>2]|0;
   $283 = (($282) + 4120|0);
   $284 = HEAP32[$283>>2]|0;
   $285 = ($284|0)==(1560820397);
   if (!($285)) {
    HEAP32[$277>>2] = 3;
    $ci$01$i113 = 0;
    while(1) {
     $355 = ((($277) + ($ci$01$i113<<2)|0) + 4|0);
     HEAP32[$355>>2] = $ci$01$i113;
     $356 = (($ci$01$i113) + 1)|0;
     $exitcond$i114 = ($356|0)==(3);
     if ($exitcond$i114) {
      break;
     } else {
      $ci$01$i113 = $356;
     }
    }
    $357 = (($277) + 24|0);
    HEAP32[$357>>2] = 0;
    $358 = (($277) + 20|0);
    HEAP32[$358>>2] = 0;
    $359 = (($277) + 28|0);
    HEAP32[$359>>2] = 0;
    $360 = (($277) + 32|0);
    HEAP32[$360>>2] = 1;
    $361 = (($277) + 36|0);
    HEAP32[$361>>2] = 1;
    $362 = (($277) + 40|0);
    HEAP32[$362>>2] = 0;
    $363 = (($277) + 56|0);
    HEAP32[$363>>2] = 1;
    $364 = (($277) + 60|0);
    HEAP32[$364>>2] = 5;
    $365 = (($277) + 64|0);
    HEAP32[$365>>2] = 0;
    $366 = (($277) + 68|0);
    HEAP32[$366>>2] = 2;
    $367 = (($277) + 72|0);
    HEAP32[$367>>2] = 1;
    $368 = (($277) + 76|0);
    HEAP32[$368>>2] = 2;
    $369 = (($277) + 92|0);
    HEAP32[$369>>2] = 1;
    $370 = (($277) + 96|0);
    HEAP32[$370>>2] = 63;
    $371 = (($277) + 100|0);
    HEAP32[$371>>2] = 0;
    $372 = (($277) + 104|0);
    HEAP32[$372>>2] = 1;
    $373 = (($277) + 108|0);
    HEAP32[$373>>2] = 1;
    $374 = (($277) + 112|0);
    HEAP32[$374>>2] = 1;
    $375 = (($277) + 128|0);
    HEAP32[$375>>2] = 1;
    $376 = (($277) + 132|0);
    HEAP32[$376>>2] = 63;
    $377 = (($277) + 136|0);
    HEAP32[$377>>2] = 0;
    $378 = (($277) + 140|0);
    HEAP32[$378>>2] = 1;
    $379 = (($277) + 144|0);
    HEAP32[$379>>2] = 1;
    $380 = (($277) + 148|0);
    HEAP32[$380>>2] = 0;
    $381 = (($277) + 164|0);
    HEAP32[$381>>2] = 6;
    $382 = (($277) + 168|0);
    HEAP32[$382>>2] = 63;
    $383 = (($277) + 172|0);
    HEAP32[$383>>2] = 0;
    $384 = (($277) + 176|0);
    HEAP32[$384>>2] = 2;
    $385 = (($277) + 180|0);
    HEAP32[$385>>2] = 1;
    $386 = (($277) + 184|0);
    HEAP32[$386>>2] = 0;
    $387 = (($277) + 200|0);
    HEAP32[$387>>2] = 1;
    $388 = (($277) + 204|0);
    HEAP32[$388>>2] = 63;
    $389 = (($277) + 208|0);
    HEAP32[$389>>2] = 2;
    $390 = (($277) + 212|0);
    HEAP32[$390>>2] = 1;
    $391 = (($277) + 216|0);
    HEAP32[$391>>2] = 3;
    $ci$01$i101 = 0;
    while(1) {
     $392 = ((($277) + ($ci$01$i101<<2)|0) + 220|0);
     HEAP32[$392>>2] = $ci$01$i101;
     $393 = (($ci$01$i101) + 1)|0;
     $exitcond$i102 = ($393|0)==(3);
     if ($exitcond$i102) {
      break;
     } else {
      $ci$01$i101 = $393;
     }
    }
    $394 = (($277) + 240|0);
    HEAP32[$394>>2] = 0;
    $395 = (($277) + 236|0);
    HEAP32[$395>>2] = 0;
    $396 = (($277) + 244|0);
    HEAP32[$396>>2] = 1;
    $397 = (($277) + 248|0);
    HEAP32[$397>>2] = 0;
    $398 = (($277) + 252|0);
    HEAP32[$398>>2] = 1;
    $399 = (($277) + 256|0);
    HEAP32[$399>>2] = 2;
    $400 = (($277) + 272|0);
    HEAP32[$400>>2] = 1;
    $401 = (($277) + 276|0);
    HEAP32[$401>>2] = 63;
    $402 = (($277) + 280|0);
    HEAP32[$402>>2] = 1;
    $403 = (($277) + 284|0);
    HEAP32[$403>>2] = 0;
    $404 = (($277) + 288|0);
    HEAP32[$404>>2] = 1;
    $405 = (($277) + 292|0);
    HEAP32[$405>>2] = 1;
    $406 = (($277) + 308|0);
    HEAP32[$406>>2] = 1;
    $407 = (($277) + 312|0);
    HEAP32[$407>>2] = 63;
    $408 = (($277) + 316|0);
    HEAP32[$408>>2] = 1;
    $409 = (($277) + 320|0);
    HEAP32[$409>>2] = 0;
    $410 = (($277) + 324|0);
    HEAP32[$410>>2] = 1;
    $411 = (($277) + 328|0);
    HEAP32[$411>>2] = 0;
    $412 = (($277) + 344|0);
    HEAP32[$412>>2] = 1;
    $413 = (($277) + 348|0);
    HEAP32[$413>>2] = 63;
    $414 = (($277) + 352|0);
    HEAP32[$414>>2] = 1;
    $415 = (($277) + 356|0);
    HEAP32[$415>>2] = 0;
    STACKTOP = sp;return;
   }
   $286 = (($282) + 4124|0);
   $287 = HEAP32[$286>>2]|0;
   if ((($287|0) == 1)) {
    HEAP32[$277>>2] = 1;
    $292 = (($277) + 4|0);
    HEAP32[$292>>2] = 0;
    $293 = (($277) + 20|0);
    $294 = (($277) + 36|0);
    ;HEAP32[$293+0>>2]=0|0;HEAP32[$293+4>>2]=0|0;HEAP32[$293+8>>2]=0|0;HEAP32[$293+12>>2]=0|0;
    HEAP32[$294>>2] = 1;
    $295 = (($277) + 40|0);
    HEAP32[$295>>2] = 1;
    $296 = (($277) + 56|0);
    $297 = (($277) + 72|0);
    ;HEAP32[$296+0>>2]=0|0;HEAP32[$296+4>>2]=0|0;HEAP32[$296+8>>2]=0|0;HEAP32[$296+12>>2]=0|0;
    HEAP32[$297>>2] = 1;
    $298 = (($277) + 76|0);
    HEAP32[$298>>2] = 2;
    $299 = (($277) + 92|0);
    $300 = (($277) + 108|0);
    ;HEAP32[$299+0>>2]=0|0;HEAP32[$299+4>>2]=0|0;HEAP32[$299+8>>2]=0|0;HEAP32[$299+12>>2]=0|0;
    $scanptr$0 = $300;
   } else if ((($287|0) == 0)) {
    HEAP32[$277>>2] = 3;
    $ci$01$i = 0;
    while(1) {
     $288 = ((($277) + ($ci$01$i<<2)|0) + 4|0);
     HEAP32[$288>>2] = $ci$01$i;
     $289 = (($ci$01$i) + 1)|0;
     $exitcond$i = ($289|0)==(3);
     if ($exitcond$i) {
      break;
     } else {
      $ci$01$i = $289;
     }
    }
    $290 = (($277) + 20|0);
    $291 = (($277) + 36|0);
    ;HEAP32[$290+0>>2]=0|0;HEAP32[$290+4>>2]=0|0;HEAP32[$290+8>>2]=0|0;HEAP32[$290+12>>2]=0|0;
    $scanptr$0 = $291;
   } else {
    HEAP32[$277>>2] = 1;
    $301 = (($277) + 4|0);
    HEAP32[$301>>2] = 0;
    $302 = (($277) + 20|0);
    $303 = (($277) + 36|0);
    ;HEAP32[$302+0>>2]=0|0;HEAP32[$302+4>>2]=0|0;HEAP32[$302+8>>2]=0|0;HEAP32[$302+12>>2]=0|0;
    HEAP32[$303>>2] = 2;
    $304 = (($277) + 40|0);
    HEAP32[$304>>2] = 1;
    $305 = (($277) + 44|0);
    HEAP32[$305>>2] = 2;
    $306 = (($277) + 56|0);
    $307 = (($277) + 72|0);
    ;HEAP32[$306+0>>2]=0|0;HEAP32[$306+4>>2]=0|0;HEAP32[$306+8>>2]=0|0;HEAP32[$306+12>>2]=0|0;
    $scanptr$0 = $307;
   }
   HEAP32[$scanptr$0>>2] = 1;
   $308 = (($scanptr$0) + 4|0);
   HEAP32[$308>>2] = 0;
   $309 = (($scanptr$0) + 20|0);
   HEAP32[$309>>2] = 1;
   $310 = (($scanptr$0) + 24|0);
   HEAP32[$310>>2] = 8;
   $311 = (($scanptr$0) + 28|0);
   HEAP32[$311>>2] = 0;
   $312 = (($scanptr$0) + 32|0);
   HEAP32[$312>>2] = 2;
   $313 = (($scanptr$0) + 36|0);
   HEAP32[$313>>2] = 1;
   $314 = (($scanptr$0) + 40|0);
   HEAP32[$314>>2] = 1;
   $315 = (($scanptr$0) + 56|0);
   HEAP32[$315>>2] = 1;
   $316 = (($scanptr$0) + 60|0);
   HEAP32[$316>>2] = 8;
   $317 = (($scanptr$0) + 64|0);
   HEAP32[$317>>2] = 0;
   $318 = (($scanptr$0) + 68|0);
   HEAP32[$318>>2] = 0;
   $319 = (($scanptr$0) + 72|0);
   HEAP32[$319>>2] = 1;
   $320 = (($scanptr$0) + 76|0);
   HEAP32[$320>>2] = 2;
   $321 = (($scanptr$0) + 92|0);
   HEAP32[$321>>2] = 1;
   $322 = (($scanptr$0) + 96|0);
   HEAP32[$322>>2] = 8;
   $323 = (($scanptr$0) + 100|0);
   HEAP32[$323>>2] = 0;
   $324 = (($scanptr$0) + 104|0);
   HEAP32[$324>>2] = 0;
   $325 = (($scanptr$0) + 108|0);
   HEAP32[$325>>2] = 1;
   $326 = (($scanptr$0) + 112|0);
   HEAP32[$326>>2] = 0;
   $327 = (($scanptr$0) + 128|0);
   HEAP32[$327>>2] = 9;
   $328 = (($scanptr$0) + 132|0);
   HEAP32[$328>>2] = 63;
   $329 = (($scanptr$0) + 136|0);
   HEAP32[$329>>2] = 0;
   $330 = (($scanptr$0) + 140|0);
   HEAP32[$330>>2] = 2;
   $331 = (($scanptr$0) + 144|0);
   HEAP32[$331>>2] = 1;
   $332 = (($scanptr$0) + 148|0);
   HEAP32[$332>>2] = 0;
   $333 = (($scanptr$0) + 164|0);
   HEAP32[$333>>2] = 1;
   $334 = (($scanptr$0) + 168|0);
   HEAP32[$334>>2] = 63;
   $335 = (($scanptr$0) + 172|0);
   HEAP32[$335>>2] = 2;
   $336 = (($scanptr$0) + 176|0);
   HEAP32[$336>>2] = 1;
   $337 = (($scanptr$0) + 180|0);
   HEAP32[$337>>2] = 1;
   $338 = (($scanptr$0) + 184|0);
   HEAP32[$338>>2] = 0;
   $339 = (($scanptr$0) + 200|0);
   HEAP32[$339>>2] = 1;
   $340 = (($scanptr$0) + 204|0);
   HEAP32[$340>>2] = 63;
   $341 = (($scanptr$0) + 208|0);
   HEAP32[$341>>2] = 1;
   $342 = (($scanptr$0) + 212|0);
   HEAP32[$342>>2] = 0;
   $343 = (($scanptr$0) + 216|0);
   HEAP32[$343>>2] = 1;
   $344 = (($scanptr$0) + 220|0);
   HEAP32[$344>>2] = 1;
   $345 = (($scanptr$0) + 236|0);
   HEAP32[$345>>2] = 9;
   $346 = (($scanptr$0) + 240|0);
   HEAP32[$346>>2] = 63;
   $347 = (($scanptr$0) + 244|0);
   HEAP32[$347>>2] = 0;
   $348 = (($scanptr$0) + 248|0);
   HEAP32[$348>>2] = 0;
   $349 = (($scanptr$0) + 252|0);
   HEAP32[$349>>2] = 1;
   $350 = (($scanptr$0) + 256|0);
   HEAP32[$350>>2] = 2;
   $351 = (($scanptr$0) + 272|0);
   HEAP32[$351>>2] = 9;
   $352 = (($scanptr$0) + 276|0);
   HEAP32[$352>>2] = 63;
   $353 = (($scanptr$0) + 280|0);
   HEAP32[$353>>2] = 0;
   $354 = (($scanptr$0) + 284|0);
   HEAP32[$354>>2] = 0;
   STACKTOP = sp;return;
  }
 }
 $416 = HEAP32[$0>>2]|0;
 $417 = (($416) + 4120|0);
 $418 = HEAP32[$417>>2]|0;
 $419 = ($418|0)==(1560820397);
 $420 = ($248|0)<(5);
 if ($419) {
  if ($420) {
   HEAP32[$277>>2] = $248;
   $421 = ($248|0)>(0);
   if ($421) {
    $ci$01$i89 = 0;
    while(1) {
     $422 = ((($277) + ($ci$01$i89<<2)|0) + 4|0);
     HEAP32[$422>>2] = $ci$01$i89;
     $423 = (($ci$01$i89) + 1)|0;
     $exitcond$i90 = ($423|0)==($248|0);
     if ($exitcond$i90) {
      break;
     } else {
      $ci$01$i89 = $423;
     }
    }
   }
   $424 = (($277) + 20|0);
   $425 = (($277) + 36|0);
   ;HEAP32[$424+0>>2]=0|0;HEAP32[$424+4>>2]=0|0;HEAP32[$424+8>>2]=0|0;HEAP32[$424+12>>2]=0|0;
   $$0$i99 = $425;
  } else {
   $$01$i$i94 = $277;$ci$02$i$i93 = 0;
   while(1) {
    HEAP32[$$01$i$i94>>2] = 1;
    $426 = (($$01$i$i94) + 4|0);
    HEAP32[$426>>2] = $ci$02$i$i93;
    $427 = (($$01$i$i94) + 20|0);
    $428 = (($$01$i$i94) + 36|0);
    $429 = (($ci$02$i$i93) + 1)|0;
    $exitcond$i$i95 = ($429|0)==($248|0);
    ;HEAP32[$427+0>>2]=0|0;HEAP32[$427+4>>2]=0|0;HEAP32[$427+8>>2]=0|0;HEAP32[$427+12>>2]=0|0;
    if ($exitcond$i$i95) {
     break;
    } else {
     $$01$i$i94 = $428;$ci$02$i$i93 = $429;
    }
   }
   $scevgep$i$i97 = (($277) + (($248*36)|0)|0);
   $$0$i99 = $scevgep$i$i97;
  }
  $430 = ($248|0)>(0);
  if ($430) {
   $$01$i82 = $$0$i99;$ci$02$i81 = 0;
  } else {
   STACKTOP = sp;return;
  }
  while(1) {
   HEAP32[$$01$i82>>2] = 1;
   $431 = (($$01$i82) + 4|0);
   HEAP32[$431>>2] = $ci$02$i81;
   $432 = (($$01$i82) + 20|0);
   HEAP32[$432>>2] = 1;
   $433 = (($$01$i82) + 24|0);
   HEAP32[$433>>2] = 8;
   $434 = (($$01$i82) + 28|0);
   HEAP32[$434>>2] = 0;
   $435 = (($$01$i82) + 32|0);
   HEAP32[$435>>2] = 2;
   $436 = (($$01$i82) + 36|0);
   $437 = (($ci$02$i81) + 1)|0;
   $exitcond$i83 = ($437|0)==($248|0);
   if ($exitcond$i83) {
    break;
   } else {
    $$01$i82 = $436;$ci$02$i81 = $437;
   }
  }
  $scevgep$i85 = (($$0$i99) + (($248*36)|0)|0);
  $$01$i74 = $scevgep$i85;$ci$02$i73 = 0;
  while(1) {
   HEAP32[$$01$i74>>2] = 1;
   $438 = (($$01$i74) + 4|0);
   HEAP32[$438>>2] = $ci$02$i73;
   $439 = (($$01$i74) + 20|0);
   HEAP32[$439>>2] = 9;
   $440 = (($$01$i74) + 24|0);
   HEAP32[$440>>2] = 63;
   $441 = (($$01$i74) + 28|0);
   HEAP32[$441>>2] = 0;
   $442 = (($$01$i74) + 32|0);
   HEAP32[$442>>2] = 2;
   $443 = (($$01$i74) + 36|0);
   $444 = (($ci$02$i73) + 1)|0;
   $exitcond$i75 = ($444|0)==($248|0);
   if ($exitcond$i75) {
    break;
   } else {
    $$01$i74 = $443;$ci$02$i73 = $444;
   }
  }
  $scevgep$i85$sum = $248 << 1;
  $scevgep$i77 = (($$0$i99) + (($scevgep$i85$sum*36)|0)|0);
  $$01$i66 = $scevgep$i77;$ci$02$i65 = 0;
  while(1) {
   HEAP32[$$01$i66>>2] = 1;
   $445 = (($$01$i66) + 4|0);
   HEAP32[$445>>2] = $ci$02$i65;
   $446 = (($$01$i66) + 20|0);
   HEAP32[$446>>2] = 1;
   $447 = (($$01$i66) + 24|0);
   HEAP32[$447>>2] = 63;
   $448 = (($$01$i66) + 28|0);
   HEAP32[$448>>2] = 2;
   $449 = (($$01$i66) + 32|0);
   HEAP32[$449>>2] = 1;
   $450 = (($$01$i66) + 36|0);
   $451 = (($ci$02$i65) + 1)|0;
   $exitcond$i67 = ($451|0)==($248|0);
   if ($exitcond$i67) {
    break;
   } else {
    $$01$i66 = $450;$ci$02$i65 = $451;
   }
  }
  $scevgep$i77$sum = (($scevgep$i85$sum) + ($248))|0;
  $scevgep$i69 = (($$0$i99) + (($scevgep$i77$sum*36)|0)|0);
  $$01$i58 = $scevgep$i69;$ci$02$i57 = 0;
  while(1) {
   HEAP32[$$01$i58>>2] = 1;
   $452 = (($$01$i58) + 4|0);
   HEAP32[$452>>2] = $ci$02$i57;
   $453 = (($$01$i58) + 20|0);
   HEAP32[$453>>2] = 1;
   $454 = (($$01$i58) + 24|0);
   HEAP32[$454>>2] = 63;
   $455 = (($$01$i58) + 28|0);
   HEAP32[$455>>2] = 1;
   $456 = (($$01$i58) + 32|0);
   HEAP32[$456>>2] = 0;
   $457 = (($$01$i58) + 36|0);
   $458 = (($ci$02$i57) + 1)|0;
   $exitcond$i59 = ($458|0)==($248|0);
   if ($exitcond$i59) {
    break;
   } else {
    $$01$i58 = $457;$ci$02$i57 = $458;
   }
  }
  STACKTOP = sp;return;
 }
 if ($420) {
  HEAP32[$277>>2] = $248;
  $459 = ($248|0)>(0);
  if ($459) {
   $ci$01$i45 = 0;
   while(1) {
    $460 = ((($277) + ($ci$01$i45<<2)|0) + 4|0);
    HEAP32[$460>>2] = $ci$01$i45;
    $461 = (($ci$01$i45) + 1)|0;
    $exitcond$i46 = ($461|0)==($248|0);
    if ($exitcond$i46) {
     break;
    } else {
     $ci$01$i45 = $461;
    }
   }
  }
  $462 = (($277) + 24|0);
  HEAP32[$462>>2] = 0;
  $463 = (($277) + 20|0);
  HEAP32[$463>>2] = 0;
  $464 = (($277) + 28|0);
  HEAP32[$464>>2] = 0;
  $465 = (($277) + 32|0);
  HEAP32[$465>>2] = 1;
  $466 = (($277) + 36|0);
  $$0$i55 = $466;
 } else {
  $$01$i$i50 = $277;$ci$02$i$i49 = 0;
  while(1) {
   HEAP32[$$01$i$i50>>2] = 1;
   $467 = (($$01$i$i50) + 4|0);
   HEAP32[$467>>2] = $ci$02$i$i49;
   $468 = (($$01$i$i50) + 20|0);
   HEAP32[$468>>2] = 0;
   $469 = (($$01$i$i50) + 24|0);
   HEAP32[$469>>2] = 0;
   $470 = (($$01$i$i50) + 28|0);
   HEAP32[$470>>2] = 0;
   $471 = (($$01$i$i50) + 32|0);
   HEAP32[$471>>2] = 1;
   $472 = (($$01$i$i50) + 36|0);
   $473 = (($ci$02$i$i49) + 1)|0;
   $exitcond$i$i51 = ($473|0)==($248|0);
   if ($exitcond$i$i51) {
    break;
   } else {
    $$01$i$i50 = $472;$ci$02$i$i49 = $473;
   }
  }
  $scevgep$i$i53 = (($277) + (($248*36)|0)|0);
  $$0$i55 = $scevgep$i$i53;
 }
 $474 = ($248|0)>(0);
 if ($474) {
  $$01$i38 = $$0$i55;$ci$02$i37 = 0;
  while(1) {
   HEAP32[$$01$i38>>2] = 1;
   $475 = (($$01$i38) + 4|0);
   HEAP32[$475>>2] = $ci$02$i37;
   $476 = (($$01$i38) + 20|0);
   HEAP32[$476>>2] = 1;
   $477 = (($$01$i38) + 24|0);
   HEAP32[$477>>2] = 5;
   $478 = (($$01$i38) + 28|0);
   HEAP32[$478>>2] = 0;
   $479 = (($$01$i38) + 32|0);
   HEAP32[$479>>2] = 2;
   $480 = (($$01$i38) + 36|0);
   $481 = (($ci$02$i37) + 1)|0;
   $exitcond$i39 = ($481|0)==($248|0);
   if ($exitcond$i39) {
    break;
   } else {
    $$01$i38 = $480;$ci$02$i37 = $481;
   }
  }
  $scevgep$i41 = (($$0$i55) + (($248*36)|0)|0);
  $$01$i30 = $scevgep$i41;$ci$02$i29 = 0;
  while(1) {
   HEAP32[$$01$i30>>2] = 1;
   $482 = (($$01$i30) + 4|0);
   HEAP32[$482>>2] = $ci$02$i29;
   $483 = (($$01$i30) + 20|0);
   HEAP32[$483>>2] = 6;
   $484 = (($$01$i30) + 24|0);
   HEAP32[$484>>2] = 63;
   $485 = (($$01$i30) + 28|0);
   HEAP32[$485>>2] = 0;
   $486 = (($$01$i30) + 32|0);
   HEAP32[$486>>2] = 2;
   $487 = (($$01$i30) + 36|0);
   $488 = (($ci$02$i29) + 1)|0;
   $exitcond$i31 = ($488|0)==($248|0);
   if ($exitcond$i31) {
    break;
   } else {
    $$01$i30 = $487;$ci$02$i29 = $488;
   }
  }
  $scevgep$i41$sum = $248 << 1;
  $scevgep$i33 = (($$0$i55) + (($scevgep$i41$sum*36)|0)|0);
  $$01$i22 = $scevgep$i33;$ci$02$i21 = 0;
  while(1) {
   HEAP32[$$01$i22>>2] = 1;
   $489 = (($$01$i22) + 4|0);
   HEAP32[$489>>2] = $ci$02$i21;
   $490 = (($$01$i22) + 20|0);
   HEAP32[$490>>2] = 1;
   $491 = (($$01$i22) + 24|0);
   HEAP32[$491>>2] = 63;
   $492 = (($$01$i22) + 28|0);
   HEAP32[$492>>2] = 2;
   $493 = (($$01$i22) + 32|0);
   HEAP32[$493>>2] = 1;
   $494 = (($$01$i22) + 36|0);
   $495 = (($ci$02$i21) + 1)|0;
   $exitcond$i23 = ($495|0)==($248|0);
   if ($exitcond$i23) {
    break;
   } else {
    $$01$i22 = $494;$ci$02$i21 = $495;
   }
  }
  $scevgep$i33$sum = (($scevgep$i41$sum) + ($248))|0;
  $scevgep$i25 = (($$0$i55) + (($scevgep$i33$sum*36)|0)|0);
  $$0$lcssa$i27 = $scevgep$i25;
 } else {
  $$0$lcssa$i27 = $$0$i55;
 }
 if ($420) {
  HEAP32[$$0$lcssa$i27>>2] = $248;
  if ($474) {
   $ci$01$i9 = 0;
   while(1) {
    $496 = ((($$0$lcssa$i27) + ($ci$01$i9<<2)|0) + 4|0);
    HEAP32[$496>>2] = $ci$01$i9;
    $497 = (($ci$01$i9) + 1)|0;
    $exitcond$i10 = ($497|0)==($248|0);
    if ($exitcond$i10) {
     break;
    } else {
     $ci$01$i9 = $497;
    }
   }
  }
  $498 = (($$0$lcssa$i27) + 24|0);
  HEAP32[$498>>2] = 0;
  $499 = (($$0$lcssa$i27) + 20|0);
  HEAP32[$499>>2] = 0;
  $500 = (($$0$lcssa$i27) + 28|0);
  HEAP32[$500>>2] = 1;
  $501 = (($$0$lcssa$i27) + 32|0);
  HEAP32[$501>>2] = 0;
  $502 = (($$0$lcssa$i27) + 36|0);
  $$0$i19 = $502;
 } else {
  $$01$i$i14 = $$0$lcssa$i27;$ci$02$i$i13 = 0;
  while(1) {
   HEAP32[$$01$i$i14>>2] = 1;
   $503 = (($$01$i$i14) + 4|0);
   HEAP32[$503>>2] = $ci$02$i$i13;
   $504 = (($$01$i$i14) + 20|0);
   HEAP32[$504>>2] = 0;
   $505 = (($$01$i$i14) + 24|0);
   HEAP32[$505>>2] = 0;
   $506 = (($$01$i$i14) + 28|0);
   HEAP32[$506>>2] = 1;
   $507 = (($$01$i$i14) + 32|0);
   HEAP32[$507>>2] = 0;
   $508 = (($$01$i$i14) + 36|0);
   $509 = (($ci$02$i$i13) + 1)|0;
   $exitcond$i$i15 = ($509|0)==($248|0);
   if ($exitcond$i$i15) {
    break;
   } else {
    $$01$i$i14 = $508;$ci$02$i$i13 = $509;
   }
  }
  $scevgep$i$i17 = (($$0$lcssa$i27) + (($248*36)|0)|0);
  $$0$i19 = $scevgep$i$i17;
 }
 if ($474) {
  $$01$i = $$0$i19;$ci$02$i = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  HEAP32[$$01$i>>2] = 1;
  $510 = (($$01$i) + 4|0);
  HEAP32[$510>>2] = $ci$02$i;
  $511 = (($$01$i) + 20|0);
  HEAP32[$511>>2] = 1;
  $512 = (($$01$i) + 24|0);
  HEAP32[$512>>2] = 63;
  $513 = (($$01$i) + 28|0);
  HEAP32[$513>>2] = 1;
  $514 = (($$01$i) + 32|0);
  HEAP32[$514>>2] = 0;
  $515 = (($$01$i) + 36|0);
  $516 = (($ci$02$i) + 1)|0;
  $exitcond$i6 = ($516|0)==($248|0);
  if ($exitcond$i6) {
   break;
  } else {
   $$01$i = $515;$ci$02$i = $516;
  }
 }
 STACKTOP = sp;return;
}
function _jpeg_set_colorspace($cinfo,$colorspace) {
 $cinfo = $cinfo|0;
 $colorspace = $colorspace|0;
 var $$off = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ci$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(100);
 if (!($2)) {
  $3 = HEAP32[$cinfo>>2]|0;
  $4 = (($3) + 20|0);
  HEAP32[$4>>2] = 20;
  $5 = HEAP32[$0>>2]|0;
  $6 = (($3) + 24|0);
  HEAP32[$6>>2] = $5;
  $7 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$7 & 63]($cinfo);
 }
 $8 = (($cinfo) + 64|0);
 HEAP32[$8>>2] = $colorspace;
 $9 = (($cinfo) + 196|0);
 HEAP8[$9>>0] = 0;
 $10 = (($cinfo) + 204|0);
 HEAP8[$10>>0] = 0;
 switch ($colorspace|0) {
 case 2:  {
  HEAP8[$10>>0] = 1;
  $19 = (($cinfo) + 60|0);
  HEAP32[$19>>2] = 3;
  $20 = (($cinfo) + 68|0);
  $21 = HEAP32[$20>>2]|0;
  HEAP32[$21>>2] = 82;
  $22 = (($21) + 8|0);
  HEAP32[$22>>2] = 1;
  $23 = (($21) + 12|0);
  HEAP32[$23>>2] = 1;
  $24 = (($21) + 16|0);
  HEAP32[$24>>2] = 0;
  $25 = (($21) + 20|0);
  HEAP32[$25>>2] = 0;
  $26 = (($21) + 24|0);
  HEAP32[$26>>2] = 0;
  $27 = (($21) + 84|0);
  HEAP32[$27>>2] = 71;
  $28 = (($21) + 92|0);
  HEAP32[$28>>2] = 1;
  $29 = (($21) + 96|0);
  HEAP32[$29>>2] = 1;
  $30 = (($21) + 100|0);
  HEAP32[$30>>2] = 0;
  $31 = (($21) + 104|0);
  HEAP32[$31>>2] = 0;
  $32 = (($21) + 108|0);
  HEAP32[$32>>2] = 0;
  $33 = (($21) + 168|0);
  HEAP32[$33>>2] = 66;
  $34 = (($21) + 176|0);
  HEAP32[$34>>2] = 1;
  $35 = (($21) + 180|0);
  HEAP32[$35>>2] = 1;
  $36 = (($21) + 184|0);
  HEAP32[$36>>2] = 0;
  $37 = (($21) + 188|0);
  HEAP32[$37>>2] = 0;
  $38 = (($21) + 192|0);
  HEAP32[$38>>2] = 0;
  STACKTOP = sp;return;
  break;
 }
 case 4:  {
  HEAP8[$10>>0] = 1;
  $59 = (($cinfo) + 60|0);
  HEAP32[$59>>2] = 4;
  $60 = (($cinfo) + 68|0);
  $61 = HEAP32[$60>>2]|0;
  HEAP32[$61>>2] = 67;
  $62 = (($61) + 8|0);
  HEAP32[$62>>2] = 1;
  $63 = (($61) + 12|0);
  HEAP32[$63>>2] = 1;
  $64 = (($61) + 16|0);
  HEAP32[$64>>2] = 0;
  $65 = (($61) + 20|0);
  HEAP32[$65>>2] = 0;
  $66 = (($61) + 24|0);
  HEAP32[$66>>2] = 0;
  $67 = (($61) + 84|0);
  HEAP32[$67>>2] = 77;
  $68 = (($61) + 92|0);
  HEAP32[$68>>2] = 1;
  $69 = (($61) + 96|0);
  HEAP32[$69>>2] = 1;
  $70 = (($61) + 100|0);
  HEAP32[$70>>2] = 0;
  $71 = (($61) + 104|0);
  HEAP32[$71>>2] = 0;
  $72 = (($61) + 108|0);
  HEAP32[$72>>2] = 0;
  $73 = (($61) + 168|0);
  HEAP32[$73>>2] = 89;
  $74 = (($61) + 176|0);
  HEAP32[$74>>2] = 1;
  $75 = (($61) + 180|0);
  HEAP32[$75>>2] = 1;
  $76 = (($61) + 184|0);
  HEAP32[$76>>2] = 0;
  $77 = (($61) + 188|0);
  HEAP32[$77>>2] = 0;
  $78 = (($61) + 192|0);
  HEAP32[$78>>2] = 0;
  $79 = (($61) + 252|0);
  HEAP32[$79>>2] = 75;
  $80 = (($61) + 260|0);
  HEAP32[$80>>2] = 1;
  $81 = (($61) + 264|0);
  HEAP32[$81>>2] = 1;
  $82 = (($61) + 268|0);
  HEAP32[$82>>2] = 0;
  $83 = (($61) + 272|0);
  HEAP32[$83>>2] = 0;
  $84 = (($61) + 276|0);
  HEAP32[$84>>2] = 0;
  STACKTOP = sp;return;
  break;
 }
 case 5:  {
  HEAP8[$10>>0] = 1;
  $85 = (($cinfo) + 60|0);
  HEAP32[$85>>2] = 4;
  $86 = (($cinfo) + 68|0);
  $87 = HEAP32[$86>>2]|0;
  HEAP32[$87>>2] = 1;
  $88 = (($87) + 8|0);
  HEAP32[$88>>2] = 2;
  $89 = (($87) + 12|0);
  HEAP32[$89>>2] = 2;
  $90 = (($87) + 16|0);
  HEAP32[$90>>2] = 0;
  $91 = (($87) + 20|0);
  HEAP32[$91>>2] = 0;
  $92 = (($87) + 24|0);
  HEAP32[$92>>2] = 0;
  $93 = (($87) + 84|0);
  HEAP32[$93>>2] = 2;
  $94 = (($87) + 92|0);
  HEAP32[$94>>2] = 1;
  $95 = (($87) + 96|0);
  HEAP32[$95>>2] = 1;
  $96 = (($87) + 100|0);
  HEAP32[$96>>2] = 1;
  $97 = (($87) + 104|0);
  HEAP32[$97>>2] = 1;
  $98 = (($87) + 108|0);
  HEAP32[$98>>2] = 1;
  $99 = (($87) + 168|0);
  HEAP32[$99>>2] = 3;
  $100 = (($87) + 176|0);
  HEAP32[$100>>2] = 1;
  $101 = (($87) + 180|0);
  HEAP32[$101>>2] = 1;
  $102 = (($87) + 184|0);
  HEAP32[$102>>2] = 1;
  $103 = (($87) + 188|0);
  HEAP32[$103>>2] = 1;
  $104 = (($87) + 192|0);
  HEAP32[$104>>2] = 1;
  $105 = (($87) + 252|0);
  HEAP32[$105>>2] = 4;
  $106 = (($87) + 260|0);
  HEAP32[$106>>2] = 2;
  $107 = (($87) + 264|0);
  HEAP32[$107>>2] = 2;
  $108 = (($87) + 268|0);
  HEAP32[$108>>2] = 0;
  $109 = (($87) + 272|0);
  HEAP32[$109>>2] = 0;
  $110 = (($87) + 276|0);
  HEAP32[$110>>2] = 0;
  STACKTOP = sp;return;
  break;
 }
 case 1:  {
  HEAP8[$9>>0] = 1;
  $11 = (($cinfo) + 60|0);
  HEAP32[$11>>2] = 1;
  $12 = (($cinfo) + 68|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$13>>2] = 1;
  $14 = (($13) + 8|0);
  HEAP32[$14>>2] = 1;
  $15 = (($13) + 12|0);
  HEAP32[$15>>2] = 1;
  $16 = (($13) + 16|0);
  HEAP32[$16>>2] = 0;
  $17 = (($13) + 20|0);
  HEAP32[$17>>2] = 0;
  $18 = (($13) + 24|0);
  HEAP32[$18>>2] = 0;
  STACKTOP = sp;return;
  break;
 }
 case 0:  {
  $111 = (($cinfo) + 36|0);
  $112 = HEAP32[$111>>2]|0;
  $113 = (($cinfo) + 60|0);
  HEAP32[$113>>2] = $112;
  $$off = (($112) + -1)|0;
  $114 = ($$off>>>0)>(9);
  if ($114) {
   $115 = HEAP32[$cinfo>>2]|0;
   $116 = (($115) + 20|0);
   HEAP32[$116>>2] = 26;
   $117 = HEAP32[$113>>2]|0;
   $118 = (($115) + 24|0);
   HEAP32[$118>>2] = $117;
   $119 = (($115) + 28|0);
   HEAP32[$119>>2] = 10;
   $120 = HEAP32[$115>>2]|0;
   FUNCTION_TABLE_vi[$120 & 63]($cinfo);
   $$pre = HEAP32[$113>>2]|0;
   $121 = $$pre;
  } else {
   $121 = $112;
  }
  $122 = ($121|0)>(0);
  if (!($122)) {
   STACKTOP = sp;return;
  }
  $123 = (($cinfo) + 68|0);
  $124 = HEAP32[$123>>2]|0;
  $ci$01 = 0;
  while(1) {
   $125 = (($124) + (($ci$01*84)|0)|0);
   HEAP32[$125>>2] = $ci$01;
   $126 = ((($124) + (($ci$01*84)|0)|0) + 8|0);
   HEAP32[$126>>2] = 1;
   $127 = ((($124) + (($ci$01*84)|0)|0) + 12|0);
   HEAP32[$127>>2] = 1;
   $128 = ((($124) + (($ci$01*84)|0)|0) + 16|0);
   HEAP32[$128>>2] = 0;
   $129 = ((($124) + (($ci$01*84)|0)|0) + 20|0);
   HEAP32[$129>>2] = 0;
   $130 = ((($124) + (($ci$01*84)|0)|0) + 24|0);
   HEAP32[$130>>2] = 0;
   $131 = (($ci$01) + 1)|0;
   $132 = HEAP32[$113>>2]|0;
   $133 = ($131|0)<($132|0);
   if ($133) {
    $ci$01 = $131;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
  break;
 }
 case 3:  {
  HEAP8[$9>>0] = 1;
  $39 = (($cinfo) + 60|0);
  HEAP32[$39>>2] = 3;
  $40 = (($cinfo) + 68|0);
  $41 = HEAP32[$40>>2]|0;
  HEAP32[$41>>2] = 1;
  $42 = (($41) + 8|0);
  HEAP32[$42>>2] = 2;
  $43 = (($41) + 12|0);
  HEAP32[$43>>2] = 2;
  $44 = (($41) + 16|0);
  HEAP32[$44>>2] = 0;
  $45 = (($41) + 20|0);
  HEAP32[$45>>2] = 0;
  $46 = (($41) + 24|0);
  HEAP32[$46>>2] = 0;
  $47 = (($41) + 84|0);
  HEAP32[$47>>2] = 2;
  $48 = (($41) + 92|0);
  HEAP32[$48>>2] = 1;
  $49 = (($41) + 96|0);
  HEAP32[$49>>2] = 1;
  $50 = (($41) + 100|0);
  HEAP32[$50>>2] = 1;
  $51 = (($41) + 104|0);
  HEAP32[$51>>2] = 1;
  $52 = (($41) + 108|0);
  HEAP32[$52>>2] = 1;
  $53 = (($41) + 168|0);
  HEAP32[$53>>2] = 3;
  $54 = (($41) + 176|0);
  HEAP32[$54>>2] = 1;
  $55 = (($41) + 180|0);
  HEAP32[$55>>2] = 1;
  $56 = (($41) + 184|0);
  HEAP32[$56>>2] = 1;
  $57 = (($41) + 188|0);
  HEAP32[$57>>2] = 1;
  $58 = (($41) + 192|0);
  HEAP32[$58>>2] = 1;
  STACKTOP = sp;return;
  break;
 }
 default: {
  $134 = HEAP32[$cinfo>>2]|0;
  $135 = (($134) + 20|0);
  HEAP32[$135>>2] = 10;
  $136 = HEAP32[$134>>2]|0;
  FUNCTION_TABLE_vi[$136 & 63]($cinfo);
  STACKTOP = sp;return;
 }
 }
}
function _add_huff_table($cinfo,$htblptr,$bits,$val) {
 $cinfo = $cinfo|0;
 $htblptr = $htblptr|0;
 $bits = $bits|0;
 $val = $val|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $nsymbols$0$off = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[$htblptr>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (_jpeg_alloc_huff_table($cinfo)|0);
 HEAP32[$htblptr>>2] = $2;
 dest=$2+0|0; src=$bits+0|0; stop=dest+17|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $3 = (($bits) + 1|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = (($bits) + 2|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = (($8) + ($5))|0;
 $10 = (($bits) + 3|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = (($12) + ($9))|0;
 $14 = (($bits) + 4|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = $15&255;
 $17 = (($16) + ($13))|0;
 $18 = (($bits) + 5|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = (($20) + ($17))|0;
 $22 = (($bits) + 6|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = (($24) + ($21))|0;
 $26 = (($bits) + 7|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = $27&255;
 $29 = (($28) + ($25))|0;
 $30 = (($bits) + 8|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = $31&255;
 $33 = (($32) + ($29))|0;
 $34 = (($bits) + 9|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = $35&255;
 $37 = (($36) + ($33))|0;
 $38 = (($bits) + 10|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = $39&255;
 $41 = (($40) + ($37))|0;
 $42 = (($bits) + 11|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = $43&255;
 $45 = (($44) + ($41))|0;
 $46 = (($bits) + 12|0);
 $47 = HEAP8[$46>>0]|0;
 $48 = $47&255;
 $49 = (($48) + ($45))|0;
 $50 = (($bits) + 13|0);
 $51 = HEAP8[$50>>0]|0;
 $52 = $51&255;
 $53 = (($52) + ($49))|0;
 $54 = (($bits) + 14|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = $55&255;
 $57 = (($56) + ($53))|0;
 $58 = (($bits) + 15|0);
 $59 = HEAP8[$58>>0]|0;
 $60 = $59&255;
 $61 = (($60) + ($57))|0;
 $62 = (($bits) + 16|0);
 $63 = HEAP8[$62>>0]|0;
 $64 = $63&255;
 $65 = (($64) + ($61))|0;
 $nsymbols$0$off = (($65) + -1)|0;
 $66 = ($nsymbols$0$off>>>0)>(255);
 if ($66) {
  $67 = HEAP32[$cinfo>>2]|0;
  $68 = (($67) + 20|0);
  HEAP32[$68>>2] = 8;
  $69 = HEAP32[$67>>2]|0;
  FUNCTION_TABLE_vi[$69 & 63]($cinfo);
 }
 $70 = HEAP32[$htblptr>>2]|0;
 $71 = (($70) + 17|0);
 _memcpy(($71|0),($val|0),($65|0))|0;
 $72 = HEAP32[$htblptr>>2]|0;
 $73 = (($72) + 273|0);
 HEAP8[$73>>0] = 0;
 STACKTOP = sp;return;
}
function _jinit_phuff_encoder($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 7]($cinfo,1,108)|0);
 $4 = (($cinfo) + 348|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$3>>2] = 8;
 $5 = (($3) + 76|0);
 $6 = (($3) + 92|0);
 HEAP32[$5>>2] = 0;
 HEAP32[$6>>2] = 0;
 $7 = (($3) + 80|0);
 HEAP32[$7>>2] = 0;
 $8 = (($3) + 96|0);
 HEAP32[$8>>2] = 0;
 $9 = (($3) + 84|0);
 HEAP32[$9>>2] = 0;
 $10 = (($3) + 100|0);
 HEAP32[$10>>2] = 0;
 $11 = (($3) + 88|0);
 HEAP32[$11>>2] = 0;
 $12 = (($3) + 104|0);
 HEAP32[$12>>2] = 0;
 $13 = (($3) + 64|0);
 HEAP32[$13>>2] = 0;
 STACKTOP = sp;return;
}
function _start_pass_phuff($cinfo,$gather_statistics) {
 $cinfo = $cinfo|0;
 $gather_statistics = $gather_statistics|0;
 var $$ = 0, $$c = 0, $$c2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ci$07 = 0, $ci$07$us = 0, $exitcond = 0, $exitcond9 = 0, $i$06 = 0, $i$06$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 32|0);
 HEAP32[$2>>2] = $cinfo;
 $3 = (($1) + 12|0);
 HEAP8[$3>>0] = $gather_statistics;
 $4 = (($cinfo) + 300|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 $7 = $6&1;
 $8 = (($cinfo) + 308|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 $11 = (($1) + 4|0);
 do {
  if ($10) {
   if ($6) {
    HEAP32[$11>>2] = 12;
    break;
   } else {
    HEAP32[$11>>2] = 13;
    break;
   }
  } else {
   if ($6) {
    HEAP32[$11>>2] = 14;
    break;
   }
   HEAP32[$11>>2] = 15;
   $12 = (($1) + 64|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    $15 = (($cinfo) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (FUNCTION_TABLE_iiii[$17 & 7]($cinfo,1,1000)|0);
    HEAP32[$12>>2] = $18;
   }
  }
 } while(0);
 $19 = ($gather_statistics<<24>>24)!=(0);
 $20 = (($1) + 8|0);
 $$ = $19 ? 22 : 21;
 HEAP32[$20>>2] = $$;
 $21 = (($cinfo) + 228|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)>(0);
 if (!($23)) {
  $134 = (($1) + 56|0);
  HEAP32[$134>>2] = 0;
  $135 = (($1) + 60|0);
  HEAP32[$135>>2] = 0;
  $136 = (($1) + 24|0);
  HEAP32[$136>>2] = 0;
  $137 = (($1) + 28|0);
  HEAP32[$137>>2] = 0;
  $138 = (($cinfo) + 188|0);
  $139 = HEAP32[$138>>2]|0;
  $140 = (($1) + 68|0);
  $$c = $139;
  HEAP32[$140>>2] = $$c;
  $141 = (($1) + 72|0);
  HEAP32[$141>>2] = 0;
  STACKTOP = sp;return;
 }
 $24 = (($1) + 36|0);
 $25 = (($1) + 92|0);
 $26 = (($cinfo) + 4|0);
 $27 = (($cinfo) + 316|0);
 $28 = (($1) + 76|0);
 $29 = (($1) + 52|0);
 if ($6) {
  $ci$07$us = 0;
 } else {
  $ci$07 = 0;
  while(1) {
   $83 = ((($cinfo) + ($ci$07<<2)|0) + 232|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($24) + ($ci$07<<2)|0);
   HEAP32[$85>>2] = 0;
   $86 = (($84) + 24|0);
   $87 = HEAP32[$86>>2]|0;
   $$c2 = $87;
   HEAP32[$29>>2] = $$c2;
   if ($19) {
    $88 = ($87>>>0)>(3);
    if ($88) {
     $89 = HEAP32[$cinfo>>2]|0;
     $90 = (($89) + 20|0);
     HEAP32[$90>>2] = 50;
     $91 = (($89) + 24|0);
     HEAP32[$91>>2] = $87;
     $92 = HEAP32[$89>>2]|0;
     FUNCTION_TABLE_vi[$92 & 63]($cinfo);
    }
    $93 = (($25) + ($87<<2)|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = ($94|0)==(0|0);
    if ($95) {
     $96 = HEAP32[$26>>2]|0;
     $97 = HEAP32[$96>>2]|0;
     $98 = (FUNCTION_TABLE_iiii[$97 & 7]($cinfo,1,1028)|0);
     HEAP32[$93>>2] = $98;
     $99 = $98;
    } else {
     $99 = $94;
    }
    _memset(($99|0),0,1028)|0;
    $100 = HEAP32[$27>>2]|0;
    $101 = (($100) + 20|0);
    $102 = HEAP8[$101>>0]|0;
    $103 = ($102<<24>>24)==(0);
    if (!($103)) {
     $104 = HEAP32[$93>>2]|0;
     $i$06 = 0;
     while(1) {
      $105 = $i$06 << 4;
      $106 = (($104) + ($105<<2)|0);
      HEAP32[$106>>2] = 1;
      $107 = $105 | 1;
      $108 = (($104) + ($107<<2)|0);
      HEAP32[$108>>2] = 1;
      $109 = $105 | 2;
      $110 = (($104) + ($109<<2)|0);
      HEAP32[$110>>2] = 1;
      $111 = $105 | 3;
      $112 = (($104) + ($111<<2)|0);
      HEAP32[$112>>2] = 1;
      $113 = $105 | 4;
      $114 = (($104) + ($113<<2)|0);
      HEAP32[$114>>2] = 1;
      $115 = $105 | 5;
      $116 = (($104) + ($115<<2)|0);
      HEAP32[$116>>2] = 1;
      $117 = $105 | 6;
      $118 = (($104) + ($117<<2)|0);
      HEAP32[$118>>2] = 1;
      $119 = $105 | 7;
      $120 = (($104) + ($119<<2)|0);
      HEAP32[$120>>2] = 1;
      $121 = $105 | 8;
      $122 = (($104) + ($121<<2)|0);
      HEAP32[$122>>2] = 1;
      $123 = $105 | 9;
      $124 = (($104) + ($123<<2)|0);
      HEAP32[$124>>2] = 1;
      $125 = $105 | 10;
      $126 = (($104) + ($125<<2)|0);
      HEAP32[$126>>2] = 1;
      $127 = $105 | 11;
      $128 = (($104) + ($127<<2)|0);
      HEAP32[$128>>2] = 1;
      $129 = (($i$06) + 1)|0;
      $exitcond = ($129|0)==(16);
      if ($exitcond) {
       break;
      } else {
       $i$06 = $129;
      }
     }
    }
   } else {
    $130 = (($28) + ($87<<2)|0);
    _jpeg_make_c_derived_tbl($cinfo,$7,$87,$130);
   }
   $131 = (($ci$07) + 1)|0;
   $132 = HEAP32[$21>>2]|0;
   $133 = ($131|0)<($132|0);
   if ($133) {
    $ci$07 = $131;
   } else {
    break;
   }
  }
  $134 = (($1) + 56|0);
  HEAP32[$134>>2] = 0;
  $135 = (($1) + 60|0);
  HEAP32[$135>>2] = 0;
  $136 = (($1) + 24|0);
  HEAP32[$136>>2] = 0;
  $137 = (($1) + 28|0);
  HEAP32[$137>>2] = 0;
  $138 = (($cinfo) + 188|0);
  $139 = HEAP32[$138>>2]|0;
  $140 = (($1) + 68|0);
  $$c = $139;
  HEAP32[$140>>2] = $$c;
  $141 = (($1) + 72|0);
  HEAP32[$141>>2] = 0;
  STACKTOP = sp;return;
 }
 while(1) {
  $30 = ((($cinfo) + ($ci$07$us<<2)|0) + 232|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($24) + ($ci$07$us<<2)|0);
  HEAP32[$32>>2] = 0;
  $33 = HEAP32[$8>>2]|0;
  $34 = ($33|0)==(0);
  do {
   if ($34) {
    $35 = (($31) + 20|0);
    $36 = HEAP32[$35>>2]|0;
    if (!($19)) {
     $37 = (($28) + ($36<<2)|0);
     _jpeg_make_c_derived_tbl($cinfo,$7,$36,$37);
     break;
    }
    $38 = ($36>>>0)>(3);
    if ($38) {
     $39 = HEAP32[$cinfo>>2]|0;
     $40 = (($39) + 20|0);
     HEAP32[$40>>2] = 50;
     $41 = (($39) + 24|0);
     HEAP32[$41>>2] = $36;
     $42 = HEAP32[$39>>2]|0;
     FUNCTION_TABLE_vi[$42 & 63]($cinfo);
    }
    $43 = (($25) + ($36<<2)|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44|0)==(0|0);
    if ($45) {
     $46 = HEAP32[$26>>2]|0;
     $47 = HEAP32[$46>>2]|0;
     $48 = (FUNCTION_TABLE_iiii[$47 & 7]($cinfo,1,1028)|0);
     HEAP32[$43>>2] = $48;
     $49 = $48;
    } else {
     $49 = $44;
    }
    _memset(($49|0),0,1028)|0;
    $50 = HEAP32[$27>>2]|0;
    $51 = (($50) + 20|0);
    $52 = HEAP8[$51>>0]|0;
    $53 = ($52<<24>>24)==(0);
    if (!($53)) {
     $59 = HEAP32[$43>>2]|0;
     $i$06$us = 0;
     while(1) {
      $57 = $i$06$us << 4;
      $58 = (($59) + ($57<<2)|0);
      HEAP32[$58>>2] = 1;
      $60 = $57 | 1;
      $61 = (($59) + ($60<<2)|0);
      HEAP32[$61>>2] = 1;
      $62 = $57 | 2;
      $63 = (($59) + ($62<<2)|0);
      HEAP32[$63>>2] = 1;
      $64 = $57 | 3;
      $65 = (($59) + ($64<<2)|0);
      HEAP32[$65>>2] = 1;
      $66 = $57 | 4;
      $67 = (($59) + ($66<<2)|0);
      HEAP32[$67>>2] = 1;
      $68 = $57 | 5;
      $69 = (($59) + ($68<<2)|0);
      HEAP32[$69>>2] = 1;
      $70 = $57 | 6;
      $71 = (($59) + ($70<<2)|0);
      HEAP32[$71>>2] = 1;
      $72 = $57 | 7;
      $73 = (($59) + ($72<<2)|0);
      HEAP32[$73>>2] = 1;
      $74 = $57 | 8;
      $75 = (($59) + ($74<<2)|0);
      HEAP32[$75>>2] = 1;
      $76 = $57 | 9;
      $77 = (($59) + ($76<<2)|0);
      HEAP32[$77>>2] = 1;
      $78 = $57 | 10;
      $79 = (($59) + ($78<<2)|0);
      HEAP32[$79>>2] = 1;
      $80 = $57 | 11;
      $81 = (($59) + ($80<<2)|0);
      HEAP32[$81>>2] = 1;
      $82 = (($i$06$us) + 1)|0;
      $exitcond9 = ($82|0)==(16);
      if ($exitcond9) {
       break;
      } else {
       $i$06$us = $82;
      }
     }
    }
   }
  } while(0);
  $54 = (($ci$07$us) + 1)|0;
  $55 = HEAP32[$21>>2]|0;
  $56 = ($54|0)<($55|0);
  if ($56) {
   $ci$07$us = $54;
  } else {
   break;
  }
 }
 $134 = (($1) + 56|0);
 HEAP32[$134>>2] = 0;
 $135 = (($1) + 60|0);
 HEAP32[$135>>2] = 0;
 $136 = (($1) + 24|0);
 HEAP32[$136>>2] = 0;
 $137 = (($1) + 28|0);
 HEAP32[$137>>2] = 0;
 $138 = (($cinfo) + 188|0);
 $139 = HEAP32[$138>>2]|0;
 $140 = (($1) + 68|0);
 $$c = $139;
 HEAP32[$140>>2] = $$c;
 $141 = (($1) + 72|0);
 HEAP32[$141>>2] = 0;
 STACKTOP = sp;return;
}
function _encode_mcu_DC_first24($cinfo,$MCU_data) {
 $cinfo = $cinfo|0;
 $MCU_data = $MCU_data|0;
 var $$c1 = 0, $$c2 = 0, $$c3 = 0, $$c4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $blkn$07 = 0, $nbits$0$lcssa10 = 0, $nbits$05 = 0, $temp$0 = 0, $temp$16 = 0, $temp2$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 312|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($cinfo) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($1) + 16|0);
 HEAP32[$7>>2] = $6;
 $8 = HEAP32[$4>>2]|0;
 $9 = (($8) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($1) + 20|0);
 $$c1 = $10;
 HEAP32[$11>>2] = $$c1;
 $12 = (($cinfo) + 188|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = (($1) + 68|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0);
  if ($17) {
   $18 = (($1) + 72|0);
   $19 = HEAP32[$18>>2]|0;
   _emit_restart28($1,$19);
  }
 }
 $20 = (($cinfo) + 256|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)>(0);
 if ($22) {
  $23 = (($1) + 36|0);
  $24 = (($1) + 12|0);
  $blkn$07 = 0;
  while(1) {
   $25 = (($MCU_data) + ($blkn$07<<2)|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($cinfo) + ($blkn$07<<2)|0) + 260|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ((($cinfo) + ($28<<2)|0) + 232|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP16[$26>>1]|0;
   $32 = $31 << 16 >> 16;
   $33 = $32 >> $3;
   $34 = (($23) + ($28<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($33) - ($35))|0;
   HEAP32[$34>>2] = $33;
   $37 = ($36|0)<(0);
   if ($37) {
    $38 = (0 - ($36))|0;
    $39 = (($36) + -1)|0;
    $temp$0 = $38;$temp2$0 = $39;
   } else {
    $temp$0 = $36;$temp2$0 = $36;
   }
   $40 = ($temp$0|0)==(0);
   if ($40) {
    $nbits$0$lcssa10 = 0;
   } else {
    $nbits$05 = 0;$temp$16 = $temp$0;
    while(1) {
     $41 = (($nbits$05) + 1)|0;
     $42 = $temp$16 >> 1;
     $43 = ($42|0)==(0);
     if ($43) {
      break;
     } else {
      $nbits$05 = $41;$temp$16 = $42;
     }
    }
    $44 = ($nbits$05|0)>(10);
    if ($44) {
     $45 = HEAP32[$cinfo>>2]|0;
     $46 = (($45) + 20|0);
     HEAP32[$46>>2] = 6;
     $47 = HEAP32[$45>>2]|0;
     FUNCTION_TABLE_vi[$47 & 63]($cinfo);
     $nbits$0$lcssa10 = $41;
    } else {
     $nbits$0$lcssa10 = $41;
    }
   }
   $48 = (($30) + 20|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = HEAP8[$24>>0]|0;
   $51 = ($50<<24>>24)==(0);
   if ($51) {
    $57 = ((($1) + ($49<<2)|0) + 76|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = (($58) + ($nbits$0$lcssa10<<2)|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ((($58) + ($nbits$0$lcssa10)|0) + 1024|0);
    $62 = HEAP8[$61>>0]|0;
    $63 = $62 << 24 >> 24;
    _emit_bits($1,$60,$63);
   } else {
    $52 = ((($1) + ($49<<2)|0) + 92|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($53) + ($nbits$0$lcssa10<<2)|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($55) + 1)|0;
    HEAP32[$54>>2] = $56;
   }
   $64 = ($nbits$0$lcssa10|0)==(0);
   if (!($64)) {
    _emit_bits($1,$temp2$0,$nbits$0$lcssa10);
   }
   $65 = (($blkn$07) + 1)|0;
   $66 = HEAP32[$20>>2]|0;
   $67 = ($65|0)<($66|0);
   if ($67) {
    $blkn$07 = $65;
   } else {
    break;
   }
  }
 }
 $68 = HEAP32[$7>>2]|0;
 $69 = HEAP32[$4>>2]|0;
 HEAP32[$69>>2] = $68;
 $70 = HEAP32[$11>>2]|0;
 $71 = HEAP32[$4>>2]|0;
 $72 = (($71) + 4|0);
 HEAP32[$72>>2] = $70;
 $73 = HEAP32[$12>>2]|0;
 $74 = ($73|0)==(0);
 if ($74) {
  STACKTOP = sp;return 1;
 }
 $75 = (($1) + 68|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = ($76|0)==(0);
 if ($77) {
  $$c3 = $73;
  HEAP32[$75>>2] = $$c3;
  $78 = (($1) + 72|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = (($79) + 1)|0;
  $81 = $80 & 7;
  $$c4 = $81;
  HEAP32[$78>>2] = $$c4;
  $83 = $73;
 } else {
  $83 = $76;
 }
 $82 = (($83) + -1)|0;
 $$c2 = $82;
 HEAP32[$75>>2] = $$c2;
 STACKTOP = sp;return 1;
}
function _encode_mcu_AC_first25($cinfo,$MCU_data) {
 $cinfo = $cinfo|0;
 $MCU_data = $MCU_data|0;
 var $$c1 = 0, $$c2 = 0, $$c3 = 0, $$c4 = 0, $$c5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $k$08 = 0, $nbits$0 = 0;
 var $r$09 = 0, $r$1$lcssa = 0, $r$17 = 0, $r$2 = 0, $temp$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 304|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($cinfo) + 312|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = 1 << $5;
 $7 = (($6) + -1)|0;
 $8 = (($cinfo) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($1) + 16|0);
 HEAP32[$11>>2] = $10;
 $12 = HEAP32[$8>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($1) + 20|0);
 $$c1 = $14;
 HEAP32[$15>>2] = $$c1;
 $16 = (($cinfo) + 188|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if (!($18)) {
  $19 = (($1) + 68|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0);
  if ($21) {
   $22 = (($1) + 72|0);
   $23 = HEAP32[$22>>2]|0;
   _emit_restart28($1,$23);
  }
 }
 $24 = HEAP32[$MCU_data>>2]|0;
 $25 = (($cinfo) + 300|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)>($3|0);
 if (!($27)) {
  $28 = $7 << 1;
  $29 = (($1) + 56|0);
  $30 = (($1) + 52|0);
  $31 = (($1) + 12|0);
  $k$08 = $26;$r$09 = 0;
  while(1) {
   $32 = (142704 + ($k$08<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($24) + ($33<<1)|0);
   $35 = HEAP16[$34>>1]|0;
   $36 = $35 << 16 >> 16;
   $37 = (($36) + ($7))|0;
   $38 = ($37>>>0)>($28>>>0);
   if ($38) {
    $40 = $36 >> 31;
    $41 = (($40) + ($36))|0;
    $42 = $41 ^ $40;
    $43 = $42 >> $5;
    $44 = $43 ^ $40;
    $45 = HEAP32[$29>>2]|0;
    $46 = ($45|0)==(0);
    if (!($46)) {
     _emit_eobrun($1);
    }
    $47 = ($r$09|0)>(15);
    if ($47) {
     $r$17 = $r$09;
     while(1) {
      $48 = HEAP32[$30>>2]|0;
      $49 = HEAP8[$31>>0]|0;
      $50 = ($49<<24>>24)==(0);
      if ($50) {
       $56 = ((($1) + ($48<<2)|0) + 76|0);
       $57 = HEAP32[$56>>2]|0;
       $58 = (($57) + 960|0);
       $59 = HEAP32[$58>>2]|0;
       $60 = (($57) + 1264|0);
       $61 = HEAP8[$60>>0]|0;
       $62 = $61 << 24 >> 24;
       _emit_bits($1,$59,$62);
      } else {
       $51 = ((($1) + ($48<<2)|0) + 92|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 960|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = (($54) + 1)|0;
       HEAP32[$53>>2] = $55;
      }
      $63 = (($r$17) + -16)|0;
      $64 = ($63|0)>(15);
      if ($64) {
       $r$17 = $63;
      } else {
       break;
      }
     }
     $65 = $r$09 & 15;
     $r$1$lcssa = $65;
    } else {
     $r$1$lcssa = $r$09;
    }
    $nbits$0 = 1;$temp$0 = $43;
    while(1) {
     $66 = $temp$0 >> 1;
     $67 = ($66|0)==(0);
     $68 = (($nbits$0) + 1)|0;
     if ($67) {
      break;
     } else {
      $nbits$0 = $68;$temp$0 = $66;
     }
    }
    $69 = ($nbits$0|0)>(10);
    if ($69) {
     $70 = HEAP32[$cinfo>>2]|0;
     $71 = (($70) + 20|0);
     HEAP32[$71>>2] = 6;
     $72 = HEAP32[$70>>2]|0;
     FUNCTION_TABLE_vi[$72 & 63]($cinfo);
    }
    $73 = HEAP32[$30>>2]|0;
    $74 = $r$1$lcssa << 4;
    $75 = (($nbits$0) + ($74))|0;
    $76 = HEAP8[$31>>0]|0;
    $77 = ($76<<24>>24)==(0);
    if ($77) {
     $83 = ((($1) + ($73<<2)|0) + 76|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = (($84) + ($75<<2)|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = ((($84) + ($75)|0) + 1024|0);
     $88 = HEAP8[$87>>0]|0;
     $89 = $88 << 24 >> 24;
     _emit_bits($1,$86,$89);
    } else {
     $78 = ((($1) + ($73<<2)|0) + 92|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = (($79) + ($75<<2)|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = (($81) + 1)|0;
     HEAP32[$80>>2] = $82;
    }
    _emit_bits($1,$44,$nbits$0);
    $r$2 = 0;
   } else {
    $39 = (($r$09) + 1)|0;
    $r$2 = $39;
   }
   $90 = (($k$08) + 1)|0;
   $91 = ($k$08|0)<($3|0);
   if ($91) {
    $k$08 = $90;$r$09 = $r$2;
   } else {
    break;
   }
  }
  $92 = ($r$2|0)>(0);
  if ($92) {
   $93 = (($1) + 56|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 1)|0;
   $$c5 = $95;
   HEAP32[$93>>2] = $$c5;
   $96 = ($95|0)==(32767);
   if ($96) {
    _emit_eobrun($1);
   }
  }
 }
 $97 = HEAP32[$11>>2]|0;
 $98 = HEAP32[$8>>2]|0;
 HEAP32[$98>>2] = $97;
 $99 = HEAP32[$15>>2]|0;
 $100 = HEAP32[$8>>2]|0;
 $101 = (($100) + 4|0);
 HEAP32[$101>>2] = $99;
 $102 = HEAP32[$16>>2]|0;
 $103 = ($102|0)==(0);
 if ($103) {
  STACKTOP = sp;return 1;
 }
 $104 = (($1) + 68|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = ($105|0)==(0);
 if ($106) {
  $$c3 = $102;
  HEAP32[$104>>2] = $$c3;
  $107 = (($1) + 72|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (($108) + 1)|0;
  $110 = $109 & 7;
  $$c4 = $110;
  HEAP32[$107>>2] = $$c4;
  $112 = $102;
 } else {
  $112 = $105;
 }
 $111 = (($112) + -1)|0;
 $$c2 = $111;
 HEAP32[$104>>2] = $$c2;
 STACKTOP = sp;return 1;
}
function _encode_mcu_DC_refine26($cinfo,$MCU_data) {
 $cinfo = $cinfo|0;
 $MCU_data = $MCU_data|0;
 var $$c1 = 0, $$c2 = 0, $$c3 = 0, $$c4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $blkn$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 312|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($cinfo) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($1) + 16|0);
 HEAP32[$7>>2] = $6;
 $8 = HEAP32[$4>>2]|0;
 $9 = (($8) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($1) + 20|0);
 $$c1 = $10;
 HEAP32[$11>>2] = $$c1;
 $12 = (($cinfo) + 188|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = (($1) + 68|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0);
  if ($17) {
   $18 = (($1) + 72|0);
   $19 = HEAP32[$18>>2]|0;
   _emit_restart28($1,$19);
  }
 }
 $20 = (($cinfo) + 256|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)>(0);
 if ($22) {
  $blkn$05 = 0;
  while(1) {
   $23 = (($MCU_data) + ($blkn$05<<2)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = HEAP16[$24>>1]|0;
   $26 = $25 << 16 >> 16;
   $27 = $26 >> $3;
   _emit_bits($1,$27,1);
   $28 = (($blkn$05) + 1)|0;
   $29 = HEAP32[$20>>2]|0;
   $30 = ($28|0)<($29|0);
   if ($30) {
    $blkn$05 = $28;
   } else {
    break;
   }
  }
 }
 $31 = HEAP32[$7>>2]|0;
 $32 = HEAP32[$4>>2]|0;
 HEAP32[$32>>2] = $31;
 $33 = HEAP32[$11>>2]|0;
 $34 = HEAP32[$4>>2]|0;
 $35 = (($34) + 4|0);
 HEAP32[$35>>2] = $33;
 $36 = HEAP32[$12>>2]|0;
 $37 = ($36|0)==(0);
 if ($37) {
  STACKTOP = sp;return 1;
 }
 $38 = (($1) + 68|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0);
 if ($40) {
  $$c3 = $36;
  HEAP32[$38>>2] = $$c3;
  $41 = (($1) + 72|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($42) + 1)|0;
  $44 = $43 & 7;
  $$c4 = $44;
  HEAP32[$41>>2] = $$c4;
  $46 = $36;
 } else {
  $46 = $39;
 }
 $45 = (($46) + -1)|0;
 $$c2 = $45;
 HEAP32[$38>>2] = $$c2;
 STACKTOP = sp;return 1;
}
function _encode_mcu_AC_refine27($cinfo,$MCU_data) {
 $cinfo = $cinfo|0;
 $MCU_data = $MCU_data|0;
 var $$ = 0, $$012$i = 0, $$012$i12 = 0, $$03$i = 0, $$03$i11 = 0, $$c1 = 0, $$c2 = 0, $$c3 = 0, $$c4 = 0, $$c5 = 0, $$c6 = 0, $$lobit = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $BR$0$lcssa = 0, $BR$022 = 0, $BR$1$lcssa = 0, $BR$117 = 0;
 var $BR$2 = 0, $BR_buffer$021 = 0, $BR_buffer$1$lcssa = 0, $BR_buffer$116 = 0, $BR_buffer$2 = 0, $EOB$029 = 0, $EOB$1 = 0, $absvalues = 0, $k$030 = 0, $k$123 = 0, $or$cond$i = 0, $or$cond$i10 = 0, $or$cond15 = 0, $or$cond7 = 0, $or$cond8 = 0, $r$0$lcssa = 0, $r$025 = 0, $r$1$lcssa = 0, $r$118 = 0, $r$2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $absvalues = sp;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 304|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($cinfo) + 312|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($cinfo) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($1) + 16|0);
 HEAP32[$9>>2] = $8;
 $10 = HEAP32[$6>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($1) + 20|0);
 $$c1 = $12;
 HEAP32[$13>>2] = $$c1;
 $14 = (($cinfo) + 188|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if (!($16)) {
  $17 = (($1) + 68|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0);
  if ($19) {
   $20 = (($1) + 72|0);
   $21 = HEAP32[$20>>2]|0;
   _emit_restart28($1,$21);
  }
 }
 $22 = HEAP32[$MCU_data>>2]|0;
 $23 = (($cinfo) + 300|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>($3|0);
 if ($25) {
  $26 = (($1) + 60|0);
  $122 = $26;$124 = $26;$BR$0$lcssa = 0;$r$0$lcssa = 0;
 } else {
  $EOB$029 = 0;$k$030 = $24;
  while(1) {
   $27 = (142704 + ($k$030<<2)|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($22) + ($28<<1)|0);
   $30 = HEAP16[$29>>1]|0;
   $31 = $30 << 16 >> 16;
   $32 = ($30<<16>>16)<(0);
   $33 = (0 - ($31))|0;
   $$ = $32 ? $33 : $31;
   $34 = $$ >> $5;
   $35 = (($absvalues) + ($k$030<<2)|0);
   HEAP32[$35>>2] = $34;
   $36 = ($34|0)==(1);
   $EOB$1 = $36 ? $k$030 : $EOB$029;
   $37 = (($k$030) + 1)|0;
   $38 = ($k$030|0)<($3|0);
   if ($38) {
    $EOB$029 = $EOB$1;$k$030 = $37;
   } else {
    break;
   }
  }
  $39 = (($1) + 64|0);
  $40 = (($1) + 60|0);
  if ($25) {
   $122 = $40;$124 = $40;$BR$0$lcssa = 0;$r$0$lcssa = 0;
  } else {
   $41 = HEAP32[$39>>2]|0;
   $42 = HEAP32[$40>>2]|0;
   $43 = (($41) + ($42)|0);
   $44 = (($1) + 52|0);
   $45 = (($1) + 12|0);
   $BR$022 = 0;$BR_buffer$021 = $43;$k$123 = $24;$r$025 = 0;
   while(1) {
    $46 = (($absvalues) + ($k$123<<2)|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ($47|0)==(0);
    do {
     if ($48) {
      $51 = (($r$025) + 1)|0;
      $BR$2 = $BR$022;$BR_buffer$2 = $BR_buffer$021;$r$2 = $51;
     } else {
      $49 = ($r$025|0)<(16);
      $50 = ($k$123|0)>($EOB$1|0);
      $or$cond15 = $49 | $50;
      if ($or$cond15) {
       $BR$1$lcssa = $BR$022;$BR_buffer$1$lcssa = $BR_buffer$021;$r$1$lcssa = $r$025;
      } else {
       $BR$117 = $BR$022;$BR_buffer$116 = $BR_buffer$021;$r$118 = $r$025;
       while(1) {
        _emit_eobrun($1);
        $52 = HEAP32[$44>>2]|0;
        $53 = HEAP8[$45>>0]|0;
        $54 = ($53<<24>>24)==(0);
        if ($54) {
         $60 = ((($1) + ($52<<2)|0) + 76|0);
         $61 = HEAP32[$60>>2]|0;
         $62 = (($61) + 960|0);
         $63 = HEAP32[$62>>2]|0;
         $64 = (($61) + 1264|0);
         $65 = HEAP8[$64>>0]|0;
         $66 = $65 << 24 >> 24;
         _emit_bits($1,$63,$66);
        } else {
         $55 = ((($1) + ($52<<2)|0) + 92|0);
         $56 = HEAP32[$55>>2]|0;
         $57 = (($56) + 960|0);
         $58 = HEAP32[$57>>2]|0;
         $59 = (($58) + 1)|0;
         HEAP32[$57>>2] = $59;
        }
        $67 = (($r$118) + -16)|0;
        $68 = HEAP8[$45>>0]|0;
        $69 = ($68<<24>>24)!=(0);
        $70 = ($BR$117|0)==(0);
        $or$cond$i = $69 | $70;
        if (!($or$cond$i)) {
         $$012$i = $BR_buffer$116;$$03$i = $BR$117;
         while(1) {
          $71 = HEAP8[$$012$i>>0]|0;
          $72 = $71 << 24 >> 24;
          _emit_bits($1,$72,1);
          $73 = (($$012$i) + 1|0);
          $74 = (($$03$i) + -1)|0;
          $75 = ($74|0)==(0);
          if ($75) {
           break;
          } else {
           $$012$i = $73;$$03$i = $74;
          }
         }
        }
        $76 = HEAP32[$39>>2]|0;
        $77 = ($67|0)<(16);
        if ($77) {
         $BR$1$lcssa = 0;$BR_buffer$1$lcssa = $76;$r$1$lcssa = $67;
         break;
        } else {
         $BR$117 = 0;$BR_buffer$116 = $76;$r$118 = $67;
        }
       }
      }
      $78 = ($47|0)>(1);
      if ($78) {
       $79 = $47 & 1;
       $80 = $79&255;
       $81 = (($BR$1$lcssa) + 1)|0;
       $82 = (($BR_buffer$1$lcssa) + ($BR$1$lcssa)|0);
       HEAP8[$82>>0] = $80;
       $BR$2 = $81;$BR_buffer$2 = $BR_buffer$1$lcssa;$r$2 = $r$1$lcssa;
       break;
      }
      _emit_eobrun($1);
      $83 = HEAP32[$44>>2]|0;
      $84 = $r$1$lcssa << 4;
      $85 = $84 | 1;
      $86 = HEAP8[$45>>0]|0;
      $87 = ($86<<24>>24)==(0);
      if ($87) {
       $93 = ((($1) + ($83<<2)|0) + 76|0);
       $94 = HEAP32[$93>>2]|0;
       $95 = (($94) + ($85<<2)|0);
       $96 = HEAP32[$95>>2]|0;
       $97 = ((($94) + ($85)|0) + 1024|0);
       $98 = HEAP8[$97>>0]|0;
       $99 = $98 << 24 >> 24;
       _emit_bits($1,$96,$99);
      } else {
       $88 = ((($1) + ($83<<2)|0) + 92|0);
       $89 = HEAP32[$88>>2]|0;
       $90 = (($89) + ($85<<2)|0);
       $91 = HEAP32[$90>>2]|0;
       $92 = (($91) + 1)|0;
       HEAP32[$90>>2] = $92;
      }
      $100 = (142704 + ($k$123<<2)|0);
      $101 = HEAP32[$100>>2]|0;
      $102 = (($22) + ($101<<1)|0);
      $103 = HEAP16[$102>>1]|0;
      $$lobit = ($103&65535) >>> 15;
      $104 = $$lobit&65535;
      $$not = $104 ^ 1;
      _emit_bits($1,$$not,1);
      $105 = HEAP8[$45>>0]|0;
      $106 = ($105<<24>>24)!=(0);
      $107 = ($BR$1$lcssa|0)==(0);
      $or$cond$i10 = $106 | $107;
      if (!($or$cond$i10)) {
       $$012$i12 = $BR_buffer$1$lcssa;$$03$i11 = $BR$1$lcssa;
       while(1) {
        $108 = HEAP8[$$012$i12>>0]|0;
        $109 = $108 << 24 >> 24;
        _emit_bits($1,$109,1);
        $110 = (($$012$i12) + 1|0);
        $111 = (($$03$i11) + -1)|0;
        $112 = ($111|0)==(0);
        if ($112) {
         break;
        } else {
         $$012$i12 = $110;$$03$i11 = $111;
        }
       }
      }
      $113 = HEAP32[$39>>2]|0;
      $BR$2 = 0;$BR_buffer$2 = $113;$r$2 = 0;
     }
    } while(0);
    $114 = (($k$123) + 1)|0;
    $115 = ($k$123|0)<($3|0);
    if ($115) {
     $BR$022 = $BR$2;$BR_buffer$021 = $BR_buffer$2;$k$123 = $114;$r$025 = $r$2;
    } else {
     $122 = $40;$124 = $40;$BR$0$lcssa = $BR$2;$r$0$lcssa = $r$2;
     break;
    }
   }
  }
 }
 $116 = ($r$0$lcssa|0)<(1);
 $117 = ($BR$0$lcssa|0)==(0);
 $or$cond7 = $116 & $117;
 if (!($or$cond7)) {
  $118 = (($1) + 56|0);
  $119 = HEAP32[$118>>2]|0;
  $120 = (($119) + 1)|0;
  $$c5 = $120;
  HEAP32[$118>>2] = $$c5;
  $121 = HEAP32[$122>>2]|0;
  $123 = (($121) + ($BR$0$lcssa))|0;
  $$c6 = $123;
  HEAP32[$124>>2] = $$c6;
  $125 = ($120|0)==(32767);
  $126 = ($123>>>0)>(937);
  $or$cond8 = $125 | $126;
  if ($or$cond8) {
   _emit_eobrun($1);
  }
 }
 $127 = HEAP32[$9>>2]|0;
 $128 = HEAP32[$6>>2]|0;
 HEAP32[$128>>2] = $127;
 $129 = HEAP32[$13>>2]|0;
 $130 = HEAP32[$6>>2]|0;
 $131 = (($130) + 4|0);
 HEAP32[$131>>2] = $129;
 $132 = HEAP32[$14>>2]|0;
 $133 = ($132|0)==(0);
 if ($133) {
  STACKTOP = sp;return 1;
 }
 $134 = (($1) + 68|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = ($135|0)==(0);
 if ($136) {
  $$c3 = $132;
  HEAP32[$134>>2] = $$c3;
  $137 = (($1) + 72|0);
  $138 = HEAP32[$137>>2]|0;
  $139 = (($138) + 1)|0;
  $140 = $139 & 7;
  $$c4 = $140;
  HEAP32[$137>>2] = $$c4;
  $142 = $132;
 } else {
  $142 = $135;
 }
 $141 = (($142) + -1)|0;
 $$c2 = $141;
 HEAP32[$134>>2] = $$c2;
 STACKTOP = sp;return 1;
}
function _finish_pass_gather_phuff($cinfo) {
 $cinfo = $cinfo|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ci$01 = 0, $did = 0, $htblptr$0 = 0, $tbl$0 = 0, $tbl$0$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $did = sp;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 _emit_eobrun($1);
 $2 = (($cinfo) + 300|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 HEAP32[$did>>2] = 0;
 $5 = (($cinfo) + 228|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)>(0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($cinfo) + 308|0);
 $9 = (($1) + 92|0);
 $30 = $6;$ci$01 = 0;
 while(1) {
  $10 = ((($cinfo) + ($ci$01<<2)|0) + 232|0);
  $11 = HEAP32[$10>>2]|0;
  if ($4) {
   $12 = HEAP32[$8>>2]|0;
   $13 = ($12|0)==(0);
   if ($13) {
    $14 = (($11) + 20|0);
    $tbl$0$in = $14;
    label = 7;
   } else {
    $29 = $30;
   }
  } else {
   $15 = (($11) + 24|0);
   $tbl$0$in = $15;
   label = 7;
  }
  if ((label|0) == 7) {
   label = 0;
   $tbl$0 = HEAP32[$tbl$0$in>>2]|0;
   $16 = (($did) + ($tbl$0)|0);
   $17 = HEAP8[$16>>0]|0;
   $18 = ($17<<24>>24)==(0);
   if ($18) {
    if ($4) {
     $19 = ((($cinfo) + ($tbl$0<<2)|0) + 88|0);
     $htblptr$0 = $19;
    } else {
     $20 = ((($cinfo) + ($tbl$0<<2)|0) + 104|0);
     $htblptr$0 = $20;
    }
    $21 = HEAP32[$htblptr$0>>2]|0;
    $22 = ($21|0)==(0|0);
    if ($22) {
     $23 = (_jpeg_alloc_huff_table($cinfo)|0);
     HEAP32[$htblptr$0>>2] = $23;
     $26 = $23;
    } else {
     $26 = $21;
    }
    $24 = (($9) + ($tbl$0<<2)|0);
    $25 = HEAP32[$24>>2]|0;
    _jpeg_gen_optimal_table($cinfo,$26,$25);
    HEAP8[$16>>0] = 1;
    $$pre = HEAP32[$5>>2]|0;
    $29 = $$pre;
   } else {
    $29 = $30;
   }
  }
  $27 = (($ci$01) + 1)|0;
  $28 = ($27|0)<($29|0);
  if ($28) {
   $30 = $29;$ci$01 = $27;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _finish_pass_phuff($cinfo) {
 $cinfo = $cinfo|0;
 var $$c1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($1) + 16|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[$2>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($1) + 20|0);
 $$c1 = $8;
 HEAP32[$9>>2] = $$c1;
 _emit_eobrun($1);
 _emit_bits($1,127,7);
 $10 = (($1) + 24|0);
 HEAP32[$10>>2] = 0;
 $11 = (($1) + 28|0);
 HEAP32[$11>>2] = 0;
 $12 = HEAP32[$5>>2]|0;
 $13 = HEAP32[$2>>2]|0;
 HEAP32[$13>>2] = $12;
 $14 = HEAP32[$9>>2]|0;
 $15 = HEAP32[$2>>2]|0;
 $16 = (($15) + 4|0);
 HEAP32[$16>>2] = $14;
 STACKTOP = sp;return;
}
function _emit_eobrun($entropy) {
 $entropy = $entropy|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $nbits$0 = 0, $or$cond$i = 0, $temp$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($entropy) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 } else {
  $nbits$0 = 0;$temp$0 = $1;
 }
 while(1) {
  $3 = $temp$0 >> 1;
  $4 = ($3|0)==(0);
  $5 = (($nbits$0) + 1)|0;
  if ($4) {
   break;
  } else {
   $nbits$0 = $5;$temp$0 = $3;
  }
 }
 $6 = ($nbits$0|0)>(14);
 if ($6) {
  $7 = (($entropy) + 32|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 20|0);
  HEAP32[$10>>2] = 40;
  $11 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vi[$11 & 63]($8);
 }
 $12 = (($entropy) + 52|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $nbits$0 << 4;
 $15 = (($entropy) + 12|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)==(0);
 if ($17) {
  $23 = ((($entropy) + ($13<<2)|0) + 76|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + ($14<<2)|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ((($24) + ($14)|0) + 1024|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = $28 << 24 >> 24;
  _emit_bits($entropy,$26,$29);
 } else {
  $18 = ((($entropy) + ($13<<2)|0) + 92|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + ($14<<2)|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + 1)|0;
  HEAP32[$20>>2] = $22;
 }
 $30 = ($nbits$0|0)==(0);
 if (!($30)) {
  $31 = HEAP32[$0>>2]|0;
  _emit_bits($entropy,$31,$nbits$0);
 }
 HEAP32[$0>>2] = 0;
 $32 = (($entropy) + 60|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP8[$15>>0]|0;
 $35 = ($34<<24>>24)!=(0);
 $36 = ($33|0)==(0);
 $or$cond$i = $35 | $36;
 if (!($or$cond$i)) {
  $37 = (($entropy) + 64|0);
  $38 = HEAP32[$37>>2]|0;
  $$012$i = $38;$$03$i = $33;
  while(1) {
   $39 = HEAP8[$$012$i>>0]|0;
   $40 = $39 << 24 >> 24;
   _emit_bits($entropy,$40,1);
   $41 = (($$012$i) + 1|0);
   $42 = (($$03$i) + -1)|0;
   $43 = ($42|0)==(0);
   if ($43) {
    break;
   } else {
    $$012$i = $41;$$03$i = $42;
   }
  }
 }
 HEAP32[$32>>2] = 0;
 STACKTOP = sp;return;
}
function _emit_bits($entropy,$code,$size) {
 $entropy = $entropy|0;
 $code = $code|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $put_bits$0$lcssa = 0, $put_bits$02 = 0, $put_buffer$0$lcssa = 0, $put_buffer$03 = 0;
 var $smax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($entropy) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($size|0)==(0);
 if ($2) {
  $3 = (($entropy) + 32|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 20|0);
  HEAP32[$6>>2] = 40;
  $7 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vi[$7 & 63]($4);
 }
 $8 = (($entropy) + 12|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = 1 << $size;
 $12 = (($11) + -1)|0;
 $13 = $12 & $code;
 $14 = (($1) + ($size))|0;
 $15 = (24 - ($14))|0;
 $16 = $13 << $15;
 $17 = (($entropy) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 | $16;
 $20 = ($14|0)>(7);
 if ($20) {
  $21 = (($entropy) + 16|0);
  $22 = (($entropy) + 20|0);
  $23 = (($entropy) + 32|0);
  $24 = (7 - ($1))|0;
  $25 = (($24) - ($size))|0;
  $26 = ($25|0)>(-8);
  $smax = $26 ? $25 : -8;
  $27 = (($14) + ($smax))|0;
  $28 = $27 & -8;
  $put_bits$02 = $14;$put_buffer$03 = $19;
  while(1) {
   $29 = $put_buffer$03 >>> 16;
   $30 = $29 & 255;
   $31 = $29&255;
   $32 = HEAP32[$21>>2]|0;
   $33 = (($32) + 1|0);
   HEAP32[$21>>2] = $33;
   HEAP8[$32>>0] = $31;
   $34 = HEAP32[$22>>2]|0;
   $35 = (($34) + -1)|0;
   HEAP32[$22>>2] = $35;
   $36 = ($35|0)==(0);
   if ($36) {
    $37 = HEAP32[$23>>2]|0;
    $38 = (($37) + 24|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($39) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (FUNCTION_TABLE_ii[$41 & 7]($37)|0);
    $43 = ($42<<24>>24)==(0);
    if ($43) {
     $44 = HEAP32[$23>>2]|0;
     $45 = HEAP32[$44>>2]|0;
     $46 = (($45) + 20|0);
     HEAP32[$46>>2] = 24;
     $47 = HEAP32[$45>>2]|0;
     FUNCTION_TABLE_vi[$47 & 63]($44);
    }
    $48 = HEAP32[$39>>2]|0;
    HEAP32[$21>>2] = $48;
    $49 = (($39) + 4|0);
    $50 = HEAP32[$49>>2]|0;
    HEAP32[$22>>2] = $50;
   }
   $51 = ($30|0)==(255);
   if ($51) {
    $52 = HEAP32[$21>>2]|0;
    $53 = (($52) + 1|0);
    HEAP32[$21>>2] = $53;
    HEAP8[$52>>0] = 0;
    $54 = HEAP32[$22>>2]|0;
    $55 = (($54) + -1)|0;
    HEAP32[$22>>2] = $55;
    $56 = ($55|0)==(0);
    if ($56) {
     $57 = HEAP32[$23>>2]|0;
     $58 = (($57) + 24|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = (($59) + 12|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = (FUNCTION_TABLE_ii[$61 & 7]($57)|0);
     $63 = ($62<<24>>24)==(0);
     if ($63) {
      $64 = HEAP32[$23>>2]|0;
      $65 = HEAP32[$64>>2]|0;
      $66 = (($65) + 20|0);
      HEAP32[$66>>2] = 24;
      $67 = HEAP32[$65>>2]|0;
      FUNCTION_TABLE_vi[$67 & 63]($64);
     }
     $68 = HEAP32[$59>>2]|0;
     HEAP32[$21>>2] = $68;
     $69 = (($59) + 4|0);
     $70 = HEAP32[$69>>2]|0;
     HEAP32[$22>>2] = $70;
    }
   }
   $71 = $put_buffer$03 << 8;
   $72 = (($put_bits$02) + -8)|0;
   $73 = ($72|0)>(7);
   if ($73) {
    $put_bits$02 = $72;$put_buffer$03 = $71;
   } else {
    break;
   }
  }
  $74 = (($14) + -8)|0;
  $75 = (($74) - ($28))|0;
  $put_bits$0$lcssa = $75;$put_buffer$0$lcssa = $71;
 } else {
  $put_bits$0$lcssa = $14;$put_buffer$0$lcssa = $19;
 }
 HEAP32[$17>>2] = $put_buffer$0$lcssa;
 HEAP32[$0>>2] = $put_bits$0$lcssa;
 STACKTOP = sp;return;
}
function _emit_restart28($entropy,$restart_num) {
 $entropy = $entropy|0;
 $restart_num = $restart_num|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $ci$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _emit_eobrun($entropy);
 $0 = (($entropy) + 12|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  _emit_bits($entropy,127,7);
  $3 = (($entropy) + 24|0);
  HEAP32[$3>>2] = 0;
  $4 = (($entropy) + 28|0);
  HEAP32[$4>>2] = 0;
  $5 = (($entropy) + 16|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 1|0);
  HEAP32[$5>>2] = $7;
  HEAP8[$6>>0] = -1;
  $8 = (($entropy) + 20|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + -1)|0;
  HEAP32[$8>>2] = $10;
  $11 = ($10|0)==(0);
  if ($11) {
   $12 = (($entropy) + 32|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + 12|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (FUNCTION_TABLE_ii[$17 & 7]($13)|0);
   $19 = ($18<<24>>24)==(0);
   if ($19) {
    $20 = HEAP32[$12>>2]|0;
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 20|0);
    HEAP32[$22>>2] = 24;
    $23 = HEAP32[$21>>2]|0;
    FUNCTION_TABLE_vi[$23 & 63]($20);
   }
   $24 = HEAP32[$15>>2]|0;
   HEAP32[$5>>2] = $24;
   $25 = (($15) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   HEAP32[$8>>2] = $26;
   $30 = $24;
  } else {
   $$pre = HEAP32[$5>>2]|0;
   $30 = $$pre;
  }
  $27 = (($restart_num) + 208)|0;
  $28 = $27&255;
  $29 = (($30) + 1|0);
  HEAP32[$5>>2] = $29;
  HEAP8[$30>>0] = $28;
  $31 = HEAP32[$8>>2]|0;
  $32 = (($31) + -1)|0;
  HEAP32[$8>>2] = $32;
  $33 = ($32|0)==(0);
  if ($33) {
   $34 = (($entropy) + 32|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($35) + 24|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($37) + 12|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (FUNCTION_TABLE_ii[$39 & 7]($35)|0);
   $41 = ($40<<24>>24)==(0);
   if ($41) {
    $42 = HEAP32[$34>>2]|0;
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 20|0);
    HEAP32[$44>>2] = 24;
    $45 = HEAP32[$43>>2]|0;
    FUNCTION_TABLE_vi[$45 & 63]($42);
   }
   $46 = HEAP32[$37>>2]|0;
   HEAP32[$5>>2] = $46;
   $47 = (($37) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   HEAP32[$8>>2] = $48;
  }
 }
 $49 = (($entropy) + 32|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($50) + 300|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(0);
 if (!($53)) {
  $63 = (($entropy) + 56|0);
  HEAP32[$63>>2] = 0;
  $64 = (($entropy) + 60|0);
  HEAP32[$64>>2] = 0;
  STACKTOP = sp;return;
 }
 $54 = (($50) + 228|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)>(0);
 if ($56) {
  $ci$02 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $57 = ((($entropy) + ($ci$02<<2)|0) + 36|0);
  HEAP32[$57>>2] = 0;
  $58 = (($ci$02) + 1)|0;
  $59 = HEAP32[$49>>2]|0;
  $60 = (($59) + 228|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ($58|0)<($61|0);
  if ($62) {
   $ci$02 = $58;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _jinit_c_prep_controller($cinfo,$need_full_buffer) {
 $cinfo = $cinfo|0;
 $need_full_buffer = $need_full_buffer|0;
 var $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ci$01 = 0, $ci$03$i = 0, $ci$03$us$i = 0, $compptr$02 = 0, $compptr$02$i = 0, $compptr$02$us$i = 0, $exitcond$i = 0, $fake_buffer$04$i = 0, $fake_buffer$04$us$i = 0;
 var $i$01$us$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($need_full_buffer<<24>>24)==(0);
 if ($0) {
  $$pre$phiZ2D = $cinfo;
 } else {
  $1 = HEAP32[$cinfo>>2]|0;
  $2 = (($1) + 20|0);
  HEAP32[$2>>2] = 4;
  $3 = HEAP32[$1>>2]|0;
  FUNCTION_TABLE_vi[$3 & 63]($cinfo);
  $$pre$phiZ2D = $cinfo;
 }
 $4 = (($cinfo) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$6 & 7]($$pre$phiZ2D,1,64)|0);
 $8 = (($cinfo) + 324|0);
 HEAP32[$8>>2] = $7;
 HEAP32[$7>>2] = 9;
 $9 = (($cinfo) + 340|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 $14 = (($7) + 4|0);
 if ($13) {
  HEAP32[$14>>2] = 2;
  $84 = (($cinfo) + 60|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = ($85|0)>(0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($cinfo) + 68|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = (($cinfo) + 216|0);
  $90 = (($cinfo) + 220|0);
  $91 = (($7) + 8|0);
  $ci$01 = 0;$compptr$02 = $88;
  while(1) {
   $92 = HEAP32[$4>>2]|0;
   $93 = (($92) + 8|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($compptr$02) + 28|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = $96 << 3;
   $98 = HEAP32[$89>>2]|0;
   $99 = Math_imul($97, $98)|0;
   $100 = (($compptr$02) + 8|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = (($99|0) / ($101|0))&-1;
   $103 = HEAP32[$90>>2]|0;
   $104 = (FUNCTION_TABLE_iiiii[$94 & 3]($$pre$phiZ2D,1,$102,$103)|0);
   $105 = (($91) + ($ci$01<<2)|0);
   HEAP32[$105>>2] = $104;
   $106 = (($ci$01) + 1)|0;
   $107 = (($compptr$02) + 84|0);
   $108 = HEAP32[$84>>2]|0;
   $109 = ($106|0)<($108|0);
   if ($109) {
    $ci$01 = $106;$compptr$02 = $107;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 }
 HEAP32[$14>>2] = 1;
 $15 = HEAP32[$8>>2]|0;
 $16 = (($cinfo) + 220|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$4>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($cinfo) + 60|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($17*20)|0;
 $23 = Math_imul($22, $21)|0;
 $24 = (FUNCTION_TABLE_iiii[$19 & 7]($$pre$phiZ2D,1,$23)|0);
 $25 = (($cinfo) + 68|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$20>>2]|0;
 $28 = ($27|0)>(0);
 if (!($28)) {
  STACKTOP = sp;return;
 }
 $29 = (($cinfo) + 216|0);
 $30 = ($17*3)|0;
 $31 = ($17*12)|0;
 $32 = ($17|0)>(0);
 $33 = (($15) + 8|0);
 $34 = ($17*5)|0;
 $35 = $17 << 1;
 $36 = $17 << 2;
 if ($32) {
  $ci$03$us$i = 0;$compptr$02$us$i = $26;$fake_buffer$04$us$i = $24;
 } else {
  $ci$03$i = 0;$compptr$02$i = $26;$fake_buffer$04$i = $24;
  while(1) {
   $65 = HEAP32[$4>>2]|0;
   $66 = (($65) + 8|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($compptr$02$i) + 28|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = $69 << 3;
   $71 = HEAP32[$29>>2]|0;
   $72 = Math_imul($70, $71)|0;
   $73 = (($compptr$02$i) + 8|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = (($72|0) / ($74|0))&-1;
   $76 = (FUNCTION_TABLE_iiiii[$67 & 3]($$pre$phiZ2D,1,$75,$30)|0);
   $77 = (($fake_buffer$04$i) + ($17<<2)|0);
   _memcpy(($77|0),($76|0),($31|0))|0;
   $78 = (($33) + ($ci$03$i<<2)|0);
   HEAP32[$78>>2] = $77;
   $79 = (($fake_buffer$04$i) + ($34<<2)|0);
   $80 = (($ci$03$i) + 1)|0;
   $81 = (($compptr$02$i) + 84|0);
   $82 = HEAP32[$20>>2]|0;
   $83 = ($80|0)<($82|0);
   if ($83) {
    $ci$03$i = $80;$compptr$02$i = $81;$fake_buffer$04$i = $79;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 }
 while(1) {
  $54 = HEAP32[$4>>2]|0;
  $55 = (($54) + 8|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (($compptr$02$us$i) + 28|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = $58 << 3;
  $60 = HEAP32[$29>>2]|0;
  $61 = Math_imul($59, $60)|0;
  $62 = (($compptr$02$us$i) + 8|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (($61|0) / ($63|0))&-1;
  $46 = (FUNCTION_TABLE_iiiii[$56 & 3]($$pre$phiZ2D,1,$64,$30)|0);
  $38 = (($fake_buffer$04$us$i) + ($17<<2)|0);
  _memcpy(($38|0),($46|0),($31|0))|0;
  $i$01$us$i = 0;
  while(1) {
   $44 = (($i$01$us$i) + ($35))|0;
   $45 = (($46) + ($44<<2)|0);
   $47 = HEAP32[$45>>2]|0;
   $48 = (($fake_buffer$04$us$i) + ($i$01$us$i<<2)|0);
   HEAP32[$48>>2] = $47;
   $49 = (($46) + ($i$01$us$i<<2)|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($i$01$us$i) + ($36))|0;
   $52 = (($fake_buffer$04$us$i) + ($51<<2)|0);
   HEAP32[$52>>2] = $50;
   $53 = (($i$01$us$i) + 1)|0;
   $exitcond$i = ($53|0)==($17|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$us$i = $53;
   }
  }
  $37 = (($33) + ($ci$03$us$i<<2)|0);
  HEAP32[$37>>2] = $38;
  $39 = (($fake_buffer$04$us$i) + ($34<<2)|0);
  $40 = (($ci$03$us$i) + 1)|0;
  $41 = (($compptr$02$us$i) + 84|0);
  $42 = HEAP32[$20>>2]|0;
  $43 = ($40|0)<($42|0);
  if ($43) {
   $ci$03$us$i = $40;$compptr$02$us$i = $41;$fake_buffer$04$us$i = $39;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _start_pass_prep($cinfo,$pass_mode) {
 $cinfo = $cinfo|0;
 $pass_mode = $pass_mode|0;
 var $$c = 0, $$c1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 324|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($pass_mode|0)==(0);
 if (!($2)) {
  $3 = HEAP32[$cinfo>>2]|0;
  $4 = (($3) + 20|0);
  HEAP32[$4>>2] = 4;
  $5 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$5 & 63]($cinfo);
 }
 $6 = (($cinfo) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($1) + 48|0);
 $$c = $7;
 HEAP32[$8>>2] = $$c;
 $9 = (($1) + 52|0);
 HEAP32[$9>>2] = 0;
 $10 = (($1) + 56|0);
 HEAP32[$10>>2] = 0;
 $11 = (($cinfo) + 220|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 << 1;
 $14 = (($1) + 60|0);
 $$c1 = $13;
 HEAP32[$14>>2] = $$c1;
 STACKTOP = sp;return;
}
function _pre_process_context($cinfo,$input_buf,$in_row_ctr,$in_rows_avail,$output_buf,$out_row_group_ctr,$out_row_groups_avail) {
 $cinfo = $cinfo|0;
 $input_buf = $input_buf|0;
 $in_row_ctr = $in_row_ctr|0;
 $in_rows_avail = $in_rows_avail|0;
 $output_buf = $output_buf|0;
 $out_row_group_ctr = $out_row_group_ctr|0;
 $out_row_groups_avail = $out_row_groups_avail|0;
 var $$c = 0, $$c$ = 0, $$c1 = 0, $$c2 = 0, $$c3 = 0, $$c4 = 0, $$pre = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $ci$011 = 0, $ci$15 = 0, $exitcond$i = 0, $row$01$i = 0, $row$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 324|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 220|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3*3)|0;
 $5 = (($1) + 48|0);
 $6 = HEAP32[$out_row_group_ctr>>2]|0;
 $7 = ($6>>>0)<($out_row_groups_avail>>>0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($1) + 60|0);
 $9 = (($1) + 52|0);
 $10 = (($cinfo) + 336|0);
 $11 = (($1) + 8|0);
 $12 = (($cinfo) + 32|0);
 $13 = (($cinfo) + 60|0);
 $14 = (($cinfo) + 28|0);
 $15 = (($cinfo) + 340|0);
 $16 = (($1) + 56|0);
 while(1) {
  $17 = HEAP32[$in_row_ctr>>2]|0;
  $18 = ($17>>>0)<($in_rows_avail>>>0);
  if ($18) {
   $19 = (($in_rows_avail) - ($17))|0;
   $20 = HEAP32[$8>>2]|0;
   $21 = HEAP32[$9>>2]|0;
   $22 = (($20) - ($21))|0;
   $23 = ($22>>>0)<($19>>>0);
   $24 = $23 ? $22 : $19;
   $25 = HEAP32[$10>>2]|0;
   $26 = (($25) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($input_buf) + ($17<<2)|0);
   FUNCTION_TABLE_viiiii[$27 & 15]($cinfo,$28,$11,$21,$24);
   $29 = HEAP32[$5>>2]|0;
   $30 = HEAP32[$12>>2]|0;
   $31 = ($29|0)==($30|0);
   if ($31) {
    $32 = HEAP32[$13>>2]|0;
    $33 = ($32|0)>(0);
    if ($33) {
     $$pre = HEAP32[$2>>2]|0;
     $34 = $$pre;$92 = $32;$ci$011 = 0;
     while(1) {
      $35 = ($34|0)<(1);
      if ($35) {
       $45 = $92;$93 = $34;
      } else {
       $36 = (($11) + ($ci$011<<2)|0);
       $row$07 = 1;
       while(1) {
        $37 = HEAP32[$36>>2]|0;
        $38 = (0 - ($row$07))|0;
        $39 = HEAP32[$14>>2]|0;
        _jcopy_sample_rows($37,0,$37,$38,1,$39);
        $40 = (($row$07) + 1)|0;
        $41 = HEAP32[$2>>2]|0;
        $42 = ($row$07|0)<($41|0);
        if ($42) {
         $row$07 = $40;
        } else {
         break;
        }
       }
       $$pre15 = HEAP32[$13>>2]|0;
       $45 = $$pre15;$93 = $41;
      }
      $43 = (($ci$011) + 1)|0;
      $44 = ($43|0)<($45|0);
      if ($44) {
       $34 = $93;$92 = $45;$ci$011 = $43;
      } else {
       break;
      }
     }
    }
   }
   $46 = HEAP32[$in_row_ctr>>2]|0;
   $47 = (($46) + ($24))|0;
   HEAP32[$in_row_ctr>>2] = $47;
   $48 = HEAP32[$9>>2]|0;
   $49 = (($48) + ($24))|0;
   $$c3 = $49;
   HEAP32[$9>>2] = $$c3;
   $50 = HEAP32[$5>>2]|0;
   $51 = (($50) - ($24))|0;
   $$c4 = $51;
   HEAP32[$5>>2] = $$c4;
   $$pre16 = HEAP32[$8>>2]|0;
   $71 = $49;$73 = $$pre16;
   label = 24;
  } else {
   $52 = HEAP32[$5>>2]|0;
   $53 = ($52|0)==(0);
   if (!($53)) {
    label = 29;
    break;
   }
   $54 = HEAP32[$9>>2]|0;
   $55 = HEAP32[$8>>2]|0;
   $56 = ($54|0)<($55|0);
   if ($56) {
    $57 = HEAP32[$13>>2]|0;
    $58 = ($57|0)>(0);
    if ($58) {
     $62 = $54;$64 = $55;$94 = $57;$ci$15 = 0;
     while(1) {
      $59 = (($11) + ($ci$15<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = HEAP32[$14>>2]|0;
      $63 = ($62|0)<($64|0);
      if ($63) {
       $65 = (($62) + -1)|0;
       $row$01$i = $62;
       while(1) {
        _jcopy_sample_rows($60,$65,$60,$row$01$i,1,$61);
        $66 = (($row$01$i) + 1)|0;
        $exitcond$i = ($66|0)==($64|0);
        if ($exitcond$i) {
         break;
        } else {
         $row$01$i = $66;
        }
       }
       $$pre18 = HEAP32[$13>>2]|0;
       $69 = $$pre18;
      } else {
       $69 = $94;
      }
      $67 = (($ci$15) + 1)|0;
      $68 = ($67|0)<($69|0);
      if (!($68)) {
       break;
      }
      $$pre19 = HEAP32[$9>>2]|0;
      $$pre20 = HEAP32[$8>>2]|0;
      $62 = $$pre19;$64 = $$pre20;$94 = $69;$ci$15 = $67;
     }
     $$pre17 = HEAP32[$8>>2]|0;
     $70 = $$pre17;
    } else {
     $70 = $55;
    }
    $$c2 = $70;
    HEAP32[$9>>2] = $$c2;
    label = 25;
   } else {
    $71 = $54;$73 = $55;
    label = 24;
   }
  }
  if ((label|0) == 24) {
   label = 0;
   $72 = ($71|0)==($73|0);
   if ($72) {
    label = 25;
   }
  }
  if ((label|0) == 25) {
   label = 0;
   $74 = HEAP32[$15>>2]|0;
   $75 = (($74) + 4|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = HEAP32[$16>>2]|0;
   $78 = HEAP32[$out_row_group_ctr>>2]|0;
   FUNCTION_TABLE_viiiii[$76 & 15]($cinfo,$11,$77,$output_buf,$78);
   $79 = HEAP32[$out_row_group_ctr>>2]|0;
   $80 = (($79) + 1)|0;
   HEAP32[$out_row_group_ctr>>2] = $80;
   $81 = HEAP32[$2>>2]|0;
   $82 = HEAP32[$16>>2]|0;
   $83 = (($82) + ($81))|0;
   $$c = $83;
   $84 = ($83|0)<($4|0);
   $$c$ = $84 ? $$c : 0;
   HEAP32[$16>>2] = $$c$;
   $85 = HEAP32[$9>>2]|0;
   $86 = ($85|0)<($4|0);
   if ($86) {
    $89 = $85;
   } else {
    HEAP32[$9>>2] = 0;
    $89 = 0;
   }
   $87 = HEAP32[$2>>2]|0;
   $88 = (($87) + ($89))|0;
   $$c1 = $88;
   HEAP32[$8>>2] = $$c1;
  }
  $90 = HEAP32[$out_row_group_ctr>>2]|0;
  $91 = ($90>>>0)<($out_row_groups_avail>>>0);
  if (!($91)) {
   label = 29;
   break;
  }
 }
 if ((label|0) == 29) {
  STACKTOP = sp;return;
 }
}
function _pre_process_data($cinfo,$input_buf,$in_row_ctr,$in_rows_avail,$output_buf,$out_row_group_ctr,$out_row_groups_avail) {
 $cinfo = $cinfo|0;
 $input_buf = $input_buf|0;
 $in_row_ctr = $in_row_ctr|0;
 $in_rows_avail = $in_rows_avail|0;
 $output_buf = $output_buf|0;
 $out_row_group_ctr = $out_row_group_ctr|0;
 $out_row_groups_avail = $out_row_groups_avail|0;
 var $$c = 0, $$c1 = 0, $$c2 = 0, $$pre = 0, $$pre14 = 0, $$pre15 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $ci$09 = 0, $ci$17 = 0, $compptr$08 = 0, $exitcond$i = 0, $exitcond$i5 = 0;
 var $row$01$i = 0, $row$01$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 324|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$in_row_ctr>>2]|0;
 $3 = ($2>>>0)<($in_rows_avail>>>0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($cinfo) + 220|0);
 $5 = (($1) + 52|0);
 $6 = (($cinfo) + 336|0);
 $7 = (($1) + 8|0);
 $8 = (($1) + 48|0);
 $9 = (($cinfo) + 60|0);
 $10 = (($cinfo) + 28|0);
 $11 = (($cinfo) + 340|0);
 $15 = $2;
 while(1) {
  $12 = HEAP32[$out_row_group_ctr>>2]|0;
  $13 = ($12>>>0)<($out_row_groups_avail>>>0);
  if (!($13)) {
   label = 29;
   break;
  }
  $14 = (($in_rows_avail) - ($15))|0;
  $16 = HEAP32[$4>>2]|0;
  $17 = HEAP32[$5>>2]|0;
  $18 = (($16) - ($17))|0;
  $19 = ($18>>>0)<($14>>>0);
  $20 = $19 ? $18 : $14;
  $21 = HEAP32[$6>>2]|0;
  $22 = (($21) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($input_buf) + ($15<<2)|0);
  FUNCTION_TABLE_viiiii[$23 & 15]($cinfo,$24,$7,$17,$20);
  $25 = HEAP32[$in_row_ctr>>2]|0;
  $26 = (($25) + ($20))|0;
  HEAP32[$in_row_ctr>>2] = $26;
  $27 = HEAP32[$5>>2]|0;
  $28 = (($27) + ($20))|0;
  $$c = $28;
  HEAP32[$5>>2] = $$c;
  $29 = HEAP32[$8>>2]|0;
  $30 = (($29) - ($20))|0;
  $$c1 = $30;
  HEAP32[$8>>2] = $$c1;
  $31 = ($29|0)==($20|0);
  if ($31) {
   $32 = HEAP32[$4>>2]|0;
   $33 = ($28|0)<($32|0);
   if ($33) {
    $34 = HEAP32[$9>>2]|0;
    $35 = ($34|0)>(0);
    if ($35) {
     $39 = $28;$41 = $32;$84 = $34;$ci$09 = 0;
     while(1) {
      $36 = (($7) + ($ci$09<<2)|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = HEAP32[$10>>2]|0;
      $40 = ($39|0)<($41|0);
      if ($40) {
       $42 = (($39) + -1)|0;
       $row$01$i = $39;
       while(1) {
        _jcopy_sample_rows($37,$42,$37,$row$01$i,1,$38);
        $43 = (($row$01$i) + 1)|0;
        $exitcond$i = ($43|0)==($41|0);
        if ($exitcond$i) {
         break;
        } else {
         $row$01$i = $43;
        }
       }
       $$pre14 = HEAP32[$9>>2]|0;
       $46 = $$pre14;
      } else {
       $46 = $84;
      }
      $44 = (($ci$09) + 1)|0;
      $45 = ($44|0)<($46|0);
      if (!($45)) {
       break;
      }
      $$pre18 = HEAP32[$5>>2]|0;
      $$pre19 = HEAP32[$4>>2]|0;
      $39 = $$pre18;$41 = $$pre19;$84 = $46;$ci$09 = $44;
     }
     $$pre = HEAP32[$4>>2]|0;
     $47 = $$pre;
    } else {
     $47 = $32;
    }
    $$c2 = $47;
    HEAP32[$5>>2] = $$c2;
    $49 = $47;
   } else {
    $49 = $28;
   }
  } else {
   $49 = $28;
  }
  $48 = HEAP32[$4>>2]|0;
  $50 = ($49|0)==($48|0);
  if ($50) {
   $51 = HEAP32[$11>>2]|0;
   $52 = (($51) + 4|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = HEAP32[$out_row_group_ctr>>2]|0;
   FUNCTION_TABLE_viiiii[$53 & 15]($cinfo,$7,0,$output_buf,$54);
   HEAP32[$5>>2] = 0;
   $55 = HEAP32[$out_row_group_ctr>>2]|0;
   $56 = (($55) + 1)|0;
   HEAP32[$out_row_group_ctr>>2] = $56;
  }
  $57 = HEAP32[$8>>2]|0;
  $58 = ($57|0)==(0);
  if ($58) {
   $59 = HEAP32[$out_row_group_ctr>>2]|0;
   $60 = ($59>>>0)<($out_row_groups_avail>>>0);
   if ($60) {
    label = 20;
    break;
   }
  }
  $61 = HEAP32[$in_row_ctr>>2]|0;
  $62 = ($61>>>0)<($in_rows_avail>>>0);
  if ($62) {
   $15 = $61;
  } else {
   label = 29;
   break;
  }
 }
 if ((label|0) == 20) {
  $63 = HEAP32[$9>>2]|0;
  $64 = ($63|0)>(0);
  L31: do {
   if ($64) {
    $65 = (($cinfo) + 68|0);
    $66 = HEAP32[$65>>2]|0;
    $75 = $59;$85 = $63;$ci$17 = 0;$compptr$08 = $66;
    while(1) {
     $67 = (($output_buf) + ($ci$17<<2)|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (($compptr$08) + 28|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = $70 << 3;
     $72 = (($compptr$08) + 12|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = Math_imul($73, $75)|0;
     $76 = Math_imul($73, $out_row_groups_avail)|0;
     $77 = ($74|0)<($76|0);
     if ($77) {
      $78 = (($74) + -1)|0;
      $row$01$i4 = $74;
      while(1) {
       _jcopy_sample_rows($68,$78,$68,$row$01$i4,1,$71);
       $79 = (($row$01$i4) + 1)|0;
       $exitcond$i5 = ($79|0)==($76|0);
       if ($exitcond$i5) {
        break;
       } else {
        $row$01$i4 = $79;
       }
      }
      $$pre15 = HEAP32[$9>>2]|0;
      $82 = $$pre15;
     } else {
      $82 = $85;
     }
     $80 = (($ci$17) + 1)|0;
     $81 = ($80|0)<($82|0);
     if (!($81)) {
      break L31;
     }
     $83 = (($compptr$08) + 84|0);
     $$pre20 = HEAP32[$out_row_group_ctr>>2]|0;
     $75 = $$pre20;$85 = $82;$ci$17 = $80;$compptr$08 = $83;
    }
   }
  } while(0);
  HEAP32[$out_row_group_ctr>>2] = $out_row_groups_avail;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 29) {
  STACKTOP = sp;return;
 }
}
function _jinit_downsampler($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $ci$01 = 0, $compptr$03 = 0, $or$cond = 0, $smoothok$05 = 0, $smoothok$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 7]($cinfo,1,52)|0);
 $4 = (($cinfo) + 340|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$3>>2] = 23;
 $5 = (($3) + 4|0);
 HEAP32[$5>>2] = 9;
 $6 = (($3) + 8|0);
 HEAP8[$6>>0] = 0;
 $7 = (($cinfo) + 179|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if (!($9)) {
  $10 = HEAP32[$cinfo>>2]|0;
  $11 = (($10) + 20|0);
  HEAP32[$11>>2] = 25;
  $12 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$12 & 63]($cinfo);
 }
 $13 = (($cinfo) + 60|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)>(0);
 if (!($15)) {
  STACKTOP = sp;return;
 }
 $16 = (($cinfo) + 68|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($cinfo) + 216|0);
 $19 = (($cinfo) + 220|0);
 $20 = (($cinfo) + 180|0);
 $21 = (($3) + 12|0);
 $ci$01 = 0;$compptr$03 = $17;$smoothok$05 = 1;
 while(1) {
  $22 = (($compptr$03) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = HEAP32[$18>>2]|0;
  $25 = ($23|0)==($24|0);
  do {
   if ($25) {
    $26 = (($compptr$03) + 12|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = HEAP32[$19>>2]|0;
    $29 = ($27|0)==($28|0);
    if ($29) {
     $30 = HEAP32[$20>>2]|0;
     $31 = ($30|0)==(0);
     $32 = (($21) + ($ci$01<<2)|0);
     if ($31) {
      HEAP32[$32>>2] = 3;
      $smoothok$1 = $smoothok$05;
      break;
     } else {
      HEAP32[$32>>2] = 2;
      HEAP8[$6>>0] = 1;
      $smoothok$1 = $smoothok$05;
      break;
     }
    } else {
     label = 10;
    }
   } else {
    label = 10;
   }
  } while(0);
  do {
   if ((label|0) == 10) {
    label = 0;
    $33 = $23 << 1;
    $34 = ($33|0)==($24|0);
    if ($34) {
     $35 = (($compptr$03) + 12|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = HEAP32[$19>>2]|0;
     $38 = ($36|0)==($37|0);
     if ($38) {
      $39 = (_jsimd_can_h2v1_downsample()|0);
      $40 = ($39|0)==(0);
      $41 = (($21) + ($ci$01<<2)|0);
      if ($40) {
       HEAP32[$41>>2] = 5;
       $smoothok$1 = 0;
       break;
      } else {
       HEAP32[$41>>2] = 4;
       $smoothok$1 = 0;
       break;
      }
     }
     $42 = (($compptr$03) + 12|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = $43 << 1;
     $45 = HEAP32[$19>>2]|0;
     $46 = ($44|0)==($45|0);
     if ($46) {
      $47 = HEAP32[$20>>2]|0;
      $48 = ($47|0)==(0);
      if (!($48)) {
       $49 = (($21) + ($ci$01<<2)|0);
       HEAP32[$49>>2] = 6;
       HEAP8[$6>>0] = 1;
       $smoothok$1 = $smoothok$05;
       break;
      }
      $50 = (_jsimd_can_h2v2_downsample()|0);
      $51 = ($50|0)==(0);
      $52 = (($21) + ($ci$01<<2)|0);
      if ($51) {
       HEAP32[$52>>2] = 8;
       $smoothok$1 = $smoothok$05;
       break;
      } else {
       HEAP32[$52>>2] = 7;
       $smoothok$1 = $smoothok$05;
       break;
      }
     }
    }
    $53 = (($24|0) % ($23|0))&-1;
    $54 = ($53|0)==(0);
    if ($54) {
     $55 = HEAP32[$19>>2]|0;
     $56 = (($compptr$03) + 12|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = (($55|0) % ($57|0))&-1;
     $59 = ($58|0)==(0);
     if ($59) {
      $60 = (($21) + ($ci$01<<2)|0);
      HEAP32[$60>>2] = 9;
      $smoothok$1 = 0;
      break;
     }
    }
    $61 = HEAP32[$cinfo>>2]|0;
    $62 = (($61) + 20|0);
    HEAP32[$62>>2] = 38;
    $63 = HEAP32[$61>>2]|0;
    FUNCTION_TABLE_vi[$63 & 63]($cinfo);
    $smoothok$1 = $smoothok$05;
   }
  } while(0);
  $64 = (($ci$01) + 1)|0;
  $65 = HEAP32[$13>>2]|0;
  $66 = ($64|0)<($65|0);
  if (!($66)) {
   break;
  }
  $67 = (($compptr$03) + 84|0);
  $ci$01 = $64;$compptr$03 = $67;$smoothok$05 = $smoothok$1;
 }
 $68 = HEAP32[$20>>2]|0;
 $69 = ($68|0)!=(0);
 $70 = ($smoothok$1<<24>>24)==(0);
 $or$cond = $69 & $70;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 $71 = HEAP32[$cinfo>>2]|0;
 $72 = (($71) + 20|0);
 HEAP32[$72>>2] = 99;
 $73 = (($71) + 4|0);
 $74 = HEAP32[$73>>2]|0;
 FUNCTION_TABLE_vii[$74 & 15]($cinfo,0);
 STACKTOP = sp;return;
}
function _start_pass_downsample($cinfo) {
 $cinfo = $cinfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _sep_downsample($cinfo,$input_buf,$in_row_index,$output_buf,$out_row_group_index) {
 $cinfo = $cinfo|0;
 $input_buf = $input_buf|0;
 $in_row_index = $in_row_index|0;
 $output_buf = $output_buf|0;
 $out_row_group_index = $out_row_group_index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $ci$02 = 0, $compptr$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($cinfo) + 68|0);
 $4 = (($cinfo) + 340|0);
 $5 = HEAP32[$3>>2]|0;
 $6 = HEAP32[$4>>2]|0;
 $7 = (($6) + 12|0);
 $ci$02 = 0;$compptr$01 = $5;
 while(1) {
  $8 = (($input_buf) + ($ci$02<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($in_row_index<<2)|0);
  $11 = (($output_buf) + ($ci$02<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($compptr$01) + 12|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = Math_imul($14, $out_row_group_index)|0;
  $16 = (($12) + ($15<<2)|0);
  $17 = (($7) + ($ci$02<<2)|0);
  $18 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_viiii[$18 & 15]($cinfo,$compptr$01,$10,$16);
  $19 = (($ci$02) + 1)|0;
  $20 = (($compptr$01) + 84|0);
  $21 = HEAP32[$0>>2]|0;
  $22 = ($19|0)<($21|0);
  if ($22) {
   $ci$02 = $19;$compptr$01 = $20;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _fullsize_smooth_downsample($cinfo,$compptr,$input_data,$output_data) {
 $cinfo = $cinfo|0;
 $compptr = $compptr|0;
 $input_data = $input_data|0;
 $output_data = $output_data|0;
 var $$pn = 0, $$sum = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $above_ptr$04 = 0, $below_ptr$05 = 0, $colctr$06 = 0, $colsum$07 = 0, $exitcond$i = 0, $factor = 0, $inptr$03 = 0, $lastcolsum$08 = 0, $lastcolsum$08$phi = 0, $or$cond$i = 0, $outptr$09 = 0, $outrow$010 = 0, $row$03$us$i = 0, $scevgep = 0, $scevgep12 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($compptr) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 << 3;
 $3 = (($cinfo) + 220|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 2)|0;
 $6 = (($cinfo) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($2) - ($7))|0;
 $9 = ($8|0)>(0);
 $10 = ($5|0)>(0);
 $or$cond$i = $9 & $10;
 if ($or$cond$i) {
  $$sum$i = (($7) + -1)|0;
  $row$03$us$i = 0;
  while(1) {
   $$sum = (($row$03$us$i) + -1)|0;
   $11 = (($input_data) + ($$sum<<2)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + ($$sum$i)|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = (($12) + ($7)|0);
   _memset(($15|0),($14|0),($8|0))|0;
   $16 = (($row$03$us$i) + 1)|0;
   $exitcond$i = ($16|0)==($5|0);
   if ($exitcond$i) {
    break;
   } else {
    $row$03$us$i = $16;
   }
  }
 }
 $17 = (($cinfo) + 180|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 << 9;
 $20 = (65536 - ($19))|0;
 $21 = $18 << 6;
 $22 = (($compptr) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)>(0);
 if (!($24)) {
  STACKTOP = sp;return;
 }
 $25 = (($2) + -2)|0;
 $26 = $1 << 3;
 $27 = (($26) + -1)|0;
 $outrow$010 = 0;
 while(1) {
  $28 = (($output_data) + ($outrow$010<<2)|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($input_data) + ($outrow$010<<2)|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($outrow$010) + -1)|0;
  $33 = (($input_data) + ($32<<2)|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($outrow$010) + 1)|0;
  $36 = (($input_data) + ($35<<2)|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($34) + 1|0);
  $39 = HEAP8[$34>>0]|0;
  $40 = $39&255;
  $41 = (($37) + 1|0);
  $42 = HEAP8[$37>>0]|0;
  $43 = $42&255;
  $44 = (($43) + ($40))|0;
  $45 = HEAP8[$31>>0]|0;
  $46 = $45&255;
  $47 = (($44) + ($46))|0;
  $48 = (($31) + 1|0);
  $49 = HEAP8[$38>>0]|0;
  $50 = $49&255;
  $51 = HEAP8[$41>>0]|0;
  $52 = $51&255;
  $53 = (($52) + ($50))|0;
  $54 = HEAP8[$48>>0]|0;
  $55 = $54&255;
  $56 = (($53) + ($55))|0;
  $57 = (($47) + ($44))|0;
  $58 = (($57) + ($56))|0;
  $59 = Math_imul($46, $20)|0;
  $60 = Math_imul($58, $21)|0;
  $61 = (($59) + 32768)|0;
  $62 = (($61) + ($60))|0;
  $63 = $62 >>> 16;
  $64 = $63&255;
  HEAP8[$29>>0] = $64;
  $scevgep = (($29) + ($27)|0);
  $$pn = $29;$above_ptr$04 = $38;$below_ptr$05 = $41;$colctr$06 = $25;$colsum$07 = $56;$inptr$03 = $48;$lastcolsum$08 = $47;
  while(1) {
   $outptr$09 = (($$pn) + 1|0);
   $65 = (($inptr$03) + 1|0);
   $66 = HEAP8[$inptr$03>>0]|0;
   $67 = $66&255;
   $68 = (($above_ptr$04) + 1|0);
   $69 = (($below_ptr$05) + 1|0);
   $70 = HEAP8[$68>>0]|0;
   $71 = $70&255;
   $72 = HEAP8[$69>>0]|0;
   $73 = $72&255;
   $74 = (($73) + ($71))|0;
   $75 = HEAP8[$65>>0]|0;
   $76 = $75&255;
   $77 = (($74) + ($76))|0;
   $78 = (($lastcolsum$08) + ($colsum$07))|0;
   $79 = (($78) - ($67))|0;
   $80 = (($79) + ($77))|0;
   $81 = Math_imul($67, $20)|0;
   $82 = Math_imul($80, $21)|0;
   $83 = (($81) + 32768)|0;
   $84 = (($83) + ($82))|0;
   $85 = $84 >>> 16;
   $86 = $85&255;
   HEAP8[$outptr$09>>0] = $86;
   $87 = (($colctr$06) + -1)|0;
   $88 = ($87|0)==(0);
   if ($88) {
    break;
   } else {
    $lastcolsum$08$phi = $colsum$07;$$pn = $outptr$09;$above_ptr$04 = $68;$below_ptr$05 = $69;$colctr$06 = $87;$colsum$07 = $77;$inptr$03 = $65;$lastcolsum$08 = $lastcolsum$08$phi;
   }
  }
  $scevgep12 = (($31) + ($27)|0);
  $89 = HEAP8[$scevgep12>>0]|0;
  $90 = $89&255;
  $factor = $77 << 1;
  $91 = (($colsum$07) - ($90))|0;
  $92 = (($91) + ($factor))|0;
  $93 = Math_imul($90, $20)|0;
  $94 = Math_imul($92, $21)|0;
  $95 = (($93) + 32768)|0;
  $96 = (($95) + ($94))|0;
  $97 = $96 >>> 16;
  $98 = $97&255;
  HEAP8[$scevgep>>0] = $98;
  $99 = HEAP32[$22>>2]|0;
  $100 = ($35|0)<($99|0);
  if ($100) {
   $outrow$010 = $35;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _fullsize_downsample($cinfo,$compptr,$input_data,$output_data) {
 $cinfo = $cinfo|0;
 $compptr = $compptr|0;
 $input_data = $input_data|0;
 $output_data = $output_data|0;
 var $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0;
 var $or$cond$i = 0, $row$03$us$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 220|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 _jcopy_sample_rows($input_data,0,$output_data,0,$1,$3);
 $4 = HEAP32[$0>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($compptr) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 << 3;
 $9 = (($8) - ($5))|0;
 $10 = ($9|0)>(0);
 $11 = ($4|0)>(0);
 $or$cond$i = $10 & $11;
 if (!($or$cond$i)) {
  STACKTOP = sp;return;
 }
 $$sum$i = (($5) + -1)|0;
 $row$03$us$i = 0;
 while(1) {
  $12 = (($output_data) + ($row$03$us$i<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + ($$sum$i)|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = (($13) + ($5)|0);
  _memset(($16|0),($15|0),($9|0))|0;
  $17 = (($row$03$us$i) + 1)|0;
  $exitcond$i = ($17|0)==($4|0);
  if ($exitcond$i) {
   break;
  } else {
   $row$03$us$i = $17;
  }
 }
 STACKTOP = sp;return;
}
function _h2v1_downsample($cinfo,$compptr,$input_data,$output_data) {
 $cinfo = $cinfo|0;
 $compptr = $compptr|0;
 $input_data = $input_data|0;
 $output_data = $output_data|0;
 var $$mask = 0, $$pre = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bias$04$us = 0, $exitcond = 0, $exitcond$i = 0, $inptr$02$us = 0, $or$cond$i = 0, $outcol$01$us = 0, $outptr$03$us = 0, $outrow$05 = 0, $outrow$05$us = 0, $row$03$us$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($compptr) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 220|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($cinfo) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $1 << 4;
 $7 = (($6) - ($5))|0;
 $8 = ($7|0)>(0);
 $9 = ($3|0)>(0);
 $or$cond$i = $8 & $9;
 if ($or$cond$i) {
  $$sum$i = (($5) + -1)|0;
  $row$03$us$i = 0;
  while(1) {
   $10 = (($input_data) + ($row$03$us$i<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + ($$sum$i)|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = (($11) + ($5)|0);
   _memset(($14|0),($13|0),($7|0))|0;
   $15 = (($row$03$us$i) + 1)|0;
   $exitcond$i = ($15|0)==($3|0);
   if ($exitcond$i) {
    break;
   } else {
    $row$03$us$i = $15;
   }
  }
 }
 $16 = (($compptr) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)>(0);
 if (!($18)) {
  STACKTOP = sp;return;
 }
 $$mask = $1 & 536870911;
 $19 = ($$mask|0)==(0);
 if ($19) {
  $outrow$05 = 0;
  while(1) {
   $40 = (($outrow$05) + 1)|0;
   $41 = ($40|0)<($17|0);
   if ($41) {
    $outrow$05 = $40;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 }
 $20 = $1 << 3;
 $outrow$05$us = 0;
 while(1) {
  $36 = (($input_data) + ($outrow$05$us<<2)|0);
  $37 = (($output_data) + ($outrow$05$us<<2)|0);
  $38 = HEAP32[$36>>2]|0;
  $39 = HEAP32[$37>>2]|0;
  $bias$04$us = 0;$inptr$02$us = $38;$outcol$01$us = 0;$outptr$03$us = $39;
  while(1) {
   $23 = HEAP8[$inptr$02$us>>0]|0;
   $24 = $23&255;
   $25 = (($inptr$02$us) + 1|0);
   $26 = HEAP8[$25>>0]|0;
   $27 = $26&255;
   $28 = (($24) + ($bias$04$us))|0;
   $29 = (($28) + ($27))|0;
   $30 = $29 >>> 1;
   $31 = $30&255;
   $32 = (($outptr$03$us) + 1|0);
   HEAP8[$outptr$03$us>>0] = $31;
   $33 = $bias$04$us ^ 1;
   $34 = (($inptr$02$us) + 2|0);
   $35 = (($outcol$01$us) + 1)|0;
   $exitcond = ($35|0)==($20|0);
   if ($exitcond) {
    break;
   } else {
    $bias$04$us = $33;$inptr$02$us = $34;$outcol$01$us = $35;$outptr$03$us = $32;
   }
  }
  $$pre = HEAP32[$16>>2]|0;
  $21 = (($outrow$05$us) + 1)|0;
  $22 = ($21|0)<($$pre|0);
  if ($22) {
   $outrow$05$us = $21;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _h2v2_smooth_downsample($cinfo,$compptr,$input_data,$output_data) {
 $cinfo = $cinfo|0;
 $compptr = $compptr|0;
 $input_data = $input_data|0;
 $output_data = $output_data|0;
 var $$pn = 0, $$sum = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $above_ptr$0 = 0, $below_ptr$0 = 0, $colctr$0 = 0, $exitcond$i = 0, $inptr0$0 = 0, $inptr1$0 = 0, $inrow$07 = 0, $or$cond$i = 0;
 var $outptr$0 = 0, $outrow$06 = 0, $row$03$us$i = 0, $scevgep = 0, $scevgep13$sum = 0, $scevgep14$sum = 0, $scevgep15$sum = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($compptr) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 << 3;
 $3 = (($cinfo) + 220|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 2)|0;
 $6 = (($cinfo) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $1 << 4;
 $9 = (($8) - ($7))|0;
 $10 = ($9|0)>(0);
 $11 = ($5|0)>(0);
 $or$cond$i = $10 & $11;
 if ($or$cond$i) {
  $$sum$i = (($7) + -1)|0;
  $row$03$us$i = 0;
  while(1) {
   $$sum = (($row$03$us$i) + -1)|0;
   $12 = (($input_data) + ($$sum<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + ($$sum$i)|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = (($13) + ($7)|0);
   _memset(($16|0),($15|0),($9|0))|0;
   $17 = (($row$03$us$i) + 1)|0;
   $exitcond$i = ($17|0)==($5|0);
   if ($exitcond$i) {
    break;
   } else {
    $row$03$us$i = $17;
   }
  }
 }
 $18 = (($cinfo) + 180|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = Math_imul($19, -80)|0;
 $21 = (($20) + 16384)|0;
 $22 = $19 << 4;
 $23 = (($compptr) + 12|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(0);
 if (!($25)) {
  STACKTOP = sp;return;
 }
 $26 = (($2) + -2)|0;
 $27 = $1 << 3;
 $28 = (($27) + -1)|0;
 $29 = $1 << 4;
 $inrow$07 = 0;$outrow$06 = 0;
 while(1) {
  $30 = (($output_data) + ($outrow$06<<2)|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($input_data) + ($inrow$07<<2)|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $inrow$07 | 1;
  $35 = (($input_data) + ($34<<2)|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($inrow$07) + -1)|0;
  $38 = (($input_data) + ($37<<2)|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($inrow$07) + 2)|0;
  $41 = (($input_data) + ($40<<2)|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = HEAP8[$33>>0]|0;
  $44 = $43&255;
  $45 = (($33) + 1|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = $46&255;
  $48 = (($47) + ($44))|0;
  $49 = HEAP8[$36>>0]|0;
  $50 = $49&255;
  $51 = (($48) + ($50))|0;
  $52 = (($36) + 1|0);
  $53 = HEAP8[$52>>0]|0;
  $54 = $53&255;
  $55 = (($51) + ($54))|0;
  $56 = HEAP8[$39>>0]|0;
  $57 = $56&255;
  $58 = (($39) + 1|0);
  $59 = HEAP8[$58>>0]|0;
  $60 = $59&255;
  $61 = HEAP8[$42>>0]|0;
  $62 = $61&255;
  $63 = (($42) + 1|0);
  $64 = HEAP8[$63>>0]|0;
  $65 = $64&255;
  $66 = (($33) + 2|0);
  $67 = HEAP8[$66>>0]|0;
  $68 = $67&255;
  $69 = (($36) + 2|0);
  $70 = HEAP8[$69>>0]|0;
  $71 = $70&255;
  $72 = (($50) + ($44))|0;
  $73 = (($72) + ($57))|0;
  $74 = (($73) + ($60))|0;
  $75 = (($74) + ($62))|0;
  $76 = (($75) + ($65))|0;
  $77 = (($76) + ($68))|0;
  $78 = (($77) + ($71))|0;
  $79 = $78 << 1;
  $80 = (($39) + 2|0);
  $81 = HEAP8[$80>>0]|0;
  $82 = $81&255;
  $83 = (($42) + 2|0);
  $84 = HEAP8[$83>>0]|0;
  $85 = $84&255;
  $86 = (($62) + ($57))|0;
  $87 = (($86) + ($82))|0;
  $88 = (($87) + ($85))|0;
  $89 = (($88) + ($79))|0;
  $90 = Math_imul($55, $21)|0;
  $91 = Math_imul($89, $22)|0;
  $92 = (($90) + 32768)|0;
  $93 = (($92) + ($91))|0;
  $94 = $93 >>> 16;
  $95 = $94&255;
  HEAP8[$31>>0] = $95;
  $scevgep = (($31) + ($28)|0);
  $$pn = $31;$above_ptr$0 = $80;$below_ptr$0 = $83;$colctr$0 = $26;$inptr0$0 = $66;$inptr1$0 = $69;
  while(1) {
   $outptr$0 = (($$pn) + 1|0);
   $96 = ($colctr$0|0)==(0);
   $97 = HEAP8[$inptr0$0>>0]|0;
   $98 = $97&255;
   $99 = (($inptr0$0) + 1|0);
   $100 = HEAP8[$99>>0]|0;
   $101 = $100&255;
   $102 = (($101) + ($98))|0;
   $103 = HEAP8[$inptr1$0>>0]|0;
   $104 = $103&255;
   $105 = (($102) + ($104))|0;
   $106 = (($inptr1$0) + 1|0);
   $107 = HEAP8[$106>>0]|0;
   $108 = $107&255;
   $109 = (($105) + ($108))|0;
   $110 = HEAP8[$above_ptr$0>>0]|0;
   $111 = $110&255;
   $112 = (($above_ptr$0) + 1|0);
   $113 = HEAP8[$112>>0]|0;
   $114 = $113&255;
   $115 = (($114) + ($111))|0;
   $116 = HEAP8[$below_ptr$0>>0]|0;
   $117 = $116&255;
   $118 = (($115) + ($117))|0;
   $119 = (($below_ptr$0) + 1|0);
   $120 = HEAP8[$119>>0]|0;
   $121 = $120&255;
   $122 = (($118) + ($121))|0;
   $123 = (($inptr0$0) + -1|0);
   $124 = HEAP8[$123>>0]|0;
   $125 = $124&255;
   $126 = (($122) + ($125))|0;
   if ($96) {
    break;
   }
   $127 = (($inptr0$0) + 2|0);
   $128 = HEAP8[$127>>0]|0;
   $129 = $128&255;
   $130 = (($129) + ($126))|0;
   $131 = (($inptr1$0) + -1|0);
   $132 = HEAP8[$131>>0]|0;
   $133 = $132&255;
   $134 = (($130) + ($133))|0;
   $135 = (($inptr1$0) + 2|0);
   $136 = HEAP8[$135>>0]|0;
   $137 = $136&255;
   $138 = (($134) + ($137))|0;
   $139 = $138 << 1;
   $140 = (($above_ptr$0) + -1|0);
   $141 = HEAP8[$140>>0]|0;
   $142 = $141&255;
   $143 = (($above_ptr$0) + 2|0);
   $144 = HEAP8[$143>>0]|0;
   $145 = $144&255;
   $146 = (($145) + ($142))|0;
   $147 = (($below_ptr$0) + -1|0);
   $148 = HEAP8[$147>>0]|0;
   $149 = $148&255;
   $150 = (($below_ptr$0) + 2|0);
   $151 = HEAP8[$150>>0]|0;
   $152 = $151&255;
   $153 = (($146) + ($139))|0;
   $154 = (($153) + ($149))|0;
   $155 = (($154) + ($152))|0;
   $156 = Math_imul($109, $21)|0;
   $157 = Math_imul($155, $22)|0;
   $158 = (($156) + 32768)|0;
   $159 = (($158) + ($157))|0;
   $160 = $159 >>> 16;
   $161 = $160&255;
   HEAP8[$outptr$0>>0] = $161;
   $162 = (($colctr$0) + -1)|0;
   $$pn = $outptr$0;$above_ptr$0 = $143;$below_ptr$0 = $150;$colctr$0 = $162;$inptr0$0 = $127;$inptr1$0 = $135;
  }
  $scevgep15$sum = (($29) + -3)|0;
  $163 = (($36) + ($scevgep15$sum)|0);
  $164 = HEAP8[$163>>0]|0;
  $165 = $164&255;
  $166 = (($108) + ($101))|0;
  $167 = (($166) + ($126))|0;
  $168 = (($167) + ($165))|0;
  $169 = $168 << 1;
  $scevgep14$sum = (($29) + -3)|0;
  $170 = (($39) + ($scevgep14$sum)|0);
  $171 = HEAP8[$170>>0]|0;
  $172 = $171&255;
  $scevgep13$sum = (($29) + -3)|0;
  $173 = (($42) + ($scevgep13$sum)|0);
  $174 = HEAP8[$173>>0]|0;
  $175 = $174&255;
  $176 = (($121) + ($114))|0;
  $177 = (($176) + ($172))|0;
  $178 = (($177) + ($175))|0;
  $179 = (($178) + ($169))|0;
  $180 = Math_imul($109, $21)|0;
  $181 = Math_imul($179, $22)|0;
  $182 = (($180) + 32768)|0;
  $183 = (($182) + ($181))|0;
  $184 = $183 >>> 16;
  $185 = $184&255;
  HEAP8[$scevgep>>0] = $185;
  $186 = (($outrow$06) + 1)|0;
  $187 = HEAP32[$23>>2]|0;
  $188 = ($186|0)<($187|0);
  if ($188) {
   $inrow$07 = $40;$outrow$06 = $186;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _h2v2_downsample($cinfo,$compptr,$input_data,$output_data) {
 $cinfo = $cinfo|0;
 $compptr = $compptr|0;
 $input_data = $input_data|0;
 $output_data = $output_data|0;
 var $$mask = 0, $$pre = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bias$05$us = 0, $exitcond = 0, $exitcond$i = 0;
 var $inptr0$02$us = 0, $inptr1$03$us = 0, $inrow$07$us = 0, $or$cond$i = 0, $outcol$01$us = 0, $outptr$04$us = 0, $outrow$06 = 0, $outrow$06$us = 0, $row$03$us$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($compptr) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cinfo) + 220|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($cinfo) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $1 << 4;
 $7 = (($6) - ($5))|0;
 $8 = ($7|0)>(0);
 $9 = ($3|0)>(0);
 $or$cond$i = $8 & $9;
 if ($or$cond$i) {
  $$sum$i = (($5) + -1)|0;
  $row$03$us$i = 0;
  while(1) {
   $10 = (($input_data) + ($row$03$us$i<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + ($$sum$i)|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = (($11) + ($5)|0);
   _memset(($14|0),($13|0),($7|0))|0;
   $15 = (($row$03$us$i) + 1)|0;
   $exitcond$i = ($15|0)==($3|0);
   if ($exitcond$i) {
    break;
   } else {
    $row$03$us$i = $15;
   }
  }
 }
 $16 = (($compptr) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)>(0);
 if (!($18)) {
  STACKTOP = sp;return;
 }
 $$mask = $1 & 536870911;
 $19 = ($$mask|0)==(0);
 if ($19) {
  $outrow$06 = 0;
  while(1) {
   $52 = (($outrow$06) + 1)|0;
   $53 = ($52|0)<($17|0);
   if ($53) {
    $outrow$06 = $52;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 }
 $20 = $1 << 3;
 $inrow$07$us = 0;$outrow$06$us = 0;
 while(1) {
  $45 = $inrow$07$us | 1;
  $46 = (($input_data) + ($45<<2)|0);
  $47 = (($input_data) + ($inrow$07$us<<2)|0);
  $48 = (($output_data) + ($outrow$06$us<<2)|0);
  $49 = HEAP32[$46>>2]|0;
  $50 = HEAP32[$47>>2]|0;
  $51 = HEAP32[$48>>2]|0;
  $bias$05$us = 1;$inptr0$02$us = $50;$inptr1$03$us = $49;$outcol$01$us = 0;$outptr$04$us = $51;
  while(1) {
   $24 = HEAP8[$inptr0$02$us>>0]|0;
   $25 = $24&255;
   $26 = (($inptr0$02$us) + 1|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = $27&255;
   $29 = HEAP8[$inptr1$03$us>>0]|0;
   $30 = $29&255;
   $31 = (($inptr1$03$us) + 1|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = $32&255;
   $34 = (($25) + ($bias$05$us))|0;
   $35 = (($34) + ($28))|0;
   $36 = (($35) + ($30))|0;
   $37 = (($36) + ($33))|0;
   $38 = $37 >>> 2;
   $39 = $38&255;
   $40 = (($outptr$04$us) + 1|0);
   HEAP8[$outptr$04$us>>0] = $39;
   $41 = $bias$05$us ^ 3;
   $42 = (($inptr0$02$us) + 2|0);
   $43 = (($inptr1$03$us) + 2|0);
   $44 = (($outcol$01$us) + 1)|0;
   $exitcond = ($44|0)==($20|0);
   if ($exitcond) {
    break;
   } else {
    $bias$05$us = $41;$inptr0$02$us = $42;$inptr1$03$us = $43;$outcol$01$us = $44;$outptr$04$us = $40;
   }
  }
  $$pre = HEAP32[$16>>2]|0;
  $21 = (($inrow$07$us) + 2)|0;
  $22 = (($outrow$06$us) + 1)|0;
  $23 = ($22|0)<($$pre|0);
  if ($23) {
   $inrow$07$us = $21;$outrow$06$us = $22;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _int_downsample($cinfo,$compptr,$input_data,$output_data) {
 $cinfo = $cinfo|0;
 $compptr = $compptr|0;
 $input_data = $input_data|0;
 $output_data = $output_data|0;
 var $$not = 0, $$not22 = 0, $$pre = 0, $$pre21 = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0;
 var $exitcond = 0, $exitcond$i = 0, $exitcond19 = 0, $exitcond20 = 0, $h$01$us = 0, $inptr$02$us = 0, $inrow$016 = 0, $or$cond$i = 0, $outcol$09 = 0, $outcol_h$010 = 0, $outptr$013 = 0, $outrow$015 = 0, $outvalue$0$lcssa = 0, $outvalue$05$us = 0, $outvalue$13$us = 0, $row$03$us$i = 0, $v$04$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($compptr) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 << 3;
 $3 = (($cinfo) + 216|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($compptr) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4|0) / ($6|0))&-1;
 $8 = (($cinfo) + 220|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($compptr) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9|0) / ($11|0))&-1;
 $13 = Math_imul($12, $7)|0;
 $14 = (($13|0) / 2)&-1;
 $15 = (($cinfo) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = Math_imul($7, $2)|0;
 $18 = (($17) - ($16))|0;
 $19 = ($18|0)>(0);
 $20 = ($9|0)>(0);
 $or$cond$i = $19 & $20;
 if ($or$cond$i) {
  $$sum$i = (($16) + -1)|0;
  $row$03$us$i = 0;
  while(1) {
   $21 = (($input_data) + ($row$03$us$i<<2)|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + ($$sum$i)|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = (($22) + ($16)|0);
   _memset(($25|0),($24|0),($18|0))|0;
   $26 = (($row$03$us$i) + 1)|0;
   $exitcond$i = ($26|0)==($9|0);
   if ($exitcond$i) {
    break;
   } else {
    $row$03$us$i = $26;
   }
  }
  $$pre = HEAP32[$10>>2]|0;
  $27 = $$pre;
 } else {
  $27 = $11;
 }
 $28 = ($27|0)>(0);
 if (!($28)) {
  STACKTOP = sp;return;
 }
 $29 = ($2|0)==(0);
 $30 = $1 << 3;
 $53 = $27;$inrow$016 = 0;$outrow$015 = 0;
 while(1) {
  if ($29) {
   $52 = $53;
  } else {
   $31 = (($output_data) + ($outrow$015<<2)|0);
   $32 = HEAP32[$31>>2]|0;
   $outcol$09 = 0;$outcol_h$010 = 0;$outptr$013 = $32;
   while(1) {
    $$not = ($12|0)<(1);
    $$not22 = ($7|0)<(1);
    $brmerge = $$not | $$not22;
    if ($brmerge) {
     $outvalue$0$lcssa = 0;
    } else {
     $outvalue$05$us = 0;$v$04$us = 0;
     while(1) {
      $39 = (($v$04$us) + ($inrow$016))|0;
      $40 = (($input_data) + ($39<<2)|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = (($41) + ($outcol_h$010)|0);
      $h$01$us = 0;$inptr$02$us = $42;$outvalue$13$us = $outvalue$05$us;
      while(1) {
       $34 = (($inptr$02$us) + 1|0);
       $35 = HEAP8[$inptr$02$us>>0]|0;
       $36 = $35&255;
       $37 = (($36) + ($outvalue$13$us))|0;
       $38 = (($h$01$us) + 1)|0;
       $exitcond = ($38|0)==($7|0);
       if ($exitcond) {
        break;
       } else {
        $h$01$us = $38;$inptr$02$us = $34;$outvalue$13$us = $37;
       }
      }
      $33 = (($v$04$us) + 1)|0;
      $exitcond19 = ($33|0)==($12|0);
      if ($exitcond19) {
       $outvalue$0$lcssa = $37;
       break;
      } else {
       $outvalue$05$us = $37;$v$04$us = $33;
      }
     }
    }
    $43 = (($outvalue$0$lcssa) + ($14))|0;
    $44 = (($43|0) / ($13|0))&-1;
    $45 = $44&255;
    $46 = (($outptr$013) + 1|0);
    HEAP8[$outptr$013>>0] = $45;
    $47 = (($outcol$09) + 1)|0;
    $48 = (($outcol_h$010) + ($7))|0;
    $exitcond20 = ($47|0)==($30|0);
    if ($exitcond20) {
     break;
    } else {
     $outcol$09 = $47;$outcol_h$010 = $48;$outptr$013 = $46;
    }
   }
   $$pre21 = HEAP32[$10>>2]|0;
   $52 = $$pre21;
  }
  $49 = (($inrow$016) + ($12))|0;
  $50 = (($outrow$015) + 1)|0;
  $51 = ($50|0)<($52|0);
  if ($51) {
   $53 = $52;$inrow$016 = $49;$outrow$015 = $50;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _jpeg_mem_dest_tj($cinfo,$outbuffer,$outsize,$alloc) {
 $cinfo = $cinfo|0;
 $outbuffer = $outbuffer|0;
 $outsize = $outsize|0;
 $alloc = $alloc|0;
 var $$c1 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond4 = 0, $outsize$c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($outbuffer|0)==(0|0);
 $1 = ($outsize|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  $2 = HEAP32[$cinfo>>2]|0;
  $3 = (($2) + 20|0);
  HEAP32[$3>>2] = 23;
  $4 = HEAP32[$2>>2]|0;
  FUNCTION_TABLE_vi[$4 & 63]($cinfo);
 }
 $5 = (($cinfo) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = (($cinfo) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_iiii[$10 & 7]($cinfo,0,44)|0);
  HEAP32[$5>>2] = $11;
  $12 = (($11) + 28|0);
  HEAP32[$12>>2] = 0;
  $13 = (($11) + 32|0);
  HEAP32[$13>>2] = 0;
  $$pre = HEAP32[$5>>2]|0;
  $15 = $$pre;
 } else {
  $15 = $6;
 }
 $14 = (($15) + 8|0);
 HEAP32[$14>>2] = 24;
 $16 = (($15) + 12|0);
 HEAP32[$16>>2] = 1;
 $17 = (($15) + 16|0);
 HEAP32[$17>>2] = 25;
 $18 = (($15) + 32|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$outbuffer>>2]|0;
 $21 = ($19|0)!=($20|0);
 $22 = ($20|0)==(0|0);
 $or$cond3 = $21 | $22;
 $23 = ($alloc<<24>>24)==(0);
 $or$cond4 = $or$cond3 | $23;
 $24 = (($15) + 20|0);
 HEAP32[$24>>2] = $outbuffer;
 $25 = (($15) + 24|0);
 $outsize$c = $outsize;
 HEAP32[$25>>2] = $outsize$c;
 $26 = (($15) + 40|0);
 HEAP8[$26>>0] = $alloc;
 $27 = HEAP32[$outbuffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  label = 7;
 } else {
  $29 = HEAP32[$outsize>>2]|0;
  $30 = ($29|0)==(0);
  if ($30) {
   label = 7;
  }
 }
 do {
  if ((label|0) == 7) {
   if ($23) {
    $38 = HEAP32[$cinfo>>2]|0;
    $39 = (($38) + 20|0);
    HEAP32[$39>>2] = 23;
    $40 = HEAP32[$38>>2]|0;
    FUNCTION_TABLE_vi[$40 & 63]($cinfo);
    break;
   }
   $31 = (_malloc(4096)|0);
   HEAP32[$outbuffer>>2] = $31;
   $32 = (($15) + 28|0);
   HEAP32[$32>>2] = $31;
   $33 = ($31|0)==(0|0);
   if ($33) {
    $34 = HEAP32[$cinfo>>2]|0;
    $35 = (($34) + 20|0);
    HEAP32[$35>>2] = 54;
    $36 = (($34) + 24|0);
    HEAP32[$36>>2] = 10;
    $37 = HEAP32[$34>>2]|0;
    FUNCTION_TABLE_vi[$37 & 63]($cinfo);
   }
   HEAP32[$outsize>>2] = 4096;
  }
 } while(0);
 $41 = HEAP32[$outbuffer>>2]|0;
 HEAP32[$18>>2] = $41;
 HEAP32[$15>>2] = $41;
 if ($or$cond4) {
  $42 = HEAP32[$outsize>>2]|0;
  $43 = (($15) + 36|0);
  $$c1 = $42;
  HEAP32[$43>>2] = $$c1;
  $45 = $42;
  $44 = (($15) + 4|0);
  HEAP32[$44>>2] = $45;
  STACKTOP = sp;return;
 } else {
  $$phi$trans$insert = (($15) + 36|0);
  $$pre6 = HEAP32[$$phi$trans$insert>>2]|0;
  $45 = $$pre6;
  $44 = (($15) + 4|0);
  HEAP32[$44>>2] = $45;
  STACKTOP = sp;return;
 }
}
function _init_mem_destination($cinfo) {
 $cinfo = $cinfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _empty_mem_output_buffer($cinfo) {
 $cinfo = $cinfo|0;
 var $$c2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 40|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $5 = HEAP32[$cinfo>>2]|0;
  $6 = (($5) + 20|0);
  HEAP32[$6>>2] = 23;
  $7 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vi[$7 & 63]($cinfo);
 }
 $8 = (($1) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 << 1;
 $11 = (_malloc($10)|0);
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$cinfo>>2]|0;
  $14 = (($13) + 20|0);
  HEAP32[$14>>2] = 54;
  $15 = (($13) + 24|0);
  HEAP32[$15>>2] = 10;
  $16 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_vi[$16 & 63]($cinfo);
 }
 $17 = (($1) + 32|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$8>>2]|0;
 _memcpy(($11|0),($18|0),($19|0))|0;
 $20 = (($1) + 28|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  _free($21);
 }
 HEAP32[$20>>2] = $11;
 $23 = HEAP32[$8>>2]|0;
 $24 = (($11) + ($23)|0);
 HEAP32[$1>>2] = $24;
 $25 = (($1) + 4|0);
 HEAP32[$25>>2] = $23;
 HEAP32[$17>>2] = $11;
 $$c2 = $10;
 HEAP32[$8>>2] = $$c2;
 STACKTOP = sp;return 1;
}
function _term_mem_destination($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 40|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  $5 = (($1) + 32|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($1) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  HEAP32[$8>>2] = $6;
 }
 $9 = (($1) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($1) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) - ($12))|0;
 $14 = (($1) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$15>>2] = $13;
 STACKTOP = sp;return;
}
function _jpeg_mem_dest($cinfo,$outbuffer,$outsize) {
 $cinfo = $cinfo|0;
 $outbuffer = $outbuffer|0;
 $outsize = $outsize|0;
 var $$c1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $outsize$c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($outbuffer|0)==(0|0);
 $1 = ($outsize|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  $2 = HEAP32[$cinfo>>2]|0;
  $3 = (($2) + 20|0);
  HEAP32[$3>>2] = 23;
  $4 = HEAP32[$2>>2]|0;
  FUNCTION_TABLE_vi[$4 & 63]($cinfo);
 }
 $5 = (($cinfo) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = (($cinfo) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_iiii[$10 & 7]($cinfo,0,40)|0);
  HEAP32[$5>>2] = $11;
  $13 = $11;
 } else {
  $13 = $6;
 }
 $12 = (($13) + 8|0);
 HEAP32[$12>>2] = 26;
 $14 = (($13) + 12|0);
 HEAP32[$14>>2] = 2;
 $15 = (($13) + 16|0);
 HEAP32[$15>>2] = 27;
 $16 = (($13) + 20|0);
 HEAP32[$16>>2] = $outbuffer;
 $17 = (($13) + 24|0);
 $outsize$c = $outsize;
 HEAP32[$17>>2] = $outsize$c;
 $18 = (($13) + 28|0);
 HEAP32[$18>>2] = 0;
 $19 = HEAP32[$outbuffer>>2]|0;
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  $21 = HEAP32[$outsize>>2]|0;
  $22 = ($21|0)==(0);
  if (!($22)) {
   $30 = $19;$32 = $21;
   $29 = (($13) + 32|0);
   HEAP32[$29>>2] = $30;
   HEAP32[$13>>2] = $30;
   $31 = (($13) + 36|0);
   $$c1 = $32;
   HEAP32[$31>>2] = $$c1;
   $33 = (($13) + 4|0);
   HEAP32[$33>>2] = $32;
   STACKTOP = sp;return;
  }
 }
 $23 = (_malloc(4096)|0);
 HEAP32[$outbuffer>>2] = $23;
 HEAP32[$18>>2] = $23;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = HEAP32[$cinfo>>2]|0;
  $26 = (($25) + 20|0);
  HEAP32[$26>>2] = 54;
  $27 = (($25) + 24|0);
  HEAP32[$27>>2] = 10;
  $28 = HEAP32[$25>>2]|0;
  FUNCTION_TABLE_vi[$28 & 63]($cinfo);
 }
 HEAP32[$outsize>>2] = 4096;
 $$pre = HEAP32[$outbuffer>>2]|0;
 $30 = $$pre;$32 = 4096;
 $29 = (($13) + 32|0);
 HEAP32[$29>>2] = $30;
 HEAP32[$13>>2] = $30;
 $31 = (($13) + 36|0);
 $$c1 = $32;
 HEAP32[$31>>2] = $$c1;
 $33 = (($13) + 4|0);
 HEAP32[$33>>2] = $32;
 STACKTOP = sp;return;
}
function _init_mem_destination38($cinfo) {
 $cinfo = $cinfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _empty_mem_output_buffer39($cinfo) {
 $cinfo = $cinfo|0;
 var $$c2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 << 1;
 $5 = (_malloc($4)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = HEAP32[$cinfo>>2]|0;
  $8 = (($7) + 20|0);
  HEAP32[$8>>2] = 54;
  $9 = (($7) + 24|0);
  HEAP32[$9>>2] = 10;
  $10 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_vi[$10 & 63]($cinfo);
 }
 $11 = (($1) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$2>>2]|0;
 _memcpy(($5|0),($12|0),($13|0))|0;
 $14 = (($1) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  _free($15);
 }
 HEAP32[$14>>2] = $5;
 $17 = HEAP32[$2>>2]|0;
 $18 = (($5) + ($17)|0);
 HEAP32[$1>>2] = $18;
 $19 = (($1) + 4|0);
 HEAP32[$19>>2] = $17;
 HEAP32[$11>>2] = $5;
 $$c2 = $4;
 HEAP32[$2>>2] = $$c2;
 STACKTOP = sp;return 1;
}
function _term_mem_destination40($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$5>>2] = $3;
 $6 = (($1) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($1) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) - ($9))|0;
 $11 = (($1) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$12>>2] = $10;
 STACKTOP = sp;return;
}
function _jpeg_std_error($err) {
 $err = $err|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$err>>2] = 28;
 $0 = (($err) + 4|0);
 HEAP32[$0>>2] = 10;
 $1 = (($err) + 8|0);
 HEAP32[$1>>2] = 29;
 $2 = (($err) + 12|0);
 HEAP32[$2>>2] = 11;
 $3 = (($err) + 16|0);
 HEAP32[$3>>2] = 30;
 $4 = (($err) + 104|0);
 HEAP32[$4>>2] = 0;
 $5 = (($err) + 108|0);
 HEAP32[$5>>2] = 0;
 $6 = (($err) + 20|0);
 HEAP32[$6>>2] = 0;
 $7 = (($err) + 112|0);
 HEAP32[$7>>2] = 142136;
 $8 = (($err) + 116|0);
 HEAP32[$8>>2] = 129;
 $9 = (($err) + 120|0);
 HEAP32[$9>>2] = 0;
 $10 = (($err) + 124|0);
 HEAP32[$10>>2] = 0;
 $11 = (($err) + 128|0);
 HEAP32[$11>>2] = 0;
 STACKTOP = sp;return ($err|0);
}
function _error_exit($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cinfo>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 63]($cinfo);
 _jpeg_destroy($cinfo);
 _exit(1);
 // unreachable;
}
function _emit_message($cinfo,$msg_level) {
 $cinfo = $cinfo|0;
 $msg_level = $msg_level|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cinfo>>2]|0;
 $1 = ($msg_level|0)<(0);
 if (!($1)) {
  $12 = (($0) + 104|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)<($msg_level|0);
  if ($14) {
   STACKTOP = sp;return;
  }
  $15 = (($0) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  FUNCTION_TABLE_vi[$16 & 63]($cinfo);
  STACKTOP = sp;return;
 }
 $2 = (($0) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  label = 4;
 } else {
  $5 = (($0) + 104|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)>(2);
  if ($7) {
   label = 4;
  } else {
   $11 = $3;
  }
 }
 if ((label|0) == 4) {
  $8 = (($0) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vi[$9 & 63]($cinfo);
  $$pre = HEAP32[$2>>2]|0;
  $11 = $$pre;
 }
 $10 = (($11) + 1)|0;
 HEAP32[$2>>2] = $10;
 STACKTOP = sp;return;
}
function _output_message($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $buffer = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $vararg_buffer = sp;
 $buffer = sp + 8|0;
 $0 = HEAP32[$cinfo>>2]|0;
 $1 = (($0) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 15]($cinfo,$buffer);
 $3 = HEAP32[_stderr>>2]|0;
 HEAP32[$vararg_buffer>>2] = $buffer;
 (_fprintf(($3|0),(142664|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function _format_message($cinfo,$buffer) {
 $cinfo = $cinfo|0;
 $buffer = $buffer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $msgptr$0 = 0, $msgtext$0 = 0, $msgtext$0$in = 0, $msgtext$1 = 0, $vararg_buffer1 = 0, $vararg_ptr10 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, $vararg_ptr6 = 0, $vararg_ptr7 = 0, $vararg_ptr8 = 0, $vararg_ptr9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer1 = sp;
 $0 = HEAP32[$cinfo>>2]|0;
 $1 = (($0) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(0);
 if ($3) {
  $4 = (($0) + 116|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($2|0)>($5|0);
  if ($6) {
   label = 4;
  } else {
   $7 = (($0) + 112|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + ($2<<2)|0);
   $msgtext$0$in = $9;
   label = 8;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $10 = (($0) + 120|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   label = 9;
  } else {
   $13 = (($0) + 124|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($2|0)<($14|0);
   if ($15) {
    label = 9;
   } else {
    $16 = (($0) + 128|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($2|0)>($17|0);
    if ($18) {
     label = 9;
    } else {
     $19 = (($2) - ($14))|0;
     $20 = (($11) + ($19<<2)|0);
     $msgtext$0$in = $20;
     label = 8;
    }
   }
  }
 }
 if ((label|0) == 8) {
  $msgtext$0 = HEAP32[$msgtext$0$in>>2]|0;
  $21 = ($msgtext$0|0)==(0|0);
  if ($21) {
   label = 9;
  } else {
   $msgtext$1 = $msgtext$0;
  }
 }
 if ((label|0) == 9) {
  $22 = (($0) + 24|0);
  HEAP32[$22>>2] = $2;
  $23 = (($0) + 112|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = HEAP32[$24>>2]|0;
  $msgtext$1 = $25;
 }
 $msgptr$0 = $msgtext$1;
 while(1) {
  $26 = (($msgptr$0) + 1|0);
  $27 = HEAP8[$msgptr$0>>0]|0;
  if ((($27<<24>>24) == 0)) {
   label = 12;
   break;
  } else if ((($27<<24>>24) == 37)) {
   label = 13;
   break;
  } else {
   $msgptr$0 = $26;
  }
 }
 if ((label|0) == 12) {
  $28 = (($0) + 24|0);
  $33 = $28;
 }
 else if ((label|0) == 13) {
  $29 = HEAP8[$26>>0]|0;
  $30 = ($29<<24>>24)==(115);
  $31 = (($0) + 24|0);
  if ($30) {
   HEAP32[$vararg_buffer1>>2] = $31;
   (_sprintf($buffer,$msgtext$1,$vararg_buffer1)|0);
   STACKTOP = sp;return;
  } else {
   $33 = $31;
  }
 }
 $32 = HEAP32[$33>>2]|0;
 $34 = (($0) + 28|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($0) + 32|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($0) + 36|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($0) + 40|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($0) + 44|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($0) + 48|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($0) + 52|0);
 $47 = HEAP32[$46>>2]|0;
 HEAP32[$vararg_buffer1>>2] = $32;
 $vararg_ptr4 = (($vararg_buffer1) + 4|0);
 HEAP32[$vararg_ptr4>>2] = $35;
 $vararg_ptr5 = (($vararg_buffer1) + 8|0);
 HEAP32[$vararg_ptr5>>2] = $37;
 $vararg_ptr6 = (($vararg_buffer1) + 12|0);
 HEAP32[$vararg_ptr6>>2] = $39;
 $vararg_ptr7 = (($vararg_buffer1) + 16|0);
 HEAP32[$vararg_ptr7>>2] = $41;
 $vararg_ptr8 = (($vararg_buffer1) + 20|0);
 HEAP32[$vararg_ptr8>>2] = $43;
 $vararg_ptr9 = (($vararg_buffer1) + 24|0);
 HEAP32[$vararg_ptr9>>2] = $45;
 $vararg_ptr10 = (($vararg_buffer1) + 28|0);
 HEAP32[$vararg_ptr10>>2] = $47;
 (_sprintf($buffer,$msgtext$1,$vararg_buffer1)|0);
 STACKTOP = sp;return;
}
function _reset_error_mgr($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cinfo>>2]|0;
 $1 = (($0) + 108|0);
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 20|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function _jpeg_fdct_float($data) {
 $data = $data|0;
 var $0 = 0.0, $1 = 0, $10 = 0.0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0;
 var $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0.0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0.0;
 var $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0;
 var $6 = 0.0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0;
 var $78 = 0.0, $79 = 0.0, $8 = 0.0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0.0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0;
 var $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $ctr$04 = 0, $ctr$12 = 0, $dataptr$03 = 0, $dataptr$11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $ctr$04 = 7;$dataptr$03 = $data;
 while(1) {
  $0 = +HEAPF32[$dataptr$03>>2];
  $1 = (($dataptr$03) + 28|0);
  $2 = +HEAPF32[$1>>2];
  $3 = $0 + $2;
  $4 = $0 - $2;
  $5 = (($dataptr$03) + 4|0);
  $6 = +HEAPF32[$5>>2];
  $7 = (($dataptr$03) + 24|0);
  $8 = +HEAPF32[$7>>2];
  $9 = $6 + $8;
  $10 = $6 - $8;
  $11 = (($dataptr$03) + 8|0);
  $12 = +HEAPF32[$11>>2];
  $13 = (($dataptr$03) + 20|0);
  $14 = +HEAPF32[$13>>2];
  $15 = $12 + $14;
  $16 = $12 - $14;
  $17 = (($dataptr$03) + 12|0);
  $18 = +HEAPF32[$17>>2];
  $19 = (($dataptr$03) + 16|0);
  $20 = +HEAPF32[$19>>2];
  $21 = $18 + $20;
  $22 = $18 - $20;
  $23 = $3 + $21;
  $24 = $3 - $21;
  $25 = $9 + $15;
  $26 = $9 - $15;
  $27 = $25 + $23;
  HEAPF32[$dataptr$03>>2] = $27;
  $28 = $23 - $25;
  HEAPF32[$19>>2] = $28;
  $29 = $26 + $24;
  $30 = $29 * 0.70710676908493042;
  $31 = $24 + $30;
  HEAPF32[$11>>2] = $31;
  $32 = $24 - $30;
  HEAPF32[$7>>2] = $32;
  $33 = $16 + $22;
  $34 = $10 + $16;
  $35 = $4 + $10;
  $36 = $33 - $35;
  $37 = $36 * 0.38268342614173889;
  $38 = $33 * 0.54119610786437988;
  $39 = $38 + $37;
  $40 = $35 * 1.3065630197525024;
  $41 = $40 + $37;
  $42 = $34 * 0.70710676908493042;
  $43 = $4 + $42;
  $44 = $4 - $42;
  $45 = $44 + $39;
  HEAPF32[$13>>2] = $45;
  $46 = $44 - $39;
  HEAPF32[$17>>2] = $46;
  $47 = $43 + $41;
  HEAPF32[$5>>2] = $47;
  $48 = $43 - $41;
  HEAPF32[$1>>2] = $48;
  $49 = (($dataptr$03) + 32|0);
  $50 = (($ctr$04) + -1)|0;
  $51 = ($ctr$04|0)>(0);
  if ($51) {
   $ctr$04 = $50;$dataptr$03 = $49;
  } else {
   $ctr$12 = 7;$dataptr$11 = $data;
   break;
  }
 }
 while(1) {
  $52 = +HEAPF32[$dataptr$11>>2];
  $53 = (($dataptr$11) + 224|0);
  $54 = +HEAPF32[$53>>2];
  $55 = $52 + $54;
  $56 = $52 - $54;
  $57 = (($dataptr$11) + 32|0);
  $58 = +HEAPF32[$57>>2];
  $59 = (($dataptr$11) + 192|0);
  $60 = +HEAPF32[$59>>2];
  $61 = $58 + $60;
  $62 = $58 - $60;
  $63 = (($dataptr$11) + 64|0);
  $64 = +HEAPF32[$63>>2];
  $65 = (($dataptr$11) + 160|0);
  $66 = +HEAPF32[$65>>2];
  $67 = $64 + $66;
  $68 = $64 - $66;
  $69 = (($dataptr$11) + 96|0);
  $70 = +HEAPF32[$69>>2];
  $71 = (($dataptr$11) + 128|0);
  $72 = +HEAPF32[$71>>2];
  $73 = $70 + $72;
  $74 = $70 - $72;
  $75 = $55 + $73;
  $76 = $55 - $73;
  $77 = $61 + $67;
  $78 = $61 - $67;
  $79 = $77 + $75;
  HEAPF32[$dataptr$11>>2] = $79;
  $80 = $75 - $77;
  HEAPF32[$71>>2] = $80;
  $81 = $78 + $76;
  $82 = $81 * 0.70710676908493042;
  $83 = $76 + $82;
  HEAPF32[$63>>2] = $83;
  $84 = $76 - $82;
  HEAPF32[$59>>2] = $84;
  $85 = $68 + $74;
  $86 = $62 + $68;
  $87 = $56 + $62;
  $88 = $85 - $87;
  $89 = $88 * 0.38268342614173889;
  $90 = $85 * 0.54119610786437988;
  $91 = $90 + $89;
  $92 = $87 * 1.3065630197525024;
  $93 = $92 + $89;
  $94 = $86 * 0.70710676908493042;
  $95 = $56 + $94;
  $96 = $56 - $94;
  $97 = $96 + $91;
  HEAPF32[$65>>2] = $97;
  $98 = $96 - $91;
  HEAPF32[$69>>2] = $98;
  $99 = $95 + $93;
  HEAPF32[$57>>2] = $99;
  $100 = $95 - $93;
  HEAPF32[$53>>2] = $100;
  $101 = (($dataptr$11) + 4|0);
  $102 = (($ctr$12) + -1)|0;
  $103 = ($ctr$12|0)>(0);
  if ($103) {
   $ctr$12 = $102;$dataptr$11 = $101;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _jpeg_fdct_ifast($data) {
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ctr$05 = 0, $ctr$13 = 0, $dataptr$04 = 0, $dataptr$12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $ctr$05 = 7;$dataptr$04 = $data;
 while(1) {
  $0 = HEAP32[$dataptr$04>>2]|0;
  $1 = (($dataptr$04) + 28|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($2) + ($0))|0;
  $4 = (($0) - ($2))|0;
  $5 = (($dataptr$04) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($dataptr$04) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + ($6))|0;
  $10 = (($6) - ($8))|0;
  $11 = (($dataptr$04) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($dataptr$04) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($12))|0;
  $16 = (($12) - ($14))|0;
  $17 = (($dataptr$04) + 12|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($dataptr$04) + 16|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + ($18))|0;
  $22 = (($18) - ($20))|0;
  $23 = (($21) + ($3))|0;
  $24 = (($3) - ($21))|0;
  $25 = (($15) + ($9))|0;
  $26 = (($9) - ($15))|0;
  $27 = (($23) + ($25))|0;
  HEAP32[$dataptr$04>>2] = $27;
  $28 = (($23) - ($25))|0;
  HEAP32[$19>>2] = $28;
  $29 = (($26) + ($24))|0;
  $30 = ($29*181)|0;
  $31 = $30 >> 8;
  $32 = (($31) + ($24))|0;
  HEAP32[$11>>2] = $32;
  $33 = (($24) - ($31))|0;
  HEAP32[$7>>2] = $33;
  $34 = (($22) + ($16))|0;
  $35 = (($16) + ($10))|0;
  $36 = (($10) + ($4))|0;
  $37 = (($34) - ($36))|0;
  $38 = ($37*98)|0;
  $39 = $38 >> 8;
  $40 = ($34*139)|0;
  $41 = $40 >> 8;
  $42 = (($39) + ($41))|0;
  $43 = ($36*334)|0;
  $44 = $43 >> 8;
  $45 = (($39) + ($44))|0;
  $46 = ($35*181)|0;
  $47 = $46 >> 8;
  $48 = (($47) + ($4))|0;
  $49 = (($4) - ($47))|0;
  $50 = (($42) + ($49))|0;
  HEAP32[$13>>2] = $50;
  $51 = (($49) - ($42))|0;
  HEAP32[$17>>2] = $51;
  $52 = (($45) + ($48))|0;
  HEAP32[$5>>2] = $52;
  $53 = (($48) - ($45))|0;
  HEAP32[$1>>2] = $53;
  $54 = (($dataptr$04) + 32|0);
  $55 = (($ctr$05) + -1)|0;
  $56 = ($ctr$05|0)>(0);
  if ($56) {
   $ctr$05 = $55;$dataptr$04 = $54;
  } else {
   $ctr$13 = 7;$dataptr$12 = $data;
   break;
  }
 }
 while(1) {
  $57 = HEAP32[$dataptr$12>>2]|0;
  $58 = (($dataptr$12) + 224|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = (($59) + ($57))|0;
  $61 = (($57) - ($59))|0;
  $62 = (($dataptr$12) + 32|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (($dataptr$12) + 192|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = (($65) + ($63))|0;
  $67 = (($63) - ($65))|0;
  $68 = (($dataptr$12) + 64|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = (($dataptr$12) + 160|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = (($71) + ($69))|0;
  $73 = (($69) - ($71))|0;
  $74 = (($dataptr$12) + 96|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (($dataptr$12) + 128|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = (($77) + ($75))|0;
  $79 = (($75) - ($77))|0;
  $80 = (($78) + ($60))|0;
  $81 = (($60) - ($78))|0;
  $82 = (($72) + ($66))|0;
  $83 = (($66) - ($72))|0;
  $84 = (($80) + ($82))|0;
  HEAP32[$dataptr$12>>2] = $84;
  $85 = (($80) - ($82))|0;
  HEAP32[$76>>2] = $85;
  $86 = (($83) + ($81))|0;
  $87 = ($86*181)|0;
  $88 = $87 >> 8;
  $89 = (($88) + ($81))|0;
  HEAP32[$68>>2] = $89;
  $90 = (($81) - ($88))|0;
  HEAP32[$64>>2] = $90;
  $91 = (($79) + ($73))|0;
  $92 = (($73) + ($67))|0;
  $93 = (($67) + ($61))|0;
  $94 = (($91) - ($93))|0;
  $95 = ($94*98)|0;
  $96 = $95 >> 8;
  $97 = ($91*139)|0;
  $98 = $97 >> 8;
  $99 = (($96) + ($98))|0;
  $100 = ($93*334)|0;
  $101 = $100 >> 8;
  $102 = (($96) + ($101))|0;
  $103 = ($92*181)|0;
  $104 = $103 >> 8;
  $105 = (($104) + ($61))|0;
  $106 = (($61) - ($104))|0;
  $107 = (($99) + ($106))|0;
  HEAP32[$70>>2] = $107;
  $108 = (($106) - ($99))|0;
  HEAP32[$74>>2] = $108;
  $109 = (($102) + ($105))|0;
  HEAP32[$62>>2] = $109;
  $110 = (($105) - ($102))|0;
  HEAP32[$58>>2] = $110;
  $111 = (($dataptr$12) + 4|0);
  $112 = (($ctr$13) + -1)|0;
  $113 = ($ctr$13|0)>(0);
  if ($113) {
   $ctr$13 = $112;$dataptr$12 = $111;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _jpeg_fdct_islow($data) {
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ctr$04 = 0, $ctr$12 = 0, $dataptr$03 = 0, $dataptr$11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $ctr$04 = 7;$dataptr$03 = $data;
 while(1) {
  $0 = HEAP32[$dataptr$03>>2]|0;
  $1 = (($dataptr$03) + 28|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($2) + ($0))|0;
  $4 = (($0) - ($2))|0;
  $5 = (($dataptr$03) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($dataptr$03) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + ($6))|0;
  $10 = (($6) - ($8))|0;
  $11 = (($dataptr$03) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($dataptr$03) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($12))|0;
  $16 = (($12) - ($14))|0;
  $17 = (($dataptr$03) + 12|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($dataptr$03) + 16|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + ($18))|0;
  $22 = (($18) - ($20))|0;
  $23 = (($21) + ($3))|0;
  $24 = (($3) - ($21))|0;
  $25 = (($15) + ($9))|0;
  $26 = (($9) - ($15))|0;
  $27 = (($23) + ($25))|0;
  $28 = $27 << 2;
  HEAP32[$dataptr$03>>2] = $28;
  $29 = (($23) - ($25))|0;
  $30 = $29 << 2;
  HEAP32[$19>>2] = $30;
  $31 = (($24) + ($26))|0;
  $32 = ($31*4433)|0;
  $33 = ($24*6270)|0;
  $34 = (($33) + 1024)|0;
  $35 = (($34) + ($32))|0;
  $36 = $35 >> 11;
  HEAP32[$11>>2] = $36;
  $37 = Math_imul($26, -15137)|0;
  $38 = (($37) + 1024)|0;
  $39 = (($38) + ($32))|0;
  $40 = $39 >> 11;
  HEAP32[$7>>2] = $40;
  $41 = (($22) + ($4))|0;
  $42 = (($16) + ($10))|0;
  $43 = (($22) + ($10))|0;
  $44 = (($16) + ($4))|0;
  $45 = (($43) + ($44))|0;
  $46 = ($45*9633)|0;
  $47 = ($22*2446)|0;
  $48 = ($16*16819)|0;
  $49 = ($10*25172)|0;
  $50 = ($4*12299)|0;
  $51 = Math_imul($41, -7373)|0;
  $52 = Math_imul($42, -20995)|0;
  $53 = Math_imul($43, -16069)|0;
  $54 = Math_imul($44, -3196)|0;
  $55 = (($46) + ($53))|0;
  $56 = (($46) + ($54))|0;
  $57 = (($47) + 1024)|0;
  $58 = (($57) + ($51))|0;
  $59 = (($58) + ($55))|0;
  $60 = $59 >> 11;
  HEAP32[$1>>2] = $60;
  $61 = (($48) + 1024)|0;
  $62 = (($61) + ($52))|0;
  $63 = (($62) + ($56))|0;
  $64 = $63 >> 11;
  HEAP32[$13>>2] = $64;
  $65 = (($49) + 1024)|0;
  $66 = (($65) + ($52))|0;
  $67 = (($66) + ($55))|0;
  $68 = $67 >> 11;
  HEAP32[$17>>2] = $68;
  $69 = (($50) + 1024)|0;
  $70 = (($69) + ($51))|0;
  $71 = (($70) + ($56))|0;
  $72 = $71 >> 11;
  HEAP32[$5>>2] = $72;
  $73 = (($dataptr$03) + 32|0);
  $74 = (($ctr$04) + -1)|0;
  $75 = ($ctr$04|0)>(0);
  if ($75) {
   $ctr$04 = $74;$dataptr$03 = $73;
  } else {
   $ctr$12 = 7;$dataptr$11 = $data;
   break;
  }
 }
 while(1) {
  $76 = HEAP32[$dataptr$11>>2]|0;
  $77 = (($dataptr$11) + 224|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (($78) + ($76))|0;
  $80 = (($76) - ($78))|0;
  $81 = (($dataptr$11) + 32|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = (($dataptr$11) + 192|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (($84) + ($82))|0;
  $86 = (($82) - ($84))|0;
  $87 = (($dataptr$11) + 64|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = (($dataptr$11) + 160|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (($90) + ($88))|0;
  $92 = (($88) - ($90))|0;
  $93 = (($dataptr$11) + 96|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = (($dataptr$11) + 128|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = (($96) + ($94))|0;
  $98 = (($94) - ($96))|0;
  $99 = (($97) + ($79))|0;
  $100 = (($79) - ($97))|0;
  $101 = (($91) + ($85))|0;
  $102 = (($85) - ($91))|0;
  $103 = (($101) + 2)|0;
  $104 = (($103) + ($99))|0;
  $105 = $104 >> 2;
  HEAP32[$dataptr$11>>2] = $105;
  $106 = (2 - ($101))|0;
  $107 = (($106) + ($99))|0;
  $108 = $107 >> 2;
  HEAP32[$95>>2] = $108;
  $109 = (($100) + ($102))|0;
  $110 = ($109*4433)|0;
  $111 = ($100*6270)|0;
  $112 = (($111) + 16384)|0;
  $113 = (($112) + ($110))|0;
  $114 = $113 >> 15;
  HEAP32[$87>>2] = $114;
  $115 = Math_imul($102, -15137)|0;
  $116 = (($115) + 16384)|0;
  $117 = (($116) + ($110))|0;
  $118 = $117 >> 15;
  HEAP32[$83>>2] = $118;
  $119 = (($98) + ($80))|0;
  $120 = (($92) + ($86))|0;
  $121 = (($98) + ($86))|0;
  $122 = (($92) + ($80))|0;
  $123 = (($121) + ($122))|0;
  $124 = ($123*9633)|0;
  $125 = ($98*2446)|0;
  $126 = ($92*16819)|0;
  $127 = ($86*25172)|0;
  $128 = ($80*12299)|0;
  $129 = Math_imul($119, -7373)|0;
  $130 = Math_imul($120, -20995)|0;
  $131 = Math_imul($121, -16069)|0;
  $132 = Math_imul($122, -3196)|0;
  $133 = (($124) + ($131))|0;
  $134 = (($124) + ($132))|0;
  $135 = (($125) + 16384)|0;
  $136 = (($135) + ($129))|0;
  $137 = (($136) + ($133))|0;
  $138 = $137 >> 15;
  HEAP32[$77>>2] = $138;
  $139 = (($126) + 16384)|0;
  $140 = (($139) + ($130))|0;
  $141 = (($140) + ($134))|0;
  $142 = $141 >> 15;
  HEAP32[$89>>2] = $142;
  $143 = (($127) + 16384)|0;
  $144 = (($143) + ($130))|0;
  $145 = (($144) + ($133))|0;
  $146 = $145 >> 15;
  HEAP32[$93>>2] = $146;
  $147 = (($128) + 16384)|0;
  $148 = (($147) + ($129))|0;
  $149 = (($148) + ($134))|0;
  $150 = $149 >> 15;
  HEAP32[$81>>2] = $150;
  $151 = (($dataptr$11) + 4|0);
  $152 = (($ctr$12) + -1)|0;
  $153 = ($ctr$12|0)>(0);
  if ($153) {
   $ctr$12 = $152;$dataptr$11 = $151;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _jinit_memory_mgr($cinfo) {
 $cinfo = $cinfo|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ch = 0, $max_to_use = 0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $max_to_use = sp + 8|0;
 $ch = sp + 12|0;
 $0 = (($cinfo) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (_jpeg_mem_init($cinfo)|0);
 HEAP32[$max_to_use>>2] = $1;
 $2 = (_jpeg_get_small($cinfo,84)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  _jpeg_mem_term($cinfo);
  $4 = HEAP32[$cinfo>>2]|0;
  $5 = (($4) + 20|0);
  HEAP32[$5>>2] = 54;
  $6 = (($4) + 24|0);
  HEAP32[$6>>2] = 0;
  $7 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vi[$7 & 63]($cinfo);
 }
 HEAP32[$2>>2] = 2;
 $8 = (($2) + 4|0);
 HEAP32[$8>>2] = 3;
 $9 = (($2) + 8|0);
 HEAP32[$9>>2] = 1;
 $10 = (($2) + 12|0);
 HEAP32[$10>>2] = 2;
 $11 = (($2) + 16|0);
 HEAP32[$11>>2] = 1;
 $12 = (($2) + 20|0);
 HEAP32[$12>>2] = 2;
 $13 = (($2) + 24|0);
 HEAP32[$13>>2] = 31;
 $14 = (($2) + 28|0);
 HEAP32[$14>>2] = 1;
 $15 = (($2) + 32|0);
 HEAP32[$15>>2] = 2;
 $16 = (($2) + 36|0);
 HEAP32[$16>>2] = 12;
 $17 = (($2) + 40|0);
 HEAP32[$17>>2] = 32;
 $18 = (($2) + 48|0);
 HEAP32[$18>>2] = 1000000000;
 $19 = HEAP32[$max_to_use>>2]|0;
 $20 = (($2) + 44|0);
 HEAP32[$20>>2] = $19;
 $21 = (($2) + 52|0);
 $22 = (($2) + 60|0);
 $23 = (($2) + 56|0);
 HEAP32[$23>>2] = 0;
 $24 = (($2) + 64|0);
 HEAP32[$24>>2] = 0;
 HEAP32[$21>>2] = 0;
 HEAP32[$22>>2] = 0;
 $25 = (($2) + 68|0);
 HEAP32[$25>>2] = 0;
 $26 = (($2) + 72|0);
 HEAP32[$26>>2] = 0;
 $27 = (($2) + 76|0);
 HEAP32[$27>>2] = 84;
 HEAP32[$0>>2] = $2;
 $28 = (_getenv((142672|0))|0);
 $29 = ($28|0)==(0|0);
 if ($29) {
  STACKTOP = sp;return;
 }
 HEAP8[$ch>>0] = 120;
 HEAP32[$vararg_buffer>>2] = $max_to_use;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $ch;
 $30 = (_sscanf($28,142680,$vararg_buffer)|0);
 $31 = ($30|0)>(0);
 if (!($31)) {
  STACKTOP = sp;return;
 }
 $32 = HEAP8[$ch>>0]|0;
 if ((($32<<24>>24) == 77) | (($32<<24>>24) == 109)) {
  $33 = HEAP32[$max_to_use>>2]|0;
  $34 = ($33*1000)|0;
  HEAP32[$max_to_use>>2] = $34;
  $36 = $34;
 } else {
  $$pre = HEAP32[$max_to_use>>2]|0;
  $36 = $$pre;
 }
 $35 = ($36*1000)|0;
 HEAP32[$20>>2] = $35;
 STACKTOP = sp;return;
}
function _alloc_small($cinfo,$pool_id,$sizeofobject) {
 $cinfo = $cinfo|0;
 $pool_id = $pool_id|0;
 $sizeofobject = $sizeofobject|0;
 var $$c = 0, $$lcssa = 0, $$lcssa3$in = 0, $$slop$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cond = 0, $cond12 = 0;
 var $data_ptr$0 = 0, $first_pool_slop$extra_pool_slop = 0, $hdr_ptr$0 = 0, $hdr_ptr$011 = 0, $hdr_ptr$014 = 0, $hdr_ptr$1 = 0, $prev_hdr_ptr$09 = 0, $slop$0 = 0, $slop$0$in = 0, $slop$1$lcssa = 0, $slop$14 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($sizeofobject) + 7)|0;
 $3 = $2 & -8;
 $4 = (($3) + 19)|0;
 $5 = ($4>>>0)>(1000000000);
 if ($5) {
  $6 = HEAP32[$cinfo>>2]|0;
  $7 = (($6) + 20|0);
  HEAP32[$7>>2] = 54;
  $8 = (($6) + 24|0);
  HEAP32[$8>>2] = 1;
  $9 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vi[$9 & 63]($cinfo);
 }
 $10 = ($pool_id>>>0)>(1);
 if ($10) {
  $11 = HEAP32[$cinfo>>2]|0;
  $12 = (($11) + 20|0);
  HEAP32[$12>>2] = 14;
  $13 = (($11) + 24|0);
  HEAP32[$13>>2] = $pool_id;
  $14 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vi[$14 & 63]($cinfo);
 }
 $15 = (($1) + 52|0);
 $16 = (($15) + ($pool_id<<2)|0);
 $hdr_ptr$011 = HEAP32[$16>>2]|0;
 $cond12 = ($hdr_ptr$011|0)==(0|0);
 L7: do {
  if ($cond12) {
   $prev_hdr_ptr$09 = 0;
   label = 8;
  } else {
   $hdr_ptr$014 = $hdr_ptr$011;
   while(1) {
    $17 = (($hdr_ptr$014) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18>>>0)<($3>>>0);
    if (!($19)) {
     $hdr_ptr$1 = $hdr_ptr$014;
     break L7;
    }
    $hdr_ptr$0 = HEAP32[$hdr_ptr$014>>2]|0;
    $cond = ($hdr_ptr$0|0)==(0|0);
    if ($cond) {
     $prev_hdr_ptr$09 = $hdr_ptr$014;
     label = 8;
     break;
    } else {
     $hdr_ptr$014 = $hdr_ptr$0;
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 8) {
   $20 = ($prev_hdr_ptr$09|0)==(0|0);
   $first_pool_slop$extra_pool_slop = $20 ? 142688 : 142696;
   $slop$0$in = (($first_pool_slop$extra_pool_slop) + ($pool_id<<2)|0);
   $slop$0 = HEAP32[$slop$0$in>>2]|0;
   $21 = (999999981 - ($3))|0;
   $22 = ($slop$0>>>0)>($21>>>0);
   $$slop$0 = $22 ? $21 : $slop$0;
   $23 = (($$slop$0) + ($4))|0;
   $24 = (_jpeg_get_small($cinfo,$23)|0);
   $25 = ($24|0)==(0|0);
   if ($25) {
    $slop$14 = $$slop$0;
    while(1) {
     $26 = $slop$14 >>> 1;
     $27 = ($slop$14>>>0)<(100);
     if ($27) {
      $28 = HEAP32[$cinfo>>2]|0;
      $29 = (($28) + 20|0);
      HEAP32[$29>>2] = 54;
      $30 = (($28) + 24|0);
      HEAP32[$30>>2] = 2;
      $31 = HEAP32[$28>>2]|0;
      FUNCTION_TABLE_vi[$31 & 63]($cinfo);
     }
     $32 = (($26) + ($4))|0;
     $33 = (_jpeg_get_small($cinfo,$32)|0);
     $34 = ($33|0)==(0|0);
     if ($34) {
      $slop$14 = $26;
     } else {
      $$lcssa = $32;$$lcssa3$in = $33;$slop$1$lcssa = $26;
      break;
     }
    }
   } else {
    $$lcssa = $23;$$lcssa3$in = $24;$slop$1$lcssa = $$slop$0;
   }
   $35 = (($1) + 76|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + ($$lcssa))|0;
   $$c = $37;
   HEAP32[$35>>2] = $$c;
   HEAP32[$$lcssa3$in>>2] = 0;
   $38 = (($$lcssa3$in) + 4|0);
   HEAP32[$38>>2] = 0;
   $39 = (($slop$1$lcssa) + ($3))|0;
   $40 = (($$lcssa3$in) + 8|0);
   HEAP32[$40>>2] = $39;
   if ($20) {
    HEAP32[$16>>2] = $$lcssa3$in;
    $hdr_ptr$1 = $$lcssa3$in;
    break;
   } else {
    HEAP32[$prev_hdr_ptr$09>>2] = $$lcssa3$in;
    $hdr_ptr$1 = $$lcssa3$in;
    break;
   }
  }
 } while(0);
 $41 = (($hdr_ptr$1) + 12|0);
 $42 = $41;
 $43 = $42 & 7;
 $44 = ($43|0)==(0);
 if ($44) {
  $data_ptr$0 = $41;
  $47 = (($hdr_ptr$1) + 4|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($data_ptr$0) + ($48)|0);
  $50 = (($48) + ($3))|0;
  HEAP32[$47>>2] = $50;
  $51 = (($hdr_ptr$1) + 8|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (($52) - ($3))|0;
  HEAP32[$51>>2] = $53;
  STACKTOP = sp;return ($49|0);
 }
 $45 = (8 - ($43))|0;
 $46 = (($41) + ($45)|0);
 $data_ptr$0 = $46;
 $47 = (($hdr_ptr$1) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($data_ptr$0) + ($48)|0);
 $50 = (($48) + ($3))|0;
 HEAP32[$47>>2] = $50;
 $51 = (($hdr_ptr$1) + 8|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) - ($3))|0;
 HEAP32[$51>>2] = $53;
 STACKTOP = sp;return ($49|0);
}
function _alloc_large($cinfo,$pool_id,$sizeofobject) {
 $cinfo = $cinfo|0;
 $pool_id = $pool_id|0;
 $sizeofobject = $sizeofobject|0;
 var $$c = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data_ptr$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($sizeofobject) + 7)|0;
 $3 = $2 & -8;
 $4 = (($3) + 19)|0;
 $5 = ($4>>>0)>(1000000000);
 if ($5) {
  $6 = HEAP32[$cinfo>>2]|0;
  $7 = (($6) + 20|0);
  HEAP32[$7>>2] = 54;
  $8 = (($6) + 24|0);
  HEAP32[$8>>2] = 3;
  $9 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vi[$9 & 63]($cinfo);
 }
 $10 = ($pool_id>>>0)>(1);
 if ($10) {
  $11 = HEAP32[$cinfo>>2]|0;
  $12 = (($11) + 20|0);
  HEAP32[$12>>2] = 14;
  $13 = (($11) + 24|0);
  HEAP32[$13>>2] = $pool_id;
  $14 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vi[$14 & 63]($cinfo);
 }
 $15 = (_jpeg_get_large($cinfo,$4)|0);
 $16 = ($15|0)==(0|0);
 if ($16) {
  $17 = HEAP32[$cinfo>>2]|0;
  $18 = (($17) + 20|0);
  HEAP32[$18>>2] = 54;
  $19 = (($17) + 24|0);
  HEAP32[$19>>2] = 4;
  $20 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_vi[$20 & 63]($cinfo);
 }
 $21 = (($1) + 76|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + ($4))|0;
 $$c = $23;
 HEAP32[$21>>2] = $$c;
 $24 = (($1) + 60|0);
 $25 = (($24) + ($pool_id<<2)|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$15>>2] = $26;
 $27 = (($15) + 4|0);
 HEAP32[$27>>2] = $3;
 $28 = (($15) + 8|0);
 HEAP32[$28>>2] = 0;
 HEAP32[$25>>2] = $15;
 $29 = (($15) + 12|0);
 $30 = $29;
 $31 = $30 & 7;
 $32 = ($31|0)==(0);
 if ($32) {
  $data_ptr$0 = $29;
  STACKTOP = sp;return ($data_ptr$0|0);
 }
 $$sum = (20 - ($31))|0;
 $33 = (($15) + ($$sum)|0);
 $data_ptr$0 = $33;
 STACKTOP = sp;return ($data_ptr$0|0);
}
function _alloc_sarray($cinfo,$pool_id,$samplesperrow,$numrows) {
 $cinfo = $cinfo|0;
 $pool_id = $pool_id|0;
 $samplesperrow = $samplesperrow|0;
 $numrows = $numrows|0;
 var $$numrows = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $currow$05 = 0, $currow$1$lcssa = 0, $currow$12 = 0, $i$03 = 0, $rowsperchunk$0$c = 0, $rowsperchunk$1$ = 0, $rowsperchunk$14 = 0, $umax = 0;
 var $workspace$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($samplesperrow) + 15)|0;
 $3 = $2 & -16;
 $4 = (999999988 / ($3>>>0))&-1;
 $5 = ($4|0)==(0);
 if ($5) {
  $6 = HEAP32[$cinfo>>2]|0;
  $7 = (($6) + 20|0);
  HEAP32[$7>>2] = 70;
  $8 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vi[$8 & 63]($cinfo);
 }
 $9 = ($4|0)<($numrows|0);
 $$numrows = $9 ? $4 : $numrows;
 $10 = (($1) + 80|0);
 $rowsperchunk$0$c = $$numrows;
 HEAP32[$10>>2] = $rowsperchunk$0$c;
 $11 = $numrows << 2;
 $12 = (_alloc_small($cinfo,$pool_id,$11)|0);
 $13 = ($numrows|0)==(0);
 if ($13) {
  STACKTOP = sp;return ($12|0);
 }
 $14 = $numrows ^ -1;
 $currow$05 = 0;$rowsperchunk$14 = $$numrows;
 while(1) {
  $18 = (($numrows) - ($currow$05))|0;
  $19 = ($rowsperchunk$14>>>0)<($18>>>0);
  $rowsperchunk$1$ = $19 ? $rowsperchunk$14 : $18;
  $20 = Math_imul($rowsperchunk$1$, $3)|0;
  $21 = (_alloc_large($cinfo,$pool_id,$20)|0);
  $22 = ($rowsperchunk$1$|0)==(0);
  if ($22) {
   $currow$1$lcssa = $currow$05;
  } else {
   $23 = $rowsperchunk$14 ^ -1;
   $24 = (($currow$05) + ($14))|0;
   $25 = ($24>>>0)<($23>>>0);
   $umax = $25 ? $23 : $24;
   $currow$12 = $currow$05;$i$03 = $rowsperchunk$1$;$workspace$01 = $21;
   while(1) {
    $26 = (($currow$12) + 1)|0;
    $27 = (($12) + ($currow$12<<2)|0);
    HEAP32[$27>>2] = $workspace$01;
    $28 = (($workspace$01) + ($3)|0);
    $29 = (($i$03) + -1)|0;
    $30 = ($29|0)==(0);
    if ($30) {
     break;
    } else {
     $currow$12 = $26;$i$03 = $29;$workspace$01 = $28;
    }
   }
   $15 = (($currow$05) + -1)|0;
   $16 = (($15) - ($umax))|0;
   $currow$1$lcssa = $16;
  }
  $17 = ($currow$1$lcssa>>>0)<($numrows>>>0);
  if ($17) {
   $currow$05 = $currow$1$lcssa;$rowsperchunk$14 = $rowsperchunk$1$;
  } else {
   break;
  }
 }
 STACKTOP = sp;return ($12|0);
}
function _alloc_barray($cinfo,$pool_id,$blocksperrow,$numrows) {
 $cinfo = $cinfo|0;
 $pool_id = $pool_id|0;
 $blocksperrow = $blocksperrow|0;
 $numrows = $numrows|0;
 var $$numrows = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $currow$05 = 0, $currow$1$lcssa = 0, $currow$11 = 0, $i$02 = 0, $rowsperchunk$0$c = 0, $rowsperchunk$1$ = 0, $rowsperchunk$14 = 0, $umax = 0, $workspace$03 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $blocksperrow << 7;
 $3 = (999999988 / ($2>>>0))&-1;
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = HEAP32[$cinfo>>2]|0;
  $6 = (($5) + 20|0);
  HEAP32[$6>>2] = 70;
  $7 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vi[$7 & 63]($cinfo);
 }
 $8 = ($3|0)<($numrows|0);
 $$numrows = $8 ? $3 : $numrows;
 $9 = (($1) + 80|0);
 $rowsperchunk$0$c = $$numrows;
 HEAP32[$9>>2] = $rowsperchunk$0$c;
 $10 = $numrows << 2;
 $11 = (_alloc_small($cinfo,$pool_id,$10)|0);
 $12 = ($numrows|0)==(0);
 if ($12) {
  STACKTOP = sp;return ($11|0);
 }
 $13 = $numrows ^ -1;
 $currow$05 = 0;$rowsperchunk$14 = $$numrows;
 while(1) {
  $17 = (($numrows) - ($currow$05))|0;
  $18 = ($rowsperchunk$14>>>0)<($17>>>0);
  $rowsperchunk$1$ = $18 ? $rowsperchunk$14 : $17;
  $19 = Math_imul($2, $rowsperchunk$1$)|0;
  $20 = (_alloc_large($cinfo,$pool_id,$19)|0);
  $21 = ($rowsperchunk$1$|0)==(0);
  if ($21) {
   $currow$1$lcssa = $currow$05;
  } else {
   $22 = $rowsperchunk$14 ^ -1;
   $23 = (($currow$05) + ($13))|0;
   $24 = ($23>>>0)<($22>>>0);
   $umax = $24 ? $22 : $23;
   $currow$11 = $currow$05;$i$02 = $rowsperchunk$1$;$workspace$03 = $20;
   while(1) {
    $25 = (($currow$11) + 1)|0;
    $26 = (($11) + ($currow$11<<2)|0);
    HEAP32[$26>>2] = $workspace$03;
    $27 = (($workspace$03) + ($blocksperrow<<7)|0);
    $28 = (($i$02) + -1)|0;
    $29 = ($28|0)==(0);
    if ($29) {
     break;
    } else {
     $currow$11 = $25;$i$02 = $28;$workspace$03 = $27;
    }
   }
   $14 = (($currow$05) + -1)|0;
   $15 = (($14) - ($umax))|0;
   $currow$1$lcssa = $15;
  }
  $16 = ($currow$1$lcssa>>>0)<($numrows>>>0);
  if ($16) {
   $currow$05 = $currow$1$lcssa;$rowsperchunk$14 = $rowsperchunk$1$;
  } else {
   break;
  }
 }
 STACKTOP = sp;return ($11|0);
}
function _request_virt_sarray($cinfo,$pool_id,$pre_zero,$samplesperrow,$numrows,$maxaccess) {
 $cinfo = $cinfo|0;
 $pool_id = $pool_id|0;
 $pre_zero = $pre_zero|0;
 $samplesperrow = $samplesperrow|0;
 $numrows = $numrows|0;
 $maxaccess = $maxaccess|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($pool_id|0)==(1);
 if (!($2)) {
  $3 = HEAP32[$cinfo>>2]|0;
  $4 = (($3) + 20|0);
  HEAP32[$4>>2] = 14;
  $5 = (($3) + 24|0);
  HEAP32[$5>>2] = $pool_id;
  $6 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$6 & 63]($cinfo);
 }
 $7 = (_alloc_small($cinfo,$pool_id,120)|0);
 HEAP32[$7>>2] = 0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $numrows;
 $9 = (($7) + 8|0);
 HEAP32[$9>>2] = $samplesperrow;
 $10 = (($7) + 12|0);
 HEAP32[$10>>2] = $maxaccess;
 $11 = (($7) + 32|0);
 HEAP8[$11>>0] = $pre_zero;
 $12 = (($7) + 34|0);
 HEAP8[$12>>0] = 0;
 $13 = (($1) + 68|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($7) + 36|0);
 HEAP32[$15>>2] = $14;
 HEAP32[$13>>2] = $7;
 STACKTOP = sp;return ($7|0);
}
function _request_virt_barray($cinfo,$pool_id,$pre_zero,$blocksperrow,$numrows,$maxaccess) {
 $cinfo = $cinfo|0;
 $pool_id = $pool_id|0;
 $pre_zero = $pre_zero|0;
 $blocksperrow = $blocksperrow|0;
 $numrows = $numrows|0;
 $maxaccess = $maxaccess|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($pool_id|0)==(1);
 if (!($2)) {
  $3 = HEAP32[$cinfo>>2]|0;
  $4 = (($3) + 20|0);
  HEAP32[$4>>2] = 14;
  $5 = (($3) + 24|0);
  HEAP32[$5>>2] = $pool_id;
  $6 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$6 & 63]($cinfo);
 }
 $7 = (_alloc_small($cinfo,$pool_id,120)|0);
 HEAP32[$7>>2] = 0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $numrows;
 $9 = (($7) + 8|0);
 HEAP32[$9>>2] = $blocksperrow;
 $10 = (($7) + 12|0);
 HEAP32[$10>>2] = $maxaccess;
 $11 = (($7) + 32|0);
 HEAP8[$11>>0] = $pre_zero;
 $12 = (($7) + 34|0);
 HEAP8[$12>>0] = 0;
 $13 = (($1) + 72|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($7) + 36|0);
 HEAP32[$15>>2] = $14;
 HEAP32[$13>>2] = $7;
 STACKTOP = sp;return ($7|0);
}
function _realize_virt_arrays($cinfo) {
 $cinfo = $cinfo|0;
 var $$ = 0, $$pre = 0, $$pre$phi23Z2D = 0, $$pre$phiZ2D = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bptr$06 = 0;
 var $bptr$11 = 0, $max_minheights$0 = 0, $maximum_space$0$lcssa = 0, $maximum_space$011 = 0, $maximum_space$1 = 0, $maximum_space$2$lcssa = 0, $maximum_space$24 = 0, $maximum_space$3 = 0, $space_per_minheight$0$lcssa = 0, $space_per_minheight$012 = 0, $space_per_minheight$1 = 0, $space_per_minheight$2$lcssa = 0, $space_per_minheight$25 = 0, $space_per_minheight$3 = 0, $sptr$013 = 0, $sptr$12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $maximum_space$0$lcssa = 0;$space_per_minheight$0$lcssa = 0;
 } else {
  $maximum_space$011 = 0;$space_per_minheight$012 = 0;$sptr$013 = $3;
  while(1) {
   $5 = HEAP32[$sptr$013>>2]|0;
   $6 = ($5|0)==(0|0);
   if ($6) {
    $7 = (($sptr$013) + 12|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($sptr$013) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = Math_imul($10, $8)|0;
    $12 = (($11) + ($space_per_minheight$012))|0;
    $13 = (($sptr$013) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = Math_imul($14, $10)|0;
    $16 = (($15) + ($maximum_space$011))|0;
    $maximum_space$1 = $16;$space_per_minheight$1 = $12;
   } else {
    $maximum_space$1 = $maximum_space$011;$space_per_minheight$1 = $space_per_minheight$012;
   }
   $17 = (($sptr$013) + 36|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0|0);
   if ($19) {
    $maximum_space$0$lcssa = $maximum_space$1;$space_per_minheight$0$lcssa = $space_per_minheight$1;
    break;
   } else {
    $maximum_space$011 = $maximum_space$1;$space_per_minheight$012 = $space_per_minheight$1;$sptr$013 = $18;
   }
  }
 }
 $20 = (($1) + 72|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $maximum_space$2$lcssa = $maximum_space$0$lcssa;$space_per_minheight$2$lcssa = $space_per_minheight$0$lcssa;
 } else {
  $bptr$06 = $21;$maximum_space$24 = $maximum_space$0$lcssa;$space_per_minheight$25 = $space_per_minheight$0$lcssa;
  while(1) {
   $23 = HEAP32[$bptr$06>>2]|0;
   $24 = ($23|0)==(0|0);
   if ($24) {
    $25 = (($bptr$06) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($bptr$06) + 8|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = $26 << 7;
    $30 = Math_imul($29, $28)|0;
    $31 = (($30) + ($space_per_minheight$25))|0;
    $32 = (($bptr$06) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = $28 << 7;
    $35 = Math_imul($34, $33)|0;
    $36 = (($35) + ($maximum_space$24))|0;
    $maximum_space$3 = $36;$space_per_minheight$3 = $31;
   } else {
    $maximum_space$3 = $maximum_space$24;$space_per_minheight$3 = $space_per_minheight$25;
   }
   $37 = (($bptr$06) + 36|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    $maximum_space$2$lcssa = $maximum_space$3;$space_per_minheight$2$lcssa = $space_per_minheight$3;
    break;
   } else {
    $bptr$06 = $38;$maximum_space$24 = $maximum_space$3;$space_per_minheight$25 = $space_per_minheight$3;
   }
  }
 }
 $40 = ($space_per_minheight$2$lcssa|0)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($1) + 76|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (_jpeg_mem_available($cinfo,$space_per_minheight$2$lcssa,$maximum_space$2$lcssa,$42)|0);
 $44 = ($43>>>0)<($maximum_space$2$lcssa>>>0);
 if ($44) {
  $45 = (($43>>>0) / ($space_per_minheight$2$lcssa>>>0))&-1;
  $46 = ($45|0)==(0);
  $$ = $46 ? 1 : $45;
  $max_minheights$0 = $$;
 } else {
  $max_minheights$0 = 1000000000;
 }
 $47 = HEAP32[$2>>2]|0;
 $48 = ($47|0)==(0|0);
 if (!($48)) {
  $49 = (($1) + 80|0);
  $sptr$12 = $47;
  while(1) {
   $50 = HEAP32[$sptr$12>>2]|0;
   $51 = ($50|0)==(0|0);
   if ($51) {
    $52 = (($sptr$12) + 4|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($53) + -1)|0;
    $55 = (($sptr$12) + 12|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($54>>>0) / ($56>>>0))&-1;
    $58 = (($57) + 1)|0;
    $59 = ($58>>>0)>($max_minheights$0>>>0);
    if ($59) {
     $61 = Math_imul($56, $max_minheights$0)|0;
     $62 = (($sptr$12) + 16|0);
     HEAP32[$62>>2] = $61;
     $63 = (($sptr$12) + 40|0);
     $64 = (($sptr$12) + 8|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = Math_imul($65, $53)|0;
     _jpeg_open_backing_store($cinfo,$63,$66);
     $67 = (($sptr$12) + 34|0);
     HEAP8[$67>>0] = 1;
     $$pre20 = HEAP32[$62>>2]|0;
     $$pre$phi23Z2D = $64;$69 = $$pre20;
    } else {
     $60 = (($sptr$12) + 16|0);
     HEAP32[$60>>2] = $53;
     $$pre22 = (($sptr$12) + 8|0);
     $$pre$phi23Z2D = $$pre22;$69 = $53;
    }
    $68 = HEAP32[$$pre$phi23Z2D>>2]|0;
    $70 = (_alloc_sarray($cinfo,1,$68,$69)|0);
    HEAP32[$sptr$12>>2] = $70;
    $71 = HEAP32[$49>>2]|0;
    $72 = (($sptr$12) + 20|0);
    HEAP32[$72>>2] = $71;
    $73 = (($sptr$12) + 24|0);
    HEAP32[$73>>2] = 0;
    $74 = (($sptr$12) + 28|0);
    HEAP32[$74>>2] = 0;
    $75 = (($sptr$12) + 33|0);
    HEAP8[$75>>0] = 0;
   }
   $76 = (($sptr$12) + 36|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(0|0);
   if ($78) {
    break;
   } else {
    $sptr$12 = $77;
   }
  }
 }
 $79 = HEAP32[$20>>2]|0;
 $80 = ($79|0)==(0|0);
 if ($80) {
  STACKTOP = sp;return;
 }
 $81 = (($1) + 80|0);
 $bptr$11 = $79;
 while(1) {
  $82 = HEAP32[$bptr$11>>2]|0;
  $83 = ($82|0)==(0|0);
  if ($83) {
   $84 = (($bptr$11) + 4|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = (($85) + -1)|0;
   $87 = (($bptr$11) + 12|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (($86>>>0) / ($88>>>0))&-1;
   $90 = (($89) + 1)|0;
   $91 = ($90>>>0)>($max_minheights$0>>>0);
   if ($91) {
    $93 = Math_imul($88, $max_minheights$0)|0;
    $94 = (($bptr$11) + 16|0);
    HEAP32[$94>>2] = $93;
    $95 = (($bptr$11) + 40|0);
    $96 = (($bptr$11) + 8|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = $85 << 7;
    $99 = Math_imul($98, $97)|0;
    _jpeg_open_backing_store($cinfo,$95,$99);
    $100 = (($bptr$11) + 34|0);
    HEAP8[$100>>0] = 1;
    $$pre = HEAP32[$94>>2]|0;
    $$pre$phiZ2D = $96;$102 = $$pre;
   } else {
    $92 = (($bptr$11) + 16|0);
    HEAP32[$92>>2] = $85;
    $$pre21 = (($bptr$11) + 8|0);
    $$pre$phiZ2D = $$pre21;$102 = $85;
   }
   $101 = HEAP32[$$pre$phiZ2D>>2]|0;
   $103 = (_alloc_barray($cinfo,1,$101,$102)|0);
   HEAP32[$bptr$11>>2] = $103;
   $104 = HEAP32[$81>>2]|0;
   $105 = (($bptr$11) + 20|0);
   HEAP32[$105>>2] = $104;
   $106 = (($bptr$11) + 24|0);
   HEAP32[$106>>2] = 0;
   $107 = (($bptr$11) + 28|0);
   HEAP32[$107>>2] = 0;
   $108 = (($bptr$11) + 33|0);
   HEAP8[$108>>0] = 0;
  }
  $109 = (($bptr$11) + 36|0);
  $110 = HEAP32[$109>>2]|0;
  $111 = ($110|0)==(0|0);
  if ($111) {
   break;
  } else {
   $bptr$11 = $110;
  }
 }
 STACKTOP = sp;return;
}
function _access_virt_sarray($cinfo,$ptr,$start_row,$num_rows,$writable) {
 $cinfo = $cinfo|0;
 $ptr = $ptr|0;
 $start_row = $start_row|0;
 $num_rows = $num_rows|0;
 $writable = $writable|0;
 var $$ = 0, $$$i = 0, $$$i12 = 0, $$$us$i = 0, $$$us$i6 = 0, $$1$i = 0, $$1$i13 = 0, $$1$i16 = 0, $$1$us$i = 0, $$1$us$i10 = 0, $$1$us$i7 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre11$i = 0, $$pre12$i = 0, $$pre4$i = 0, $$pre5$i = 0, $$pre7$i = 0;
 var $$pre8$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $exitcond = 0, $file_offset$02$i15 = 0, $file_offset$02$us$i9 = 0, $i$03$i14 = 0, $i$03$us$i8 = 0, $storemerge = 0, $undef_row$0 = 0, $undef_row$04 = 0, $undef_row$15 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($num_rows) + ($start_row))|0;
 $1 = (($ptr) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0>>>0)>($2>>>0);
 if ($3) {
  label = 4;
 } else {
  $4 = (($ptr) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5>>>0)<($num_rows>>>0);
  if ($6) {
   label = 4;
  } else {
   $7 = HEAP32[$ptr>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    label = 4;
   }
  }
 }
 if ((label|0) == 4) {
  $9 = HEAP32[$cinfo>>2]|0;
  $10 = (($9) + 20|0);
  HEAP32[$10>>2] = 22;
  $11 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vi[$11 & 63]($cinfo);
 }
 $12 = (($ptr) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13>>>0)>($start_row>>>0);
 if ($14) {
  label = 7;
 } else {
  $15 = (($ptr) + 16|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + ($13))|0;
  $18 = ($0>>>0)>($17>>>0);
  if ($18) {
   label = 7;
  }
 }
 L9: do {
  if ((label|0) == 7) {
   $19 = (($ptr) + 34|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = ($20<<24>>24)==(0);
   if ($21) {
    $22 = HEAP32[$cinfo>>2]|0;
    $23 = (($22) + 20|0);
    HEAP32[$23>>2] = 69;
    $24 = HEAP32[$22>>2]|0;
    FUNCTION_TABLE_vi[$24 & 63]($cinfo);
   }
   $25 = (($ptr) + 33|0);
   $26 = HEAP8[$25>>0]|0;
   $27 = ($26<<24>>24)==(0);
   if (!($27)) {
    $28 = (($ptr) + 8|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = HEAP32[$12>>2]|0;
    $31 = (($ptr) + 20|0);
    $32 = (($ptr) + 16|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)>(0);
    L16: do {
     if ($34) {
      $35 = (($ptr) + 28|0);
      $36 = (($ptr) + 40|0);
      $37 = (($ptr) + 44|0);
      $$pre$i = HEAP32[$31>>2]|0;
      $38 = ($$pre$i|0)<($33|0);
      $$$i12 = $38 ? $$pre$i : $33;
      $39 = HEAP32[$35>>2]|0;
      $40 = (($39) - ($30))|0;
      $41 = ($$$i12|0)<($40|0);
      $42 = $41 ? $$$i12 : $40;
      $43 = HEAP32[$1>>2]|0;
      $44 = (($43) - ($30))|0;
      $45 = ($42|0)<($44|0);
      $$1$i13 = $45 ? $42 : $44;
      $46 = ($$1$i13|0)<(1);
      if (!($46)) {
       $47 = Math_imul($30, $29)|0;
       $$1$i16 = $$1$i13;$file_offset$02$i15 = $47;$i$03$i14 = 0;
       while(1) {
        $48 = Math_imul($$1$i16, $29)|0;
        $49 = HEAP32[$37>>2]|0;
        $50 = HEAP32[$ptr>>2]|0;
        $51 = (($50) + ($i$03$i14<<2)|0);
        $52 = HEAP32[$51>>2]|0;
        FUNCTION_TABLE_viiiii[$49 & 15]($cinfo,$36,$52,$file_offset$02$i15,$48);
        $$pre7$i = HEAP32[$31>>2]|0;
        $$pre8$i = HEAP32[$32>>2]|0;
        $53 = (($$pre7$i) + ($i$03$i14))|0;
        $54 = ($53|0)<($$pre8$i|0);
        if (!($54)) {
         break L16;
        }
        $$pre12$i = HEAP32[$12>>2]|0;
        $55 = (($$pre8$i) - ($53))|0;
        $56 = ($$pre7$i|0)<($55|0);
        $$$i = $56 ? $$pre7$i : $55;
        $57 = (($53) + ($$pre12$i))|0;
        $58 = HEAP32[$35>>2]|0;
        $59 = (($58) - ($57))|0;
        $60 = ($$$i|0)<($59|0);
        $61 = $60 ? $$$i : $59;
        $62 = HEAP32[$1>>2]|0;
        $63 = (($62) - ($57))|0;
        $64 = ($61|0)<($63|0);
        $$1$i = $64 ? $61 : $63;
        $65 = ($$1$i|0)<(1);
        if ($65) {
         break L16;
        }
        $66 = (($48) + ($file_offset$02$i15))|0;
        $$1$i16 = $$1$i;$file_offset$02$i15 = $66;$i$03$i14 = $53;
       }
      }
     }
    } while(0);
    HEAP8[$25>>0] = 0;
   }
   $67 = HEAP32[$12>>2]|0;
   $68 = ($67>>>0)<($start_row>>>0);
   $$phi$trans$insert = (($ptr) + 16|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   if ($68) {
    $storemerge = $start_row;
   } else {
    $69 = (($0) - ($$pre))|0;
    $70 = ($69|0)<(0);
    $$ = $70 ? 0 : $69;
    $storemerge = $$;
   }
   HEAP32[$12>>2] = $storemerge;
   $71 = (($ptr) + 8|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = (($ptr) + 20|0);
   $74 = (($ptr) + 16|0);
   $75 = ($$pre|0)>(0);
   if ($75) {
    $76 = (($ptr) + 28|0);
    $77 = (($ptr) + 40|0);
    $$pre$i1 = HEAP32[$73>>2]|0;
    $78 = ($$pre$i1|0)<($$pre|0);
    $$$us$i6 = $78 ? $$pre$i1 : $$pre;
    $79 = HEAP32[$76>>2]|0;
    $80 = (($79) - ($storemerge))|0;
    $81 = ($$$us$i6|0)<($80|0);
    $82 = $81 ? $$$us$i6 : $80;
    $83 = HEAP32[$1>>2]|0;
    $84 = (($83) - ($storemerge))|0;
    $85 = ($82|0)<($84|0);
    $$1$us$i7 = $85 ? $82 : $84;
    $86 = ($$1$us$i7|0)<(1);
    if (!($86)) {
     $87 = Math_imul($72, $storemerge)|0;
     $$1$us$i10 = $$1$us$i7;$file_offset$02$us$i9 = $87;$i$03$us$i8 = 0;
     while(1) {
      $88 = Math_imul($$1$us$i10, $72)|0;
      $89 = HEAP32[$77>>2]|0;
      $90 = HEAP32[$ptr>>2]|0;
      $91 = (($90) + ($i$03$us$i8<<2)|0);
      $92 = HEAP32[$91>>2]|0;
      FUNCTION_TABLE_viiiii[$89 & 15]($cinfo,$77,$92,$file_offset$02$us$i9,$88);
      $$pre4$i = HEAP32[$73>>2]|0;
      $$pre5$i = HEAP32[$74>>2]|0;
      $93 = (($$pre4$i) + ($i$03$us$i8))|0;
      $94 = ($93|0)<($$pre5$i|0);
      if (!($94)) {
       break L9;
      }
      $$pre11$i = HEAP32[$12>>2]|0;
      $95 = (($$pre5$i) - ($93))|0;
      $96 = ($$pre4$i|0)<($95|0);
      $$$us$i = $96 ? $$pre4$i : $95;
      $97 = (($93) + ($$pre11$i))|0;
      $98 = HEAP32[$76>>2]|0;
      $99 = (($98) - ($97))|0;
      $100 = ($$$us$i|0)<($99|0);
      $101 = $100 ? $$$us$i : $99;
      $102 = HEAP32[$1>>2]|0;
      $103 = (($102) - ($97))|0;
      $104 = ($101|0)<($103|0);
      $$1$us$i = $104 ? $101 : $103;
      $105 = ($$1$us$i|0)<(1);
      if ($105) {
       break L9;
      }
      $106 = (($88) + ($file_offset$02$us$i9))|0;
      $$1$us$i10 = $$1$us$i;$file_offset$02$us$i9 = $106;$i$03$us$i8 = $93;
     }
    }
   }
  }
 } while(0);
 $107 = (($ptr) + 28|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = ($108>>>0)<($0>>>0);
 do {
  if ($109) {
   $110 = ($108>>>0)<($start_row>>>0);
   if ($110) {
    $111 = ($writable<<24>>24)==(0);
    if ($111) {
     $138 = 0;$undef_row$04 = $start_row;
    } else {
     $112 = HEAP32[$cinfo>>2]|0;
     $113 = (($112) + 20|0);
     HEAP32[$113>>2] = 22;
     $114 = HEAP32[$112>>2]|0;
     FUNCTION_TABLE_vi[$114 & 63]($cinfo);
     $undef_row$0 = $start_row;
     label = 29;
    }
   } else {
    $undef_row$0 = $108;
    label = 29;
   }
   if ((label|0) == 29) {
    $115 = ($writable<<24>>24)==(0);
    if ($115) {
     $138 = 0;$undef_row$04 = $undef_row$0;
    } else {
     HEAP32[$107>>2] = $0;
     $138 = 1;$undef_row$04 = $undef_row$0;
    }
   }
   $116 = (($ptr) + 32|0);
   $117 = HEAP8[$116>>0]|0;
   $118 = ($117<<24>>24)==(0);
   if ($118) {
    if ($138) {
     break;
    }
    $129 = HEAP32[$cinfo>>2]|0;
    $130 = (($129) + 20|0);
    HEAP32[$130>>2] = 22;
    $131 = HEAP32[$129>>2]|0;
    FUNCTION_TABLE_vi[$131 & 63]($cinfo);
    break;
   }
   $119 = (($ptr) + 8|0);
   $120 = HEAP32[$119>>2]|0;
   $121 = HEAP32[$12>>2]|0;
   $122 = (($undef_row$04) - ($121))|0;
   $123 = (($0) - ($121))|0;
   $124 = ($122>>>0)<($123>>>0);
   if ($124) {
    $undef_row$15 = $122;
    while(1) {
     $125 = HEAP32[$ptr>>2]|0;
     $126 = (($125) + ($undef_row$15<<2)|0);
     $127 = HEAP32[$126>>2]|0;
     _jzero_far($127,$120);
     $128 = (($undef_row$15) + 1)|0;
     $exitcond = ($128|0)==($123|0);
     if ($exitcond) {
      break;
     } else {
      $undef_row$15 = $128;
     }
    }
   }
  }
 } while(0);
 $132 = ($writable<<24>>24)==(0);
 if ($132) {
  $134 = HEAP32[$ptr>>2]|0;
  $135 = HEAP32[$12>>2]|0;
  $136 = (($start_row) - ($135))|0;
  $137 = (($134) + ($136<<2)|0);
  STACKTOP = sp;return ($137|0);
 }
 $133 = (($ptr) + 33|0);
 HEAP8[$133>>0] = 1;
 $134 = HEAP32[$ptr>>2]|0;
 $135 = HEAP32[$12>>2]|0;
 $136 = (($start_row) - ($135))|0;
 $137 = (($134) + ($136<<2)|0);
 STACKTOP = sp;return ($137|0);
}
function _access_virt_barray($cinfo,$ptr,$start_row,$num_rows,$writable) {
 $cinfo = $cinfo|0;
 $ptr = $ptr|0;
 $start_row = $start_row|0;
 $num_rows = $num_rows|0;
 $writable = $writable|0;
 var $$ = 0, $$$i = 0, $$$i12 = 0, $$$us$i = 0, $$$us$i6 = 0, $$1$i = 0, $$1$i13 = 0, $$1$i16 = 0, $$1$us$i = 0, $$1$us$i10 = 0, $$1$us$i7 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre11$i = 0, $$pre12$i = 0, $$pre4$i = 0, $$pre5$i = 0, $$pre7$i = 0;
 var $$pre8$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $file_offset$02$i15 = 0, $file_offset$02$us$i9 = 0, $i$03$i14 = 0, $i$03$us$i8 = 0, $storemerge = 0, $undef_row$0 = 0, $undef_row$04 = 0, $undef_row$15 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($num_rows) + ($start_row))|0;
 $1 = (($ptr) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0>>>0)>($2>>>0);
 if ($3) {
  label = 4;
 } else {
  $4 = (($ptr) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5>>>0)<($num_rows>>>0);
  if ($6) {
   label = 4;
  } else {
   $7 = HEAP32[$ptr>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    label = 4;
   }
  }
 }
 if ((label|0) == 4) {
  $9 = HEAP32[$cinfo>>2]|0;
  $10 = (($9) + 20|0);
  HEAP32[$10>>2] = 22;
  $11 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vi[$11 & 63]($cinfo);
 }
 $12 = (($ptr) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13>>>0)>($start_row>>>0);
 if ($14) {
  label = 7;
 } else {
  $15 = (($ptr) + 16|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + ($13))|0;
  $18 = ($0>>>0)>($17>>>0);
  if ($18) {
   label = 7;
  }
 }
 L9: do {
  if ((label|0) == 7) {
   $19 = (($ptr) + 34|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = ($20<<24>>24)==(0);
   if ($21) {
    $22 = HEAP32[$cinfo>>2]|0;
    $23 = (($22) + 20|0);
    HEAP32[$23>>2] = 69;
    $24 = HEAP32[$22>>2]|0;
    FUNCTION_TABLE_vi[$24 & 63]($cinfo);
   }
   $25 = (($ptr) + 33|0);
   $26 = HEAP8[$25>>0]|0;
   $27 = ($26<<24>>24)==(0);
   if (!($27)) {
    $28 = (($ptr) + 8|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = $29 << 7;
    $31 = HEAP32[$12>>2]|0;
    $32 = (($ptr) + 20|0);
    $33 = (($ptr) + 16|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)>(0);
    L16: do {
     if ($35) {
      $36 = (($ptr) + 28|0);
      $37 = (($ptr) + 40|0);
      $38 = (($ptr) + 44|0);
      $$pre$i = HEAP32[$32>>2]|0;
      $39 = ($$pre$i|0)<($34|0);
      $$$i12 = $39 ? $$pre$i : $34;
      $40 = HEAP32[$36>>2]|0;
      $41 = (($40) - ($31))|0;
      $42 = ($$$i12|0)<($41|0);
      $43 = $42 ? $$$i12 : $41;
      $44 = HEAP32[$1>>2]|0;
      $45 = (($44) - ($31))|0;
      $46 = ($43|0)<($45|0);
      $$1$i13 = $46 ? $43 : $45;
      $47 = ($$1$i13|0)<(1);
      if (!($47)) {
       $48 = Math_imul($31, $30)|0;
       $$1$i16 = $$1$i13;$file_offset$02$i15 = $48;$i$03$i14 = 0;
       while(1) {
        $49 = Math_imul($$1$i16, $30)|0;
        $50 = HEAP32[$38>>2]|0;
        $51 = HEAP32[$ptr>>2]|0;
        $52 = (($51) + ($i$03$i14<<2)|0);
        $53 = HEAP32[$52>>2]|0;
        FUNCTION_TABLE_viiiii[$50 & 15]($cinfo,$37,$53,$file_offset$02$i15,$49);
        $$pre7$i = HEAP32[$32>>2]|0;
        $$pre8$i = HEAP32[$33>>2]|0;
        $54 = (($$pre7$i) + ($i$03$i14))|0;
        $55 = ($54|0)<($$pre8$i|0);
        if (!($55)) {
         break L16;
        }
        $$pre12$i = HEAP32[$12>>2]|0;
        $56 = (($$pre8$i) - ($54))|0;
        $57 = ($$pre7$i|0)<($56|0);
        $$$i = $57 ? $$pre7$i : $56;
        $58 = (($54) + ($$pre12$i))|0;
        $59 = HEAP32[$36>>2]|0;
        $60 = (($59) - ($58))|0;
        $61 = ($$$i|0)<($60|0);
        $62 = $61 ? $$$i : $60;
        $63 = HEAP32[$1>>2]|0;
        $64 = (($63) - ($58))|0;
        $65 = ($62|0)<($64|0);
        $$1$i = $65 ? $62 : $64;
        $66 = ($$1$i|0)<(1);
        if ($66) {
         break L16;
        }
        $67 = (($49) + ($file_offset$02$i15))|0;
        $$1$i16 = $$1$i;$file_offset$02$i15 = $67;$i$03$i14 = $54;
       }
      }
     }
    } while(0);
    HEAP8[$25>>0] = 0;
   }
   $68 = HEAP32[$12>>2]|0;
   $69 = ($68>>>0)<($start_row>>>0);
   $$phi$trans$insert = (($ptr) + 16|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   if ($69) {
    $storemerge = $start_row;
   } else {
    $70 = (($0) - ($$pre))|0;
    $71 = ($70|0)<(0);
    $$ = $71 ? 0 : $70;
    $storemerge = $$;
   }
   HEAP32[$12>>2] = $storemerge;
   $72 = (($ptr) + 8|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = $73 << 7;
   $75 = (($ptr) + 20|0);
   $76 = (($ptr) + 16|0);
   $77 = ($$pre|0)>(0);
   if ($77) {
    $78 = (($ptr) + 28|0);
    $79 = (($ptr) + 40|0);
    $$pre$i1 = HEAP32[$75>>2]|0;
    $80 = ($$pre$i1|0)<($$pre|0);
    $$$us$i6 = $80 ? $$pre$i1 : $$pre;
    $81 = HEAP32[$78>>2]|0;
    $82 = (($81) - ($storemerge))|0;
    $83 = ($$$us$i6|0)<($82|0);
    $84 = $83 ? $$$us$i6 : $82;
    $85 = HEAP32[$1>>2]|0;
    $86 = (($85) - ($storemerge))|0;
    $87 = ($84|0)<($86|0);
    $$1$us$i7 = $87 ? $84 : $86;
    $88 = ($$1$us$i7|0)<(1);
    if (!($88)) {
     $89 = Math_imul($74, $storemerge)|0;
     $$1$us$i10 = $$1$us$i7;$file_offset$02$us$i9 = $89;$i$03$us$i8 = 0;
     while(1) {
      $90 = Math_imul($$1$us$i10, $74)|0;
      $91 = HEAP32[$79>>2]|0;
      $92 = HEAP32[$ptr>>2]|0;
      $93 = (($92) + ($i$03$us$i8<<2)|0);
      $94 = HEAP32[$93>>2]|0;
      FUNCTION_TABLE_viiiii[$91 & 15]($cinfo,$79,$94,$file_offset$02$us$i9,$90);
      $$pre4$i = HEAP32[$75>>2]|0;
      $$pre5$i = HEAP32[$76>>2]|0;
      $95 = (($$pre4$i) + ($i$03$us$i8))|0;
      $96 = ($95|0)<($$pre5$i|0);
      if (!($96)) {
       break L9;
      }
      $$pre11$i = HEAP32[$12>>2]|0;
      $97 = (($$pre5$i) - ($95))|0;
      $98 = ($$pre4$i|0)<($97|0);
      $$$us$i = $98 ? $$pre4$i : $97;
      $99 = (($95) + ($$pre11$i))|0;
      $100 = HEAP32[$78>>2]|0;
      $101 = (($100) - ($99))|0;
      $102 = ($$$us$i|0)<($101|0);
      $103 = $102 ? $$$us$i : $101;
      $104 = HEAP32[$1>>2]|0;
      $105 = (($104) - ($99))|0;
      $106 = ($103|0)<($105|0);
      $$1$us$i = $106 ? $103 : $105;
      $107 = ($$1$us$i|0)<(1);
      if ($107) {
       break L9;
      }
      $108 = (($90) + ($file_offset$02$us$i9))|0;
      $$1$us$i10 = $$1$us$i;$file_offset$02$us$i9 = $108;$i$03$us$i8 = $95;
     }
    }
   }
  }
 } while(0);
 $109 = (($ptr) + 28|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = ($110>>>0)<($0>>>0);
 do {
  if ($111) {
   $112 = ($110>>>0)<($start_row>>>0);
   if ($112) {
    $113 = ($writable<<24>>24)==(0);
    if ($113) {
     $141 = 0;$undef_row$04 = $start_row;
    } else {
     $114 = HEAP32[$cinfo>>2]|0;
     $115 = (($114) + 20|0);
     HEAP32[$115>>2] = 22;
     $116 = HEAP32[$114>>2]|0;
     FUNCTION_TABLE_vi[$116 & 63]($cinfo);
     $undef_row$0 = $start_row;
     label = 29;
    }
   } else {
    $undef_row$0 = $110;
    label = 29;
   }
   if ((label|0) == 29) {
    $117 = ($writable<<24>>24)==(0);
    if ($117) {
     $141 = 0;$undef_row$04 = $undef_row$0;
    } else {
     HEAP32[$109>>2] = $0;
     $141 = 1;$undef_row$04 = $undef_row$0;
    }
   }
   $118 = (($ptr) + 32|0);
   $119 = HEAP8[$118>>0]|0;
   $120 = ($119<<24>>24)==(0);
   if ($120) {
    if ($141) {
     break;
    }
    $132 = HEAP32[$cinfo>>2]|0;
    $133 = (($132) + 20|0);
    HEAP32[$133>>2] = 22;
    $134 = HEAP32[$132>>2]|0;
    FUNCTION_TABLE_vi[$134 & 63]($cinfo);
    break;
   }
   $121 = (($ptr) + 8|0);
   $122 = HEAP32[$121>>2]|0;
   $123 = $122 << 7;
   $124 = HEAP32[$12>>2]|0;
   $125 = (($undef_row$04) - ($124))|0;
   $126 = (($0) - ($124))|0;
   $127 = ($125>>>0)<($126>>>0);
   if ($127) {
    $undef_row$15 = $125;
    while(1) {
     $128 = HEAP32[$ptr>>2]|0;
     $129 = (($128) + ($undef_row$15<<2)|0);
     $130 = HEAP32[$129>>2]|0;
     _jzero_far($130,$123);
     $131 = (($undef_row$15) + 1)|0;
     $exitcond = ($131|0)==($126|0);
     if ($exitcond) {
      break;
     } else {
      $undef_row$15 = $131;
     }
    }
   }
  }
 } while(0);
 $135 = ($writable<<24>>24)==(0);
 if ($135) {
  $137 = HEAP32[$ptr>>2]|0;
  $138 = HEAP32[$12>>2]|0;
  $139 = (($start_row) - ($138))|0;
  $140 = (($137) + ($139<<2)|0);
  STACKTOP = sp;return ($140|0);
 }
 $136 = (($ptr) + 33|0);
 HEAP8[$136>>0] = 1;
 $137 = HEAP32[$ptr>>2]|0;
 $138 = HEAP32[$12>>2]|0;
 $139 = (($start_row) - ($138))|0;
 $140 = (($137) + ($139<<2)|0);
 STACKTOP = sp;return ($140|0);
}
function _free_pool($cinfo,$pool_id) {
 $cinfo = $cinfo|0;
 $pool_id = $pool_id|0;
 var $$c = 0, $$c2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $bptr$08 = 0, $lhdr_ptr$04 = 0, $shdr_ptr$03 = 0, $sptr$012 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($pool_id>>>0)>(1);
 if ($2) {
  $3 = HEAP32[$cinfo>>2]|0;
  $4 = (($3) + 20|0);
  HEAP32[$4>>2] = 14;
  $5 = (($3) + 24|0);
  HEAP32[$5>>2] = $pool_id;
  $6 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$6 & 63]($cinfo);
 } else {
  $7 = ($pool_id|0)==(1);
  if ($7) {
   $8 = (($1) + 68|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $sptr$012 = $9;
    while(1) {
     $11 = (($sptr$012) + 34|0);
     $12 = HEAP8[$11>>0]|0;
     $13 = ($12<<24>>24)==(0);
     if (!($13)) {
      HEAP8[$11>>0] = 0;
      $14 = (($sptr$012) + 40|0);
      $15 = (($sptr$012) + 48|0);
      $16 = HEAP32[$15>>2]|0;
      FUNCTION_TABLE_vii[$16 & 15]($cinfo,$14);
     }
     $17 = (($sptr$012) + 36|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = ($18|0)==(0|0);
     if ($19) {
      break;
     } else {
      $sptr$012 = $18;
     }
    }
   }
   HEAP32[$8>>2] = 0;
   $20 = (($1) + 72|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(0|0);
   if (!($22)) {
    $bptr$08 = $21;
    while(1) {
     $23 = (($bptr$08) + 34|0);
     $24 = HEAP8[$23>>0]|0;
     $25 = ($24<<24>>24)==(0);
     if (!($25)) {
      HEAP8[$23>>0] = 0;
      $26 = (($bptr$08) + 40|0);
      $27 = (($bptr$08) + 48|0);
      $28 = HEAP32[$27>>2]|0;
      FUNCTION_TABLE_vii[$28 & 15]($cinfo,$26);
     }
     $29 = (($bptr$08) + 36|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      break;
     } else {
      $bptr$08 = $30;
     }
    }
   }
   HEAP32[$20>>2] = 0;
  }
 }
 $32 = (($1) + 60|0);
 $33 = (($32) + ($pool_id<<2)|0);
 $34 = HEAP32[$33>>2]|0;
 HEAP32[$33>>2] = 0;
 $35 = ($34|0)==(0|0);
 if (!($35)) {
  $36 = (($1) + 76|0);
  $lhdr_ptr$04 = $34;
  while(1) {
   $37 = HEAP32[$lhdr_ptr$04>>2]|0;
   $38 = (($lhdr_ptr$04) + 4|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($lhdr_ptr$04) + 8|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($39) + 12)|0;
   $43 = (($42) + ($41))|0;
   _jpeg_free_large($cinfo,$lhdr_ptr$04,$43);
   $44 = HEAP32[$36>>2]|0;
   $45 = (($44) - ($43))|0;
   $$c2 = $45;
   HEAP32[$36>>2] = $$c2;
   $46 = ($37|0)==(0|0);
   if ($46) {
    break;
   } else {
    $lhdr_ptr$04 = $37;
   }
  }
 }
 $47 = (($1) + 52|0);
 $48 = (($47) + ($pool_id<<2)|0);
 $49 = HEAP32[$48>>2]|0;
 HEAP32[$48>>2] = 0;
 $50 = ($49|0)==(0|0);
 if ($50) {
  STACKTOP = sp;return;
 }
 $51 = (($1) + 76|0);
 $shdr_ptr$03 = $49;
 while(1) {
  $52 = HEAP32[$shdr_ptr$03>>2]|0;
  $53 = (($shdr_ptr$03) + 4|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = (($shdr_ptr$03) + 8|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (($54) + 12)|0;
  $58 = (($57) + ($56))|0;
  _jpeg_free_small($cinfo,$shdr_ptr$03,$58);
  $59 = HEAP32[$51>>2]|0;
  $60 = (($59) - ($58))|0;
  $$c = $60;
  HEAP32[$51>>2] = $$c;
  $61 = ($52|0)==(0|0);
  if ($61) {
   break;
  } else {
   $shdr_ptr$03 = $52;
  }
 }
 STACKTOP = sp;return;
}
function _self_destruct($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _free_pool($cinfo,1);
 _free_pool($cinfo,0);
 $0 = (($cinfo) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 _jpeg_free_small($cinfo,$1,84);
 HEAP32[$0>>2] = 0;
 _jpeg_mem_term($cinfo);
 STACKTOP = sp;return;
}
function _jpeg_get_small($cinfo,$sizeofobject) {
 $cinfo = $cinfo|0;
 $sizeofobject = $sizeofobject|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_malloc($sizeofobject)|0);
 STACKTOP = sp;return ($0|0);
}
function _jpeg_free_small($cinfo,$object,$sizeofobject) {
 $cinfo = $cinfo|0;
 $object = $object|0;
 $sizeofobject = $sizeofobject|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _free($object);
 STACKTOP = sp;return;
}
function _jpeg_get_large($cinfo,$sizeofobject) {
 $cinfo = $cinfo|0;
 $sizeofobject = $sizeofobject|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_malloc($sizeofobject)|0);
 STACKTOP = sp;return ($0|0);
}
function _jpeg_free_large($cinfo,$object,$sizeofobject) {
 $cinfo = $cinfo|0;
 $object = $object|0;
 $sizeofobject = $sizeofobject|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _free($object);
 STACKTOP = sp;return;
}
function _jpeg_mem_available($cinfo,$min_bytes_needed,$max_bytes_needed,$already_allocated) {
 $cinfo = $cinfo|0;
 $min_bytes_needed = $min_bytes_needed|0;
 $max_bytes_needed = $max_bytes_needed|0;
 $already_allocated = $already_allocated|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($max_bytes_needed|0);
}
function _jpeg_open_backing_store($cinfo,$info,$total_bytes_needed) {
 $cinfo = $cinfo|0;
 $info = $info|0;
 $total_bytes_needed = $total_bytes_needed|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cinfo>>2]|0;
 $1 = (($0) + 20|0);
 HEAP32[$1>>2] = 49;
 $2 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_vi[$2 & 63]($cinfo);
 STACKTOP = sp;return;
}
function _jpeg_mem_init($cinfo) {
 $cinfo = $cinfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function _jpeg_mem_term($cinfo) {
 $cinfo = $cinfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _jsimd_can_rgb_ycc() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function _jsimd_can_rgb_gray() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function _jsimd_rgb_ycc_convert($cinfo,$input_buf,$output_buf,$output_row,$num_rows) {
 $cinfo = $cinfo|0;
 $input_buf = $input_buf|0;
 $output_buf = $output_buf|0;
 $output_row = $output_row|0;
 $num_rows = $num_rows|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _jsimd_rgb_gray_convert($cinfo,$input_buf,$output_buf,$output_row,$num_rows) {
 $cinfo = $cinfo|0;
 $input_buf = $input_buf|0;
 $output_buf = $output_buf|0;
 $output_row = $output_row|0;
 $num_rows = $num_rows|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _jsimd_can_h2v2_downsample() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function _jsimd_can_h2v1_downsample() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function _jsimd_h2v2_downsample($cinfo,$compptr,$input_data,$output_data) {
 $cinfo = $cinfo|0;
 $compptr = $compptr|0;
 $input_data = $input_data|0;
 $output_data = $output_data|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _jsimd_h2v1_downsample($cinfo,$compptr,$input_data,$output_data) {
 $cinfo = $cinfo|0;
 $compptr = $compptr|0;
 $input_data = $input_data|0;
 $output_data = $output_data|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _jsimd_can_convsamp() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function _jsimd_can_convsamp_float() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function _jsimd_convsamp($sample_data,$start_col,$workspace) {
 $sample_data = $sample_data|0;
 $start_col = $start_col|0;
 $workspace = $workspace|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _jsimd_convsamp_float($sample_data,$start_col,$workspace) {
 $sample_data = $sample_data|0;
 $start_col = $start_col|0;
 $workspace = $workspace|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _jsimd_can_fdct_islow() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function _jsimd_can_fdct_ifast() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function _jsimd_can_fdct_float() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function _jsimd_fdct_islow($data) {
 $data = $data|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _jsimd_fdct_ifast($data) {
 $data = $data|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _jsimd_fdct_float($data) {
 $data = $data|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _jsimd_can_quantize() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function _jsimd_can_quantize_float() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function _jsimd_quantize($coef_block,$divisors,$workspace) {
 $coef_block = $coef_block|0;
 $divisors = $divisors|0;
 $workspace = $workspace|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _jsimd_quantize_float($coef_block,$divisors,$workspace) {
 $coef_block = $coef_block|0;
 $divisors = $divisors|0;
 $workspace = $workspace|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _jdiv_round_up($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($a) + -1)|0;
 $1 = (($0) + ($b))|0;
 $2 = (($1|0) / ($b|0))&-1;
 STACKTOP = sp;return ($2|0);
}
function _jround_up($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($a) + -1)|0;
 $1 = (($0) + ($b))|0;
 $2 = (($1|0) % ($b|0))&-1;
 $3 = (($1) - ($2))|0;
 STACKTOP = sp;return ($3|0);
}
function _jcopy_sample_rows($input_array,$source_row,$output_array,$dest_row,$num_rows,$num_cols) {
 $input_array = $input_array|0;
 $source_row = $source_row|0;
 $output_array = $output_array|0;
 $dest_row = $dest_row|0;
 $num_rows = $num_rows|0;
 $num_cols = $num_cols|0;
 var $$012 = 0, $$03 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $row$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($num_rows|0)>(0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = (($output_array) + ($dest_row<<2)|0);
 $2 = (($input_array) + ($source_row<<2)|0);
 $$012 = $1;$$03 = $2;$row$04 = $num_rows;
 while(1) {
  $3 = (($$03) + 4|0);
  $4 = HEAP32[$$03>>2]|0;
  $5 = (($$012) + 4|0);
  $6 = HEAP32[$$012>>2]|0;
  _memcpy(($6|0),($4|0),($num_cols|0))|0;
  $7 = (($row$04) + -1)|0;
  $8 = ($7|0)>(0);
  if ($8) {
   $$012 = $5;$$03 = $3;$row$04 = $7;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _jzero_far($target,$bytestozero) {
 $target = $target|0;
 $bytestozero = $bytestozero|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _memset(($target|0),0,($bytestozero|0))|0;
 STACKTOP = sp;return;
}
function _tjGetErrorStr() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (143024|0);
}
function _tjInitCompress() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (_malloc(1088)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  (_snprintf(143024,200,143240,$vararg_buffer)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  _memset(($0|0),0,1088)|0;
  $2 = (__tjInitCompress($0)|0);
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __tjInitCompress($this) {
 $this = $this|0;
 var $$0$reg2mem$0 = 0, $$reg2mem12$0 = 0, $$reg2mem12$0$phi = 0, $$reg2mem22$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buf = 0, $buffer = 0, $size = 0, _setjmpTable = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 _setjmpTable = STACKTOP; STACKTOP = STACKTOP + 168|0;HEAP32[_setjmpTable>>2]=0;
 $buffer = sp + 8|0;
 $buf = sp + 4|0;
 $size = sp;
 HEAP32[$buf>>2] = $buffer;
 HEAP32[$size>>2] = 1;
 $0 = (($this) + 792|0);
 __THREW__ = 0;
 $1 = (invoke_ii(3,($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 if ((($2|0) != 0) & ((threwValue|0) != 0)) { $3 = _testSetjmp(HEAP32[$2>>2]|0, _setjmpTable)|0; if (($3|0) == 0) { _longjmp($2|0, threwValue|0); } tempRet0 = threwValue; } else { $3 = -1; };
 $4 = tempRet0;
 if ((($3|0) == 1)) {
  $$reg2mem12$0 = 0;$$reg2mem22$0 = $4;
 } else {
  HEAP32[$this>>2] = $1;
  HEAP32[$0>>2] = 33;
  $5 = (($this) + 800|0);
  HEAP32[$5>>2] = 34;
  $6 = (($this) + 924|0);
  _saveSetjmp($6,1,_setjmpTable|0)|0;
  __THREW__ = 0;
  $7 = __THREW__; __THREW__ = 0;
  if ((($7|0) != 0) & ((threwValue|0) != 0)) { $8 = _testSetjmp(HEAP32[$7>>2]|0, _setjmpTable)|0; if (($8|0) == 0) { _longjmp($7|0, threwValue|0); } tempRet0 = threwValue; } else { $8 = -1; };
  $9 = tempRet0;
  if ((($8|0) == 1)) {
   $$reg2mem12$0 = $this;$$reg2mem22$0 = $9;
  } else {
   $$reg2mem12$0 = $this;$$reg2mem22$0 = 0;
  }
 }
 while(1) {
  $10 = ($$reg2mem22$0|0)==(0);
  if (!($10)) {
   __THREW__ = 0;
   invoke_vi(35,($this|0));
   $11 = __THREW__; __THREW__ = 0;
   if ((($11|0) != 0) & ((threwValue|0) != 0)) { $12 = _testSetjmp(HEAP32[$11>>2]|0, _setjmpTable)|0; if (($12|0) == 0) { _longjmp($11|0, threwValue|0); } tempRet0 = threwValue; } else { $12 = -1; };
   $13 = tempRet0;
   if ((($12|0) == 1)) {
    $$reg2mem12$0$phi = $$reg2mem12$0;$$reg2mem22$0 = $13;$$reg2mem12$0 = $$reg2mem12$0$phi;
    continue;
   } else {
    label = 6;
    break;
   }
  }
  __THREW__ = 0;
  invoke_viii(10,($$reg2mem12$0|0),62,360);
  $14 = __THREW__; __THREW__ = 0;
  if ((($14|0) != 0) & ((threwValue|0) != 0)) { $15 = _testSetjmp(HEAP32[$14>>2]|0, _setjmpTable)|0; if (($15|0) == 0) { _longjmp($14|0, threwValue|0); } tempRet0 = threwValue; } else { $15 = -1; };
  $16 = tempRet0;
  if ((($15|0) == 1)) {
   $$reg2mem12$0$phi = $$reg2mem12$0;$$reg2mem22$0 = $16;$$reg2mem12$0 = $$reg2mem12$0$phi;
   continue;
  }
  __THREW__ = 0;
  invoke_viiii(10,($$reg2mem12$0|0),($buf|0),($size|0),0);
  $17 = __THREW__; __THREW__ = 0;
  if ((($17|0) != 0) & ((threwValue|0) != 0)) { $18 = _testSetjmp(HEAP32[$17>>2]|0, _setjmpTable)|0; if (($18|0) == 0) { _longjmp($17|0, threwValue|0); } tempRet0 = threwValue; } else { $18 = -1; };
  $19 = tempRet0;
  if ((($18|0) == 1)) {
   $$reg2mem12$0$phi = $$reg2mem12$0;$$reg2mem22$0 = $19;$$reg2mem12$0 = $$reg2mem12$0$phi;
  } else {
   label = 9;
   break;
  }
 }
 if ((label|0) == 6) {
  $$0$reg2mem$0 = 0;
  STACKTOP = sp;return ($$0$reg2mem$0|0);
 }
 else if ((label|0) == 9) {
  $20 = (($this) + 1080|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 | 1;
  HEAP32[$20>>2] = $22;
  $$0$reg2mem$0 = $this;
  STACKTOP = sp;return ($$0$reg2mem$0|0);
 }
 return 0|0;
}
function _tjCompress2($handle,$srcBuf,$width,$pitch,$height,$pixelFormat,$jpegBuf,$jpegSize,$jpegSubsamp,$jpegQual,$flags) {
 $handle = $handle|0;
 $srcBuf = $srcBuf|0;
 $width = $width|0;
 $pitch = $pitch|0;
 $height = $height|0;
 $pixelFormat = $pixelFormat|0;
 $jpegBuf = $jpegBuf|0;
 $jpegSize = $jpegSize|0;
 $jpegSubsamp = $jpegSubsamp|0;
 $jpegQual = $jpegQual|0;
 $flags = $flags|0;
 var $$0$reg2mem$0 = 0, $$06$reg2mem108$0 = 0, $$reg2mem102$0 = 0, $$reg2mem104$0 = 0, $$reg2mem106$0 = 0, $$reg2mem110$0 = 0, $$reg2mem89$0 = 0, $$reg2mem89$0$phi = 0, $$reg2mem89$1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $alloc$0$reg2mem$0 = 0, $exitcond = 0, $exitcond17 = 0, $i$015$reg2mem$0 = 0, $i$015$us$reg2mem$0 = 0, $or$cond = 0;
 var $or$cond10 = 0, $or$cond11 = 0, $or$cond12 = 0, $or$cond13 = 0, $or$cond7 = 0, $or$cond8 = 0, $or$cond9 = 0, $phitmp$i = 0, $retval$0$reg2mem100$0 = 0, $row_pointer$0$reg2mem98$0 = 0, $vararg_buffer117 = 0, _setjmpTable = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer117 = sp;
 _setjmpTable = STACKTOP; STACKTOP = STACKTOP + 168|0;HEAP32[_setjmpTable>>2]=0;
 $0 = ($handle|0)==(0|0);
 do {
  if ($0) {
   __THREW__ = 0;
   (invoke_iiiii(3,(143024|0),200,(143224|0),($vararg_buffer117|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   if ((($1|0) != 0) & ((threwValue|0) != 0)) { $2 = _testSetjmp(HEAP32[$1>>2]|0, _setjmpTable)|0; if (($2|0) == 0) { _longjmp($1|0, threwValue|0); } tempRet0 = threwValue; } else { $2 = -1; };
   $3 = tempRet0;
   if ((($2|0) == 1)) {
    $$reg2mem110$0 = $3;$$reg2mem89$0 = 0;
   } else {
    $$0$reg2mem$0 = -1;
    STACKTOP = sp;return ($$0$reg2mem$0|0);
   }
  } else {
   $4 = (($handle) + 1080|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = $5 & 1;
   $7 = ($6|0)==(0);
   if ($7) {
    __THREW__ = 0;
    HEAP32[$vararg_buffer117>>2] = 143344;
    (invoke_iiiii(3,(143024|0),200,(143288|0),($vararg_buffer117|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    if ((($8|0) != 0) & ((threwValue|0) != 0)) { $9 = _testSetjmp(HEAP32[$8>>2]|0, _setjmpTable)|0; if (($9|0) == 0) { _longjmp($8|0, threwValue|0); } tempRet0 = threwValue; } else { $9 = -1; };
    $10 = tempRet0;
    if ((($9|0) == 1)) {
     $$reg2mem110$0 = $10;$$reg2mem89$0 = $handle;
     break;
    }
    $$reg2mem89$1 = $handle;$retval$0$reg2mem100$0 = -1;$row_pointer$0$reg2mem98$0 = 0;
    label = 44;
    break;
   }
   $11 = ($srcBuf|0)==(0|0);
   $12 = ($width|0)<(1);
   $or$cond = $11 | $12;
   $13 = ($pitch|0)<(0);
   $or$cond7 = $or$cond | $13;
   $14 = ($height|0)<(1);
   $or$cond8 = $or$cond7 | $14;
   $15 = ($pixelFormat>>>0)>(11);
   $or$cond9 = $or$cond8 | $15;
   $16 = ($jpegBuf|0)==(0|0);
   $or$cond10 = $or$cond9 | $16;
   $17 = ($jpegSize|0)==(0|0);
   $or$cond11 = $or$cond10 | $17;
   $18 = ($jpegSubsamp>>>0)>(5);
   $or$cond12 = $or$cond11 | $18;
   $19 = ($jpegQual>>>0)>(100);
   $or$cond13 = $or$cond12 | $19;
   if ($or$cond13) {
    __THREW__ = 0;
    HEAP32[$vararg_buffer117>>2] = 143416;
    (invoke_iiiii(3,(143024|0),200,(143288|0),($vararg_buffer117|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    if ((($20|0) != 0) & ((threwValue|0) != 0)) { $21 = _testSetjmp(HEAP32[$20>>2]|0, _setjmpTable)|0; if (($21|0) == 0) { _longjmp($20|0, threwValue|0); } tempRet0 = threwValue; } else { $21 = -1; };
    $22 = tempRet0;
    if ((($21|0) == 1)) {
     $$reg2mem110$0 = $22;$$reg2mem89$0 = $handle;
     break;
    }
    $$reg2mem89$1 = $handle;$retval$0$reg2mem100$0 = -1;$row_pointer$0$reg2mem98$0 = 0;
    label = 44;
    break;
   } else {
    $23 = (($handle) + 924|0);
    _saveSetjmp($23,1,_setjmpTable|0)|0;
    __THREW__ = 0;
    $24 = __THREW__; __THREW__ = 0;
    if ((($24|0) != 0) & ((threwValue|0) != 0)) { $25 = _testSetjmp(HEAP32[$24>>2]|0, _setjmpTable)|0; if (($25|0) == 0) { _longjmp($24|0, threwValue|0); } tempRet0 = threwValue; } else { $25 = -1; };
    $26 = tempRet0;
    if ((($25|0) == 1)) {
     $$reg2mem110$0 = $26;$$reg2mem89$0 = $handle;
     break;
    }
    $$reg2mem110$0 = 0;$$reg2mem89$0 = $handle;
    break;
   }
  }
 } while(0);
 L15: while(1) {
  if ((label|0) == 44) {
   label = 0;
   $115 = (($handle) + 20|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = ($116|0)>(100);
   if ($117) {
    __THREW__ = 0;
    invoke_vi(37,($$reg2mem89$1|0));
    $118 = __THREW__; __THREW__ = 0;
    if ((($118|0) != 0) & ((threwValue|0) != 0)) { $119 = _testSetjmp(HEAP32[$118>>2]|0, _setjmpTable)|0; if (($119|0) == 0) { _longjmp($118|0, threwValue|0); } tempRet0 = threwValue; } else { $119 = -1; };
    $120 = tempRet0;
    if ((($119|0) == 1)) {
     $$reg2mem110$0 = $120;$$reg2mem89$0 = $$reg2mem89$1;
     continue;
    }
   }
   $121 = ($row_pointer$0$reg2mem98$0|0)==(0|0);
   if ($121) {
    $$0$reg2mem$0 = $retval$0$reg2mem100$0;
    label = 50;
    break;
   }
   __THREW__ = 0;
   invoke_vi(35,($row_pointer$0$reg2mem98$0|0));
   $122 = __THREW__; __THREW__ = 0;
   if ((($122|0) != 0) & ((threwValue|0) != 0)) { $123 = _testSetjmp(HEAP32[$122>>2]|0, _setjmpTable)|0; if (($123|0) == 0) { _longjmp($122|0, threwValue|0); } tempRet0 = threwValue; } else { $123 = -1; };
   $124 = tempRet0;
   if ((($123|0) == 1)) {
    $$reg2mem110$0 = $124;$$reg2mem89$0 = $$reg2mem89$1;
   } else {
    break;
   }
  }
  $27 = ($$reg2mem110$0|0)==(0);
  if (!($27)) {
   $$reg2mem89$1 = $$reg2mem89$0;$retval$0$reg2mem100$0 = -1;$row_pointer$0$reg2mem98$0 = 0;
   label = 44;
   continue;
  }
  $28 = ($pitch|0)==(0);
  if ($28) {
   $29 = (143448 + ($pixelFormat<<2)|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = Math_imul($30, $width)|0;
   $$06$reg2mem108$0 = $31;
  } else {
   $$06$reg2mem108$0 = $pitch;
  }
  $32 = (($handle) + 28|0);
  HEAP32[$32>>2] = $width;
  $33 = (($handle) + 32|0);
  HEAP32[$33>>2] = $height;
  $34 = $flags & 8;
  $35 = ($34|0)==(0);
  do {
   if ($35) {
    $39 = $flags & 16;
    $40 = ($39|0)==(0);
    if (!($40)) {
     __THREW__ = 0;
     (invoke_ii(4,(143520|0))|0);
     $41 = __THREW__; __THREW__ = 0;
     if ((($41|0) != 0) & ((threwValue|0) != 0)) { $42 = _testSetjmp(HEAP32[$41>>2]|0, _setjmpTable)|0; if (($42|0) == 0) { _longjmp($41|0, threwValue|0); } tempRet0 = threwValue; } else { $42 = -1; };
     $43 = tempRet0;
     if ((($42|0) == 1)) {
      $$reg2mem89$0$phi = $$reg2mem89$0;$$reg2mem110$0 = $43;$$reg2mem89$0 = $$reg2mem89$0$phi;
      continue L15;
     }
     break;
    }
    $44 = $flags & 32;
    $45 = ($44|0)==(0);
    if (!($45)) {
     __THREW__ = 0;
     (invoke_ii(4,(143544|0))|0);
     $46 = __THREW__; __THREW__ = 0;
     if ((($46|0) != 0) & ((threwValue|0) != 0)) { $47 = _testSetjmp(HEAP32[$46>>2]|0, _setjmpTable)|0; if (($47|0) == 0) { _longjmp($46|0, threwValue|0); } tempRet0 = threwValue; } else { $47 = -1; };
     $48 = tempRet0;
     if ((($47|0) == 1)) {
      $$reg2mem89$0$phi = $$reg2mem89$0;$$reg2mem110$0 = $48;$$reg2mem89$0 = $$reg2mem89$0$phi;
      continue L15;
     }
    }
   } else {
    __THREW__ = 0;
    (invoke_ii(4,(143496|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    if ((($36|0) != 0) & ((threwValue|0) != 0)) { $37 = _testSetjmp(HEAP32[$36>>2]|0, _setjmpTable)|0; if (($37|0) == 0) { _longjmp($36|0, threwValue|0); } tempRet0 = threwValue; } else { $37 = -1; };
    $38 = tempRet0;
    if ((($37|0) == 1)) {
     $$reg2mem89$0$phi = $$reg2mem89$0;$$reg2mem110$0 = $38;$$reg2mem89$0 = $$reg2mem89$0$phi;
     continue L15;
    }
   }
  } while(0);
  $49 = $flags & 1024;
  $50 = ($49|0)==(0);
  if ($50) {
   $alloc$0$reg2mem$0 = 1;
  } else {
   $51 = (143296 + ($jpegSubsamp<<2)|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (143320 + ($jpegSubsamp<<2)|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($jpegSubsamp|0)==(3);
   if ($55) {
    $$reg2mem106$0 = 2;
   } else {
    $56 = Math_imul($54, $52)|0;
    $57 = (256 / ($56|0))&-1;
    $phitmp$i = (($57) + 2)|0;
    $$reg2mem106$0 = $phitmp$i;
   }
   $58 = (($width) + -1)|0;
   $59 = (($58) + ($52))|0;
   $60 = (0 - ($52))|0;
   $61 = $59 & $60;
   $62 = (($height) + -1)|0;
   $63 = (($62) + ($54))|0;
   $64 = (0 - ($54))|0;
   $65 = $63 & $64;
   $66 = Math_imul($65, $61)|0;
   $67 = Math_imul($66, $$reg2mem106$0)|0;
   $68 = (($67) + 2048)|0;
   HEAP32[$jpegSize>>2] = $68;
   $alloc$0$reg2mem$0 = 0;
  }
  __THREW__ = 0;
  invoke_viiii(10,($$reg2mem89$0|0),($jpegBuf|0),($jpegSize|0),($alloc$0$reg2mem$0|0));
  $69 = __THREW__; __THREW__ = 0;
  if ((($69|0) != 0) & ((threwValue|0) != 0)) { $70 = _testSetjmp(HEAP32[$69>>2]|0, _setjmpTable)|0; if (($70|0) == 0) { _longjmp($69|0, threwValue|0); } tempRet0 = threwValue; } else { $70 = -1; };
  $71 = tempRet0;
  if ((($70|0) == 1)) {
   $$reg2mem89$0$phi = $$reg2mem89$0;$$reg2mem110$0 = $71;$$reg2mem89$0 = $$reg2mem89$0$phi;
   continue;
  }
  __THREW__ = 0;
  invoke_viiiii(10,($$reg2mem89$0|0),($pixelFormat|0),($jpegSubsamp|0),($jpegQual|0),($flags|0));
  $72 = __THREW__; __THREW__ = 0;
  if ((($72|0) != 0) & ((threwValue|0) != 0)) { $73 = _testSetjmp(HEAP32[$72>>2]|0, _setjmpTable)|0; if (($73|0) == 0) { _longjmp($72|0, threwValue|0); } tempRet0 = threwValue; } else { $73 = -1; };
  $74 = tempRet0;
  if ((($73|0) == 1)) {
   $$reg2mem89$0$phi = $$reg2mem89$0;$$reg2mem110$0 = $74;$$reg2mem89$0 = $$reg2mem89$0$phi;
   continue;
  }
  __THREW__ = 0;
  invoke_vii(13,($$reg2mem89$0|0),1);
  $75 = __THREW__; __THREW__ = 0;
  if ((($75|0) != 0) & ((threwValue|0) != 0)) { $76 = _testSetjmp(HEAP32[$75>>2]|0, _setjmpTable)|0; if (($76|0) == 0) { _longjmp($75|0, threwValue|0); } tempRet0 = threwValue; } else { $76 = -1; };
  $77 = tempRet0;
  if ((($76|0) == 1)) {
   $$reg2mem89$0$phi = $$reg2mem89$0;$$reg2mem110$0 = $77;$$reg2mem89$0 = $$reg2mem89$0$phi;
   continue;
  }
  $78 = $height << 2;
  __THREW__ = 0;
  $79 = (invoke_ii(5,($78|0))|0);
  $80 = __THREW__; __THREW__ = 0;
  if ((($80|0) != 0) & ((threwValue|0) != 0)) { $81 = _testSetjmp(HEAP32[$80>>2]|0, _setjmpTable)|0; if (($81|0) == 0) { _longjmp($80|0, threwValue|0); } tempRet0 = threwValue; } else { $81 = -1; };
  $82 = tempRet0;
  if ((($81|0) == 1)) {
   $$reg2mem89$0$phi = $$reg2mem89$0;$$reg2mem110$0 = $82;$$reg2mem89$0 = $$reg2mem89$0$phi;
   continue;
  }
  $83 = ($79|0)==(0|0);
  if ($83) {
   __THREW__ = 0;
   HEAP32[$vararg_buffer117>>2] = 143568;
   (invoke_iiiii(3,(143024|0),200,(143288|0),($vararg_buffer117|0))|0);
   $92 = __THREW__; __THREW__ = 0;
   if ((($92|0) != 0) & ((threwValue|0) != 0)) { $93 = _testSetjmp(HEAP32[$92>>2]|0, _setjmpTable)|0; if (($93|0) == 0) { _longjmp($92|0, threwValue|0); } tempRet0 = threwValue; } else { $93 = -1; };
   $94 = tempRet0;
   if ((($93|0) == 1)) {
    $$reg2mem89$0$phi = $$reg2mem89$0;$$reg2mem110$0 = $94;$$reg2mem89$0 = $$reg2mem89$0$phi;
    continue;
   }
   $$reg2mem89$1 = $$reg2mem89$0;$retval$0$reg2mem100$0 = -1;$row_pointer$0$reg2mem98$0 = $79;
   label = 44;
   continue;
  }
  $84 = ($height|0)>(0);
  if ($84) {
   $85 = $flags & 2;
   $86 = ($85|0)==(0);
   $87 = (($height) + -1)|0;
   if ($86) {
    $i$015$us$reg2mem$0 = 0;
    while(1) {
     $88 = Math_imul($i$015$us$reg2mem$0, $$06$reg2mem108$0)|0;
     $89 = (($srcBuf) + ($88)|0);
     $90 = (($79) + ($i$015$us$reg2mem$0<<2)|0);
     HEAP32[$90>>2] = $89;
     $91 = (($i$015$us$reg2mem$0) + 1)|0;
     $exitcond17 = ($91|0)==($height|0);
     if ($exitcond17) {
      break;
     } else {
      $i$015$us$reg2mem$0 = $91;
     }
    }
   } else {
    $i$015$reg2mem$0 = 0;
    while(1) {
     $99 = (($87) - ($i$015$reg2mem$0))|0;
     $100 = Math_imul($99, $$06$reg2mem108$0)|0;
     $101 = (($srcBuf) + ($100)|0);
     $102 = (($79) + ($i$015$reg2mem$0<<2)|0);
     HEAP32[$102>>2] = $101;
     $103 = (($i$015$reg2mem$0) + 1)|0;
     $exitcond = ($103|0)==($height|0);
     if ($exitcond) {
      break;
     } else {
      $i$015$reg2mem$0 = $103;
     }
    }
   }
  }
  $95 = (($handle) + 208|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = HEAP32[$33>>2]|0;
  $98 = ($96>>>0)<($97>>>0);
  if ($98) {
   $$reg2mem102$0 = $96;$$reg2mem104$0 = $97;
   while(1) {
    $104 = (($79) + ($$reg2mem102$0<<2)|0);
    $105 = (($$reg2mem104$0) - ($$reg2mem102$0))|0;
    __THREW__ = 0;
    (invoke_iiii(4,($$reg2mem89$0|0),($104|0),($105|0))|0);
    $106 = __THREW__; __THREW__ = 0;
    if ((($106|0) != 0) & ((threwValue|0) != 0)) { $107 = _testSetjmp(HEAP32[$106>>2]|0, _setjmpTable)|0; if (($107|0) == 0) { _longjmp($106|0, threwValue|0); } tempRet0 = threwValue; } else { $107 = -1; };
    $108 = tempRet0;
    if ((($107|0) == 1)) {
     $$reg2mem89$0$phi = $$reg2mem89$0;$$reg2mem110$0 = $108;$$reg2mem89$0 = $$reg2mem89$0$phi;
     continue L15;
    }
    $109 = HEAP32[$95>>2]|0;
    $110 = HEAP32[$33>>2]|0;
    $111 = ($109>>>0)<($110>>>0);
    if ($111) {
     $$reg2mem102$0 = $109;$$reg2mem104$0 = $110;
    } else {
     break;
    }
   }
  }
  __THREW__ = 0;
  invoke_vi(36,($$reg2mem89$0|0));
  $112 = __THREW__; __THREW__ = 0;
  if ((($112|0) != 0) & ((threwValue|0) != 0)) { $113 = _testSetjmp(HEAP32[$112>>2]|0, _setjmpTable)|0; if (($113|0) == 0) { _longjmp($112|0, threwValue|0); } tempRet0 = threwValue; } else { $113 = -1; };
  $114 = tempRet0;
  if ((($113|0) == 1)) {
   $$reg2mem89$0$phi = $$reg2mem89$0;$$reg2mem110$0 = $114;$$reg2mem89$0 = $$reg2mem89$0$phi;
   continue;
  }
  $$reg2mem89$1 = $$reg2mem89$0;$retval$0$reg2mem100$0 = 0;$row_pointer$0$reg2mem98$0 = $79;
  label = 44;
 }
 if ((label|0) == 50) {
  STACKTOP = sp;return ($$0$reg2mem$0|0);
 }
 $$0$reg2mem$0 = $retval$0$reg2mem100$0;
 STACKTOP = sp;return ($$0$reg2mem$0|0);
}
function _setCompDefaults($cinfo,$pixelFormat,$subsamp,$jpegQual,$flags) {
 $cinfo = $cinfo|0;
 $pixelFormat = $pixelFormat|0;
 $subsamp = $subsamp|0;
 $jpegQual = $jpegQual|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $9 = 0, $or$cond = 0, $or$cond3 = 0, $strlenfirst = 0, $strlenfirst1 = 0, $strlenfirst2 = 0, $strlenfirst3 = 0, $temp = 0, $tempc = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $temp = sp + 8|0;
 $tempc = sp + 12|0;
 switch ($pixelFormat|0) {
 case 7: case 2:  {
  $3 = (($cinfo) + 40|0);
  HEAP32[$3>>2] = 7;
  break;
 }
 case 10: case 5:  {
  $5 = (($cinfo) + 40|0);
  HEAP32[$5>>2] = 11;
  break;
 }
 case 8: case 3:  {
  $4 = (($cinfo) + 40|0);
  HEAP32[$4>>2] = 9;
  break;
 }
 case 0:  {
  $1 = (($cinfo) + 40|0);
  HEAP32[$1>>2] = 6;
  break;
 }
 case 9: case 4:  {
  $6 = (($cinfo) + 40|0);
  HEAP32[$6>>2] = 10;
  break;
 }
 case 11:  {
  $7 = (($cinfo) + 40|0);
  HEAP32[$7>>2] = 4;
  break;
 }
 case 6:  {
  $0 = (($cinfo) + 40|0);
  HEAP32[$0>>2] = 1;
  break;
 }
 case 1:  {
  $2 = (($cinfo) + 40|0);
  HEAP32[$2>>2] = 8;
  break;
 }
 default: {
 }
 }
 $8 = (143448 + ($pixelFormat<<2)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($cinfo) + 36|0);
 HEAP32[$10>>2] = $9;
 $11 = (_getenv((143616|0))|0);
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $strlenfirst3 = HEAP8[$11>>0]|0;
  $13 = ($strlenfirst3<<24>>24)==(0);
  if (!($13)) {
   $14 = (_strcmp($11,143632)|0);
   $15 = ($14|0)==(0);
   if ($15) {
    $16 = (($cinfo) + 316|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 4120|0);
    HEAP32[$18>>2] = 720002228;
   }
  }
 }
 _jpeg_set_defaults($cinfo);
 $19 = (_getenv((143640|0))|0);
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  $strlenfirst2 = HEAP8[$19>>0]|0;
  $21 = ($strlenfirst2<<24>>24)==(0);
  if (!($21)) {
   $22 = (_strcmp($19,143632)|0);
   $23 = ($22|0)==(0);
   if ($23) {
    $24 = (($cinfo) + 178|0);
    HEAP8[$24>>0] = 1;
   }
  }
 }
 $25 = (_getenv((143656|0))|0);
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $strlenfirst1 = HEAP8[$25>>0]|0;
  $27 = ($strlenfirst1<<24>>24)==(0);
  if (!($27)) {
   $28 = (_strcmp($25,143632)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    $30 = (($cinfo) + 177|0);
    HEAP8[$30>>0] = 1;
   }
  }
 }
 $31 = (_getenv((143672|0))|0);
 $32 = ($31|0)==(0|0);
 do {
  if (!($32)) {
   $strlenfirst = HEAP8[$31>>0]|0;
   $33 = ($strlenfirst<<24>>24)==(0);
   if (!($33)) {
    HEAP32[$temp>>2] = -1;
    HEAP8[$tempc>>0] = 0;
    HEAP32[$vararg_buffer>>2] = $temp;
    $vararg_ptr1 = (($vararg_buffer) + 4|0);
    HEAP32[$vararg_ptr1>>2] = $tempc;
    $34 = (_sscanf($31,143688,$vararg_buffer)|0);
    $35 = ($34|0)>(0);
    $36 = HEAP32[$temp>>2]|0;
    $37 = ($36|0)>(-1);
    $or$cond = $35 & $37;
    $38 = ($36|0)<(65536);
    $or$cond3 = $or$cond & $38;
    if ($or$cond3) {
     $39 = HEAP8[$tempc>>0]|0;
     $40 = $39 << 24 >> 24;
     $41 = (_toupper($40)|0);
     $42 = ($41|0)==(66);
     $43 = HEAP32[$temp>>2]|0;
     if ($42) {
      $44 = (($cinfo) + 188|0);
      HEAP32[$44>>2] = $43;
      $45 = (($cinfo) + 192|0);
      HEAP32[$45>>2] = 0;
      break;
     } else {
      $46 = (($cinfo) + 192|0);
      HEAP32[$46>>2] = $43;
      break;
     }
    }
   }
  }
 } while(0);
 $47 = ($jpegQual|0)>(-1);
 do {
  if ($47) {
   _jpeg_set_quality($cinfo,$jpegQual,1);
   $48 = ($jpegQual|0)>(95);
   if (!($48)) {
    $49 = $flags & 4096;
    $50 = ($49|0)==(0);
    if ($50) {
     $52 = (($cinfo) + 184|0);
     HEAP32[$52>>2] = 1;
     break;
    }
   }
   $51 = (($cinfo) + 184|0);
   HEAP32[$51>>2] = 0;
  }
 } while(0);
 $53 = ($subsamp|0)==(3);
 do {
  if ($53) {
   _jpeg_set_colorspace($cinfo,1);
  } else {
   $54 = ($pixelFormat|0)==(11);
   if ($54) {
    _jpeg_set_colorspace($cinfo,5);
    break;
   } else {
    _jpeg_set_colorspace($cinfo,3);
    break;
   }
  }
 } while(0);
 $55 = (($cinfo) + 316|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + 4120|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58|0)==(1560820397);
 if ($59) {
  _jpeg_simple_progression($cinfo);
 }
 $60 = (143296 + ($subsamp<<2)|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($61|0) / 8)&-1;
 $63 = (($cinfo) + 68|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($64) + 8|0);
 HEAP32[$65>>2] = $62;
 $66 = (($64) + 92|0);
 HEAP32[$66>>2] = 1;
 $67 = (($64) + 176|0);
 HEAP32[$67>>2] = 1;
 $68 = (($cinfo) + 60|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69|0)>(3);
 if ($70) {
  $71 = (($64) + 260|0);
  HEAP32[$71>>2] = $62;
 }
 $72 = (143320 + ($subsamp<<2)|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (($73|0) / 8)&-1;
 $75 = (($64) + 12|0);
 HEAP32[$75>>2] = $74;
 $76 = (($64) + 96|0);
 HEAP32[$76>>2] = 1;
 $77 = (($64) + 180|0);
 HEAP32[$77>>2] = 1;
 $78 = HEAP32[$68>>2]|0;
 $79 = ($78|0)>(3);
 if (!($79)) {
  STACKTOP = sp;return;
 }
 $80 = (($64) + 264|0);
 HEAP32[$80>>2] = $74;
 STACKTOP = sp;return;
}
function _my_error_exit($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cinfo>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 63]($cinfo);
 $3 = (($0) + 132|0);
 _longjmp(($3|0),1);
 // unreachable;
}
function _my_output_message($cinfo) {
 $cinfo = $cinfo|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cinfo>>2]|0;
 $1 = (($0) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 15]($cinfo,143024);
 STACKTOP = sp;return;
}
function _islower($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($c) + -97)|0;
 $1 = ($0>>>0)<(26);
 $2 = $1&1;
 STACKTOP = sp;return ($2|0);
}
function _toupper($c) {
 $c = $c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_islower($c)|0);
 $1 = ($0|0)==(0);
 $2 = $c & 95;
 $$0 = $1 ? $c : $2;
 STACKTOP = sp;return ($$0|0);
}
function _mbrtowc($wc,$src,$n,$st) {
 $wc = $wc|0;
 $src = $src|0;
 $n = $n|0;
 $st = $st|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c$0 = 0, $c$1 = 0, $c$2 = 0, $s$0 = 0, $s$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $wc;
 $1 = ($st|0)==(0|0);
 $$01 = $1 ? 143904 : $st;
 $2 = HEAP32[$$01>>2]|0;
 $3 = ($src|0)==(0|0);
 L1: do {
  if ($3) {
   $4 = ($2|0)==(0);
   if ($4) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $5 = ($wc|0)==(0|0);
   if ($5) {
    HEAP32[$0>>2] = $0;
    $11 = $0;
   } else {
    $11 = $wc;
   }
   $6 = ($n|0)==(0);
   if ($6) {
    $$0 = -2;
    STACKTOP = sp;return ($$0|0);
   }
   $7 = ($2|0)==(0);
   do {
    if ($7) {
     $8 = HEAP8[$src>>0]|0;
     $9 = $8&255;
     $10 = ($8<<24>>24)>(-1);
     if ($10) {
      HEAP32[$11>>2] = $9;
      $12 = ($8<<24>>24)!=(0);
      $13 = $12&1;
      $$0 = $13;
      STACKTOP = sp;return ($$0|0);
     } else {
      $14 = (($9) + -194)|0;
      $15 = ($14>>>0)>(50);
      if ($15) {
       break L1;
      }
      $16 = (($src) + 1|0);
      $17 = (143696 + ($14<<2)|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = (($n) + -1)|0;
      $$02 = $19;$c$0 = $18;$s$0 = $16;
      break;
     }
    } else {
     $$02 = $n;$c$0 = $2;$s$0 = $src;
    }
   } while(0);
   $20 = ($$02|0)==(0);
   L17: do {
    if ($20) {
     $c$2 = $c$0;
    } else {
     $21 = HEAP8[$s$0>>0]|0;
     $22 = $21&255;
     $23 = $22 >>> 3;
     $24 = (($23) + -16)|0;
     $25 = $c$0 >> 26;
     $26 = (($23) + ($25))|0;
     $27 = $24 | $26;
     $28 = ($27>>>0)>(7);
     if ($28) {
      break L1;
     } else {
      $$1 = $$02;$32 = $21;$c$1 = $c$0;$s$1 = $s$0;
     }
     while(1) {
      $29 = $c$1 << 6;
      $30 = (($s$1) + 1|0);
      $31 = $32&255;
      $33 = (($31) + -128)|0;
      $34 = $33 | $29;
      $35 = (($$1) + -1)|0;
      $36 = ($34|0)<(0);
      if (!($36)) {
       break;
      }
      $38 = ($35|0)==(0);
      if ($38) {
       $c$2 = $34;
       break L17;
      }
      $39 = HEAP8[$30>>0]|0;
      $40 = $39&255;
      $41 = (($40) + -128)|0;
      $42 = ($41>>>0)>(63);
      if ($42) {
       break L1;
      } else {
       $$1 = $35;$32 = $39;$c$1 = $34;$s$1 = $30;
      }
     }
     HEAP32[$$01>>2] = 0;
     HEAP32[$11>>2] = $34;
     $37 = (($n) - ($35))|0;
     $$0 = $37;
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   HEAP32[$$01>>2] = $c$2;
   $$0 = -2;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 HEAP32[$$01>>2] = 0;
 $43 = (___errno_location()|0);
 HEAP32[$43>>2] = 84;
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _mbsinit($st) {
 $st = $st|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($st|0)==(0|0);
 if ($0) {
  $4 = 1;
 } else {
  $1 = HEAP32[$st>>2]|0;
  $2 = ($1|0)==(0);
  $4 = $2;
 }
 $3 = $4&1;
 STACKTOP = sp;return ($3|0);
}
function ___string_read($f,$buf,$len) {
 $f = $f|0;
 $buf = $buf|0;
 $len = $len|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $k$0 = 0, $k$0$len = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($f) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($len) + 256)|0;
 $3 = (_memchr($1,0,$2)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $k$0 = $2;
 } else {
  $5 = $3;
  $6 = $1;
  $7 = (($5) - ($6))|0;
  $k$0 = $7;
 }
 $8 = ($k$0>>>0)<($len>>>0);
 $k$0$len = $8 ? $k$0 : $len;
 _memcpy(($buf|0),($1|0),($k$0$len|0))|0;
 $9 = (($1) + ($k$0$len)|0);
 $10 = (($f) + 4|0);
 HEAP32[$10>>2] = $9;
 $11 = (($1) + ($k$0)|0);
 $12 = (($f) + 8|0);
 HEAP32[$12>>2] = $11;
 HEAP32[$0>>2] = $11;
 STACKTOP = sp;return ($k$0$len|0);
}
function _sscanf($s,$fmt,$varargs) {
 $s = $s|0;
 $fmt = $fmt|0;
 $varargs = $varargs|0;
 var $0 = 0, $ap = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ap = sp;
 HEAP32[$ap>>2] = $varargs;
 $0 = (_vsscanf($s,$fmt,$ap)|0);
 STACKTOP = sp;return ($0|0);
}
function _MUSL_vfscanf($f,$fmt,$ap) {
 $f = $f|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 var $$ = 0, $$10 = 0, $$4 = 0, $$7 = 0, $$8 = 0, $$9 = 0, $$lcssa18 = 0, $$matches$0 = 0, $$not = 0, $$pre = 0, $$pre$phi241Z2D = 0, $$pre221 = 0, $$pre234 = 0, $$pre235 = 0, $$pre236 = 0, $$pre237 = 0, $$pre238 = 0, $$pre239 = 0, $$pre240 = 0, $$size$0 = 0;
 var $$width$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0.0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0.0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $alloc$0 = 0, $alloc$1 = 0, $alloc$2 = 0, $ap2$i = 0, $arglist_current = 0, $arglist_current2 = 0, $arglist_next = 0, $arglist_next3 = 0, $base$0 = 0, $c$027 = 0, $dest$0 = 0, $factor = 0;
 var $factor14 = 0, $i$0$i = 0, $i$0$ph = 0, $i$0$ph46 = 0, $i$0$ph46$lcssa = 0, $i$0$ph46$us53 = 0, $i$1$lcssa = 0, $i$2 = 0, $i$2$ph = 0, $i$2$ph$phi = 0, $i$3 = 0, $i$4 = 0, $invert$0 = 0, $isdigit = 0, $isdigit3 = 0, $isdigit320 = 0, $isdigittmp = 0, $isdigittmp2 = 0, $isdigittmp219 = 0, $k$0$ph = 0;
 var $k$1$ph = 0, $matches$0$ = 0, $matches$0130 = 0, $matches$1 = 0, $matches$2 = 0, $matches$3 = 0, $not$ = 0, $or$cond$us = 0, $or$cond5 = 0, $or$cond6 = 0, $p$0136 = 0, $p$1 = 0, $p$10 = 0, $p$11 = 0, $p$2 = 0, $p$3$lcssa = 0, $p$321 = 0, $p$4 = 0, $p$5 = 0, $p$6 = 0;
 var $p$7 = 0, $p$7$ph = 0, $p$8 = 0, $p$9 = 0, $pos$0135 = 0, $pos$1 = 0, $pos$2 = 0, $s$0128 = 0, $s$1 = 0, $s$2$ph = 0, $s$3 = 0, $s$4 = 0, $s$5 = 0, $s$6 = 0, $s$7 = 0, $scanset = 0, $size$0 = 0, $st = 0, $vacopy_currentptr = 0, $wc = 0;
 var $wcs$0129 = 0, $wcs$1 = 0, $wcs$2 = 0, $wcs$3$ph = 0, $wcs$3$ph160 = 0, $wcs$4 = 0, $wcs$5 = 0, $wcs$6 = 0, $wcs$7 = 0, $wcs$8 = 0, $width$0$lcssa = 0, $width$022 = 0, $width$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $ap2$i = sp + 16|0;
 $st = sp + 8|0;
 $scanset = sp + 33|0;
 $wc = sp;
 $0 = sp + 32|0;
 $1 = HEAP8[$fmt>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $matches$3 = 0;
  STACKTOP = sp;return ($matches$3|0);
 }
 $3 = (($f) + 4|0);
 $4 = (($f) + 100|0);
 $5 = (($f) + 108|0);
 $6 = (($f) + 8|0);
 $7 = (($scanset) + 10|0);
 $8 = (($scanset) + 33|0);
 $9 = (($st) + 4|0);
 $10 = (($scanset) + 46|0);
 $11 = (($scanset) + 94|0);
 $13 = $1;$matches$0130 = 0;$p$0136 = $fmt;$pos$0135 = 0;$s$0128 = 0;$wcs$0129 = 0;
 L4: while(1) {
  $12 = $13&255;
  $14 = (_isspace($12)|0);
  $15 = ($14|0)==(0);
  L6: do {
   if ($15) {
    $42 = HEAP8[$p$0136>>0]|0;
    $43 = ($42<<24>>24)==(37);
    L8: do {
     if ($43) {
      $44 = (($p$0136) + 1|0);
      $45 = HEAP8[$44>>0]|0;
      do {
       if ((($45<<24>>24) == 37)) {
        break L8;
       } else if ((($45<<24>>24) == 42)) {
        $65 = (($p$0136) + 2|0);
        $dest$0 = 0;$p$2 = $65;
       } else {
        $66 = $45&255;
        $isdigittmp = (($66) + -48)|0;
        $isdigit = ($isdigittmp>>>0)<(10);
        if ($isdigit) {
         $67 = (($p$0136) + 2|0);
         $68 = HEAP8[$67>>0]|0;
         $69 = ($68<<24>>24)==(36);
         if ($69) {
          $vacopy_currentptr = HEAP32[$ap>>2]|0;
          HEAP32[$ap2$i>>2] = $vacopy_currentptr;
          $i$0$i = $isdigittmp;
          while(1) {
           $70 = ($i$0$i>>>0)>(1);
           $arglist_current = HEAP32[$ap2$i>>2]|0;
           $71 = HEAP32[$arglist_current>>2]|0;
           $arglist_next = (($arglist_current) + 4|0);
           HEAP32[$ap2$i>>2] = $arglist_next;
           $72 = (($i$0$i) + -1)|0;
           if ($70) {
            $i$0$i = $72;
           } else {
            break;
           }
          }
          $73 = (($p$0136) + 3|0);
          $dest$0 = $71;$p$2 = $73;
          break;
         }
        }
        $arglist_current2 = HEAP32[$ap>>2]|0;
        $74 = HEAP32[$arglist_current2>>2]|0;
        $arglist_next3 = (($arglist_current2) + 4|0);
        HEAP32[$ap>>2] = $arglist_next3;
        $dest$0 = $74;$p$2 = $44;
       }
      } while(0);
      $75 = HEAP8[$p$2>>0]|0;
      $76 = $75&255;
      $isdigittmp219 = (($76) + -48)|0;
      $isdigit320 = ($isdigittmp219>>>0)<(10);
      if ($isdigit320) {
       $80 = $76;$p$321 = $p$2;$width$022 = 0;
       while(1) {
        $77 = ($width$022*10)|0;
        $78 = (($77) + -48)|0;
        $79 = (($78) + ($80))|0;
        $81 = (($p$321) + 1|0);
        $82 = HEAP8[$81>>0]|0;
        $83 = $82&255;
        $isdigittmp2 = (($83) + -48)|0;
        $isdigit3 = ($isdigittmp2>>>0)<(10);
        if ($isdigit3) {
         $80 = $83;$p$321 = $81;$width$022 = $79;
        } else {
         $$lcssa18 = $82;$p$3$lcssa = $81;$width$0$lcssa = $79;
         break;
        }
       }
      } else {
       $$lcssa18 = $75;$p$3$lcssa = $p$2;$width$0$lcssa = 0;
      }
      $84 = ($$lcssa18<<24>>24)==(109);
      if ($84) {
       $85 = ($dest$0|0)!=(0|0);
       $86 = $85&1;
       $87 = (($p$3$lcssa) + 1|0);
       $$pre = HEAP8[$87>>0]|0;
       $90 = $$pre;$alloc$0 = $86;$p$4 = $87;$s$1 = 0;$wcs$1 = 0;
      } else {
       $90 = $$lcssa18;$alloc$0 = 0;$p$4 = $p$3$lcssa;$s$1 = $s$0128;$wcs$1 = $wcs$0129;
      }
      $88 = (($p$4) + 1|0);
      $89 = $90&255;
      switch ($89|0) {
      case 116: case 122:  {
       $p$5 = $88;$size$0 = 1;
       break;
      }
      case 76:  {
       $p$5 = $88;$size$0 = 2;
       break;
      }
      case 110: case 112: case 67: case 83: case 91: case 99: case 115: case 88: case 71: case 70: case 69: case 65: case 103: case 102: case 101: case 97: case 120: case 117: case 111: case 105: case 100:  {
       $p$5 = $p$4;$size$0 = 0;
       break;
      }
      case 108:  {
       $94 = HEAP8[$88>>0]|0;
       $95 = ($94<<24>>24)==(108);
       $96 = (($p$4) + 2|0);
       $$9 = $95 ? $96 : $88;
       $$10 = $95 ? 3 : 1;
       $p$5 = $$9;$size$0 = $$10;
       break;
      }
      case 106:  {
       $p$5 = $88;$size$0 = 3;
       break;
      }
      case 104:  {
       $91 = HEAP8[$88>>0]|0;
       $92 = ($91<<24>>24)==(104);
       $93 = (($p$4) + 2|0);
       $$7 = $92 ? $93 : $88;
       $$8 = $92 ? -2 : -1;
       $p$5 = $$7;$size$0 = $$8;
       break;
      }
      default: {
       $alloc$1 = $alloc$0;$s$6 = $s$1;$wcs$7 = $wcs$1;
       label = 162;
       break L4;
      }
      }
      $97 = HEAP8[$p$5>>0]|0;
      $98 = $97&255;
      $99 = $98 & 47;
      $100 = ($99|0)==(3);
      $101 = $98 | 32;
      $$ = $100 ? $101 : $98;
      $$size$0 = $100 ? 1 : $size$0;
      if ((($$|0) == 91)) {
       $pos$1 = $pos$0135;$width$1 = $width$0$lcssa;
      } else if ((($$|0) == 110)) {
       $103 = ($pos$0135|0)<(0);
       $104 = $103 << 31 >> 31;
       $105 = ($dest$0|0)==(0|0);
       if ($105) {
        $matches$1 = $matches$0130;$p$11 = $p$5;$pos$2 = $pos$0135;$s$5 = $s$1;$wcs$6 = $wcs$1;
        break L6;
       }
       switch ($$size$0|0) {
       case 3:  {
        $108 = $dest$0;
        $109 = $108;
        HEAP32[$109>>2] = $pos$0135;
        $110 = (($108) + 4)|0;
        $111 = $110;
        HEAP32[$111>>2] = $104;
        $matches$1 = $matches$0130;$p$11 = $p$5;$pos$2 = $pos$0135;$s$5 = $s$1;$wcs$6 = $wcs$1;
        break L6;
        break;
       }
       case -2:  {
        $106 = $pos$0135&255;
        HEAP8[$dest$0>>0] = $106;
        $matches$1 = $matches$0130;$p$11 = $p$5;$pos$2 = $pos$0135;$s$5 = $s$1;$wcs$6 = $wcs$1;
        break L6;
        break;
       }
       case -1:  {
        $107 = $pos$0135&65535;
        HEAP16[$dest$0>>1] = $107;
        $matches$1 = $matches$0130;$p$11 = $p$5;$pos$2 = $pos$0135;$s$5 = $s$1;$wcs$6 = $wcs$1;
        break L6;
        break;
       }
       case 0:  {
        HEAP32[$dest$0>>2] = $pos$0135;
        $matches$1 = $matches$0130;$p$11 = $p$5;$pos$2 = $pos$0135;$s$5 = $s$1;$wcs$6 = $wcs$1;
        break L6;
        break;
       }
       case 1:  {
        HEAP32[$dest$0>>2] = $pos$0135;
        $matches$1 = $matches$0130;$p$11 = $p$5;$pos$2 = $pos$0135;$s$5 = $s$1;$wcs$6 = $wcs$1;
        break L6;
        break;
       }
       default: {
        $matches$1 = $matches$0130;$p$11 = $p$5;$pos$2 = $pos$0135;$s$5 = $s$1;$wcs$6 = $wcs$1;
        break L6;
       }
       }
      } else if ((($$|0) == 99)) {
       $102 = ($width$0$lcssa|0)<(1);
       $$width$0 = $102 ? 1 : $width$0$lcssa;
       $pos$1 = $pos$0135;$width$1 = $$width$0;
      } else {
       ___shlim($f,0);
       while(1) {
        $112 = HEAP32[$3>>2]|0;
        $113 = HEAP32[$4>>2]|0;
        $114 = ($112>>>0)<($113>>>0);
        if ($114) {
         $115 = (($112) + 1|0);
         HEAP32[$3>>2] = $115;
         $116 = HEAP8[$112>>0]|0;
         $117 = $116&255;
         $119 = $117;
        } else {
         $118 = (___shgetc($f)|0);
         $119 = $118;
        }
        $120 = (_isspace($119)|0);
        $121 = ($120|0)==(0);
        if ($121) {
         break;
        }
       }
       $122 = HEAP32[$4>>2]|0;
       $123 = ($122|0)==(0|0);
       $$pre234 = HEAP32[$3>>2]|0;
       if ($123) {
        $127 = $$pre234;
       } else {
        $124 = (($$pre234) + -1|0);
        HEAP32[$3>>2] = $124;
        $127 = $124;
       }
       $125 = HEAP32[$5>>2]|0;
       $126 = HEAP32[$6>>2]|0;
       $128 = $127;
       $129 = $126;
       $130 = (($125) + ($pos$0135))|0;
       $131 = (($130) + ($128))|0;
       $132 = (($131) - ($129))|0;
       $pos$1 = $132;$width$1 = $width$0$lcssa;
      }
      ___shlim($f,$width$1);
      $133 = HEAP32[$3>>2]|0;
      $134 = HEAP32[$4>>2]|0;
      $135 = ($133>>>0)<($134>>>0);
      if ($135) {
       $136 = (($133) + 1|0);
       HEAP32[$3>>2] = $136;
       $139 = $134;
      } else {
       $137 = (___shgetc($f)|0);
       $138 = ($137|0)<(0);
       if ($138) {
        $alloc$1 = $alloc$0;$s$6 = $s$1;$wcs$7 = $wcs$1;
        label = 162;
        break L4;
       }
       $$pre235 = HEAP32[$4>>2]|0;
       $139 = $$pre235;
      }
      $140 = ($139|0)==(0|0);
      if (!($140)) {
       $141 = HEAP32[$3>>2]|0;
       $142 = (($141) + -1|0);
       HEAP32[$3>>2] = $142;
      }
      L65: do {
       switch ($$|0) {
       case 111:  {
        $base$0 = 8;
        label = 144;
        break;
       }
       case 117: case 100:  {
        $base$0 = 10;
        label = 144;
        break;
       }
       case 105:  {
        $base$0 = 0;
        label = 144;
        break;
       }
       case 71: case 103: case 70: case 102: case 69: case 101: case 65: case 97:  {
        $322 = (+___floatscan($f,$$size$0,0));
        $323 = HEAP32[$5>>2]|0;
        $324 = HEAP32[$3>>2]|0;
        $325 = HEAP32[$6>>2]|0;
        $326 = $324;
        $327 = $325;
        $328 = (($327) - ($326))|0;
        $329 = ($323|0)==($328|0);
        if ($329) {
         $alloc$2 = $alloc$0;$matches$2 = $matches$0130;$s$7 = $s$1;$wcs$8 = $wcs$1;
         break L4;
        }
        $330 = ($dest$0|0)==(0|0);
        if ($330) {
         $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
        } else {
         if ((($$size$0|0) == 0)) {
          $331 = $322;
          HEAPF32[$dest$0>>2] = $331;
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L65;
         } else if ((($$size$0|0) == 1)) {
          HEAPF64[$dest$0>>3] = $322;
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L65;
         } else if ((($$size$0|0) == 2)) {
          HEAPF64[$dest$0>>3] = $322;
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L65;
         } else {
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L65;
         }
        }
        break;
       }
       case 120: case 88: case 112:  {
        $base$0 = 16;
        label = 144;
        break;
       }
       case 91: case 99: case 115:  {
        $143 = ($$|0)==(99);
        $144 = $$ & 239;
        $145 = ($144|0)==(99);
        L77: do {
         if ($145) {
          $146 = ($$|0)==(115);
          _memset(($scanset|0),-1,257)|0;
          HEAP8[$scanset>>0] = 0;
          if ($146) {
           HEAP8[$8>>0] = 0;
           ;HEAP8[$7+0>>0]=0|0;HEAP8[$7+1>>0]=0|0;HEAP8[$7+2>>0]=0|0;HEAP8[$7+3>>0]=0|0;HEAP8[$7+4>>0]=0|0;
           $p$9 = $p$5;
          } else {
           $p$9 = $p$5;
          }
         } else {
          $147 = (($p$5) + 1|0);
          $148 = HEAP8[$147>>0]|0;
          $149 = ($148<<24>>24)==(94);
          $150 = (($p$5) + 2|0);
          $invert$0 = $149&1;
          $p$6 = $149 ? $150 : $147;
          $151 = $149&1;
          _memset(($scanset|0),($151|0),257)|0;
          HEAP8[$scanset>>0] = 0;
          $152 = HEAP8[$p$6>>0]|0;
          if ((($152<<24>>24) == 45)) {
           $153 = (($p$6) + 1|0);
           $154 = $invert$0 ^ 1;
           $155 = $154&255;
           HEAP8[$10>>0] = $155;
           $$pre$phi241Z2D = $155;$p$7$ph = $153;
          } else if ((($152<<24>>24) == 93)) {
           $156 = (($p$6) + 1|0);
           $157 = $invert$0 ^ 1;
           $158 = $157&255;
           HEAP8[$11>>0] = $158;
           $$pre$phi241Z2D = $158;$p$7$ph = $156;
          } else {
           $$pre239 = $invert$0 ^ 1;
           $$pre240 = $$pre239&255;
           $$pre$phi241Z2D = $$pre240;$p$7$ph = $p$6;
          }
          $p$7 = $p$7$ph;
          while(1) {
           $159 = HEAP8[$p$7>>0]|0;
           if ((($159<<24>>24) == 0)) {
            $alloc$1 = $alloc$0;$s$6 = $s$1;$wcs$7 = $wcs$1;
            label = 162;
            break L4;
           } else if ((($159<<24>>24) == 45)) {
            $160 = (($p$7) + 1|0);
            $161 = HEAP8[$160>>0]|0;
            if ((($161<<24>>24) == 93) | (($161<<24>>24) == 0)) {
             $172 = 45;$p$8 = $p$7;
            } else {
             $162 = (($p$7) + -1|0);
             $163 = HEAP8[$162>>0]|0;
             $164 = ($163&255)<($161&255);
             if ($164) {
              $165 = $163&255;
              $c$027 = $165;
              while(1) {
               $166 = (($c$027) + 1)|0;
               $167 = (($scanset) + ($166)|0);
               HEAP8[$167>>0] = $$pre$phi241Z2D;
               $168 = HEAP8[$160>>0]|0;
               $169 = $168&255;
               $170 = ($166|0)<($169|0);
               if ($170) {
                $c$027 = $166;
               } else {
                $172 = $168;$p$8 = $160;
                break;
               }
              }
             } else {
              $172 = $161;$p$8 = $160;
             }
            }
           } else if ((($159<<24>>24) == 93)) {
            $p$9 = $p$7;
            break L77;
           } else {
            $172 = $159;$p$8 = $p$7;
           }
           $171 = $172&255;
           $173 = (($171) + 1)|0;
           $174 = (($scanset) + ($173)|0);
           HEAP8[$174>>0] = $$pre$phi241Z2D;
           $175 = (($p$8) + 1|0);
           $p$7 = $175;
          }
         }
        } while(0);
        $176 = (($width$1) + 1)|0;
        $$4 = $143 ? $176 : 31;
        $177 = ($$size$0|0)==(1);
        $178 = ($alloc$0|0)!=(0);
        L96: do {
         if ($177) {
          if ($178) {
           $179 = $$4 << 2;
           $180 = (_malloc($179)|0);
           $181 = ($180|0)==(0|0);
           if ($181) {
            $alloc$1 = $alloc$0;$s$6 = 0;$wcs$7 = $180;
            label = 162;
            break L4;
           } else {
            $wcs$2 = $180;
           }
          } else {
           $wcs$2 = $dest$0;
          }
          HEAP32[$st>>2] = 0;
          HEAP32[$9>>2] = 0;
          $i$0$ph = 0;$k$0$ph = $$4;$wcs$3$ph = $wcs$2;
          L131: while(1) {
           $182 = ($wcs$3$ph|0)==(0|0);
           if ($182) {
            while(1) {
             $185 = HEAP32[$3>>2]|0;
             $196 = HEAP32[$4>>2]|0;
             $197 = ($185>>>0)<($196>>>0);
             if ($197) {
              $184 = (($185) + 1|0);
              HEAP32[$3>>2] = $184;
              $186 = HEAP8[$185>>0]|0;
              $187 = $186&255;
              $189 = $187;
             } else {
              $183 = (___shgetc($f)|0);
              $189 = $183;
             }
             $188 = (($189) + 1)|0;
             $190 = (($scanset) + ($188)|0);
             $191 = HEAP8[$190>>0]|0;
             $192 = ($191<<24>>24)==(0);
             if ($192) {
              $i$0$ph46$lcssa = $i$0$ph;$wcs$3$ph160 = 0;
              break L131;
             }
             $193 = $189&255;
             HEAP8[$0>>0] = $193;
             $194 = (_mbrtowc($wc,$0,1,$st)|0);
             if ((($194|0) == -1)) {
              $alloc$1 = $alloc$0;$s$6 = 0;$wcs$7 = 0;
              label = 162;
              break L4;
             } else if ((($194|0) == -2)) {
              continue;
             }
             $195 = ($i$0$ph|0)==($k$0$ph|0);
             $or$cond$us = $178 & $195;
             if ($or$cond$us) {
              $i$1$lcssa = $i$0$ph;
              break;
             }
            }
           } else {
            if ($178) {
             $i$0$ph46$us53 = $i$0$ph;
            } else {
             $i$0$ph46 = $i$0$ph;
             label = 98;
             break;
            }
            while(1) {
             while(1) {
              $200 = HEAP32[$3>>2]|0;
              $214 = HEAP32[$4>>2]|0;
              $215 = ($200>>>0)<($214>>>0);
              if ($215) {
               $199 = (($200) + 1|0);
               HEAP32[$3>>2] = $199;
               $201 = HEAP8[$200>>0]|0;
               $202 = $201&255;
               $204 = $202;
              } else {
               $198 = (___shgetc($f)|0);
               $204 = $198;
              }
              $203 = (($204) + 1)|0;
              $205 = (($scanset) + ($203)|0);
              $206 = HEAP8[$205>>0]|0;
              $207 = ($206<<24>>24)==(0);
              if ($207) {
               $i$0$ph46$lcssa = $i$0$ph46$us53;$wcs$3$ph160 = $wcs$3$ph;
               break L131;
              }
              $208 = $204&255;
              HEAP8[$0>>0] = $208;
              $209 = (_mbrtowc($wc,$0,1,$st)|0);
              if ((($209|0) == -1)) {
               $alloc$1 = $alloc$0;$s$6 = 0;$wcs$7 = $wcs$3$ph;
               label = 162;
               break L4;
              } else if (!((($209|0) == -2))) {
               break;
              }
             }
             $210 = HEAP32[$wc>>2]|0;
             $211 = (($i$0$ph46$us53) + 1)|0;
             $212 = (($wcs$3$ph) + ($i$0$ph46$us53<<2)|0);
             HEAP32[$212>>2] = $210;
             $213 = ($211|0)==($k$0$ph|0);
             if ($213) {
              $i$1$lcssa = $k$0$ph;
              break;
             } else {
              $i$0$ph46$us53 = $211;
             }
            }
           }
           $factor = $k$0$ph << 1;
           $233 = $factor | 1;
           $234 = $233 << 2;
           $235 = (_realloc($wcs$3$ph,$234)|0);
           $236 = ($235|0)==(0|0);
           if ($236) {
            $alloc$1 = $alloc$0;$s$6 = 0;$wcs$7 = $wcs$3$ph;
            label = 162;
            break L4;
           }
           $i$0$ph = $i$1$lcssa;$k$0$ph = $233;$wcs$3$ph = $235;
          }
          L155: do {
           if ((label|0) == 98) {
            while(1) {
             label = 0;
             while(1) {
              $216 = HEAP32[$3>>2]|0;
              $217 = HEAP32[$4>>2]|0;
              $218 = ($216>>>0)<($217>>>0);
              if ($218) {
               $219 = (($216) + 1|0);
               HEAP32[$3>>2] = $219;
               $220 = HEAP8[$216>>0]|0;
               $221 = $220&255;
               $224 = $221;
              } else {
               $222 = (___shgetc($f)|0);
               $224 = $222;
              }
              $223 = (($224) + 1)|0;
              $225 = (($scanset) + ($223)|0);
              $226 = HEAP8[$225>>0]|0;
              $227 = ($226<<24>>24)==(0);
              if ($227) {
               $i$0$ph46$lcssa = $i$0$ph46;$wcs$3$ph160 = $wcs$3$ph;
               break L155;
              }
              $228 = $224&255;
              HEAP8[$0>>0] = $228;
              $229 = (_mbrtowc($wc,$0,1,$st)|0);
              if ((($229|0) == -1)) {
               $alloc$1 = 0;$s$6 = 0;$wcs$7 = $wcs$3$ph;
               label = 162;
               break L4;
              } else if (!((($229|0) == -2))) {
               break;
              }
             }
             $230 = HEAP32[$wc>>2]|0;
             $231 = (($i$0$ph46) + 1)|0;
             $232 = (($wcs$3$ph) + ($i$0$ph46<<2)|0);
             HEAP32[$232>>2] = $230;
             $i$0$ph46 = $231;
             label = 98;
            }
           }
          } while(0);
          $237 = (_mbsinit($st)|0);
          $238 = ($237|0)==(0);
          if ($238) {
           $alloc$1 = $alloc$0;$s$6 = 0;$wcs$7 = $wcs$3$ph160;
           label = 162;
           break L4;
          } else {
           $i$4 = $i$0$ph46$lcssa;$s$3 = 0;$wcs$4 = $wcs$3$ph160;
          }
         } else {
          if ($178) {
           $239 = (_malloc($$4)|0);
           $240 = ($239|0)==(0|0);
           if ($240) {
            $alloc$1 = $alloc$0;$s$6 = 0;$wcs$7 = 0;
            label = 162;
            break L4;
           } else {
            $i$2$ph = 0;$k$1$ph = $$4;$s$2$ph = $239;
           }
           while(1) {
            $i$2 = $i$2$ph;
            while(1) {
             $241 = HEAP32[$3>>2]|0;
             $242 = HEAP32[$4>>2]|0;
             $243 = ($241>>>0)<($242>>>0);
             if ($243) {
              $244 = (($241) + 1|0);
              HEAP32[$3>>2] = $244;
              $245 = HEAP8[$241>>0]|0;
              $246 = $245&255;
              $249 = $246;
             } else {
              $247 = (___shgetc($f)|0);
              $249 = $247;
             }
             $248 = (($249) + 1)|0;
             $250 = (($scanset) + ($248)|0);
             $251 = HEAP8[$250>>0]|0;
             $252 = ($251<<24>>24)==(0);
             if ($252) {
              $i$4 = $i$2;$s$3 = $s$2$ph;$wcs$4 = 0;
              break L96;
             }
             $253 = $249&255;
             $254 = (($i$2) + 1)|0;
             $255 = (($s$2$ph) + ($i$2)|0);
             HEAP8[$255>>0] = $253;
             $256 = ($254|0)==($k$1$ph|0);
             if ($256) {
              break;
             } else {
              $i$2 = $254;
             }
            }
            $factor14 = $k$1$ph << 1;
            $257 = $factor14 | 1;
            $258 = (_realloc($s$2$ph,$257)|0);
            $259 = ($258|0)==(0|0);
            if ($259) {
             $alloc$1 = $alloc$0;$s$6 = $s$2$ph;$wcs$7 = 0;
             label = 162;
             break L4;
            } else {
             $i$2$ph$phi = $k$1$ph;$k$1$ph = $257;$s$2$ph = $258;$i$2$ph = $i$2$ph$phi;
            }
           }
          }
          $260 = ($dest$0|0)==(0|0);
          if ($260) {
           $278 = $139;
           while(1) {
            $276 = HEAP32[$3>>2]|0;
            $277 = ($276>>>0)<($278>>>0);
            if ($277) {
             $279 = (($276) + 1|0);
             HEAP32[$3>>2] = $279;
             $280 = HEAP8[$276>>0]|0;
             $281 = $280&255;
             $284 = $281;
            } else {
             $282 = (___shgetc($f)|0);
             $284 = $282;
            }
            $283 = (($284) + 1)|0;
            $285 = (($scanset) + ($283)|0);
            $286 = HEAP8[$285>>0]|0;
            $287 = ($286<<24>>24)==(0);
            if ($287) {
             $i$4 = 0;$s$3 = 0;$wcs$4 = 0;
             break L96;
            }
            $$pre237 = HEAP32[$4>>2]|0;
            $278 = $$pre237;
           }
          } else {
           $263 = $139;$i$3 = 0;
           while(1) {
            $261 = HEAP32[$3>>2]|0;
            $262 = ($261>>>0)<($263>>>0);
            if ($262) {
             $264 = (($261) + 1|0);
             HEAP32[$3>>2] = $264;
             $265 = HEAP8[$261>>0]|0;
             $266 = $265&255;
             $269 = $266;
            } else {
             $267 = (___shgetc($f)|0);
             $269 = $267;
            }
            $268 = (($269) + 1)|0;
            $270 = (($scanset) + ($268)|0);
            $271 = HEAP8[$270>>0]|0;
            $272 = ($271<<24>>24)==(0);
            if ($272) {
             $i$4 = $i$3;$s$3 = $dest$0;$wcs$4 = 0;
             break L96;
            }
            $273 = $269&255;
            $274 = (($i$3) + 1)|0;
            $275 = (($dest$0) + ($i$3)|0);
            HEAP8[$275>>0] = $273;
            $$pre221 = HEAP32[$4>>2]|0;
            $263 = $$pre221;$i$3 = $274;
           }
          }
         }
        } while(0);
        $288 = HEAP32[$4>>2]|0;
        $289 = ($288|0)==(0|0);
        $$pre236 = HEAP32[$3>>2]|0;
        if ($289) {
         $293 = $$pre236;
        } else {
         $290 = (($$pre236) + -1|0);
         HEAP32[$3>>2] = $290;
         $293 = $290;
        }
        $291 = HEAP32[$5>>2]|0;
        $292 = HEAP32[$6>>2]|0;
        $294 = $293;
        $295 = $292;
        $296 = (($294) - ($295))|0;
        $297 = (($296) + ($291))|0;
        $298 = ($297|0)==(0);
        if ($298) {
         $alloc$2 = $alloc$0;$matches$2 = $matches$0130;$s$7 = $s$3;$wcs$8 = $wcs$4;
         break L4;
        }
        $$not = $143 ^ 1;
        $299 = ($297|0)==($width$1|0);
        $or$cond5 = $299 | $$not;
        if (!($or$cond5)) {
         $alloc$2 = $alloc$0;$matches$2 = $matches$0130;$s$7 = $s$3;$wcs$8 = $wcs$4;
         break L4;
        }
        do {
         if ($178) {
          if ($177) {
           HEAP32[$dest$0>>2] = $wcs$4;
           break;
          } else {
           HEAP32[$dest$0>>2] = $s$3;
           break;
          }
         }
        } while(0);
        if ($143) {
         $p$10 = $p$9;$s$4 = $s$3;$wcs$5 = $wcs$4;
        } else {
         $300 = ($wcs$4|0)==(0|0);
         if (!($300)) {
          $301 = (($wcs$4) + ($i$4<<2)|0);
          HEAP32[$301>>2] = 0;
         }
         $302 = ($s$3|0)==(0|0);
         if ($302) {
          $p$10 = $p$9;$s$4 = 0;$wcs$5 = $wcs$4;
         } else {
          $303 = (($s$3) + ($i$4)|0);
          HEAP8[$303>>0] = 0;
          $p$10 = $p$9;$s$4 = $s$3;$wcs$5 = $wcs$4;
         }
        }
        break;
       }
       default: {
        $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
       }
       }
      } while(0);
      L184: do {
       if ((label|0) == 144) {
        label = 0;
        $304 = (___intscan($f,$base$0,0,-1,-1)|0);
        $305 = tempRet0;
        $306 = HEAP32[$5>>2]|0;
        $307 = HEAP32[$3>>2]|0;
        $308 = HEAP32[$6>>2]|0;
        $309 = $307;
        $310 = $308;
        $311 = (($310) - ($309))|0;
        $312 = ($306|0)==($311|0);
        if ($312) {
         $alloc$2 = $alloc$0;$matches$2 = $matches$0130;$s$7 = $s$1;$wcs$8 = $wcs$1;
         break L4;
        }
        $313 = ($$|0)!=(112);
        $314 = ($dest$0|0)==(0|0);
        $or$cond6 = $313 | $314;
        if (!($or$cond6)) {
         $315 = $304;
         HEAP32[$dest$0>>2] = $315;
         $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
         break;
        }
        if ($314) {
         $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
        } else {
         switch ($$size$0|0) {
         case 3:  {
          $318 = $dest$0;
          $319 = $318;
          HEAP32[$319>>2] = $304;
          $320 = (($318) + 4)|0;
          $321 = $320;
          HEAP32[$321>>2] = $305;
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L184;
          break;
         }
         case -2:  {
          $316 = $304&255;
          HEAP8[$dest$0>>0] = $316;
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L184;
          break;
         }
         case -1:  {
          $317 = $304&65535;
          HEAP16[$dest$0>>1] = $317;
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L184;
          break;
         }
         case 0:  {
          HEAP32[$dest$0>>2] = $304;
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L184;
          break;
         }
         case 1:  {
          HEAP32[$dest$0>>2] = $304;
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L184;
          break;
         }
         default: {
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L184;
         }
         }
        }
       }
      } while(0);
      $332 = HEAP32[$5>>2]|0;
      $333 = HEAP32[$3>>2]|0;
      $334 = HEAP32[$6>>2]|0;
      $335 = $333;
      $336 = $334;
      $337 = (($332) + ($pos$1))|0;
      $338 = (($337) + ($335))|0;
      $339 = (($338) - ($336))|0;
      $not$ = ($dest$0|0)!=(0|0);
      $340 = $not$&1;
      $matches$0$ = (($340) + ($matches$0130))|0;
      $matches$1 = $matches$0$;$p$11 = $p$10;$pos$2 = $339;$s$5 = $s$4;$wcs$6 = $wcs$5;
      break L6;
     }
    } while(0);
    $46 = $43&1;
    $47 = (($p$0136) + ($46)|0);
    ___shlim($f,0);
    $48 = HEAP32[$3>>2]|0;
    $49 = HEAP32[$4>>2]|0;
    $50 = ($48>>>0)<($49>>>0);
    if ($50) {
     $51 = (($48) + 1|0);
     HEAP32[$3>>2] = $51;
     $52 = HEAP8[$48>>0]|0;
     $53 = $52&255;
     $57 = $53;
    } else {
     $54 = (___shgetc($f)|0);
     $57 = $54;
    }
    $55 = HEAP8[$47>>0]|0;
    $56 = $55&255;
    $58 = ($57|0)==($56|0);
    if (!($58)) {
     label = 19;
     break L4;
    }
    $64 = (($pos$0135) + 1)|0;
    $matches$1 = $matches$0130;$p$11 = $47;$pos$2 = $64;$s$5 = $s$0128;$wcs$6 = $wcs$0129;
   } else {
    $p$1 = $p$0136;
    while(1) {
     $16 = (($p$1) + 1|0);
     $17 = HEAP8[$16>>0]|0;
     $18 = $17&255;
     $19 = (_isspace($18)|0);
     $20 = ($19|0)==(0);
     if ($20) {
      break;
     } else {
      $p$1 = $16;
     }
    }
    ___shlim($f,0);
    while(1) {
     $21 = HEAP32[$3>>2]|0;
     $22 = HEAP32[$4>>2]|0;
     $23 = ($21>>>0)<($22>>>0);
     if ($23) {
      $24 = (($21) + 1|0);
      HEAP32[$3>>2] = $24;
      $25 = HEAP8[$21>>0]|0;
      $26 = $25&255;
      $28 = $26;
     } else {
      $27 = (___shgetc($f)|0);
      $28 = $27;
     }
     $29 = (_isspace($28)|0);
     $30 = ($29|0)==(0);
     if ($30) {
      break;
     }
    }
    $31 = HEAP32[$4>>2]|0;
    $32 = ($31|0)==(0|0);
    $$pre238 = HEAP32[$3>>2]|0;
    if ($32) {
     $36 = $$pre238;
    } else {
     $33 = (($$pre238) + -1|0);
     HEAP32[$3>>2] = $33;
     $36 = $33;
    }
    $34 = HEAP32[$5>>2]|0;
    $35 = HEAP32[$6>>2]|0;
    $37 = $36;
    $38 = $35;
    $39 = (($34) + ($pos$0135))|0;
    $40 = (($39) + ($37))|0;
    $41 = (($40) - ($38))|0;
    $matches$1 = $matches$0130;$p$11 = $p$1;$pos$2 = $41;$s$5 = $s$0128;$wcs$6 = $wcs$0129;
   }
  } while(0);
  $341 = (($p$11) + 1|0);
  $342 = HEAP8[$341>>0]|0;
  $343 = ($342<<24>>24)==(0);
  if ($343) {
   $matches$3 = $matches$1;
   label = 165;
   break;
  } else {
   $13 = $342;$matches$0130 = $matches$1;$p$0136 = $341;$pos$0135 = $pos$2;$s$0128 = $s$5;$wcs$0129 = $wcs$6;
  }
 }
 if ((label|0) == 165) {
  STACKTOP = sp;return ($matches$3|0);
 }
 if ((label|0) == 19) {
  $59 = HEAP32[$4>>2]|0;
  $60 = ($59|0)==(0|0);
  if (!($60)) {
   $61 = HEAP32[$3>>2]|0;
   $62 = (($61) + -1|0);
   HEAP32[$3>>2] = $62;
  }
  $63 = ($57|0)<(0);
  if ($63) {
   $alloc$1 = 0;$s$6 = $s$0128;$wcs$7 = $wcs$0129;
   label = 162;
  } else {
   $matches$3 = $matches$0130;
   STACKTOP = sp;return ($matches$3|0);
  }
 }
 if ((label|0) == 162) {
  $344 = ($matches$0130|0)==(0);
  $345 = $344 << 31 >> 31;
  $$matches$0 = (($345) + ($matches$0130))|0;
  $alloc$2 = $alloc$1;$matches$2 = $$matches$0;$s$7 = $s$6;$wcs$8 = $wcs$7;
 }
 $346 = ($alloc$2|0)==(0);
 if ($346) {
  $matches$3 = $matches$2;
  STACKTOP = sp;return ($matches$3|0);
 }
 _free($s$7);
 _free($wcs$8);
 $matches$3 = $matches$2;
 STACKTOP = sp;return ($matches$3|0);
}
function _vsscanf($s,$fmt,$ap) {
 $s = $s|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $f = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $f = sp;
 dest=$f+0|0; stop=dest+112|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $0 = (($f) + 32|0);
 HEAP32[$0>>2] = 5;
 $1 = (($f) + 44|0);
 HEAP32[$1>>2] = $s;
 $2 = (($f) + 76|0);
 HEAP32[$2>>2] = -1;
 $3 = (($f) + 84|0);
 HEAP32[$3>>2] = $s;
 $4 = (_MUSL_vfscanf($f,$fmt,$ap)|0);
 STACKTOP = sp;return ($4|0);
}
function _do_read($f,$buf,$len) {
 $f = $f|0;
 $buf = $buf|0;
 $len = $len|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___string_read($f,$buf,$len)|0);
 STACKTOP = sp;return ($0|0);
}
function _malloc($bytes) {
 $bytes = $bytes|0;
 var $$$i = 0, $$3$i = 0, $$4$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i25 = 0, $$pre$i25$i = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi$i26$iZ2D = 0, $$pre$phi$i26Z2D = 0, $$pre$phi$iZ2D = 0, $$pre$phi58$i$iZ2D = 0, $$pre$phiZ2D = 0, $$pre57$i$i = 0, $$rsize$0$i = 0, $$rsize$3$i = 0, $$sum = 0, $$sum$i$i = 0, $$sum$i$i$i = 0;
 var $$sum$i14$i = 0, $$sum$i15$i = 0, $$sum$i18$i = 0, $$sum$i21$i = 0, $$sum$i2334 = 0, $$sum$i32 = 0, $$sum$i35 = 0, $$sum1 = 0, $$sum1$i = 0, $$sum1$i$i = 0, $$sum1$i16$i = 0, $$sum1$i22$i = 0, $$sum1$i24 = 0, $$sum10 = 0, $$sum10$i = 0, $$sum10$i$i = 0, $$sum10$pre$i$i = 0, $$sum107$i = 0, $$sum108$i = 0, $$sum109$i = 0;
 var $$sum11$i = 0, $$sum11$i$i = 0, $$sum11$i24$i = 0, $$sum110$i = 0, $$sum111$i = 0, $$sum1112 = 0, $$sum112$i = 0, $$sum113$i = 0, $$sum114$i = 0, $$sum115$i = 0, $$sum116$i = 0, $$sum117$i = 0, $$sum118$i = 0, $$sum119$i = 0, $$sum12$i = 0, $$sum12$i$i = 0, $$sum120$i = 0, $$sum13$i = 0, $$sum13$i$i = 0, $$sum14$i$i = 0;
 var $$sum14$pre$i = 0, $$sum15$i = 0, $$sum15$i$i = 0, $$sum16$i = 0, $$sum16$i$i = 0, $$sum17$i = 0, $$sum17$i$i = 0, $$sum18$i = 0, $$sum1819$i$i = 0, $$sum2 = 0, $$sum2$i = 0, $$sum2$i$i = 0, $$sum2$i$i$i = 0, $$sum2$i17$i = 0, $$sum2$i19$i = 0, $$sum2$i23$i = 0, $$sum2$pre$i = 0, $$sum20$i$i = 0, $$sum21$i$i = 0, $$sum22$i$i = 0;
 var $$sum23$i$i = 0, $$sum24$i$i = 0, $$sum25$i$i = 0, $$sum26$pre$i$i = 0, $$sum27$i$i = 0, $$sum28$i$i = 0, $$sum29$i$i = 0, $$sum3$i = 0, $$sum3$i$i = 0, $$sum3$i27 = 0, $$sum30$i$i = 0, $$sum3132$i$i = 0, $$sum34$i$i = 0, $$sum3536$i$i = 0, $$sum3738$i$i = 0, $$sum39$i$i = 0, $$sum4 = 0, $$sum4$i = 0, $$sum4$i28 = 0, $$sum40$i$i = 0;
 var $$sum41$i$i = 0, $$sum42$i$i = 0, $$sum5$i = 0, $$sum5$i$i = 0, $$sum56 = 0, $$sum6$i = 0, $$sum67$i$i = 0, $$sum7$i = 0, $$sum8$i = 0, $$sum8$pre = 0, $$sum9 = 0, $$sum9$i = 0, $$sum9$i$i = 0, $$tsize$1$i = 0, $$v$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0;
 var $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0;
 var $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0;
 var $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0;
 var $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0;
 var $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0;
 var $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0;
 var $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0;
 var $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0;
 var $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0;
 var $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0;
 var $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0;
 var $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0;
 var $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0;
 var $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0;
 var $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0;
 var $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0;
 var $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0;
 var $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0;
 var $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0;
 var $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0;
 var $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0;
 var $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0;
 var $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0;
 var $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0;
 var $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0;
 var $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0;
 var $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0;
 var $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0;
 var $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0;
 var $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0;
 var $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0;
 var $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0;
 var $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0;
 var $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0;
 var $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0;
 var $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0;
 var $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0;
 var $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0;
 var $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0;
 var $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0;
 var $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0;
 var $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0;
 var $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0;
 var $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $F$0$i$i = 0, $F1$0$i = 0, $F4$0 = 0, $F4$0$i$i = 0, $F5$0$i = 0;
 var $I1$0$c$i$i = 0, $I1$0$i$i = 0, $I7$0$i = 0, $I7$0$i$i = 0, $K12$025$i = 0, $K2$014$i$i = 0, $K8$052$i$i = 0, $R$0$i = 0, $R$0$i$i = 0, $R$0$i18 = 0, $R$1$i = 0, $R$1$i$i = 0, $R$1$i20 = 0, $RP$0$i = 0, $RP$0$i$i = 0, $RP$0$i17 = 0, $T$0$lcssa$i = 0, $T$0$lcssa$i$i = 0, $T$0$lcssa$i28$i = 0, $T$013$i$i = 0;
 var $T$024$i = 0, $T$051$i$i = 0, $br$0$i = 0, $cond$i = 0, $cond$i$i = 0, $cond$i21 = 0, $exitcond$i$i = 0, $i$02$i$i = 0, $idx$0$i = 0, $mem$0 = 0, $nb$0 = 0, $notlhs$i = 0, $notrhs$i = 0, $oldfirst$0$i$i = 0, $or$cond$i = 0, $or$cond$i29 = 0, $or$cond1$i = 0, $or$cond10$i = 0, $or$cond19$i = 0, $or$cond2$i = 0;
 var $or$cond49$i = 0, $or$cond5$i = 0, $or$cond6$i = 0, $or$cond8$not$i = 0, $or$cond9$i = 0, $qsize$0$i$i = 0, $rsize$0$i = 0, $rsize$0$i15 = 0, $rsize$1$i = 0, $rsize$2$i = 0, $rsize$3$lcssa$i = 0, $rsize$329$i = 0, $rst$0$i = 0, $rst$1$i = 0, $sizebits$0$i = 0, $sp$0$i$i = 0, $sp$0$i$i$i = 0, $sp$075$i = 0, $sp$168$i = 0, $ssize$0$$i = 0;
 var $ssize$0$i = 0, $ssize$1$i = 0, $ssize$2$i = 0, $t$0$i = 0, $t$0$i14 = 0, $t$1$i = 0, $t$2$ph$i = 0, $t$2$v$3$i = 0, $t$228$i = 0, $tbase$0$i = 0, $tbase$247$i = 0, $tsize$0$i = 0, $tsize$0323841$i = 0, $tsize$1$i = 0, $tsize$246$i = 0, $v$0$i = 0, $v$0$i16 = 0, $v$1$i = 0, $v$2$i = 0, $v$3$lcssa$i = 0;
 var $v$330$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($bytes>>>0)<(245);
 do {
  if ($0) {
   $1 = ($bytes>>>0)<(11);
   if ($1) {
    $5 = 16;
   } else {
    $2 = (($bytes) + 11)|0;
    $3 = $2 & -8;
    $5 = $3;
   }
   $4 = $5 >>> 3;
   $6 = HEAP32[143912>>2]|0;
   $7 = $6 >>> $4;
   $8 = $7 & 3;
   $9 = ($8|0)==(0);
   if (!($9)) {
    $10 = $7 & 1;
    $11 = $10 ^ 1;
    $12 = (($11) + ($4))|0;
    $13 = $12 << 1;
    $14 = ((143912 + ($13<<2)|0) + 40|0);
    $$sum10 = (($13) + 2)|0;
    $15 = ((143912 + ($$sum10<<2)|0) + 40|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($16) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($14|0)==($18|0);
    do {
     if ($19) {
      $20 = 1 << $12;
      $21 = $20 ^ -1;
      $22 = $6 & $21;
      HEAP32[143912>>2] = $22;
     } else {
      $23 = HEAP32[((143912 + 16|0))>>2]|0;
      $24 = ($18>>>0)<($23>>>0);
      if ($24) {
       _abort();
       // unreachable;
      }
      $25 = (($18) + 12|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = ($26|0)==($16|0);
      if ($27) {
       HEAP32[$25>>2] = $14;
       HEAP32[$15>>2] = $18;
       break;
      } else {
       _abort();
       // unreachable;
      }
     }
    } while(0);
    $28 = $12 << 3;
    $29 = $28 | 3;
    $30 = (($16) + 4|0);
    HEAP32[$30>>2] = $29;
    $$sum1112 = $28 | 4;
    $31 = (($16) + ($$sum1112)|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = $32 | 1;
    HEAP32[$31>>2] = $33;
    $mem$0 = $17;
    STACKTOP = sp;return ($mem$0|0);
   }
   $34 = HEAP32[((143912 + 8|0))>>2]|0;
   $35 = ($5>>>0)>($34>>>0);
   if ($35) {
    $36 = ($7|0)==(0);
    if (!($36)) {
     $37 = $7 << $4;
     $38 = 2 << $4;
     $39 = (0 - ($38))|0;
     $40 = $38 | $39;
     $41 = $37 & $40;
     $42 = (0 - ($41))|0;
     $43 = $41 & $42;
     $44 = (($43) + -1)|0;
     $45 = $44 >>> 12;
     $46 = $45 & 16;
     $47 = $44 >>> $46;
     $48 = $47 >>> 5;
     $49 = $48 & 8;
     $50 = $49 | $46;
     $51 = $47 >>> $49;
     $52 = $51 >>> 2;
     $53 = $52 & 4;
     $54 = $50 | $53;
     $55 = $51 >>> $53;
     $56 = $55 >>> 1;
     $57 = $56 & 2;
     $58 = $54 | $57;
     $59 = $55 >>> $57;
     $60 = $59 >>> 1;
     $61 = $60 & 1;
     $62 = $58 | $61;
     $63 = $59 >>> $61;
     $64 = (($62) + ($63))|0;
     $65 = $64 << 1;
     $66 = ((143912 + ($65<<2)|0) + 40|0);
     $$sum4 = (($65) + 2)|0;
     $67 = ((143912 + ($$sum4<<2)|0) + 40|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (($68) + 8|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($66|0)==($70|0);
     do {
      if ($71) {
       $72 = 1 << $64;
       $73 = $72 ^ -1;
       $74 = $6 & $73;
       HEAP32[143912>>2] = $74;
      } else {
       $75 = HEAP32[((143912 + 16|0))>>2]|0;
       $76 = ($70>>>0)<($75>>>0);
       if ($76) {
        _abort();
        // unreachable;
       }
       $77 = (($70) + 12|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = ($78|0)==($68|0);
       if ($79) {
        HEAP32[$77>>2] = $66;
        HEAP32[$67>>2] = $70;
        break;
       } else {
        _abort();
        // unreachable;
       }
      }
     } while(0);
     $80 = $64 << 3;
     $81 = (($80) - ($5))|0;
     $82 = $5 | 3;
     $83 = (($68) + 4|0);
     HEAP32[$83>>2] = $82;
     $84 = (($68) + ($5)|0);
     $85 = $81 | 1;
     $$sum56 = $5 | 4;
     $86 = (($68) + ($$sum56)|0);
     HEAP32[$86>>2] = $85;
     $87 = (($68) + ($80)|0);
     HEAP32[$87>>2] = $81;
     $88 = HEAP32[((143912 + 8|0))>>2]|0;
     $89 = ($88|0)==(0);
     if (!($89)) {
      $90 = HEAP32[((143912 + 20|0))>>2]|0;
      $91 = $88 >>> 3;
      $92 = $91 << 1;
      $93 = ((143912 + ($92<<2)|0) + 40|0);
      $94 = HEAP32[143912>>2]|0;
      $95 = 1 << $91;
      $96 = $94 & $95;
      $97 = ($96|0)==(0);
      if ($97) {
       $98 = $94 | $95;
       HEAP32[143912>>2] = $98;
       $$sum8$pre = (($92) + 2)|0;
       $$pre = ((143912 + ($$sum8$pre<<2)|0) + 40|0);
       $$pre$phiZ2D = $$pre;$F4$0 = $93;
      } else {
       $$sum9 = (($92) + 2)|0;
       $99 = ((143912 + ($$sum9<<2)|0) + 40|0);
       $100 = HEAP32[$99>>2]|0;
       $101 = HEAP32[((143912 + 16|0))>>2]|0;
       $102 = ($100>>>0)<($101>>>0);
       if ($102) {
        _abort();
        // unreachable;
       } else {
        $$pre$phiZ2D = $99;$F4$0 = $100;
       }
      }
      HEAP32[$$pre$phiZ2D>>2] = $90;
      $103 = (($F4$0) + 12|0);
      HEAP32[$103>>2] = $90;
      $104 = (($90) + 8|0);
      HEAP32[$104>>2] = $F4$0;
      $105 = (($90) + 12|0);
      HEAP32[$105>>2] = $93;
     }
     HEAP32[((143912 + 8|0))>>2] = $81;
     HEAP32[((143912 + 20|0))>>2] = $84;
     $mem$0 = $69;
     STACKTOP = sp;return ($mem$0|0);
    }
    $106 = HEAP32[((143912 + 4|0))>>2]|0;
    $107 = ($106|0)==(0);
    if ($107) {
     $nb$0 = $5;
    } else {
     $108 = (0 - ($106))|0;
     $109 = $106 & $108;
     $110 = (($109) + -1)|0;
     $111 = $110 >>> 12;
     $112 = $111 & 16;
     $113 = $110 >>> $112;
     $114 = $113 >>> 5;
     $115 = $114 & 8;
     $116 = $115 | $112;
     $117 = $113 >>> $115;
     $118 = $117 >>> 2;
     $119 = $118 & 4;
     $120 = $116 | $119;
     $121 = $117 >>> $119;
     $122 = $121 >>> 1;
     $123 = $122 & 2;
     $124 = $120 | $123;
     $125 = $121 >>> $123;
     $126 = $125 >>> 1;
     $127 = $126 & 1;
     $128 = $124 | $127;
     $129 = $125 >>> $127;
     $130 = (($128) + ($129))|0;
     $131 = ((143912 + ($130<<2)|0) + 304|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = (($132) + 4|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = $134 & -8;
     $136 = (($135) - ($5))|0;
     $rsize$0$i = $136;$t$0$i = $132;$v$0$i = $132;
     while(1) {
      $137 = (($t$0$i) + 16|0);
      $138 = HEAP32[$137>>2]|0;
      $139 = ($138|0)==(0|0);
      if ($139) {
       $140 = (($t$0$i) + 20|0);
       $141 = HEAP32[$140>>2]|0;
       $142 = ($141|0)==(0|0);
       if ($142) {
        break;
       } else {
        $144 = $141;
       }
      } else {
       $144 = $138;
      }
      $143 = (($144) + 4|0);
      $145 = HEAP32[$143>>2]|0;
      $146 = $145 & -8;
      $147 = (($146) - ($5))|0;
      $148 = ($147>>>0)<($rsize$0$i>>>0);
      $$rsize$0$i = $148 ? $147 : $rsize$0$i;
      $$v$0$i = $148 ? $144 : $v$0$i;
      $rsize$0$i = $$rsize$0$i;$t$0$i = $144;$v$0$i = $$v$0$i;
     }
     $149 = HEAP32[((143912 + 16|0))>>2]|0;
     $150 = ($v$0$i>>>0)<($149>>>0);
     if ($150) {
      _abort();
      // unreachable;
     }
     $151 = (($v$0$i) + ($5)|0);
     $152 = ($v$0$i>>>0)<($151>>>0);
     if (!($152)) {
      _abort();
      // unreachable;
     }
     $153 = (($v$0$i) + 24|0);
     $154 = HEAP32[$153>>2]|0;
     $155 = (($v$0$i) + 12|0);
     $156 = HEAP32[$155>>2]|0;
     $157 = ($156|0)==($v$0$i|0);
     do {
      if ($157) {
       $167 = (($v$0$i) + 20|0);
       $168 = HEAP32[$167>>2]|0;
       $169 = ($168|0)==(0|0);
       if ($169) {
        $170 = (($v$0$i) + 16|0);
        $171 = HEAP32[$170>>2]|0;
        $172 = ($171|0)==(0|0);
        if ($172) {
         $R$1$i = 0;
         break;
        } else {
         $R$0$i = $171;$RP$0$i = $170;
        }
       } else {
        $R$0$i = $168;$RP$0$i = $167;
       }
       while(1) {
        $173 = (($R$0$i) + 20|0);
        $174 = HEAP32[$173>>2]|0;
        $175 = ($174|0)==(0|0);
        if (!($175)) {
         $R$0$i = $174;$RP$0$i = $173;
         continue;
        }
        $176 = (($R$0$i) + 16|0);
        $177 = HEAP32[$176>>2]|0;
        $178 = ($177|0)==(0|0);
        if ($178) {
         break;
        } else {
         $R$0$i = $177;$RP$0$i = $176;
        }
       }
       $179 = ($RP$0$i>>>0)<($149>>>0);
       if ($179) {
        _abort();
        // unreachable;
       } else {
        HEAP32[$RP$0$i>>2] = 0;
        $R$1$i = $R$0$i;
        break;
       }
      } else {
       $158 = (($v$0$i) + 8|0);
       $159 = HEAP32[$158>>2]|0;
       $160 = ($159>>>0)<($149>>>0);
       if ($160) {
        _abort();
        // unreachable;
       }
       $161 = (($159) + 12|0);
       $162 = HEAP32[$161>>2]|0;
       $163 = ($162|0)==($v$0$i|0);
       if (!($163)) {
        _abort();
        // unreachable;
       }
       $164 = (($156) + 8|0);
       $165 = HEAP32[$164>>2]|0;
       $166 = ($165|0)==($v$0$i|0);
       if ($166) {
        HEAP32[$161>>2] = $156;
        HEAP32[$164>>2] = $159;
        $R$1$i = $156;
        break;
       } else {
        _abort();
        // unreachable;
       }
      }
     } while(0);
     $180 = ($154|0)==(0|0);
     do {
      if (!($180)) {
       $181 = (($v$0$i) + 28|0);
       $182 = HEAP32[$181>>2]|0;
       $183 = ((143912 + ($182<<2)|0) + 304|0);
       $184 = HEAP32[$183>>2]|0;
       $185 = ($v$0$i|0)==($184|0);
       if ($185) {
        HEAP32[$183>>2] = $R$1$i;
        $cond$i = ($R$1$i|0)==(0|0);
        if ($cond$i) {
         $186 = 1 << $182;
         $187 = $186 ^ -1;
         $188 = HEAP32[((143912 + 4|0))>>2]|0;
         $189 = $188 & $187;
         HEAP32[((143912 + 4|0))>>2] = $189;
         break;
        }
       } else {
        $190 = HEAP32[((143912 + 16|0))>>2]|0;
        $191 = ($154>>>0)<($190>>>0);
        if ($191) {
         _abort();
         // unreachable;
        }
        $192 = (($154) + 16|0);
        $193 = HEAP32[$192>>2]|0;
        $194 = ($193|0)==($v$0$i|0);
        if ($194) {
         HEAP32[$192>>2] = $R$1$i;
        } else {
         $195 = (($154) + 20|0);
         HEAP32[$195>>2] = $R$1$i;
        }
        $196 = ($R$1$i|0)==(0|0);
        if ($196) {
         break;
        }
       }
       $197 = HEAP32[((143912 + 16|0))>>2]|0;
       $198 = ($R$1$i>>>0)<($197>>>0);
       if ($198) {
        _abort();
        // unreachable;
       }
       $199 = (($R$1$i) + 24|0);
       HEAP32[$199>>2] = $154;
       $200 = (($v$0$i) + 16|0);
       $201 = HEAP32[$200>>2]|0;
       $202 = ($201|0)==(0|0);
       do {
        if (!($202)) {
         $203 = HEAP32[((143912 + 16|0))>>2]|0;
         $204 = ($201>>>0)<($203>>>0);
         if ($204) {
          _abort();
          // unreachable;
         } else {
          $205 = (($R$1$i) + 16|0);
          HEAP32[$205>>2] = $201;
          $206 = (($201) + 24|0);
          HEAP32[$206>>2] = $R$1$i;
          break;
         }
        }
       } while(0);
       $207 = (($v$0$i) + 20|0);
       $208 = HEAP32[$207>>2]|0;
       $209 = ($208|0)==(0|0);
       if (!($209)) {
        $210 = HEAP32[((143912 + 16|0))>>2]|0;
        $211 = ($208>>>0)<($210>>>0);
        if ($211) {
         _abort();
         // unreachable;
        } else {
         $212 = (($R$1$i) + 20|0);
         HEAP32[$212>>2] = $208;
         $213 = (($208) + 24|0);
         HEAP32[$213>>2] = $R$1$i;
         break;
        }
       }
      }
     } while(0);
     $214 = ($rsize$0$i>>>0)<(16);
     if ($214) {
      $215 = (($rsize$0$i) + ($5))|0;
      $216 = $215 | 3;
      $217 = (($v$0$i) + 4|0);
      HEAP32[$217>>2] = $216;
      $$sum4$i = (($215) + 4)|0;
      $218 = (($v$0$i) + ($$sum4$i)|0);
      $219 = HEAP32[$218>>2]|0;
      $220 = $219 | 1;
      HEAP32[$218>>2] = $220;
     } else {
      $221 = $5 | 3;
      $222 = (($v$0$i) + 4|0);
      HEAP32[$222>>2] = $221;
      $223 = $rsize$0$i | 1;
      $$sum$i35 = $5 | 4;
      $224 = (($v$0$i) + ($$sum$i35)|0);
      HEAP32[$224>>2] = $223;
      $$sum1$i = (($rsize$0$i) + ($5))|0;
      $225 = (($v$0$i) + ($$sum1$i)|0);
      HEAP32[$225>>2] = $rsize$0$i;
      $226 = HEAP32[((143912 + 8|0))>>2]|0;
      $227 = ($226|0)==(0);
      if (!($227)) {
       $228 = HEAP32[((143912 + 20|0))>>2]|0;
       $229 = $226 >>> 3;
       $230 = $229 << 1;
       $231 = ((143912 + ($230<<2)|0) + 40|0);
       $232 = HEAP32[143912>>2]|0;
       $233 = 1 << $229;
       $234 = $232 & $233;
       $235 = ($234|0)==(0);
       if ($235) {
        $236 = $232 | $233;
        HEAP32[143912>>2] = $236;
        $$sum2$pre$i = (($230) + 2)|0;
        $$pre$i = ((143912 + ($$sum2$pre$i<<2)|0) + 40|0);
        $$pre$phi$iZ2D = $$pre$i;$F1$0$i = $231;
       } else {
        $$sum3$i = (($230) + 2)|0;
        $237 = ((143912 + ($$sum3$i<<2)|0) + 40|0);
        $238 = HEAP32[$237>>2]|0;
        $239 = HEAP32[((143912 + 16|0))>>2]|0;
        $240 = ($238>>>0)<($239>>>0);
        if ($240) {
         _abort();
         // unreachable;
        } else {
         $$pre$phi$iZ2D = $237;$F1$0$i = $238;
        }
       }
       HEAP32[$$pre$phi$iZ2D>>2] = $228;
       $241 = (($F1$0$i) + 12|0);
       HEAP32[$241>>2] = $228;
       $242 = (($228) + 8|0);
       HEAP32[$242>>2] = $F1$0$i;
       $243 = (($228) + 12|0);
       HEAP32[$243>>2] = $231;
      }
      HEAP32[((143912 + 8|0))>>2] = $rsize$0$i;
      HEAP32[((143912 + 20|0))>>2] = $151;
     }
     $244 = (($v$0$i) + 8|0);
     $mem$0 = $244;
     STACKTOP = sp;return ($mem$0|0);
    }
   } else {
    $nb$0 = $5;
   }
  } else {
   $245 = ($bytes>>>0)>(4294967231);
   if ($245) {
    $nb$0 = -1;
   } else {
    $246 = (($bytes) + 11)|0;
    $247 = $246 & -8;
    $248 = HEAP32[((143912 + 4|0))>>2]|0;
    $249 = ($248|0)==(0);
    if ($249) {
     $nb$0 = $247;
    } else {
     $250 = (0 - ($247))|0;
     $251 = $246 >>> 8;
     $252 = ($251|0)==(0);
     if ($252) {
      $idx$0$i = 0;
     } else {
      $253 = ($247>>>0)>(16777215);
      if ($253) {
       $idx$0$i = 31;
      } else {
       $254 = (($251) + 1048320)|0;
       $255 = $254 >>> 16;
       $256 = $255 & 8;
       $257 = $251 << $256;
       $258 = (($257) + 520192)|0;
       $259 = $258 >>> 16;
       $260 = $259 & 4;
       $261 = $260 | $256;
       $262 = $257 << $260;
       $263 = (($262) + 245760)|0;
       $264 = $263 >>> 16;
       $265 = $264 & 2;
       $266 = $261 | $265;
       $267 = (14 - ($266))|0;
       $268 = $262 << $265;
       $269 = $268 >>> 15;
       $270 = (($267) + ($269))|0;
       $271 = $270 << 1;
       $272 = (($270) + 7)|0;
       $273 = $247 >>> $272;
       $274 = $273 & 1;
       $275 = $274 | $271;
       $idx$0$i = $275;
      }
     }
     $276 = ((143912 + ($idx$0$i<<2)|0) + 304|0);
     $277 = HEAP32[$276>>2]|0;
     $278 = ($277|0)==(0|0);
     L9: do {
      if ($278) {
       $rsize$2$i = $250;$t$1$i = 0;$v$2$i = 0;
      } else {
       $279 = ($idx$0$i|0)==(31);
       if ($279) {
        $283 = 0;
       } else {
        $280 = $idx$0$i >>> 1;
        $281 = (25 - ($280))|0;
        $283 = $281;
       }
       $282 = $247 << $283;
       $rsize$0$i15 = $250;$rst$0$i = 0;$sizebits$0$i = $282;$t$0$i14 = $277;$v$0$i16 = 0;
       while(1) {
        $284 = (($t$0$i14) + 4|0);
        $285 = HEAP32[$284>>2]|0;
        $286 = $285 & -8;
        $287 = (($286) - ($247))|0;
        $288 = ($287>>>0)<($rsize$0$i15>>>0);
        if ($288) {
         $289 = ($286|0)==($247|0);
         if ($289) {
          $rsize$2$i = $287;$t$1$i = $t$0$i14;$v$2$i = $t$0$i14;
          break L9;
         } else {
          $rsize$1$i = $287;$v$1$i = $t$0$i14;
         }
        } else {
         $rsize$1$i = $rsize$0$i15;$v$1$i = $v$0$i16;
        }
        $290 = (($t$0$i14) + 20|0);
        $291 = HEAP32[$290>>2]|0;
        $292 = $sizebits$0$i >>> 31;
        $293 = ((($t$0$i14) + ($292<<2)|0) + 16|0);
        $294 = HEAP32[$293>>2]|0;
        $295 = ($291|0)==(0|0);
        $296 = ($291|0)==($294|0);
        $or$cond$i = $295 | $296;
        $rst$1$i = $or$cond$i ? $rst$0$i : $291;
        $297 = ($294|0)==(0|0);
        $298 = $sizebits$0$i << 1;
        if ($297) {
         $rsize$2$i = $rsize$1$i;$t$1$i = $rst$1$i;$v$2$i = $v$1$i;
         break;
        } else {
         $rsize$0$i15 = $rsize$1$i;$rst$0$i = $rst$1$i;$sizebits$0$i = $298;$t$0$i14 = $294;$v$0$i16 = $v$1$i;
        }
       }
      }
     } while(0);
     $299 = ($t$1$i|0)==(0|0);
     $300 = ($v$2$i|0)==(0|0);
     $or$cond19$i = $299 & $300;
     if ($or$cond19$i) {
      $301 = 2 << $idx$0$i;
      $302 = (0 - ($301))|0;
      $303 = $301 | $302;
      $304 = $248 & $303;
      $305 = ($304|0)==(0);
      if ($305) {
       $nb$0 = $247;
       break;
      }
      $306 = (0 - ($304))|0;
      $307 = $304 & $306;
      $308 = (($307) + -1)|0;
      $309 = $308 >>> 12;
      $310 = $309 & 16;
      $311 = $308 >>> $310;
      $312 = $311 >>> 5;
      $313 = $312 & 8;
      $314 = $313 | $310;
      $315 = $311 >>> $313;
      $316 = $315 >>> 2;
      $317 = $316 & 4;
      $318 = $314 | $317;
      $319 = $315 >>> $317;
      $320 = $319 >>> 1;
      $321 = $320 & 2;
      $322 = $318 | $321;
      $323 = $319 >>> $321;
      $324 = $323 >>> 1;
      $325 = $324 & 1;
      $326 = $322 | $325;
      $327 = $323 >>> $325;
      $328 = (($326) + ($327))|0;
      $329 = ((143912 + ($328<<2)|0) + 304|0);
      $330 = HEAP32[$329>>2]|0;
      $t$2$ph$i = $330;
     } else {
      $t$2$ph$i = $t$1$i;
     }
     $331 = ($t$2$ph$i|0)==(0|0);
     if ($331) {
      $rsize$3$lcssa$i = $rsize$2$i;$v$3$lcssa$i = $v$2$i;
     } else {
      $rsize$329$i = $rsize$2$i;$t$228$i = $t$2$ph$i;$v$330$i = $v$2$i;
      while(1) {
       $332 = (($t$228$i) + 4|0);
       $333 = HEAP32[$332>>2]|0;
       $334 = $333 & -8;
       $335 = (($334) - ($247))|0;
       $336 = ($335>>>0)<($rsize$329$i>>>0);
       $$rsize$3$i = $336 ? $335 : $rsize$329$i;
       $t$2$v$3$i = $336 ? $t$228$i : $v$330$i;
       $337 = (($t$228$i) + 16|0);
       $338 = HEAP32[$337>>2]|0;
       $339 = ($338|0)==(0|0);
       if (!($339)) {
        $rsize$329$i = $$rsize$3$i;$t$228$i = $338;$v$330$i = $t$2$v$3$i;
        continue;
       }
       $340 = (($t$228$i) + 20|0);
       $341 = HEAP32[$340>>2]|0;
       $342 = ($341|0)==(0|0);
       if ($342) {
        $rsize$3$lcssa$i = $$rsize$3$i;$v$3$lcssa$i = $t$2$v$3$i;
        break;
       } else {
        $rsize$329$i = $$rsize$3$i;$t$228$i = $341;$v$330$i = $t$2$v$3$i;
       }
      }
     }
     $343 = ($v$3$lcssa$i|0)==(0|0);
     if ($343) {
      $nb$0 = $247;
     } else {
      $344 = HEAP32[((143912 + 8|0))>>2]|0;
      $345 = (($344) - ($247))|0;
      $346 = ($rsize$3$lcssa$i>>>0)<($345>>>0);
      if ($346) {
       $347 = HEAP32[((143912 + 16|0))>>2]|0;
       $348 = ($v$3$lcssa$i>>>0)<($347>>>0);
       if ($348) {
        _abort();
        // unreachable;
       }
       $349 = (($v$3$lcssa$i) + ($247)|0);
       $350 = ($v$3$lcssa$i>>>0)<($349>>>0);
       if (!($350)) {
        _abort();
        // unreachable;
       }
       $351 = (($v$3$lcssa$i) + 24|0);
       $352 = HEAP32[$351>>2]|0;
       $353 = (($v$3$lcssa$i) + 12|0);
       $354 = HEAP32[$353>>2]|0;
       $355 = ($354|0)==($v$3$lcssa$i|0);
       do {
        if ($355) {
         $365 = (($v$3$lcssa$i) + 20|0);
         $366 = HEAP32[$365>>2]|0;
         $367 = ($366|0)==(0|0);
         if ($367) {
          $368 = (($v$3$lcssa$i) + 16|0);
          $369 = HEAP32[$368>>2]|0;
          $370 = ($369|0)==(0|0);
          if ($370) {
           $R$1$i20 = 0;
           break;
          } else {
           $R$0$i18 = $369;$RP$0$i17 = $368;
          }
         } else {
          $R$0$i18 = $366;$RP$0$i17 = $365;
         }
         while(1) {
          $371 = (($R$0$i18) + 20|0);
          $372 = HEAP32[$371>>2]|0;
          $373 = ($372|0)==(0|0);
          if (!($373)) {
           $R$0$i18 = $372;$RP$0$i17 = $371;
           continue;
          }
          $374 = (($R$0$i18) + 16|0);
          $375 = HEAP32[$374>>2]|0;
          $376 = ($375|0)==(0|0);
          if ($376) {
           break;
          } else {
           $R$0$i18 = $375;$RP$0$i17 = $374;
          }
         }
         $377 = ($RP$0$i17>>>0)<($347>>>0);
         if ($377) {
          _abort();
          // unreachable;
         } else {
          HEAP32[$RP$0$i17>>2] = 0;
          $R$1$i20 = $R$0$i18;
          break;
         }
        } else {
         $356 = (($v$3$lcssa$i) + 8|0);
         $357 = HEAP32[$356>>2]|0;
         $358 = ($357>>>0)<($347>>>0);
         if ($358) {
          _abort();
          // unreachable;
         }
         $359 = (($357) + 12|0);
         $360 = HEAP32[$359>>2]|0;
         $361 = ($360|0)==($v$3$lcssa$i|0);
         if (!($361)) {
          _abort();
          // unreachable;
         }
         $362 = (($354) + 8|0);
         $363 = HEAP32[$362>>2]|0;
         $364 = ($363|0)==($v$3$lcssa$i|0);
         if ($364) {
          HEAP32[$359>>2] = $354;
          HEAP32[$362>>2] = $357;
          $R$1$i20 = $354;
          break;
         } else {
          _abort();
          // unreachable;
         }
        }
       } while(0);
       $378 = ($352|0)==(0|0);
       do {
        if (!($378)) {
         $379 = (($v$3$lcssa$i) + 28|0);
         $380 = HEAP32[$379>>2]|0;
         $381 = ((143912 + ($380<<2)|0) + 304|0);
         $382 = HEAP32[$381>>2]|0;
         $383 = ($v$3$lcssa$i|0)==($382|0);
         if ($383) {
          HEAP32[$381>>2] = $R$1$i20;
          $cond$i21 = ($R$1$i20|0)==(0|0);
          if ($cond$i21) {
           $384 = 1 << $380;
           $385 = $384 ^ -1;
           $386 = HEAP32[((143912 + 4|0))>>2]|0;
           $387 = $386 & $385;
           HEAP32[((143912 + 4|0))>>2] = $387;
           break;
          }
         } else {
          $388 = HEAP32[((143912 + 16|0))>>2]|0;
          $389 = ($352>>>0)<($388>>>0);
          if ($389) {
           _abort();
           // unreachable;
          }
          $390 = (($352) + 16|0);
          $391 = HEAP32[$390>>2]|0;
          $392 = ($391|0)==($v$3$lcssa$i|0);
          if ($392) {
           HEAP32[$390>>2] = $R$1$i20;
          } else {
           $393 = (($352) + 20|0);
           HEAP32[$393>>2] = $R$1$i20;
          }
          $394 = ($R$1$i20|0)==(0|0);
          if ($394) {
           break;
          }
         }
         $395 = HEAP32[((143912 + 16|0))>>2]|0;
         $396 = ($R$1$i20>>>0)<($395>>>0);
         if ($396) {
          _abort();
          // unreachable;
         }
         $397 = (($R$1$i20) + 24|0);
         HEAP32[$397>>2] = $352;
         $398 = (($v$3$lcssa$i) + 16|0);
         $399 = HEAP32[$398>>2]|0;
         $400 = ($399|0)==(0|0);
         do {
          if (!($400)) {
           $401 = HEAP32[((143912 + 16|0))>>2]|0;
           $402 = ($399>>>0)<($401>>>0);
           if ($402) {
            _abort();
            // unreachable;
           } else {
            $403 = (($R$1$i20) + 16|0);
            HEAP32[$403>>2] = $399;
            $404 = (($399) + 24|0);
            HEAP32[$404>>2] = $R$1$i20;
            break;
           }
          }
         } while(0);
         $405 = (($v$3$lcssa$i) + 20|0);
         $406 = HEAP32[$405>>2]|0;
         $407 = ($406|0)==(0|0);
         if (!($407)) {
          $408 = HEAP32[((143912 + 16|0))>>2]|0;
          $409 = ($406>>>0)<($408>>>0);
          if ($409) {
           _abort();
           // unreachable;
          } else {
           $410 = (($R$1$i20) + 20|0);
           HEAP32[$410>>2] = $406;
           $411 = (($406) + 24|0);
           HEAP32[$411>>2] = $R$1$i20;
           break;
          }
         }
        }
       } while(0);
       $412 = ($rsize$3$lcssa$i>>>0)<(16);
       L87: do {
        if ($412) {
         $413 = (($rsize$3$lcssa$i) + ($247))|0;
         $414 = $413 | 3;
         $415 = (($v$3$lcssa$i) + 4|0);
         HEAP32[$415>>2] = $414;
         $$sum18$i = (($413) + 4)|0;
         $416 = (($v$3$lcssa$i) + ($$sum18$i)|0);
         $417 = HEAP32[$416>>2]|0;
         $418 = $417 | 1;
         HEAP32[$416>>2] = $418;
        } else {
         $419 = $247 | 3;
         $420 = (($v$3$lcssa$i) + 4|0);
         HEAP32[$420>>2] = $419;
         $421 = $rsize$3$lcssa$i | 1;
         $$sum$i2334 = $247 | 4;
         $422 = (($v$3$lcssa$i) + ($$sum$i2334)|0);
         HEAP32[$422>>2] = $421;
         $$sum1$i24 = (($rsize$3$lcssa$i) + ($247))|0;
         $423 = (($v$3$lcssa$i) + ($$sum1$i24)|0);
         HEAP32[$423>>2] = $rsize$3$lcssa$i;
         $424 = $rsize$3$lcssa$i >>> 3;
         $425 = ($rsize$3$lcssa$i>>>0)<(256);
         if ($425) {
          $426 = $424 << 1;
          $427 = ((143912 + ($426<<2)|0) + 40|0);
          $428 = HEAP32[143912>>2]|0;
          $429 = 1 << $424;
          $430 = $428 & $429;
          $431 = ($430|0)==(0);
          do {
           if ($431) {
            $432 = $428 | $429;
            HEAP32[143912>>2] = $432;
            $$sum14$pre$i = (($426) + 2)|0;
            $$pre$i25 = ((143912 + ($$sum14$pre$i<<2)|0) + 40|0);
            $$pre$phi$i26Z2D = $$pre$i25;$F5$0$i = $427;
           } else {
            $$sum17$i = (($426) + 2)|0;
            $433 = ((143912 + ($$sum17$i<<2)|0) + 40|0);
            $434 = HEAP32[$433>>2]|0;
            $435 = HEAP32[((143912 + 16|0))>>2]|0;
            $436 = ($434>>>0)<($435>>>0);
            if (!($436)) {
             $$pre$phi$i26Z2D = $433;$F5$0$i = $434;
             break;
            }
            _abort();
            // unreachable;
           }
          } while(0);
          HEAP32[$$pre$phi$i26Z2D>>2] = $349;
          $437 = (($F5$0$i) + 12|0);
          HEAP32[$437>>2] = $349;
          $$sum15$i = (($247) + 8)|0;
          $438 = (($v$3$lcssa$i) + ($$sum15$i)|0);
          HEAP32[$438>>2] = $F5$0$i;
          $$sum16$i = (($247) + 12)|0;
          $439 = (($v$3$lcssa$i) + ($$sum16$i)|0);
          HEAP32[$439>>2] = $427;
          break;
         }
         $440 = $rsize$3$lcssa$i >>> 8;
         $441 = ($440|0)==(0);
         if ($441) {
          $I7$0$i = 0;
         } else {
          $442 = ($rsize$3$lcssa$i>>>0)>(16777215);
          if ($442) {
           $I7$0$i = 31;
          } else {
           $443 = (($440) + 1048320)|0;
           $444 = $443 >>> 16;
           $445 = $444 & 8;
           $446 = $440 << $445;
           $447 = (($446) + 520192)|0;
           $448 = $447 >>> 16;
           $449 = $448 & 4;
           $450 = $449 | $445;
           $451 = $446 << $449;
           $452 = (($451) + 245760)|0;
           $453 = $452 >>> 16;
           $454 = $453 & 2;
           $455 = $450 | $454;
           $456 = (14 - ($455))|0;
           $457 = $451 << $454;
           $458 = $457 >>> 15;
           $459 = (($456) + ($458))|0;
           $460 = $459 << 1;
           $461 = (($459) + 7)|0;
           $462 = $rsize$3$lcssa$i >>> $461;
           $463 = $462 & 1;
           $464 = $463 | $460;
           $I7$0$i = $464;
          }
         }
         $465 = ((143912 + ($I7$0$i<<2)|0) + 304|0);
         $$sum2$i = (($247) + 28)|0;
         $466 = (($v$3$lcssa$i) + ($$sum2$i)|0);
         HEAP32[$466>>2] = $I7$0$i;
         $$sum3$i27 = (($247) + 16)|0;
         $467 = (($v$3$lcssa$i) + ($$sum3$i27)|0);
         $$sum4$i28 = (($247) + 20)|0;
         $468 = (($v$3$lcssa$i) + ($$sum4$i28)|0);
         HEAP32[$468>>2] = 0;
         HEAP32[$467>>2] = 0;
         $469 = HEAP32[((143912 + 4|0))>>2]|0;
         $470 = 1 << $I7$0$i;
         $471 = $469 & $470;
         $472 = ($471|0)==(0);
         if ($472) {
          $473 = $469 | $470;
          HEAP32[((143912 + 4|0))>>2] = $473;
          HEAP32[$465>>2] = $349;
          $$sum5$i = (($247) + 24)|0;
          $474 = (($v$3$lcssa$i) + ($$sum5$i)|0);
          HEAP32[$474>>2] = $465;
          $$sum6$i = (($247) + 12)|0;
          $475 = (($v$3$lcssa$i) + ($$sum6$i)|0);
          HEAP32[$475>>2] = $349;
          $$sum7$i = (($247) + 8)|0;
          $476 = (($v$3$lcssa$i) + ($$sum7$i)|0);
          HEAP32[$476>>2] = $349;
          break;
         }
         $477 = HEAP32[$465>>2]|0;
         $478 = ($I7$0$i|0)==(31);
         if ($478) {
          $486 = 0;
         } else {
          $479 = $I7$0$i >>> 1;
          $480 = (25 - ($479))|0;
          $486 = $480;
         }
         $481 = (($477) + 4|0);
         $482 = HEAP32[$481>>2]|0;
         $483 = $482 & -8;
         $484 = ($483|0)==($rsize$3$lcssa$i|0);
         L108: do {
          if ($484) {
           $T$0$lcssa$i = $477;
          } else {
           $485 = $rsize$3$lcssa$i << $486;
           $K12$025$i = $485;$T$024$i = $477;
           while(1) {
            $493 = $K12$025$i >>> 31;
            $494 = ((($T$024$i) + ($493<<2)|0) + 16|0);
            $489 = HEAP32[$494>>2]|0;
            $495 = ($489|0)==(0|0);
            if ($495) {
             break;
            }
            $487 = $K12$025$i << 1;
            $488 = (($489) + 4|0);
            $490 = HEAP32[$488>>2]|0;
            $491 = $490 & -8;
            $492 = ($491|0)==($rsize$3$lcssa$i|0);
            if ($492) {
             $T$0$lcssa$i = $489;
             break L108;
            } else {
             $K12$025$i = $487;$T$024$i = $489;
            }
           }
           $496 = HEAP32[((143912 + 16|0))>>2]|0;
           $497 = ($494>>>0)<($496>>>0);
           if ($497) {
            _abort();
            // unreachable;
           } else {
            HEAP32[$494>>2] = $349;
            $$sum11$i = (($247) + 24)|0;
            $498 = (($v$3$lcssa$i) + ($$sum11$i)|0);
            HEAP32[$498>>2] = $T$024$i;
            $$sum12$i = (($247) + 12)|0;
            $499 = (($v$3$lcssa$i) + ($$sum12$i)|0);
            HEAP32[$499>>2] = $349;
            $$sum13$i = (($247) + 8)|0;
            $500 = (($v$3$lcssa$i) + ($$sum13$i)|0);
            HEAP32[$500>>2] = $349;
            break L87;
           }
          }
         } while(0);
         $501 = (($T$0$lcssa$i) + 8|0);
         $502 = HEAP32[$501>>2]|0;
         $503 = HEAP32[((143912 + 16|0))>>2]|0;
         $504 = ($T$0$lcssa$i>>>0)<($503>>>0);
         if ($504) {
          _abort();
          // unreachable;
         }
         $505 = ($502>>>0)<($503>>>0);
         if ($505) {
          _abort();
          // unreachable;
         } else {
          $506 = (($502) + 12|0);
          HEAP32[$506>>2] = $349;
          HEAP32[$501>>2] = $349;
          $$sum8$i = (($247) + 8)|0;
          $507 = (($v$3$lcssa$i) + ($$sum8$i)|0);
          HEAP32[$507>>2] = $502;
          $$sum9$i = (($247) + 12)|0;
          $508 = (($v$3$lcssa$i) + ($$sum9$i)|0);
          HEAP32[$508>>2] = $T$0$lcssa$i;
          $$sum10$i = (($247) + 24)|0;
          $509 = (($v$3$lcssa$i) + ($$sum10$i)|0);
          HEAP32[$509>>2] = 0;
          break;
         }
        }
       } while(0);
       $510 = (($v$3$lcssa$i) + 8|0);
       $mem$0 = $510;
       STACKTOP = sp;return ($mem$0|0);
      } else {
       $nb$0 = $247;
      }
     }
    }
   }
  }
 } while(0);
 $511 = HEAP32[((143912 + 8|0))>>2]|0;
 $512 = ($nb$0>>>0)>($511>>>0);
 if (!($512)) {
  $513 = (($511) - ($nb$0))|0;
  $514 = HEAP32[((143912 + 20|0))>>2]|0;
  $515 = ($513>>>0)>(15);
  if ($515) {
   $516 = (($514) + ($nb$0)|0);
   HEAP32[((143912 + 20|0))>>2] = $516;
   HEAP32[((143912 + 8|0))>>2] = $513;
   $517 = $513 | 1;
   $$sum2 = (($nb$0) + 4)|0;
   $518 = (($514) + ($$sum2)|0);
   HEAP32[$518>>2] = $517;
   $519 = (($514) + ($511)|0);
   HEAP32[$519>>2] = $513;
   $520 = $nb$0 | 3;
   $521 = (($514) + 4|0);
   HEAP32[$521>>2] = $520;
  } else {
   HEAP32[((143912 + 8|0))>>2] = 0;
   HEAP32[((143912 + 20|0))>>2] = 0;
   $522 = $511 | 3;
   $523 = (($514) + 4|0);
   HEAP32[$523>>2] = $522;
   $$sum1 = (($511) + 4)|0;
   $524 = (($514) + ($$sum1)|0);
   $525 = HEAP32[$524>>2]|0;
   $526 = $525 | 1;
   HEAP32[$524>>2] = $526;
  }
  $527 = (($514) + 8|0);
  $mem$0 = $527;
  STACKTOP = sp;return ($mem$0|0);
 }
 $528 = HEAP32[((143912 + 12|0))>>2]|0;
 $529 = ($nb$0>>>0)<($528>>>0);
 if ($529) {
  $530 = (($528) - ($nb$0))|0;
  HEAP32[((143912 + 12|0))>>2] = $530;
  $531 = HEAP32[((143912 + 24|0))>>2]|0;
  $532 = (($531) + ($nb$0)|0);
  HEAP32[((143912 + 24|0))>>2] = $532;
  $533 = $530 | 1;
  $$sum = (($nb$0) + 4)|0;
  $534 = (($531) + ($$sum)|0);
  HEAP32[$534>>2] = $533;
  $535 = $nb$0 | 3;
  $536 = (($531) + 4|0);
  HEAP32[$536>>2] = $535;
  $537 = (($531) + 8|0);
  $mem$0 = $537;
  STACKTOP = sp;return ($mem$0|0);
 }
 $538 = HEAP32[144384>>2]|0;
 $539 = ($538|0)==(0);
 do {
  if ($539) {
   $540 = (_sysconf(30)|0);
   $541 = (($540) + -1)|0;
   $542 = $541 & $540;
   $543 = ($542|0)==(0);
   if ($543) {
    HEAP32[((144384 + 8|0))>>2] = $540;
    HEAP32[((144384 + 4|0))>>2] = $540;
    HEAP32[((144384 + 12|0))>>2] = -1;
    HEAP32[((144384 + 16|0))>>2] = -1;
    HEAP32[((144384 + 20|0))>>2] = 0;
    HEAP32[((143912 + 444|0))>>2] = 0;
    $544 = (_time((0|0))|0);
    $545 = $544 & -16;
    $546 = $545 ^ 1431655768;
    HEAP32[144384>>2] = $546;
    break;
   } else {
    _abort();
    // unreachable;
   }
  }
 } while(0);
 $547 = (($nb$0) + 48)|0;
 $548 = HEAP32[((144384 + 8|0))>>2]|0;
 $549 = (($nb$0) + 47)|0;
 $550 = (($548) + ($549))|0;
 $551 = (0 - ($548))|0;
 $552 = $550 & $551;
 $553 = ($552>>>0)>($nb$0>>>0);
 if (!($553)) {
  $mem$0 = 0;
  STACKTOP = sp;return ($mem$0|0);
 }
 $554 = HEAP32[((143912 + 440|0))>>2]|0;
 $555 = ($554|0)==(0);
 if (!($555)) {
  $556 = HEAP32[((143912 + 432|0))>>2]|0;
  $557 = (($556) + ($552))|0;
  $558 = ($557>>>0)<=($556>>>0);
  $559 = ($557>>>0)>($554>>>0);
  $or$cond1$i = $558 | $559;
  if ($or$cond1$i) {
   $mem$0 = 0;
   STACKTOP = sp;return ($mem$0|0);
  }
 }
 $560 = HEAP32[((143912 + 444|0))>>2]|0;
 $561 = $560 & 4;
 $562 = ($561|0)==(0);
 L269: do {
  if ($562) {
   $563 = HEAP32[((143912 + 24|0))>>2]|0;
   $564 = ($563|0)==(0|0);
   L271: do {
    if ($564) {
     label = 182;
    } else {
     $sp$0$i$i = ((143912 + 448|0));
     while(1) {
      $565 = HEAP32[$sp$0$i$i>>2]|0;
      $566 = ($565>>>0)>($563>>>0);
      if (!($566)) {
       $567 = (($sp$0$i$i) + 4|0);
       $568 = HEAP32[$567>>2]|0;
       $569 = (($565) + ($568)|0);
       $570 = ($569>>>0)>($563>>>0);
       if ($570) {
        break;
       }
      }
      $571 = (($sp$0$i$i) + 8|0);
      $572 = HEAP32[$571>>2]|0;
      $573 = ($572|0)==(0|0);
      if ($573) {
       label = 182;
       break L271;
      } else {
       $sp$0$i$i = $572;
      }
     }
     $574 = ($sp$0$i$i|0)==(0|0);
     if ($574) {
      label = 182;
     } else {
      $597 = HEAP32[((143912 + 12|0))>>2]|0;
      $598 = (($550) - ($597))|0;
      $599 = $598 & $551;
      $600 = ($599>>>0)<(2147483647);
      if ($600) {
       $601 = (_sbrk(($599|0))|0);
       $602 = HEAP32[$sp$0$i$i>>2]|0;
       $603 = HEAP32[$567>>2]|0;
       $604 = (($602) + ($603)|0);
       $605 = ($601|0)==($604|0);
       $$3$i = $605 ? $599 : 0;
       $$4$i = $605 ? $601 : (-1);
       $br$0$i = $601;$ssize$1$i = $599;$tbase$0$i = $$4$i;$tsize$0$i = $$3$i;
       label = 191;
      } else {
       $tsize$0323841$i = 0;
      }
     }
    }
   } while(0);
   do {
    if ((label|0) == 182) {
     $575 = (_sbrk(0)|0);
     $576 = ($575|0)==((-1)|0);
     if ($576) {
      $tsize$0323841$i = 0;
     } else {
      $577 = $575;
      $578 = HEAP32[((144384 + 4|0))>>2]|0;
      $579 = (($578) + -1)|0;
      $580 = $579 & $577;
      $581 = ($580|0)==(0);
      if ($581) {
       $ssize$0$i = $552;
      } else {
       $582 = (($579) + ($577))|0;
       $583 = (0 - ($578))|0;
       $584 = $582 & $583;
       $585 = (($552) - ($577))|0;
       $586 = (($585) + ($584))|0;
       $ssize$0$i = $586;
      }
      $587 = HEAP32[((143912 + 432|0))>>2]|0;
      $588 = (($587) + ($ssize$0$i))|0;
      $589 = ($ssize$0$i>>>0)>($nb$0>>>0);
      $590 = ($ssize$0$i>>>0)<(2147483647);
      $or$cond$i29 = $589 & $590;
      if ($or$cond$i29) {
       $591 = HEAP32[((143912 + 440|0))>>2]|0;
       $592 = ($591|0)==(0);
       if (!($592)) {
        $593 = ($588>>>0)<=($587>>>0);
        $594 = ($588>>>0)>($591>>>0);
        $or$cond2$i = $593 | $594;
        if ($or$cond2$i) {
         $tsize$0323841$i = 0;
         break;
        }
       }
       $595 = (_sbrk(($ssize$0$i|0))|0);
       $596 = ($595|0)==($575|0);
       $ssize$0$$i = $596 ? $ssize$0$i : 0;
       $$$i = $596 ? $575 : (-1);
       $br$0$i = $595;$ssize$1$i = $ssize$0$i;$tbase$0$i = $$$i;$tsize$0$i = $ssize$0$$i;
       label = 191;
      } else {
       $tsize$0323841$i = 0;
      }
     }
    }
   } while(0);
   L291: do {
    if ((label|0) == 191) {
     $606 = (0 - ($ssize$1$i))|0;
     $607 = ($tbase$0$i|0)==((-1)|0);
     if (!($607)) {
      $tbase$247$i = $tbase$0$i;$tsize$246$i = $tsize$0$i;
      label = 202;
      break L269;
     }
     $608 = ($br$0$i|0)!=((-1)|0);
     $609 = ($ssize$1$i>>>0)<(2147483647);
     $or$cond5$i = $608 & $609;
     $610 = ($ssize$1$i>>>0)<($547>>>0);
     $or$cond6$i = $or$cond5$i & $610;
     do {
      if ($or$cond6$i) {
       $611 = HEAP32[((144384 + 8|0))>>2]|0;
       $612 = (($549) - ($ssize$1$i))|0;
       $613 = (($612) + ($611))|0;
       $614 = (0 - ($611))|0;
       $615 = $613 & $614;
       $616 = ($615>>>0)<(2147483647);
       if ($616) {
        $617 = (_sbrk(($615|0))|0);
        $618 = ($617|0)==((-1)|0);
        if ($618) {
         (_sbrk(($606|0))|0);
         $tsize$0323841$i = $tsize$0$i;
         break L291;
        } else {
         $619 = (($615) + ($ssize$1$i))|0;
         $ssize$2$i = $619;
         break;
        }
       } else {
        $ssize$2$i = $ssize$1$i;
       }
      } else {
       $ssize$2$i = $ssize$1$i;
      }
     } while(0);
     $620 = ($br$0$i|0)==((-1)|0);
     if ($620) {
      $tsize$0323841$i = $tsize$0$i;
     } else {
      $tbase$247$i = $br$0$i;$tsize$246$i = $ssize$2$i;
      label = 202;
      break L269;
     }
    }
   } while(0);
   $621 = HEAP32[((143912 + 444|0))>>2]|0;
   $622 = $621 | 4;
   HEAP32[((143912 + 444|0))>>2] = $622;
   $tsize$1$i = $tsize$0323841$i;
   label = 199;
  } else {
   $tsize$1$i = 0;
   label = 199;
  }
 } while(0);
 if ((label|0) == 199) {
  $623 = ($552>>>0)<(2147483647);
  if ($623) {
   $624 = (_sbrk(($552|0))|0);
   $625 = (_sbrk(0)|0);
   $notlhs$i = ($624|0)!=((-1)|0);
   $notrhs$i = ($625|0)!=((-1)|0);
   $or$cond8$not$i = $notrhs$i & $notlhs$i;
   $626 = ($624>>>0)<($625>>>0);
   $or$cond9$i = $or$cond8$not$i & $626;
   if ($or$cond9$i) {
    $627 = $625;
    $628 = $624;
    $629 = (($627) - ($628))|0;
    $630 = (($nb$0) + 40)|0;
    $631 = ($629>>>0)>($630>>>0);
    $$tsize$1$i = $631 ? $629 : $tsize$1$i;
    if ($631) {
     $tbase$247$i = $624;$tsize$246$i = $$tsize$1$i;
     label = 202;
    }
   }
  }
 }
 if ((label|0) == 202) {
  $632 = HEAP32[((143912 + 432|0))>>2]|0;
  $633 = (($632) + ($tsize$246$i))|0;
  HEAP32[((143912 + 432|0))>>2] = $633;
  $634 = HEAP32[((143912 + 436|0))>>2]|0;
  $635 = ($633>>>0)>($634>>>0);
  if ($635) {
   HEAP32[((143912 + 436|0))>>2] = $633;
  }
  $636 = HEAP32[((143912 + 24|0))>>2]|0;
  $637 = ($636|0)==(0|0);
  L311: do {
   if ($637) {
    $638 = HEAP32[((143912 + 16|0))>>2]|0;
    $639 = ($638|0)==(0|0);
    $640 = ($tbase$247$i>>>0)<($638>>>0);
    $or$cond10$i = $639 | $640;
    if ($or$cond10$i) {
     HEAP32[((143912 + 16|0))>>2] = $tbase$247$i;
    }
    HEAP32[((143912 + 448|0))>>2] = $tbase$247$i;
    HEAP32[((143912 + 452|0))>>2] = $tsize$246$i;
    HEAP32[((143912 + 460|0))>>2] = 0;
    $641 = HEAP32[144384>>2]|0;
    HEAP32[((143912 + 36|0))>>2] = $641;
    HEAP32[((143912 + 32|0))>>2] = -1;
    $i$02$i$i = 0;
    while(1) {
     $642 = $i$02$i$i << 1;
     $643 = ((143912 + ($642<<2)|0) + 40|0);
     $$sum$i$i = (($642) + 3)|0;
     $644 = ((143912 + ($$sum$i$i<<2)|0) + 40|0);
     HEAP32[$644>>2] = $643;
     $$sum1$i$i = (($642) + 2)|0;
     $645 = ((143912 + ($$sum1$i$i<<2)|0) + 40|0);
     HEAP32[$645>>2] = $643;
     $646 = (($i$02$i$i) + 1)|0;
     $exitcond$i$i = ($646|0)==(32);
     if ($exitcond$i$i) {
      break;
     } else {
      $i$02$i$i = $646;
     }
    }
    $647 = (($tsize$246$i) + -40)|0;
    $648 = (($tbase$247$i) + 8|0);
    $649 = $648;
    $650 = $649 & 7;
    $651 = ($650|0)==(0);
    if ($651) {
     $655 = 0;
    } else {
     $652 = (0 - ($649))|0;
     $653 = $652 & 7;
     $655 = $653;
    }
    $654 = (($tbase$247$i) + ($655)|0);
    $656 = (($647) - ($655))|0;
    HEAP32[((143912 + 24|0))>>2] = $654;
    HEAP32[((143912 + 12|0))>>2] = $656;
    $657 = $656 | 1;
    $$sum$i14$i = (($655) + 4)|0;
    $658 = (($tbase$247$i) + ($$sum$i14$i)|0);
    HEAP32[$658>>2] = $657;
    $$sum2$i$i = (($tsize$246$i) + -36)|0;
    $659 = (($tbase$247$i) + ($$sum2$i$i)|0);
    HEAP32[$659>>2] = 40;
    $660 = HEAP32[((144384 + 16|0))>>2]|0;
    HEAP32[((143912 + 28|0))>>2] = $660;
   } else {
    $sp$075$i = ((143912 + 448|0));
    while(1) {
     $661 = HEAP32[$sp$075$i>>2]|0;
     $662 = (($sp$075$i) + 4|0);
     $663 = HEAP32[$662>>2]|0;
     $664 = (($661) + ($663)|0);
     $665 = ($tbase$247$i|0)==($664|0);
     if ($665) {
      label = 214;
      break;
     }
     $666 = (($sp$075$i) + 8|0);
     $667 = HEAP32[$666>>2]|0;
     $668 = ($667|0)==(0|0);
     if ($668) {
      break;
     } else {
      $sp$075$i = $667;
     }
    }
    if ((label|0) == 214) {
     $669 = (($sp$075$i) + 12|0);
     $670 = HEAP32[$669>>2]|0;
     $671 = $670 & 8;
     $672 = ($671|0)==(0);
     if ($672) {
      $673 = ($636>>>0)>=($661>>>0);
      $674 = ($636>>>0)<($tbase$247$i>>>0);
      $or$cond49$i = $673 & $674;
      if ($or$cond49$i) {
       $675 = (($663) + ($tsize$246$i))|0;
       HEAP32[$662>>2] = $675;
       $676 = HEAP32[((143912 + 12|0))>>2]|0;
       $677 = (($676) + ($tsize$246$i))|0;
       $678 = (($636) + 8|0);
       $679 = $678;
       $680 = $679 & 7;
       $681 = ($680|0)==(0);
       if ($681) {
        $685 = 0;
       } else {
        $682 = (0 - ($679))|0;
        $683 = $682 & 7;
        $685 = $683;
       }
       $684 = (($636) + ($685)|0);
       $686 = (($677) - ($685))|0;
       HEAP32[((143912 + 24|0))>>2] = $684;
       HEAP32[((143912 + 12|0))>>2] = $686;
       $687 = $686 | 1;
       $$sum$i18$i = (($685) + 4)|0;
       $688 = (($636) + ($$sum$i18$i)|0);
       HEAP32[$688>>2] = $687;
       $$sum2$i19$i = (($677) + 4)|0;
       $689 = (($636) + ($$sum2$i19$i)|0);
       HEAP32[$689>>2] = 40;
       $690 = HEAP32[((144384 + 16|0))>>2]|0;
       HEAP32[((143912 + 28|0))>>2] = $690;
       break;
      }
     }
    }
    $691 = HEAP32[((143912 + 16|0))>>2]|0;
    $692 = ($tbase$247$i>>>0)<($691>>>0);
    if ($692) {
     HEAP32[((143912 + 16|0))>>2] = $tbase$247$i;
    }
    $693 = (($tbase$247$i) + ($tsize$246$i)|0);
    $sp$168$i = ((143912 + 448|0));
    while(1) {
     $694 = HEAP32[$sp$168$i>>2]|0;
     $695 = ($694|0)==($693|0);
     if ($695) {
      label = 224;
      break;
     }
     $696 = (($sp$168$i) + 8|0);
     $697 = HEAP32[$696>>2]|0;
     $698 = ($697|0)==(0|0);
     if ($698) {
      break;
     } else {
      $sp$168$i = $697;
     }
    }
    if ((label|0) == 224) {
     $699 = (($sp$168$i) + 12|0);
     $700 = HEAP32[$699>>2]|0;
     $701 = $700 & 8;
     $702 = ($701|0)==(0);
     if ($702) {
      HEAP32[$sp$168$i>>2] = $tbase$247$i;
      $703 = (($sp$168$i) + 4|0);
      $704 = HEAP32[$703>>2]|0;
      $705 = (($704) + ($tsize$246$i))|0;
      HEAP32[$703>>2] = $705;
      $706 = (($tbase$247$i) + 8|0);
      $707 = $706;
      $708 = $707 & 7;
      $709 = ($708|0)==(0);
      if ($709) {
       $713 = 0;
      } else {
       $710 = (0 - ($707))|0;
       $711 = $710 & 7;
       $713 = $711;
      }
      $712 = (($tbase$247$i) + ($713)|0);
      $$sum107$i = (($tsize$246$i) + 8)|0;
      $714 = (($tbase$247$i) + ($$sum107$i)|0);
      $715 = $714;
      $716 = $715 & 7;
      $717 = ($716|0)==(0);
      if ($717) {
       $720 = 0;
      } else {
       $718 = (0 - ($715))|0;
       $719 = $718 & 7;
       $720 = $719;
      }
      $$sum108$i = (($720) + ($tsize$246$i))|0;
      $721 = (($tbase$247$i) + ($$sum108$i)|0);
      $722 = $721;
      $723 = $712;
      $724 = (($722) - ($723))|0;
      $$sum$i21$i = (($713) + ($nb$0))|0;
      $725 = (($tbase$247$i) + ($$sum$i21$i)|0);
      $726 = (($724) - ($nb$0))|0;
      $727 = $nb$0 | 3;
      $$sum1$i22$i = (($713) + 4)|0;
      $728 = (($tbase$247$i) + ($$sum1$i22$i)|0);
      HEAP32[$728>>2] = $727;
      $729 = HEAP32[((143912 + 24|0))>>2]|0;
      $730 = ($721|0)==($729|0);
      L338: do {
       if ($730) {
        $731 = HEAP32[((143912 + 12|0))>>2]|0;
        $732 = (($731) + ($726))|0;
        HEAP32[((143912 + 12|0))>>2] = $732;
        HEAP32[((143912 + 24|0))>>2] = $725;
        $733 = $732 | 1;
        $$sum42$i$i = (($$sum$i21$i) + 4)|0;
        $734 = (($tbase$247$i) + ($$sum42$i$i)|0);
        HEAP32[$734>>2] = $733;
       } else {
        $735 = HEAP32[((143912 + 20|0))>>2]|0;
        $736 = ($721|0)==($735|0);
        if ($736) {
         $737 = HEAP32[((143912 + 8|0))>>2]|0;
         $738 = (($737) + ($726))|0;
         HEAP32[((143912 + 8|0))>>2] = $738;
         HEAP32[((143912 + 20|0))>>2] = $725;
         $739 = $738 | 1;
         $$sum40$i$i = (($$sum$i21$i) + 4)|0;
         $740 = (($tbase$247$i) + ($$sum40$i$i)|0);
         HEAP32[$740>>2] = $739;
         $$sum41$i$i = (($738) + ($$sum$i21$i))|0;
         $741 = (($tbase$247$i) + ($$sum41$i$i)|0);
         HEAP32[$741>>2] = $738;
         break;
        }
        $$sum2$i23$i = (($tsize$246$i) + 4)|0;
        $$sum109$i = (($$sum2$i23$i) + ($720))|0;
        $742 = (($tbase$247$i) + ($$sum109$i)|0);
        $743 = HEAP32[$742>>2]|0;
        $744 = $743 & 3;
        $745 = ($744|0)==(1);
        if ($745) {
         $746 = $743 & -8;
         $747 = $743 >>> 3;
         $748 = ($743>>>0)<(256);
         L346: do {
          if ($748) {
           $$sum3738$i$i = $720 | 8;
           $$sum119$i = (($$sum3738$i$i) + ($tsize$246$i))|0;
           $749 = (($tbase$247$i) + ($$sum119$i)|0);
           $750 = HEAP32[$749>>2]|0;
           $$sum39$i$i = (($tsize$246$i) + 12)|0;
           $$sum120$i = (($$sum39$i$i) + ($720))|0;
           $751 = (($tbase$247$i) + ($$sum120$i)|0);
           $752 = HEAP32[$751>>2]|0;
           $753 = $747 << 1;
           $754 = ((143912 + ($753<<2)|0) + 40|0);
           $755 = ($750|0)==($754|0);
           do {
            if (!($755)) {
             $756 = HEAP32[((143912 + 16|0))>>2]|0;
             $757 = ($750>>>0)<($756>>>0);
             if ($757) {
              _abort();
              // unreachable;
             }
             $758 = (($750) + 12|0);
             $759 = HEAP32[$758>>2]|0;
             $760 = ($759|0)==($721|0);
             if ($760) {
              break;
             }
             _abort();
             // unreachable;
            }
           } while(0);
           $761 = ($752|0)==($750|0);
           if ($761) {
            $762 = 1 << $747;
            $763 = $762 ^ -1;
            $764 = HEAP32[143912>>2]|0;
            $765 = $764 & $763;
            HEAP32[143912>>2] = $765;
            break;
           }
           $766 = ($752|0)==($754|0);
           do {
            if ($766) {
             $$pre57$i$i = (($752) + 8|0);
             $$pre$phi58$i$iZ2D = $$pre57$i$i;
            } else {
             $767 = HEAP32[((143912 + 16|0))>>2]|0;
             $768 = ($752>>>0)<($767>>>0);
             if ($768) {
              _abort();
              // unreachable;
             }
             $769 = (($752) + 8|0);
             $770 = HEAP32[$769>>2]|0;
             $771 = ($770|0)==($721|0);
             if ($771) {
              $$pre$phi58$i$iZ2D = $769;
              break;
             }
             _abort();
             // unreachable;
            }
           } while(0);
           $772 = (($750) + 12|0);
           HEAP32[$772>>2] = $752;
           HEAP32[$$pre$phi58$i$iZ2D>>2] = $750;
          } else {
           $$sum34$i$i = $720 | 24;
           $$sum110$i = (($$sum34$i$i) + ($tsize$246$i))|0;
           $773 = (($tbase$247$i) + ($$sum110$i)|0);
           $774 = HEAP32[$773>>2]|0;
           $$sum5$i$i = (($tsize$246$i) + 12)|0;
           $$sum111$i = (($$sum5$i$i) + ($720))|0;
           $775 = (($tbase$247$i) + ($$sum111$i)|0);
           $776 = HEAP32[$775>>2]|0;
           $777 = ($776|0)==($721|0);
           do {
            if ($777) {
             $$sum67$i$i = $720 | 16;
             $$sum117$i = (($$sum2$i23$i) + ($$sum67$i$i))|0;
             $788 = (($tbase$247$i) + ($$sum117$i)|0);
             $789 = HEAP32[$788>>2]|0;
             $790 = ($789|0)==(0|0);
             if ($790) {
              $$sum118$i = (($$sum67$i$i) + ($tsize$246$i))|0;
              $791 = (($tbase$247$i) + ($$sum118$i)|0);
              $792 = HEAP32[$791>>2]|0;
              $793 = ($792|0)==(0|0);
              if ($793) {
               $R$1$i$i = 0;
               break;
              } else {
               $R$0$i$i = $792;$RP$0$i$i = $791;
              }
             } else {
              $R$0$i$i = $789;$RP$0$i$i = $788;
             }
             while(1) {
              $794 = (($R$0$i$i) + 20|0);
              $795 = HEAP32[$794>>2]|0;
              $796 = ($795|0)==(0|0);
              if (!($796)) {
               $R$0$i$i = $795;$RP$0$i$i = $794;
               continue;
              }
              $797 = (($R$0$i$i) + 16|0);
              $798 = HEAP32[$797>>2]|0;
              $799 = ($798|0)==(0|0);
              if ($799) {
               break;
              } else {
               $R$0$i$i = $798;$RP$0$i$i = $797;
              }
             }
             $800 = HEAP32[((143912 + 16|0))>>2]|0;
             $801 = ($RP$0$i$i>>>0)<($800>>>0);
             if ($801) {
              _abort();
              // unreachable;
             } else {
              HEAP32[$RP$0$i$i>>2] = 0;
              $R$1$i$i = $R$0$i$i;
              break;
             }
            } else {
             $$sum3536$i$i = $720 | 8;
             $$sum112$i = (($$sum3536$i$i) + ($tsize$246$i))|0;
             $778 = (($tbase$247$i) + ($$sum112$i)|0);
             $779 = HEAP32[$778>>2]|0;
             $780 = HEAP32[((143912 + 16|0))>>2]|0;
             $781 = ($779>>>0)<($780>>>0);
             if ($781) {
              _abort();
              // unreachable;
             }
             $782 = (($779) + 12|0);
             $783 = HEAP32[$782>>2]|0;
             $784 = ($783|0)==($721|0);
             if (!($784)) {
              _abort();
              // unreachable;
             }
             $785 = (($776) + 8|0);
             $786 = HEAP32[$785>>2]|0;
             $787 = ($786|0)==($721|0);
             if ($787) {
              HEAP32[$782>>2] = $776;
              HEAP32[$785>>2] = $779;
              $R$1$i$i = $776;
              break;
             } else {
              _abort();
              // unreachable;
             }
            }
           } while(0);
           $802 = ($774|0)==(0|0);
           if ($802) {
            break;
           }
           $$sum30$i$i = (($tsize$246$i) + 28)|0;
           $$sum113$i = (($$sum30$i$i) + ($720))|0;
           $803 = (($tbase$247$i) + ($$sum113$i)|0);
           $804 = HEAP32[$803>>2]|0;
           $805 = ((143912 + ($804<<2)|0) + 304|0);
           $806 = HEAP32[$805>>2]|0;
           $807 = ($721|0)==($806|0);
           do {
            if ($807) {
             HEAP32[$805>>2] = $R$1$i$i;
             $cond$i$i = ($R$1$i$i|0)==(0|0);
             if (!($cond$i$i)) {
              break;
             }
             $808 = 1 << $804;
             $809 = $808 ^ -1;
             $810 = HEAP32[((143912 + 4|0))>>2]|0;
             $811 = $810 & $809;
             HEAP32[((143912 + 4|0))>>2] = $811;
             break L346;
            } else {
             $812 = HEAP32[((143912 + 16|0))>>2]|0;
             $813 = ($774>>>0)<($812>>>0);
             if ($813) {
              _abort();
              // unreachable;
             }
             $814 = (($774) + 16|0);
             $815 = HEAP32[$814>>2]|0;
             $816 = ($815|0)==($721|0);
             if ($816) {
              HEAP32[$814>>2] = $R$1$i$i;
             } else {
              $817 = (($774) + 20|0);
              HEAP32[$817>>2] = $R$1$i$i;
             }
             $818 = ($R$1$i$i|0)==(0|0);
             if ($818) {
              break L346;
             }
            }
           } while(0);
           $819 = HEAP32[((143912 + 16|0))>>2]|0;
           $820 = ($R$1$i$i>>>0)<($819>>>0);
           if ($820) {
            _abort();
            // unreachable;
           }
           $821 = (($R$1$i$i) + 24|0);
           HEAP32[$821>>2] = $774;
           $$sum3132$i$i = $720 | 16;
           $$sum114$i = (($$sum3132$i$i) + ($tsize$246$i))|0;
           $822 = (($tbase$247$i) + ($$sum114$i)|0);
           $823 = HEAP32[$822>>2]|0;
           $824 = ($823|0)==(0|0);
           do {
            if (!($824)) {
             $825 = HEAP32[((143912 + 16|0))>>2]|0;
             $826 = ($823>>>0)<($825>>>0);
             if ($826) {
              _abort();
              // unreachable;
             } else {
              $827 = (($R$1$i$i) + 16|0);
              HEAP32[$827>>2] = $823;
              $828 = (($823) + 24|0);
              HEAP32[$828>>2] = $R$1$i$i;
              break;
             }
            }
           } while(0);
           $$sum115$i = (($$sum2$i23$i) + ($$sum3132$i$i))|0;
           $829 = (($tbase$247$i) + ($$sum115$i)|0);
           $830 = HEAP32[$829>>2]|0;
           $831 = ($830|0)==(0|0);
           if ($831) {
            break;
           }
           $832 = HEAP32[((143912 + 16|0))>>2]|0;
           $833 = ($830>>>0)<($832>>>0);
           if ($833) {
            _abort();
            // unreachable;
           } else {
            $834 = (($R$1$i$i) + 20|0);
            HEAP32[$834>>2] = $830;
            $835 = (($830) + 24|0);
            HEAP32[$835>>2] = $R$1$i$i;
            break;
           }
          }
         } while(0);
         $$sum9$i$i = $746 | $720;
         $$sum116$i = (($$sum9$i$i) + ($tsize$246$i))|0;
         $836 = (($tbase$247$i) + ($$sum116$i)|0);
         $837 = (($746) + ($726))|0;
         $oldfirst$0$i$i = $836;$qsize$0$i$i = $837;
        } else {
         $oldfirst$0$i$i = $721;$qsize$0$i$i = $726;
        }
        $838 = (($oldfirst$0$i$i) + 4|0);
        $839 = HEAP32[$838>>2]|0;
        $840 = $839 & -2;
        HEAP32[$838>>2] = $840;
        $841 = $qsize$0$i$i | 1;
        $$sum10$i$i = (($$sum$i21$i) + 4)|0;
        $842 = (($tbase$247$i) + ($$sum10$i$i)|0);
        HEAP32[$842>>2] = $841;
        $$sum11$i24$i = (($qsize$0$i$i) + ($$sum$i21$i))|0;
        $843 = (($tbase$247$i) + ($$sum11$i24$i)|0);
        HEAP32[$843>>2] = $qsize$0$i$i;
        $844 = $qsize$0$i$i >>> 3;
        $845 = ($qsize$0$i$i>>>0)<(256);
        if ($845) {
         $846 = $844 << 1;
         $847 = ((143912 + ($846<<2)|0) + 40|0);
         $848 = HEAP32[143912>>2]|0;
         $849 = 1 << $844;
         $850 = $848 & $849;
         $851 = ($850|0)==(0);
         do {
          if ($851) {
           $852 = $848 | $849;
           HEAP32[143912>>2] = $852;
           $$sum26$pre$i$i = (($846) + 2)|0;
           $$pre$i25$i = ((143912 + ($$sum26$pre$i$i<<2)|0) + 40|0);
           $$pre$phi$i26$iZ2D = $$pre$i25$i;$F4$0$i$i = $847;
          } else {
           $$sum29$i$i = (($846) + 2)|0;
           $853 = ((143912 + ($$sum29$i$i<<2)|0) + 40|0);
           $854 = HEAP32[$853>>2]|0;
           $855 = HEAP32[((143912 + 16|0))>>2]|0;
           $856 = ($854>>>0)<($855>>>0);
           if (!($856)) {
            $$pre$phi$i26$iZ2D = $853;$F4$0$i$i = $854;
            break;
           }
           _abort();
           // unreachable;
          }
         } while(0);
         HEAP32[$$pre$phi$i26$iZ2D>>2] = $725;
         $857 = (($F4$0$i$i) + 12|0);
         HEAP32[$857>>2] = $725;
         $$sum27$i$i = (($$sum$i21$i) + 8)|0;
         $858 = (($tbase$247$i) + ($$sum27$i$i)|0);
         HEAP32[$858>>2] = $F4$0$i$i;
         $$sum28$i$i = (($$sum$i21$i) + 12)|0;
         $859 = (($tbase$247$i) + ($$sum28$i$i)|0);
         HEAP32[$859>>2] = $847;
         break;
        }
        $860 = $qsize$0$i$i >>> 8;
        $861 = ($860|0)==(0);
        do {
         if ($861) {
          $I7$0$i$i = 0;
         } else {
          $862 = ($qsize$0$i$i>>>0)>(16777215);
          if ($862) {
           $I7$0$i$i = 31;
           break;
          }
          $863 = (($860) + 1048320)|0;
          $864 = $863 >>> 16;
          $865 = $864 & 8;
          $866 = $860 << $865;
          $867 = (($866) + 520192)|0;
          $868 = $867 >>> 16;
          $869 = $868 & 4;
          $870 = $869 | $865;
          $871 = $866 << $869;
          $872 = (($871) + 245760)|0;
          $873 = $872 >>> 16;
          $874 = $873 & 2;
          $875 = $870 | $874;
          $876 = (14 - ($875))|0;
          $877 = $871 << $874;
          $878 = $877 >>> 15;
          $879 = (($876) + ($878))|0;
          $880 = $879 << 1;
          $881 = (($879) + 7)|0;
          $882 = $qsize$0$i$i >>> $881;
          $883 = $882 & 1;
          $884 = $883 | $880;
          $I7$0$i$i = $884;
         }
        } while(0);
        $885 = ((143912 + ($I7$0$i$i<<2)|0) + 304|0);
        $$sum12$i$i = (($$sum$i21$i) + 28)|0;
        $886 = (($tbase$247$i) + ($$sum12$i$i)|0);
        HEAP32[$886>>2] = $I7$0$i$i;
        $$sum13$i$i = (($$sum$i21$i) + 16)|0;
        $887 = (($tbase$247$i) + ($$sum13$i$i)|0);
        $$sum14$i$i = (($$sum$i21$i) + 20)|0;
        $888 = (($tbase$247$i) + ($$sum14$i$i)|0);
        HEAP32[$888>>2] = 0;
        HEAP32[$887>>2] = 0;
        $889 = HEAP32[((143912 + 4|0))>>2]|0;
        $890 = 1 << $I7$0$i$i;
        $891 = $889 & $890;
        $892 = ($891|0)==(0);
        if ($892) {
         $893 = $889 | $890;
         HEAP32[((143912 + 4|0))>>2] = $893;
         HEAP32[$885>>2] = $725;
         $$sum15$i$i = (($$sum$i21$i) + 24)|0;
         $894 = (($tbase$247$i) + ($$sum15$i$i)|0);
         HEAP32[$894>>2] = $885;
         $$sum16$i$i = (($$sum$i21$i) + 12)|0;
         $895 = (($tbase$247$i) + ($$sum16$i$i)|0);
         HEAP32[$895>>2] = $725;
         $$sum17$i$i = (($$sum$i21$i) + 8)|0;
         $896 = (($tbase$247$i) + ($$sum17$i$i)|0);
         HEAP32[$896>>2] = $725;
         break;
        }
        $897 = HEAP32[$885>>2]|0;
        $898 = ($I7$0$i$i|0)==(31);
        if ($898) {
         $906 = 0;
        } else {
         $899 = $I7$0$i$i >>> 1;
         $900 = (25 - ($899))|0;
         $906 = $900;
        }
        $901 = (($897) + 4|0);
        $902 = HEAP32[$901>>2]|0;
        $903 = $902 & -8;
        $904 = ($903|0)==($qsize$0$i$i|0);
        L435: do {
         if ($904) {
          $T$0$lcssa$i28$i = $897;
         } else {
          $905 = $qsize$0$i$i << $906;
          $K8$052$i$i = $905;$T$051$i$i = $897;
          while(1) {
           $913 = $K8$052$i$i >>> 31;
           $914 = ((($T$051$i$i) + ($913<<2)|0) + 16|0);
           $909 = HEAP32[$914>>2]|0;
           $915 = ($909|0)==(0|0);
           if ($915) {
            break;
           }
           $907 = $K8$052$i$i << 1;
           $908 = (($909) + 4|0);
           $910 = HEAP32[$908>>2]|0;
           $911 = $910 & -8;
           $912 = ($911|0)==($qsize$0$i$i|0);
           if ($912) {
            $T$0$lcssa$i28$i = $909;
            break L435;
           } else {
            $K8$052$i$i = $907;$T$051$i$i = $909;
           }
          }
          $916 = HEAP32[((143912 + 16|0))>>2]|0;
          $917 = ($914>>>0)<($916>>>0);
          if ($917) {
           _abort();
           // unreachable;
          } else {
           HEAP32[$914>>2] = $725;
           $$sum23$i$i = (($$sum$i21$i) + 24)|0;
           $918 = (($tbase$247$i) + ($$sum23$i$i)|0);
           HEAP32[$918>>2] = $T$051$i$i;
           $$sum24$i$i = (($$sum$i21$i) + 12)|0;
           $919 = (($tbase$247$i) + ($$sum24$i$i)|0);
           HEAP32[$919>>2] = $725;
           $$sum25$i$i = (($$sum$i21$i) + 8)|0;
           $920 = (($tbase$247$i) + ($$sum25$i$i)|0);
           HEAP32[$920>>2] = $725;
           break L338;
          }
         }
        } while(0);
        $921 = (($T$0$lcssa$i28$i) + 8|0);
        $922 = HEAP32[$921>>2]|0;
        $923 = HEAP32[((143912 + 16|0))>>2]|0;
        $924 = ($T$0$lcssa$i28$i>>>0)<($923>>>0);
        if ($924) {
         _abort();
         // unreachable;
        }
        $925 = ($922>>>0)<($923>>>0);
        if ($925) {
         _abort();
         // unreachable;
        } else {
         $926 = (($922) + 12|0);
         HEAP32[$926>>2] = $725;
         HEAP32[$921>>2] = $725;
         $$sum20$i$i = (($$sum$i21$i) + 8)|0;
         $927 = (($tbase$247$i) + ($$sum20$i$i)|0);
         HEAP32[$927>>2] = $922;
         $$sum21$i$i = (($$sum$i21$i) + 12)|0;
         $928 = (($tbase$247$i) + ($$sum21$i$i)|0);
         HEAP32[$928>>2] = $T$0$lcssa$i28$i;
         $$sum22$i$i = (($$sum$i21$i) + 24)|0;
         $929 = (($tbase$247$i) + ($$sum22$i$i)|0);
         HEAP32[$929>>2] = 0;
         break;
        }
       }
      } while(0);
      $$sum1819$i$i = $713 | 8;
      $930 = (($tbase$247$i) + ($$sum1819$i$i)|0);
      $mem$0 = $930;
      STACKTOP = sp;return ($mem$0|0);
     }
    }
    $sp$0$i$i$i = ((143912 + 448|0));
    while(1) {
     $931 = HEAP32[$sp$0$i$i$i>>2]|0;
     $932 = ($931>>>0)>($636>>>0);
     if (!($932)) {
      $933 = (($sp$0$i$i$i) + 4|0);
      $934 = HEAP32[$933>>2]|0;
      $935 = (($931) + ($934)|0);
      $936 = ($935>>>0)>($636>>>0);
      if ($936) {
       break;
      }
     }
     $937 = (($sp$0$i$i$i) + 8|0);
     $938 = HEAP32[$937>>2]|0;
     $sp$0$i$i$i = $938;
    }
    $$sum$i15$i = (($934) + -47)|0;
    $$sum1$i16$i = (($934) + -39)|0;
    $939 = (($931) + ($$sum1$i16$i)|0);
    $940 = $939;
    $941 = $940 & 7;
    $942 = ($941|0)==(0);
    if ($942) {
     $945 = 0;
    } else {
     $943 = (0 - ($940))|0;
     $944 = $943 & 7;
     $945 = $944;
    }
    $$sum2$i17$i = (($$sum$i15$i) + ($945))|0;
    $946 = (($931) + ($$sum2$i17$i)|0);
    $947 = (($636) + 16|0);
    $948 = ($946>>>0)<($947>>>0);
    $949 = $948 ? $636 : $946;
    $950 = (($949) + 8|0);
    $951 = (($tsize$246$i) + -40)|0;
    $952 = (($tbase$247$i) + 8|0);
    $953 = $952;
    $954 = $953 & 7;
    $955 = ($954|0)==(0);
    if ($955) {
     $959 = 0;
    } else {
     $956 = (0 - ($953))|0;
     $957 = $956 & 7;
     $959 = $957;
    }
    $958 = (($tbase$247$i) + ($959)|0);
    $960 = (($951) - ($959))|0;
    HEAP32[((143912 + 24|0))>>2] = $958;
    HEAP32[((143912 + 12|0))>>2] = $960;
    $961 = $960 | 1;
    $$sum$i$i$i = (($959) + 4)|0;
    $962 = (($tbase$247$i) + ($$sum$i$i$i)|0);
    HEAP32[$962>>2] = $961;
    $$sum2$i$i$i = (($tsize$246$i) + -36)|0;
    $963 = (($tbase$247$i) + ($$sum2$i$i$i)|0);
    HEAP32[$963>>2] = 40;
    $964 = HEAP32[((144384 + 16|0))>>2]|0;
    HEAP32[((143912 + 28|0))>>2] = $964;
    $965 = (($949) + 4|0);
    HEAP32[$965>>2] = 27;
    ;HEAP32[$950+0>>2]=HEAP32[((143912 + 448|0))+0>>2]|0;HEAP32[$950+4>>2]=HEAP32[((143912 + 448|0))+4>>2]|0;HEAP32[$950+8>>2]=HEAP32[((143912 + 448|0))+8>>2]|0;HEAP32[$950+12>>2]=HEAP32[((143912 + 448|0))+12>>2]|0;
    HEAP32[((143912 + 448|0))>>2] = $tbase$247$i;
    HEAP32[((143912 + 452|0))>>2] = $tsize$246$i;
    HEAP32[((143912 + 460|0))>>2] = 0;
    HEAP32[((143912 + 456|0))>>2] = $950;
    $966 = (($949) + 28|0);
    HEAP32[$966>>2] = 7;
    $967 = (($949) + 32|0);
    $968 = ($967>>>0)<($935>>>0);
    if ($968) {
     $970 = $966;
     while(1) {
      $969 = (($970) + 4|0);
      HEAP32[$969>>2] = 7;
      $971 = (($970) + 8|0);
      $972 = ($971>>>0)<($935>>>0);
      if ($972) {
       $970 = $969;
      } else {
       break;
      }
     }
    }
    $973 = ($949|0)==($636|0);
    if (!($973)) {
     $974 = $949;
     $975 = $636;
     $976 = (($974) - ($975))|0;
     $977 = (($636) + ($976)|0);
     $$sum3$i$i = (($976) + 4)|0;
     $978 = (($636) + ($$sum3$i$i)|0);
     $979 = HEAP32[$978>>2]|0;
     $980 = $979 & -2;
     HEAP32[$978>>2] = $980;
     $981 = $976 | 1;
     $982 = (($636) + 4|0);
     HEAP32[$982>>2] = $981;
     HEAP32[$977>>2] = $976;
     $983 = $976 >>> 3;
     $984 = ($976>>>0)<(256);
     if ($984) {
      $985 = $983 << 1;
      $986 = ((143912 + ($985<<2)|0) + 40|0);
      $987 = HEAP32[143912>>2]|0;
      $988 = 1 << $983;
      $989 = $987 & $988;
      $990 = ($989|0)==(0);
      do {
       if ($990) {
        $991 = $987 | $988;
        HEAP32[143912>>2] = $991;
        $$sum10$pre$i$i = (($985) + 2)|0;
        $$pre$i$i = ((143912 + ($$sum10$pre$i$i<<2)|0) + 40|0);
        $$pre$phi$i$iZ2D = $$pre$i$i;$F$0$i$i = $986;
       } else {
        $$sum11$i$i = (($985) + 2)|0;
        $992 = ((143912 + ($$sum11$i$i<<2)|0) + 40|0);
        $993 = HEAP32[$992>>2]|0;
        $994 = HEAP32[((143912 + 16|0))>>2]|0;
        $995 = ($993>>>0)<($994>>>0);
        if (!($995)) {
         $$pre$phi$i$iZ2D = $992;$F$0$i$i = $993;
         break;
        }
        _abort();
        // unreachable;
       }
      } while(0);
      HEAP32[$$pre$phi$i$iZ2D>>2] = $636;
      $996 = (($F$0$i$i) + 12|0);
      HEAP32[$996>>2] = $636;
      $997 = (($636) + 8|0);
      HEAP32[$997>>2] = $F$0$i$i;
      $998 = (($636) + 12|0);
      HEAP32[$998>>2] = $986;
      break;
     }
     $999 = $976 >>> 8;
     $1000 = ($999|0)==(0);
     if ($1000) {
      $I1$0$i$i = 0;
     } else {
      $1001 = ($976>>>0)>(16777215);
      if ($1001) {
       $I1$0$i$i = 31;
      } else {
       $1002 = (($999) + 1048320)|0;
       $1003 = $1002 >>> 16;
       $1004 = $1003 & 8;
       $1005 = $999 << $1004;
       $1006 = (($1005) + 520192)|0;
       $1007 = $1006 >>> 16;
       $1008 = $1007 & 4;
       $1009 = $1008 | $1004;
       $1010 = $1005 << $1008;
       $1011 = (($1010) + 245760)|0;
       $1012 = $1011 >>> 16;
       $1013 = $1012 & 2;
       $1014 = $1009 | $1013;
       $1015 = (14 - ($1014))|0;
       $1016 = $1010 << $1013;
       $1017 = $1016 >>> 15;
       $1018 = (($1015) + ($1017))|0;
       $1019 = $1018 << 1;
       $1020 = (($1018) + 7)|0;
       $1021 = $976 >>> $1020;
       $1022 = $1021 & 1;
       $1023 = $1022 | $1019;
       $I1$0$i$i = $1023;
      }
     }
     $1024 = ((143912 + ($I1$0$i$i<<2)|0) + 304|0);
     $1025 = (($636) + 28|0);
     $I1$0$c$i$i = $I1$0$i$i;
     HEAP32[$1025>>2] = $I1$0$c$i$i;
     $1026 = (($636) + 20|0);
     HEAP32[$1026>>2] = 0;
     $1027 = (($636) + 16|0);
     HEAP32[$1027>>2] = 0;
     $1028 = HEAP32[((143912 + 4|0))>>2]|0;
     $1029 = 1 << $I1$0$i$i;
     $1030 = $1028 & $1029;
     $1031 = ($1030|0)==(0);
     if ($1031) {
      $1032 = $1028 | $1029;
      HEAP32[((143912 + 4|0))>>2] = $1032;
      HEAP32[$1024>>2] = $636;
      $1033 = (($636) + 24|0);
      HEAP32[$1033>>2] = $1024;
      $1034 = (($636) + 12|0);
      HEAP32[$1034>>2] = $636;
      $1035 = (($636) + 8|0);
      HEAP32[$1035>>2] = $636;
      break;
     }
     $1036 = HEAP32[$1024>>2]|0;
     $1037 = ($I1$0$i$i|0)==(31);
     if ($1037) {
      $1045 = 0;
     } else {
      $1038 = $I1$0$i$i >>> 1;
      $1039 = (25 - ($1038))|0;
      $1045 = $1039;
     }
     $1040 = (($1036) + 4|0);
     $1041 = HEAP32[$1040>>2]|0;
     $1042 = $1041 & -8;
     $1043 = ($1042|0)==($976|0);
     L489: do {
      if ($1043) {
       $T$0$lcssa$i$i = $1036;
      } else {
       $1044 = $976 << $1045;
       $K2$014$i$i = $1044;$T$013$i$i = $1036;
       while(1) {
        $1052 = $K2$014$i$i >>> 31;
        $1053 = ((($T$013$i$i) + ($1052<<2)|0) + 16|0);
        $1048 = HEAP32[$1053>>2]|0;
        $1054 = ($1048|0)==(0|0);
        if ($1054) {
         break;
        }
        $1046 = $K2$014$i$i << 1;
        $1047 = (($1048) + 4|0);
        $1049 = HEAP32[$1047>>2]|0;
        $1050 = $1049 & -8;
        $1051 = ($1050|0)==($976|0);
        if ($1051) {
         $T$0$lcssa$i$i = $1048;
         break L489;
        } else {
         $K2$014$i$i = $1046;$T$013$i$i = $1048;
        }
       }
       $1055 = HEAP32[((143912 + 16|0))>>2]|0;
       $1056 = ($1053>>>0)<($1055>>>0);
       if ($1056) {
        _abort();
        // unreachable;
       } else {
        HEAP32[$1053>>2] = $636;
        $1057 = (($636) + 24|0);
        HEAP32[$1057>>2] = $T$013$i$i;
        $1058 = (($636) + 12|0);
        HEAP32[$1058>>2] = $636;
        $1059 = (($636) + 8|0);
        HEAP32[$1059>>2] = $636;
        break L311;
       }
      }
     } while(0);
     $1060 = (($T$0$lcssa$i$i) + 8|0);
     $1061 = HEAP32[$1060>>2]|0;
     $1062 = HEAP32[((143912 + 16|0))>>2]|0;
     $1063 = ($T$0$lcssa$i$i>>>0)<($1062>>>0);
     if ($1063) {
      _abort();
      // unreachable;
     }
     $1064 = ($1061>>>0)<($1062>>>0);
     if ($1064) {
      _abort();
      // unreachable;
     } else {
      $1065 = (($1061) + 12|0);
      HEAP32[$1065>>2] = $636;
      HEAP32[$1060>>2] = $636;
      $1066 = (($636) + 8|0);
      HEAP32[$1066>>2] = $1061;
      $1067 = (($636) + 12|0);
      HEAP32[$1067>>2] = $T$0$lcssa$i$i;
      $1068 = (($636) + 24|0);
      HEAP32[$1068>>2] = 0;
      break;
     }
    }
   }
  } while(0);
  $1069 = HEAP32[((143912 + 12|0))>>2]|0;
  $1070 = ($1069>>>0)>($nb$0>>>0);
  if ($1070) {
   $1071 = (($1069) - ($nb$0))|0;
   HEAP32[((143912 + 12|0))>>2] = $1071;
   $1072 = HEAP32[((143912 + 24|0))>>2]|0;
   $1073 = (($1072) + ($nb$0)|0);
   HEAP32[((143912 + 24|0))>>2] = $1073;
   $1074 = $1071 | 1;
   $$sum$i32 = (($nb$0) + 4)|0;
   $1075 = (($1072) + ($$sum$i32)|0);
   HEAP32[$1075>>2] = $1074;
   $1076 = $nb$0 | 3;
   $1077 = (($1072) + 4|0);
   HEAP32[$1077>>2] = $1076;
   $1078 = (($1072) + 8|0);
   $mem$0 = $1078;
   STACKTOP = sp;return ($mem$0|0);
  }
 }
 $1079 = (___errno_location()|0);
 HEAP32[$1079>>2] = 12;
 $mem$0 = 0;
 STACKTOP = sp;return ($mem$0|0);
}
function _free($mem) {
 $mem = $mem|0;
 var $$pre = 0, $$pre$phi68Z2D = 0, $$pre$phi70Z2D = 0, $$pre$phiZ2D = 0, $$pre67 = 0, $$pre69 = 0, $$sum = 0, $$sum16$pre = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum2 = 0, $$sum20 = 0, $$sum2324 = 0, $$sum25 = 0, $$sum26 = 0, $$sum28 = 0, $$sum29 = 0, $$sum3 = 0, $$sum30 = 0;
 var $$sum31 = 0, $$sum32 = 0, $$sum33 = 0, $$sum34 = 0, $$sum35 = 0, $$sum36 = 0, $$sum37 = 0, $$sum5 = 0, $$sum67 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0;
 var $322 = 0, $323 = 0, $324 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $F16$0 = 0, $I18$0 = 0, $I18$0$c = 0, $K19$057 = 0;
 var $R$0 = 0, $R$1 = 0, $R7$0 = 0, $R7$1 = 0, $RP$0 = 0, $RP9$0 = 0, $T$0$lcssa = 0, $T$056 = 0, $cond = 0, $cond54 = 0, $p$0 = 0, $psize$0 = 0, $psize$1 = 0, $sp$0$i = 0, $sp$0$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($mem|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($mem) + -8|0);
 $2 = HEAP32[((143912 + 16|0))>>2]|0;
 $3 = ($1>>>0)<($2>>>0);
 if ($3) {
  _abort();
  // unreachable;
 }
 $4 = (($mem) + -4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 3;
 $7 = ($6|0)==(1);
 if ($7) {
  _abort();
  // unreachable;
 }
 $8 = $5 & -8;
 $$sum = (($8) + -8)|0;
 $9 = (($mem) + ($$sum)|0);
 $10 = $5 & 1;
 $11 = ($10|0)==(0);
 do {
  if ($11) {
   $12 = HEAP32[$1>>2]|0;
   $13 = ($6|0)==(0);
   if ($13) {
    STACKTOP = sp;return;
   }
   $$sum2 = (-8 - ($12))|0;
   $14 = (($mem) + ($$sum2)|0);
   $15 = (($12) + ($8))|0;
   $16 = ($14>>>0)<($2>>>0);
   if ($16) {
    _abort();
    // unreachable;
   }
   $17 = HEAP32[((143912 + 20|0))>>2]|0;
   $18 = ($14|0)==($17|0);
   if ($18) {
    $$sum3 = (($8) + -4)|0;
    $104 = (($mem) + ($$sum3)|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = $105 & 3;
    $107 = ($106|0)==(3);
    if (!($107)) {
     $p$0 = $14;$psize$0 = $15;
     break;
    }
    HEAP32[((143912 + 8|0))>>2] = $15;
    $108 = HEAP32[$104>>2]|0;
    $109 = $108 & -2;
    HEAP32[$104>>2] = $109;
    $110 = $15 | 1;
    $$sum26 = (($$sum2) + 4)|0;
    $111 = (($mem) + ($$sum26)|0);
    HEAP32[$111>>2] = $110;
    HEAP32[$9>>2] = $15;
    STACKTOP = sp;return;
   }
   $19 = $12 >>> 3;
   $20 = ($12>>>0)<(256);
   if ($20) {
    $$sum36 = (($$sum2) + 8)|0;
    $21 = (($mem) + ($$sum36)|0);
    $22 = HEAP32[$21>>2]|0;
    $$sum37 = (($$sum2) + 12)|0;
    $23 = (($mem) + ($$sum37)|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = $19 << 1;
    $26 = ((143912 + ($25<<2)|0) + 40|0);
    $27 = ($22|0)==($26|0);
    if (!($27)) {
     $28 = ($22>>>0)<($2>>>0);
     if ($28) {
      _abort();
      // unreachable;
     }
     $29 = (($22) + 12|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==($14|0);
     if (!($31)) {
      _abort();
      // unreachable;
     }
    }
    $32 = ($24|0)==($22|0);
    if ($32) {
     $33 = 1 << $19;
     $34 = $33 ^ -1;
     $35 = HEAP32[143912>>2]|0;
     $36 = $35 & $34;
     HEAP32[143912>>2] = $36;
     $p$0 = $14;$psize$0 = $15;
     break;
    }
    $37 = ($24|0)==($26|0);
    if ($37) {
     $$pre69 = (($24) + 8|0);
     $$pre$phi70Z2D = $$pre69;
    } else {
     $38 = ($24>>>0)<($2>>>0);
     if ($38) {
      _abort();
      // unreachable;
     }
     $39 = (($24) + 8|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($40|0)==($14|0);
     if ($41) {
      $$pre$phi70Z2D = $39;
     } else {
      _abort();
      // unreachable;
     }
    }
    $42 = (($22) + 12|0);
    HEAP32[$42>>2] = $24;
    HEAP32[$$pre$phi70Z2D>>2] = $22;
    $p$0 = $14;$psize$0 = $15;
    break;
   }
   $$sum28 = (($$sum2) + 24)|0;
   $43 = (($mem) + ($$sum28)|0);
   $44 = HEAP32[$43>>2]|0;
   $$sum29 = (($$sum2) + 12)|0;
   $45 = (($mem) + ($$sum29)|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==($14|0);
   do {
    if ($47) {
     $$sum31 = (($$sum2) + 20)|0;
     $57 = (($mem) + ($$sum31)|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = ($58|0)==(0|0);
     if ($59) {
      $$sum30 = (($$sum2) + 16)|0;
      $60 = (($mem) + ($$sum30)|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($61|0)==(0|0);
      if ($62) {
       $R$1 = 0;
       break;
      } else {
       $R$0 = $61;$RP$0 = $60;
      }
     } else {
      $R$0 = $58;$RP$0 = $57;
     }
     while(1) {
      $63 = (($R$0) + 20|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = ($64|0)==(0|0);
      if (!($65)) {
       $R$0 = $64;$RP$0 = $63;
       continue;
      }
      $66 = (($R$0) + 16|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = ($67|0)==(0|0);
      if ($68) {
       break;
      } else {
       $R$0 = $67;$RP$0 = $66;
      }
     }
     $69 = ($RP$0>>>0)<($2>>>0);
     if ($69) {
      _abort();
      // unreachable;
     } else {
      HEAP32[$RP$0>>2] = 0;
      $R$1 = $R$0;
      break;
     }
    } else {
     $$sum35 = (($$sum2) + 8)|0;
     $48 = (($mem) + ($$sum35)|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49>>>0)<($2>>>0);
     if ($50) {
      _abort();
      // unreachable;
     }
     $51 = (($49) + 12|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = ($52|0)==($14|0);
     if (!($53)) {
      _abort();
      // unreachable;
     }
     $54 = (($46) + 8|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($55|0)==($14|0);
     if ($56) {
      HEAP32[$51>>2] = $46;
      HEAP32[$54>>2] = $49;
      $R$1 = $46;
      break;
     } else {
      _abort();
      // unreachable;
     }
    }
   } while(0);
   $70 = ($44|0)==(0|0);
   if ($70) {
    $p$0 = $14;$psize$0 = $15;
   } else {
    $$sum32 = (($$sum2) + 28)|0;
    $71 = (($mem) + ($$sum32)|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ((143912 + ($72<<2)|0) + 304|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = ($14|0)==($74|0);
    if ($75) {
     HEAP32[$73>>2] = $R$1;
     $cond = ($R$1|0)==(0|0);
     if ($cond) {
      $76 = 1 << $72;
      $77 = $76 ^ -1;
      $78 = HEAP32[((143912 + 4|0))>>2]|0;
      $79 = $78 & $77;
      HEAP32[((143912 + 4|0))>>2] = $79;
      $p$0 = $14;$psize$0 = $15;
      break;
     }
    } else {
     $80 = HEAP32[((143912 + 16|0))>>2]|0;
     $81 = ($44>>>0)<($80>>>0);
     if ($81) {
      _abort();
      // unreachable;
     }
     $82 = (($44) + 16|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = ($83|0)==($14|0);
     if ($84) {
      HEAP32[$82>>2] = $R$1;
     } else {
      $85 = (($44) + 20|0);
      HEAP32[$85>>2] = $R$1;
     }
     $86 = ($R$1|0)==(0|0);
     if ($86) {
      $p$0 = $14;$psize$0 = $15;
      break;
     }
    }
    $87 = HEAP32[((143912 + 16|0))>>2]|0;
    $88 = ($R$1>>>0)<($87>>>0);
    if ($88) {
     _abort();
     // unreachable;
    }
    $89 = (($R$1) + 24|0);
    HEAP32[$89>>2] = $44;
    $$sum33 = (($$sum2) + 16)|0;
    $90 = (($mem) + ($$sum33)|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = ($91|0)==(0|0);
    do {
     if (!($92)) {
      $93 = HEAP32[((143912 + 16|0))>>2]|0;
      $94 = ($91>>>0)<($93>>>0);
      if ($94) {
       _abort();
       // unreachable;
      } else {
       $95 = (($R$1) + 16|0);
       HEAP32[$95>>2] = $91;
       $96 = (($91) + 24|0);
       HEAP32[$96>>2] = $R$1;
       break;
      }
     }
    } while(0);
    $$sum34 = (($$sum2) + 20)|0;
    $97 = (($mem) + ($$sum34)|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = ($98|0)==(0|0);
    if ($99) {
     $p$0 = $14;$psize$0 = $15;
    } else {
     $100 = HEAP32[((143912 + 16|0))>>2]|0;
     $101 = ($98>>>0)<($100>>>0);
     if ($101) {
      _abort();
      // unreachable;
     } else {
      $102 = (($R$1) + 20|0);
      HEAP32[$102>>2] = $98;
      $103 = (($98) + 24|0);
      HEAP32[$103>>2] = $R$1;
      $p$0 = $14;$psize$0 = $15;
      break;
     }
    }
   }
  } else {
   $p$0 = $1;$psize$0 = $8;
  }
 } while(0);
 $112 = ($p$0>>>0)<($9>>>0);
 if (!($112)) {
  _abort();
  // unreachable;
 }
 $$sum25 = (($8) + -4)|0;
 $113 = (($mem) + ($$sum25)|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = $114 & 1;
 $116 = ($115|0)==(0);
 if ($116) {
  _abort();
  // unreachable;
 }
 $117 = $114 & 2;
 $118 = ($117|0)==(0);
 if ($118) {
  $119 = HEAP32[((143912 + 24|0))>>2]|0;
  $120 = ($9|0)==($119|0);
  if ($120) {
   $121 = HEAP32[((143912 + 12|0))>>2]|0;
   $122 = (($121) + ($psize$0))|0;
   HEAP32[((143912 + 12|0))>>2] = $122;
   HEAP32[((143912 + 24|0))>>2] = $p$0;
   $123 = $122 | 1;
   $124 = (($p$0) + 4|0);
   HEAP32[$124>>2] = $123;
   $125 = HEAP32[((143912 + 20|0))>>2]|0;
   $126 = ($p$0|0)==($125|0);
   if (!($126)) {
    STACKTOP = sp;return;
   }
   HEAP32[((143912 + 20|0))>>2] = 0;
   HEAP32[((143912 + 8|0))>>2] = 0;
   STACKTOP = sp;return;
  }
  $127 = HEAP32[((143912 + 20|0))>>2]|0;
  $128 = ($9|0)==($127|0);
  if ($128) {
   $129 = HEAP32[((143912 + 8|0))>>2]|0;
   $130 = (($129) + ($psize$0))|0;
   HEAP32[((143912 + 8|0))>>2] = $130;
   HEAP32[((143912 + 20|0))>>2] = $p$0;
   $131 = $130 | 1;
   $132 = (($p$0) + 4|0);
   HEAP32[$132>>2] = $131;
   $133 = (($p$0) + ($130)|0);
   HEAP32[$133>>2] = $130;
   STACKTOP = sp;return;
  }
  $134 = $114 & -8;
  $135 = (($134) + ($psize$0))|0;
  $136 = $114 >>> 3;
  $137 = ($114>>>0)<(256);
  do {
   if ($137) {
    $138 = (($mem) + ($8)|0);
    $139 = HEAP32[$138>>2]|0;
    $$sum2324 = $8 | 4;
    $140 = (($mem) + ($$sum2324)|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = $136 << 1;
    $143 = ((143912 + ($142<<2)|0) + 40|0);
    $144 = ($139|0)==($143|0);
    if (!($144)) {
     $145 = HEAP32[((143912 + 16|0))>>2]|0;
     $146 = ($139>>>0)<($145>>>0);
     if ($146) {
      _abort();
      // unreachable;
     }
     $147 = (($139) + 12|0);
     $148 = HEAP32[$147>>2]|0;
     $149 = ($148|0)==($9|0);
     if (!($149)) {
      _abort();
      // unreachable;
     }
    }
    $150 = ($141|0)==($139|0);
    if ($150) {
     $151 = 1 << $136;
     $152 = $151 ^ -1;
     $153 = HEAP32[143912>>2]|0;
     $154 = $153 & $152;
     HEAP32[143912>>2] = $154;
     break;
    }
    $155 = ($141|0)==($143|0);
    if ($155) {
     $$pre67 = (($141) + 8|0);
     $$pre$phi68Z2D = $$pre67;
    } else {
     $156 = HEAP32[((143912 + 16|0))>>2]|0;
     $157 = ($141>>>0)<($156>>>0);
     if ($157) {
      _abort();
      // unreachable;
     }
     $158 = (($141) + 8|0);
     $159 = HEAP32[$158>>2]|0;
     $160 = ($159|0)==($9|0);
     if ($160) {
      $$pre$phi68Z2D = $158;
     } else {
      _abort();
      // unreachable;
     }
    }
    $161 = (($139) + 12|0);
    HEAP32[$161>>2] = $141;
    HEAP32[$$pre$phi68Z2D>>2] = $139;
   } else {
    $$sum5 = (($8) + 16)|0;
    $162 = (($mem) + ($$sum5)|0);
    $163 = HEAP32[$162>>2]|0;
    $$sum67 = $8 | 4;
    $164 = (($mem) + ($$sum67)|0);
    $165 = HEAP32[$164>>2]|0;
    $166 = ($165|0)==($9|0);
    do {
     if ($166) {
      $$sum9 = (($8) + 12)|0;
      $177 = (($mem) + ($$sum9)|0);
      $178 = HEAP32[$177>>2]|0;
      $179 = ($178|0)==(0|0);
      if ($179) {
       $$sum8 = (($8) + 8)|0;
       $180 = (($mem) + ($$sum8)|0);
       $181 = HEAP32[$180>>2]|0;
       $182 = ($181|0)==(0|0);
       if ($182) {
        $R7$1 = 0;
        break;
       } else {
        $R7$0 = $181;$RP9$0 = $180;
       }
      } else {
       $R7$0 = $178;$RP9$0 = $177;
      }
      while(1) {
       $183 = (($R7$0) + 20|0);
       $184 = HEAP32[$183>>2]|0;
       $185 = ($184|0)==(0|0);
       if (!($185)) {
        $R7$0 = $184;$RP9$0 = $183;
        continue;
       }
       $186 = (($R7$0) + 16|0);
       $187 = HEAP32[$186>>2]|0;
       $188 = ($187|0)==(0|0);
       if ($188) {
        break;
       } else {
        $R7$0 = $187;$RP9$0 = $186;
       }
      }
      $189 = HEAP32[((143912 + 16|0))>>2]|0;
      $190 = ($RP9$0>>>0)<($189>>>0);
      if ($190) {
       _abort();
       // unreachable;
      } else {
       HEAP32[$RP9$0>>2] = 0;
       $R7$1 = $R7$0;
       break;
      }
     } else {
      $167 = (($mem) + ($8)|0);
      $168 = HEAP32[$167>>2]|0;
      $169 = HEAP32[((143912 + 16|0))>>2]|0;
      $170 = ($168>>>0)<($169>>>0);
      if ($170) {
       _abort();
       // unreachable;
      }
      $171 = (($168) + 12|0);
      $172 = HEAP32[$171>>2]|0;
      $173 = ($172|0)==($9|0);
      if (!($173)) {
       _abort();
       // unreachable;
      }
      $174 = (($165) + 8|0);
      $175 = HEAP32[$174>>2]|0;
      $176 = ($175|0)==($9|0);
      if ($176) {
       HEAP32[$171>>2] = $165;
       HEAP32[$174>>2] = $168;
       $R7$1 = $165;
       break;
      } else {
       _abort();
       // unreachable;
      }
     }
    } while(0);
    $191 = ($163|0)==(0|0);
    if (!($191)) {
     $$sum18 = (($8) + 20)|0;
     $192 = (($mem) + ($$sum18)|0);
     $193 = HEAP32[$192>>2]|0;
     $194 = ((143912 + ($193<<2)|0) + 304|0);
     $195 = HEAP32[$194>>2]|0;
     $196 = ($9|0)==($195|0);
     if ($196) {
      HEAP32[$194>>2] = $R7$1;
      $cond54 = ($R7$1|0)==(0|0);
      if ($cond54) {
       $197 = 1 << $193;
       $198 = $197 ^ -1;
       $199 = HEAP32[((143912 + 4|0))>>2]|0;
       $200 = $199 & $198;
       HEAP32[((143912 + 4|0))>>2] = $200;
       break;
      }
     } else {
      $201 = HEAP32[((143912 + 16|0))>>2]|0;
      $202 = ($163>>>0)<($201>>>0);
      if ($202) {
       _abort();
       // unreachable;
      }
      $203 = (($163) + 16|0);
      $204 = HEAP32[$203>>2]|0;
      $205 = ($204|0)==($9|0);
      if ($205) {
       HEAP32[$203>>2] = $R7$1;
      } else {
       $206 = (($163) + 20|0);
       HEAP32[$206>>2] = $R7$1;
      }
      $207 = ($R7$1|0)==(0|0);
      if ($207) {
       break;
      }
     }
     $208 = HEAP32[((143912 + 16|0))>>2]|0;
     $209 = ($R7$1>>>0)<($208>>>0);
     if ($209) {
      _abort();
      // unreachable;
     }
     $210 = (($R7$1) + 24|0);
     HEAP32[$210>>2] = $163;
     $$sum19 = (($8) + 8)|0;
     $211 = (($mem) + ($$sum19)|0);
     $212 = HEAP32[$211>>2]|0;
     $213 = ($212|0)==(0|0);
     do {
      if (!($213)) {
       $214 = HEAP32[((143912 + 16|0))>>2]|0;
       $215 = ($212>>>0)<($214>>>0);
       if ($215) {
        _abort();
        // unreachable;
       } else {
        $216 = (($R7$1) + 16|0);
        HEAP32[$216>>2] = $212;
        $217 = (($212) + 24|0);
        HEAP32[$217>>2] = $R7$1;
        break;
       }
      }
     } while(0);
     $$sum20 = (($8) + 12)|0;
     $218 = (($mem) + ($$sum20)|0);
     $219 = HEAP32[$218>>2]|0;
     $220 = ($219|0)==(0|0);
     if (!($220)) {
      $221 = HEAP32[((143912 + 16|0))>>2]|0;
      $222 = ($219>>>0)<($221>>>0);
      if ($222) {
       _abort();
       // unreachable;
      } else {
       $223 = (($R7$1) + 20|0);
       HEAP32[$223>>2] = $219;
       $224 = (($219) + 24|0);
       HEAP32[$224>>2] = $R7$1;
       break;
      }
     }
    }
   }
  } while(0);
  $225 = $135 | 1;
  $226 = (($p$0) + 4|0);
  HEAP32[$226>>2] = $225;
  $227 = (($p$0) + ($135)|0);
  HEAP32[$227>>2] = $135;
  $228 = HEAP32[((143912 + 20|0))>>2]|0;
  $229 = ($p$0|0)==($228|0);
  if ($229) {
   HEAP32[((143912 + 8|0))>>2] = $135;
   STACKTOP = sp;return;
  } else {
   $psize$1 = $135;
  }
 } else {
  $230 = $114 & -2;
  HEAP32[$113>>2] = $230;
  $231 = $psize$0 | 1;
  $232 = (($p$0) + 4|0);
  HEAP32[$232>>2] = $231;
  $233 = (($p$0) + ($psize$0)|0);
  HEAP32[$233>>2] = $psize$0;
  $psize$1 = $psize$0;
 }
 $234 = $psize$1 >>> 3;
 $235 = ($psize$1>>>0)<(256);
 if ($235) {
  $236 = $234 << 1;
  $237 = ((143912 + ($236<<2)|0) + 40|0);
  $238 = HEAP32[143912>>2]|0;
  $239 = 1 << $234;
  $240 = $238 & $239;
  $241 = ($240|0)==(0);
  if ($241) {
   $242 = $238 | $239;
   HEAP32[143912>>2] = $242;
   $$sum16$pre = (($236) + 2)|0;
   $$pre = ((143912 + ($$sum16$pre<<2)|0) + 40|0);
   $$pre$phiZ2D = $$pre;$F16$0 = $237;
  } else {
   $$sum17 = (($236) + 2)|0;
   $243 = ((143912 + ($$sum17<<2)|0) + 40|0);
   $244 = HEAP32[$243>>2]|0;
   $245 = HEAP32[((143912 + 16|0))>>2]|0;
   $246 = ($244>>>0)<($245>>>0);
   if ($246) {
    _abort();
    // unreachable;
   } else {
    $$pre$phiZ2D = $243;$F16$0 = $244;
   }
  }
  HEAP32[$$pre$phiZ2D>>2] = $p$0;
  $247 = (($F16$0) + 12|0);
  HEAP32[$247>>2] = $p$0;
  $248 = (($p$0) + 8|0);
  HEAP32[$248>>2] = $F16$0;
  $249 = (($p$0) + 12|0);
  HEAP32[$249>>2] = $237;
  STACKTOP = sp;return;
 }
 $250 = $psize$1 >>> 8;
 $251 = ($250|0)==(0);
 if ($251) {
  $I18$0 = 0;
 } else {
  $252 = ($psize$1>>>0)>(16777215);
  if ($252) {
   $I18$0 = 31;
  } else {
   $253 = (($250) + 1048320)|0;
   $254 = $253 >>> 16;
   $255 = $254 & 8;
   $256 = $250 << $255;
   $257 = (($256) + 520192)|0;
   $258 = $257 >>> 16;
   $259 = $258 & 4;
   $260 = $259 | $255;
   $261 = $256 << $259;
   $262 = (($261) + 245760)|0;
   $263 = $262 >>> 16;
   $264 = $263 & 2;
   $265 = $260 | $264;
   $266 = (14 - ($265))|0;
   $267 = $261 << $264;
   $268 = $267 >>> 15;
   $269 = (($266) + ($268))|0;
   $270 = $269 << 1;
   $271 = (($269) + 7)|0;
   $272 = $psize$1 >>> $271;
   $273 = $272 & 1;
   $274 = $273 | $270;
   $I18$0 = $274;
  }
 }
 $275 = ((143912 + ($I18$0<<2)|0) + 304|0);
 $276 = (($p$0) + 28|0);
 $I18$0$c = $I18$0;
 HEAP32[$276>>2] = $I18$0$c;
 $277 = (($p$0) + 20|0);
 HEAP32[$277>>2] = 0;
 $278 = (($p$0) + 16|0);
 HEAP32[$278>>2] = 0;
 $279 = HEAP32[((143912 + 4|0))>>2]|0;
 $280 = 1 << $I18$0;
 $281 = $279 & $280;
 $282 = ($281|0)==(0);
 L199: do {
  if ($282) {
   $283 = $279 | $280;
   HEAP32[((143912 + 4|0))>>2] = $283;
   HEAP32[$275>>2] = $p$0;
   $284 = (($p$0) + 24|0);
   HEAP32[$284>>2] = $275;
   $285 = (($p$0) + 12|0);
   HEAP32[$285>>2] = $p$0;
   $286 = (($p$0) + 8|0);
   HEAP32[$286>>2] = $p$0;
  } else {
   $287 = HEAP32[$275>>2]|0;
   $288 = ($I18$0|0)==(31);
   if ($288) {
    $296 = 0;
   } else {
    $289 = $I18$0 >>> 1;
    $290 = (25 - ($289))|0;
    $296 = $290;
   }
   $291 = (($287) + 4|0);
   $292 = HEAP32[$291>>2]|0;
   $293 = $292 & -8;
   $294 = ($293|0)==($psize$1|0);
   L204: do {
    if ($294) {
     $T$0$lcssa = $287;
    } else {
     $295 = $psize$1 << $296;
     $K19$057 = $295;$T$056 = $287;
     while(1) {
      $303 = $K19$057 >>> 31;
      $304 = ((($T$056) + ($303<<2)|0) + 16|0);
      $299 = HEAP32[$304>>2]|0;
      $305 = ($299|0)==(0|0);
      if ($305) {
       break;
      }
      $297 = $K19$057 << 1;
      $298 = (($299) + 4|0);
      $300 = HEAP32[$298>>2]|0;
      $301 = $300 & -8;
      $302 = ($301|0)==($psize$1|0);
      if ($302) {
       $T$0$lcssa = $299;
       break L204;
      } else {
       $K19$057 = $297;$T$056 = $299;
      }
     }
     $306 = HEAP32[((143912 + 16|0))>>2]|0;
     $307 = ($304>>>0)<($306>>>0);
     if ($307) {
      _abort();
      // unreachable;
     } else {
      HEAP32[$304>>2] = $p$0;
      $308 = (($p$0) + 24|0);
      HEAP32[$308>>2] = $T$056;
      $309 = (($p$0) + 12|0);
      HEAP32[$309>>2] = $p$0;
      $310 = (($p$0) + 8|0);
      HEAP32[$310>>2] = $p$0;
      break L199;
     }
    }
   } while(0);
   $311 = (($T$0$lcssa) + 8|0);
   $312 = HEAP32[$311>>2]|0;
   $313 = HEAP32[((143912 + 16|0))>>2]|0;
   $314 = ($T$0$lcssa>>>0)<($313>>>0);
   if ($314) {
    _abort();
    // unreachable;
   }
   $315 = ($312>>>0)<($313>>>0);
   if ($315) {
    _abort();
    // unreachable;
   } else {
    $316 = (($312) + 12|0);
    HEAP32[$316>>2] = $p$0;
    HEAP32[$311>>2] = $p$0;
    $317 = (($p$0) + 8|0);
    HEAP32[$317>>2] = $312;
    $318 = (($p$0) + 12|0);
    HEAP32[$318>>2] = $T$0$lcssa;
    $319 = (($p$0) + 24|0);
    HEAP32[$319>>2] = 0;
    break;
   }
  }
 } while(0);
 $320 = HEAP32[((143912 + 32|0))>>2]|0;
 $321 = (($320) + -1)|0;
 HEAP32[((143912 + 32|0))>>2] = $321;
 $322 = ($321|0)==(0);
 if ($322) {
  $sp$0$in$i = ((143912 + 456|0));
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $sp$0$i = HEAP32[$sp$0$in$i>>2]|0;
  $323 = ($sp$0$i|0)==(0|0);
  $324 = (($sp$0$i) + 8|0);
  if ($323) {
   break;
  } else {
   $sp$0$in$i = $324;
  }
 }
 HEAP32[((143912 + 32|0))>>2] = -1;
 STACKTOP = sp;return;
}
function _realloc($oldmem,$bytes) {
 $oldmem = $oldmem|0;
 $bytes = $bytes|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $mem$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($oldmem|0)==(0|0);
 do {
  if ($0) {
   $1 = (_malloc($bytes)|0);
   $mem$0 = $1;
  } else {
   $2 = ($bytes>>>0)>(4294967231);
   if ($2) {
    $3 = (___errno_location()|0);
    HEAP32[$3>>2] = 12;
    $mem$0 = 0;
    break;
   }
   $4 = ($bytes>>>0)<(11);
   if ($4) {
    $8 = 16;
   } else {
    $5 = (($bytes) + 11)|0;
    $6 = $5 & -8;
    $8 = $6;
   }
   $7 = (($oldmem) + -8|0);
   $9 = (_try_realloc_chunk($7,$8)|0);
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (($9) + 8|0);
    $mem$0 = $11;
    break;
   }
   $12 = (_malloc($bytes)|0);
   $13 = ($12|0)==(0|0);
   if ($13) {
    $mem$0 = 0;
   } else {
    $14 = (($oldmem) + -4|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = $15 & -8;
    $17 = $15 & 3;
    $18 = ($17|0)==(0);
    $19 = $18 ? 8 : 4;
    $20 = (($16) - ($19))|0;
    $21 = ($20>>>0)<($bytes>>>0);
    $22 = $21 ? $20 : $bytes;
    _memcpy(($12|0),($oldmem|0),($22|0))|0;
    _free($oldmem);
    $mem$0 = $12;
   }
  }
 } while(0);
 STACKTOP = sp;return ($mem$0|0);
}
function _try_realloc_chunk($p,$nb) {
 $p = $p|0;
 $nb = $nb|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $$sum16 = 0, $$sum17 = 0, $$sum19 = 0, $$sum2 = 0, $$sum20 = 0, $$sum22 = 0, $$sum23 = 0, $$sum2728 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum78 = 0;
 var $$sum910 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $R$0 = 0, $R$1 = 0, $RP$0 = 0;
 var $cond = 0, $newp$0 = 0, $or$cond = 0, $storemerge = 0, $storemerge21 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($p) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & -8;
 $3 = (($p) + ($2)|0);
 $4 = HEAP32[((143912 + 16|0))>>2]|0;
 $5 = ($p>>>0)<($4>>>0);
 if ($5) {
  _abort();
  // unreachable;
 }
 $6 = $1 & 3;
 $7 = ($6|0)!=(1);
 $8 = ($p>>>0)<($3>>>0);
 $or$cond = $7 & $8;
 if (!($or$cond)) {
  _abort();
  // unreachable;
 }
 $$sum2728 = $2 | 4;
 $9 = (($p) + ($$sum2728)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 1;
 $12 = ($11|0)==(0);
 if ($12) {
  _abort();
  // unreachable;
 }
 $13 = ($6|0)==(0);
 if ($13) {
  $14 = ($nb>>>0)<(256);
  if ($14) {
   $newp$0 = 0;
   STACKTOP = sp;return ($newp$0|0);
  }
  $15 = (($nb) + 4)|0;
  $16 = ($2>>>0)<($15>>>0);
  if (!($16)) {
   $17 = (($2) - ($nb))|0;
   $18 = HEAP32[((144384 + 8|0))>>2]|0;
   $19 = $18 << 1;
   $20 = ($17>>>0)>($19>>>0);
   if (!($20)) {
    $newp$0 = $p;
    STACKTOP = sp;return ($newp$0|0);
   }
  }
  $newp$0 = 0;
  STACKTOP = sp;return ($newp$0|0);
 }
 $21 = ($2>>>0)<($nb>>>0);
 if (!($21)) {
  $22 = (($2) - ($nb))|0;
  $23 = ($22>>>0)>(15);
  if (!($23)) {
   $newp$0 = $p;
   STACKTOP = sp;return ($newp$0|0);
  }
  $24 = (($p) + ($nb)|0);
  $25 = $1 & 1;
  $26 = $25 | $nb;
  $27 = $26 | 2;
  HEAP32[$0>>2] = $27;
  $$sum23 = (($nb) + 4)|0;
  $28 = (($p) + ($$sum23)|0);
  $29 = $22 | 3;
  HEAP32[$28>>2] = $29;
  $30 = HEAP32[$9>>2]|0;
  $31 = $30 | 1;
  HEAP32[$9>>2] = $31;
  _dispose_chunk($24,$22);
  $newp$0 = $p;
  STACKTOP = sp;return ($newp$0|0);
 }
 $32 = HEAP32[((143912 + 24|0))>>2]|0;
 $33 = ($3|0)==($32|0);
 if ($33) {
  $34 = HEAP32[((143912 + 12|0))>>2]|0;
  $35 = (($34) + ($2))|0;
  $36 = ($35>>>0)>($nb>>>0);
  if (!($36)) {
   $newp$0 = 0;
   STACKTOP = sp;return ($newp$0|0);
  }
  $37 = (($35) - ($nb))|0;
  $38 = (($p) + ($nb)|0);
  $39 = $1 & 1;
  $40 = $39 | $nb;
  $41 = $40 | 2;
  HEAP32[$0>>2] = $41;
  $$sum22 = (($nb) + 4)|0;
  $42 = (($p) + ($$sum22)|0);
  $43 = $37 | 1;
  HEAP32[$42>>2] = $43;
  HEAP32[((143912 + 24|0))>>2] = $38;
  HEAP32[((143912 + 12|0))>>2] = $37;
  $newp$0 = $p;
  STACKTOP = sp;return ($newp$0|0);
 }
 $44 = HEAP32[((143912 + 20|0))>>2]|0;
 $45 = ($3|0)==($44|0);
 if ($45) {
  $46 = HEAP32[((143912 + 8|0))>>2]|0;
  $47 = (($46) + ($2))|0;
  $48 = ($47>>>0)<($nb>>>0);
  if ($48) {
   $newp$0 = 0;
   STACKTOP = sp;return ($newp$0|0);
  }
  $49 = (($47) - ($nb))|0;
  $50 = ($49>>>0)>(15);
  if ($50) {
   $51 = (($p) + ($nb)|0);
   $52 = (($p) + ($47)|0);
   $53 = $1 & 1;
   $54 = $53 | $nb;
   $55 = $54 | 2;
   HEAP32[$0>>2] = $55;
   $$sum19 = (($nb) + 4)|0;
   $56 = (($p) + ($$sum19)|0);
   $57 = $49 | 1;
   HEAP32[$56>>2] = $57;
   HEAP32[$52>>2] = $49;
   $$sum20 = (($47) + 4)|0;
   $58 = (($p) + ($$sum20)|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = $59 & -2;
   HEAP32[$58>>2] = $60;
   $storemerge = $51;$storemerge21 = $49;
  } else {
   $61 = $1 & 1;
   $62 = $61 | $47;
   $63 = $62 | 2;
   HEAP32[$0>>2] = $63;
   $$sum17 = (($47) + 4)|0;
   $64 = (($p) + ($$sum17)|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = $65 | 1;
   HEAP32[$64>>2] = $66;
   $storemerge = 0;$storemerge21 = 0;
  }
  HEAP32[((143912 + 8|0))>>2] = $storemerge21;
  HEAP32[((143912 + 20|0))>>2] = $storemerge;
  $newp$0 = $p;
  STACKTOP = sp;return ($newp$0|0);
 }
 $67 = $10 & 2;
 $68 = ($67|0)==(0);
 if (!($68)) {
  $newp$0 = 0;
  STACKTOP = sp;return ($newp$0|0);
 }
 $69 = $10 & -8;
 $70 = (($69) + ($2))|0;
 $71 = ($70>>>0)<($nb>>>0);
 if ($71) {
  $newp$0 = 0;
  STACKTOP = sp;return ($newp$0|0);
 }
 $72 = (($70) - ($nb))|0;
 $73 = $10 >>> 3;
 $74 = ($10>>>0)<(256);
 do {
  if ($74) {
   $$sum15 = (($2) + 8)|0;
   $75 = (($p) + ($$sum15)|0);
   $76 = HEAP32[$75>>2]|0;
   $$sum16 = (($2) + 12)|0;
   $77 = (($p) + ($$sum16)|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = $73 << 1;
   $80 = ((143912 + ($79<<2)|0) + 40|0);
   $81 = ($76|0)==($80|0);
   if (!($81)) {
    $82 = ($76>>>0)<($4>>>0);
    if ($82) {
     _abort();
     // unreachable;
    }
    $83 = (($76) + 12|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = ($84|0)==($3|0);
    if (!($85)) {
     _abort();
     // unreachable;
    }
   }
   $86 = ($78|0)==($76|0);
   if ($86) {
    $87 = 1 << $73;
    $88 = $87 ^ -1;
    $89 = HEAP32[143912>>2]|0;
    $90 = $89 & $88;
    HEAP32[143912>>2] = $90;
    break;
   }
   $91 = ($78|0)==($80|0);
   if ($91) {
    $$pre = (($78) + 8|0);
    $$pre$phiZ2D = $$pre;
   } else {
    $92 = ($78>>>0)<($4>>>0);
    if ($92) {
     _abort();
     // unreachable;
    }
    $93 = (($78) + 8|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = ($94|0)==($3|0);
    if ($95) {
     $$pre$phiZ2D = $93;
    } else {
     _abort();
     // unreachable;
    }
   }
   $96 = (($76) + 12|0);
   HEAP32[$96>>2] = $78;
   HEAP32[$$pre$phiZ2D>>2] = $76;
  } else {
   $$sum = (($2) + 24)|0;
   $97 = (($p) + ($$sum)|0);
   $98 = HEAP32[$97>>2]|0;
   $$sum2 = (($2) + 12)|0;
   $99 = (($p) + ($$sum2)|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = ($100|0)==($3|0);
   do {
    if ($101) {
     $$sum4 = (($2) + 20)|0;
     $111 = (($p) + ($$sum4)|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = ($112|0)==(0|0);
     if ($113) {
      $$sum3 = (($2) + 16)|0;
      $114 = (($p) + ($$sum3)|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = ($115|0)==(0|0);
      if ($116) {
       $R$1 = 0;
       break;
      } else {
       $R$0 = $115;$RP$0 = $114;
      }
     } else {
      $R$0 = $112;$RP$0 = $111;
     }
     while(1) {
      $117 = (($R$0) + 20|0);
      $118 = HEAP32[$117>>2]|0;
      $119 = ($118|0)==(0|0);
      if (!($119)) {
       $R$0 = $118;$RP$0 = $117;
       continue;
      }
      $120 = (($R$0) + 16|0);
      $121 = HEAP32[$120>>2]|0;
      $122 = ($121|0)==(0|0);
      if ($122) {
       break;
      } else {
       $R$0 = $121;$RP$0 = $120;
      }
     }
     $123 = ($RP$0>>>0)<($4>>>0);
     if ($123) {
      _abort();
      // unreachable;
     } else {
      HEAP32[$RP$0>>2] = 0;
      $R$1 = $R$0;
      break;
     }
    } else {
     $$sum14 = (($2) + 8)|0;
     $102 = (($p) + ($$sum14)|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = ($103>>>0)<($4>>>0);
     if ($104) {
      _abort();
      // unreachable;
     }
     $105 = (($103) + 12|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = ($106|0)==($3|0);
     if (!($107)) {
      _abort();
      // unreachable;
     }
     $108 = (($100) + 8|0);
     $109 = HEAP32[$108>>2]|0;
     $110 = ($109|0)==($3|0);
     if ($110) {
      HEAP32[$105>>2] = $100;
      HEAP32[$108>>2] = $103;
      $R$1 = $100;
      break;
     } else {
      _abort();
      // unreachable;
     }
    }
   } while(0);
   $124 = ($98|0)==(0|0);
   if (!($124)) {
    $$sum11 = (($2) + 28)|0;
    $125 = (($p) + ($$sum11)|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = ((143912 + ($126<<2)|0) + 304|0);
    $128 = HEAP32[$127>>2]|0;
    $129 = ($3|0)==($128|0);
    if ($129) {
     HEAP32[$127>>2] = $R$1;
     $cond = ($R$1|0)==(0|0);
     if ($cond) {
      $130 = 1 << $126;
      $131 = $130 ^ -1;
      $132 = HEAP32[((143912 + 4|0))>>2]|0;
      $133 = $132 & $131;
      HEAP32[((143912 + 4|0))>>2] = $133;
      break;
     }
    } else {
     $134 = HEAP32[((143912 + 16|0))>>2]|0;
     $135 = ($98>>>0)<($134>>>0);
     if ($135) {
      _abort();
      // unreachable;
     }
     $136 = (($98) + 16|0);
     $137 = HEAP32[$136>>2]|0;
     $138 = ($137|0)==($3|0);
     if ($138) {
      HEAP32[$136>>2] = $R$1;
     } else {
      $139 = (($98) + 20|0);
      HEAP32[$139>>2] = $R$1;
     }
     $140 = ($R$1|0)==(0|0);
     if ($140) {
      break;
     }
    }
    $141 = HEAP32[((143912 + 16|0))>>2]|0;
    $142 = ($R$1>>>0)<($141>>>0);
    if ($142) {
     _abort();
     // unreachable;
    }
    $143 = (($R$1) + 24|0);
    HEAP32[$143>>2] = $98;
    $$sum12 = (($2) + 16)|0;
    $144 = (($p) + ($$sum12)|0);
    $145 = HEAP32[$144>>2]|0;
    $146 = ($145|0)==(0|0);
    do {
     if (!($146)) {
      $147 = HEAP32[((143912 + 16|0))>>2]|0;
      $148 = ($145>>>0)<($147>>>0);
      if ($148) {
       _abort();
       // unreachable;
      } else {
       $149 = (($R$1) + 16|0);
       HEAP32[$149>>2] = $145;
       $150 = (($145) + 24|0);
       HEAP32[$150>>2] = $R$1;
       break;
      }
     }
    } while(0);
    $$sum13 = (($2) + 20)|0;
    $151 = (($p) + ($$sum13)|0);
    $152 = HEAP32[$151>>2]|0;
    $153 = ($152|0)==(0|0);
    if (!($153)) {
     $154 = HEAP32[((143912 + 16|0))>>2]|0;
     $155 = ($152>>>0)<($154>>>0);
     if ($155) {
      _abort();
      // unreachable;
     } else {
      $156 = (($R$1) + 20|0);
      HEAP32[$156>>2] = $152;
      $157 = (($152) + 24|0);
      HEAP32[$157>>2] = $R$1;
      break;
     }
    }
   }
  }
 } while(0);
 $158 = ($72>>>0)<(16);
 if ($158) {
  $159 = HEAP32[$0>>2]|0;
  $160 = $159 & 1;
  $161 = $70 | $160;
  $162 = $161 | 2;
  HEAP32[$0>>2] = $162;
  $$sum910 = $70 | 4;
  $163 = (($p) + ($$sum910)|0);
  $164 = HEAP32[$163>>2]|0;
  $165 = $164 | 1;
  HEAP32[$163>>2] = $165;
  $newp$0 = $p;
  STACKTOP = sp;return ($newp$0|0);
 } else {
  $166 = (($p) + ($nb)|0);
  $167 = HEAP32[$0>>2]|0;
  $168 = $167 & 1;
  $169 = $168 | $nb;
  $170 = $169 | 2;
  HEAP32[$0>>2] = $170;
  $$sum5 = (($nb) + 4)|0;
  $171 = (($p) + ($$sum5)|0);
  $172 = $72 | 3;
  HEAP32[$171>>2] = $172;
  $$sum78 = $70 | 4;
  $173 = (($p) + ($$sum78)|0);
  $174 = HEAP32[$173>>2]|0;
  $175 = $174 | 1;
  HEAP32[$173>>2] = $175;
  _dispose_chunk($166,$72);
  $newp$0 = $p;
  STACKTOP = sp;return ($newp$0|0);
 }
 return 0|0;
}
function _dispose_chunk($p,$psize) {
 $p = $p|0;
 $psize = $psize|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$pre = 0, $$pre$phi63Z2D = 0, $$pre$phi65Z2D = 0, $$pre$phiZ2D = 0, $$pre62 = 0, $$pre64 = 0, $$sum = 0, $$sum1 = 0, $$sum12$pre = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum2 = 0;
 var $$sum20 = 0, $$sum22 = 0, $$sum23 = 0, $$sum24 = 0, $$sum25 = 0, $$sum26 = 0, $$sum27 = 0, $$sum28 = 0, $$sum29 = 0, $$sum3 = 0, $$sum30 = 0, $$sum31 = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $F16$0 = 0, $I19$0 = 0, $I19$0$c = 0, $K20$049 = 0, $R$0 = 0, $R$1 = 0, $R7$0 = 0, $R7$1 = 0, $RP$0 = 0, $RP9$0 = 0, $T$0$lcssa = 0, $T$048 = 0, $cond = 0, $cond46 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($p) + ($psize)|0);
 $1 = (($p) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 1;
 $4 = ($3|0)==(0);
 do {
  if ($4) {
   $5 = HEAP32[$p>>2]|0;
   $6 = $2 & 3;
   $7 = ($6|0)==(0);
   if ($7) {
    STACKTOP = sp;return;
   }
   $8 = (0 - ($5))|0;
   $9 = (($p) + ($8)|0);
   $10 = (($5) + ($psize))|0;
   $11 = HEAP32[((143912 + 16|0))>>2]|0;
   $12 = ($9>>>0)<($11>>>0);
   if ($12) {
    _abort();
    // unreachable;
   }
   $13 = HEAP32[((143912 + 20|0))>>2]|0;
   $14 = ($9|0)==($13|0);
   if ($14) {
    $$sum = (($psize) + 4)|0;
    $100 = (($p) + ($$sum)|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = $101 & 3;
    $103 = ($102|0)==(3);
    if (!($103)) {
     $$0 = $9;$$02 = $10;
     break;
    }
    HEAP32[((143912 + 8|0))>>2] = $10;
    $104 = HEAP32[$100>>2]|0;
    $105 = $104 & -2;
    HEAP32[$100>>2] = $105;
    $106 = $10 | 1;
    $$sum20 = (4 - ($5))|0;
    $107 = (($p) + ($$sum20)|0);
    HEAP32[$107>>2] = $106;
    HEAP32[$0>>2] = $10;
    STACKTOP = sp;return;
   }
   $15 = $5 >>> 3;
   $16 = ($5>>>0)<(256);
   if ($16) {
    $$sum30 = (8 - ($5))|0;
    $17 = (($p) + ($$sum30)|0);
    $18 = HEAP32[$17>>2]|0;
    $$sum31 = (12 - ($5))|0;
    $19 = (($p) + ($$sum31)|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = $15 << 1;
    $22 = ((143912 + ($21<<2)|0) + 40|0);
    $23 = ($18|0)==($22|0);
    if (!($23)) {
     $24 = ($18>>>0)<($11>>>0);
     if ($24) {
      _abort();
      // unreachable;
     }
     $25 = (($18) + 12|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = ($26|0)==($9|0);
     if (!($27)) {
      _abort();
      // unreachable;
     }
    }
    $28 = ($20|0)==($18|0);
    if ($28) {
     $29 = 1 << $15;
     $30 = $29 ^ -1;
     $31 = HEAP32[143912>>2]|0;
     $32 = $31 & $30;
     HEAP32[143912>>2] = $32;
     $$0 = $9;$$02 = $10;
     break;
    }
    $33 = ($20|0)==($22|0);
    if ($33) {
     $$pre64 = (($20) + 8|0);
     $$pre$phi65Z2D = $$pre64;
    } else {
     $34 = ($20>>>0)<($11>>>0);
     if ($34) {
      _abort();
      // unreachable;
     }
     $35 = (($20) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==($9|0);
     if ($37) {
      $$pre$phi65Z2D = $35;
     } else {
      _abort();
      // unreachable;
     }
    }
    $38 = (($18) + 12|0);
    HEAP32[$38>>2] = $20;
    HEAP32[$$pre$phi65Z2D>>2] = $18;
    $$0 = $9;$$02 = $10;
    break;
   }
   $$sum22 = (24 - ($5))|0;
   $39 = (($p) + ($$sum22)|0);
   $40 = HEAP32[$39>>2]|0;
   $$sum23 = (12 - ($5))|0;
   $41 = (($p) + ($$sum23)|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==($9|0);
   do {
    if ($43) {
     $$sum24 = (16 - ($5))|0;
     $$sum25 = (($$sum24) + 4)|0;
     $53 = (($p) + ($$sum25)|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = ($54|0)==(0|0);
     if ($55) {
      $56 = (($p) + ($$sum24)|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57|0)==(0|0);
      if ($58) {
       $R$1 = 0;
       break;
      } else {
       $R$0 = $57;$RP$0 = $56;
      }
     } else {
      $R$0 = $54;$RP$0 = $53;
     }
     while(1) {
      $59 = (($R$0) + 20|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($60|0)==(0|0);
      if (!($61)) {
       $R$0 = $60;$RP$0 = $59;
       continue;
      }
      $62 = (($R$0) + 16|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = ($63|0)==(0|0);
      if ($64) {
       break;
      } else {
       $R$0 = $63;$RP$0 = $62;
      }
     }
     $65 = ($RP$0>>>0)<($11>>>0);
     if ($65) {
      _abort();
      // unreachable;
     } else {
      HEAP32[$RP$0>>2] = 0;
      $R$1 = $R$0;
      break;
     }
    } else {
     $$sum29 = (8 - ($5))|0;
     $44 = (($p) + ($$sum29)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($11>>>0);
     if ($46) {
      _abort();
      // unreachable;
     }
     $47 = (($45) + 12|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)==($9|0);
     if (!($49)) {
      _abort();
      // unreachable;
     }
     $50 = (($42) + 8|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($9|0);
     if ($52) {
      HEAP32[$47>>2] = $42;
      HEAP32[$50>>2] = $45;
      $R$1 = $42;
      break;
     } else {
      _abort();
      // unreachable;
     }
    }
   } while(0);
   $66 = ($40|0)==(0|0);
   if ($66) {
    $$0 = $9;$$02 = $10;
   } else {
    $$sum26 = (28 - ($5))|0;
    $67 = (($p) + ($$sum26)|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = ((143912 + ($68<<2)|0) + 304|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = ($9|0)==($70|0);
    if ($71) {
     HEAP32[$69>>2] = $R$1;
     $cond = ($R$1|0)==(0|0);
     if ($cond) {
      $72 = 1 << $68;
      $73 = $72 ^ -1;
      $74 = HEAP32[((143912 + 4|0))>>2]|0;
      $75 = $74 & $73;
      HEAP32[((143912 + 4|0))>>2] = $75;
      $$0 = $9;$$02 = $10;
      break;
     }
    } else {
     $76 = HEAP32[((143912 + 16|0))>>2]|0;
     $77 = ($40>>>0)<($76>>>0);
     if ($77) {
      _abort();
      // unreachable;
     }
     $78 = (($40) + 16|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = ($79|0)==($9|0);
     if ($80) {
      HEAP32[$78>>2] = $R$1;
     } else {
      $81 = (($40) + 20|0);
      HEAP32[$81>>2] = $R$1;
     }
     $82 = ($R$1|0)==(0|0);
     if ($82) {
      $$0 = $9;$$02 = $10;
      break;
     }
    }
    $83 = HEAP32[((143912 + 16|0))>>2]|0;
    $84 = ($R$1>>>0)<($83>>>0);
    if ($84) {
     _abort();
     // unreachable;
    }
    $85 = (($R$1) + 24|0);
    HEAP32[$85>>2] = $40;
    $$sum27 = (16 - ($5))|0;
    $86 = (($p) + ($$sum27)|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = ($87|0)==(0|0);
    do {
     if (!($88)) {
      $89 = HEAP32[((143912 + 16|0))>>2]|0;
      $90 = ($87>>>0)<($89>>>0);
      if ($90) {
       _abort();
       // unreachable;
      } else {
       $91 = (($R$1) + 16|0);
       HEAP32[$91>>2] = $87;
       $92 = (($87) + 24|0);
       HEAP32[$92>>2] = $R$1;
       break;
      }
     }
    } while(0);
    $$sum28 = (($$sum27) + 4)|0;
    $93 = (($p) + ($$sum28)|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = ($94|0)==(0|0);
    if ($95) {
     $$0 = $9;$$02 = $10;
    } else {
     $96 = HEAP32[((143912 + 16|0))>>2]|0;
     $97 = ($94>>>0)<($96>>>0);
     if ($97) {
      _abort();
      // unreachable;
     } else {
      $98 = (($R$1) + 20|0);
      HEAP32[$98>>2] = $94;
      $99 = (($94) + 24|0);
      HEAP32[$99>>2] = $R$1;
      $$0 = $9;$$02 = $10;
      break;
     }
    }
   }
  } else {
   $$0 = $p;$$02 = $psize;
  }
 } while(0);
 $108 = HEAP32[((143912 + 16|0))>>2]|0;
 $109 = ($0>>>0)<($108>>>0);
 if ($109) {
  _abort();
  // unreachable;
 }
 $$sum1 = (($psize) + 4)|0;
 $110 = (($p) + ($$sum1)|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = $111 & 2;
 $113 = ($112|0)==(0);
 if ($113) {
  $114 = HEAP32[((143912 + 24|0))>>2]|0;
  $115 = ($0|0)==($114|0);
  if ($115) {
   $116 = HEAP32[((143912 + 12|0))>>2]|0;
   $117 = (($116) + ($$02))|0;
   HEAP32[((143912 + 12|0))>>2] = $117;
   HEAP32[((143912 + 24|0))>>2] = $$0;
   $118 = $117 | 1;
   $119 = (($$0) + 4|0);
   HEAP32[$119>>2] = $118;
   $120 = HEAP32[((143912 + 20|0))>>2]|0;
   $121 = ($$0|0)==($120|0);
   if (!($121)) {
    STACKTOP = sp;return;
   }
   HEAP32[((143912 + 20|0))>>2] = 0;
   HEAP32[((143912 + 8|0))>>2] = 0;
   STACKTOP = sp;return;
  }
  $122 = HEAP32[((143912 + 20|0))>>2]|0;
  $123 = ($0|0)==($122|0);
  if ($123) {
   $124 = HEAP32[((143912 + 8|0))>>2]|0;
   $125 = (($124) + ($$02))|0;
   HEAP32[((143912 + 8|0))>>2] = $125;
   HEAP32[((143912 + 20|0))>>2] = $$0;
   $126 = $125 | 1;
   $127 = (($$0) + 4|0);
   HEAP32[$127>>2] = $126;
   $128 = (($$0) + ($125)|0);
   HEAP32[$128>>2] = $125;
   STACKTOP = sp;return;
  }
  $129 = $111 & -8;
  $130 = (($129) + ($$02))|0;
  $131 = $111 >>> 3;
  $132 = ($111>>>0)<(256);
  do {
   if ($132) {
    $$sum18 = (($psize) + 8)|0;
    $133 = (($p) + ($$sum18)|0);
    $134 = HEAP32[$133>>2]|0;
    $$sum19 = (($psize) + 12)|0;
    $135 = (($p) + ($$sum19)|0);
    $136 = HEAP32[$135>>2]|0;
    $137 = $131 << 1;
    $138 = ((143912 + ($137<<2)|0) + 40|0);
    $139 = ($134|0)==($138|0);
    if (!($139)) {
     $140 = ($134>>>0)<($108>>>0);
     if ($140) {
      _abort();
      // unreachable;
     }
     $141 = (($134) + 12|0);
     $142 = HEAP32[$141>>2]|0;
     $143 = ($142|0)==($0|0);
     if (!($143)) {
      _abort();
      // unreachable;
     }
    }
    $144 = ($136|0)==($134|0);
    if ($144) {
     $145 = 1 << $131;
     $146 = $145 ^ -1;
     $147 = HEAP32[143912>>2]|0;
     $148 = $147 & $146;
     HEAP32[143912>>2] = $148;
     break;
    }
    $149 = ($136|0)==($138|0);
    if ($149) {
     $$pre62 = (($136) + 8|0);
     $$pre$phi63Z2D = $$pre62;
    } else {
     $150 = ($136>>>0)<($108>>>0);
     if ($150) {
      _abort();
      // unreachable;
     }
     $151 = (($136) + 8|0);
     $152 = HEAP32[$151>>2]|0;
     $153 = ($152|0)==($0|0);
     if ($153) {
      $$pre$phi63Z2D = $151;
     } else {
      _abort();
      // unreachable;
     }
    }
    $154 = (($134) + 12|0);
    HEAP32[$154>>2] = $136;
    HEAP32[$$pre$phi63Z2D>>2] = $134;
   } else {
    $$sum2 = (($psize) + 24)|0;
    $155 = (($p) + ($$sum2)|0);
    $156 = HEAP32[$155>>2]|0;
    $$sum3 = (($psize) + 12)|0;
    $157 = (($p) + ($$sum3)|0);
    $158 = HEAP32[$157>>2]|0;
    $159 = ($158|0)==($0|0);
    do {
     if ($159) {
      $$sum5 = (($psize) + 20)|0;
      $169 = (($p) + ($$sum5)|0);
      $170 = HEAP32[$169>>2]|0;
      $171 = ($170|0)==(0|0);
      if ($171) {
       $$sum4 = (($psize) + 16)|0;
       $172 = (($p) + ($$sum4)|0);
       $173 = HEAP32[$172>>2]|0;
       $174 = ($173|0)==(0|0);
       if ($174) {
        $R7$1 = 0;
        break;
       } else {
        $R7$0 = $173;$RP9$0 = $172;
       }
      } else {
       $R7$0 = $170;$RP9$0 = $169;
      }
      while(1) {
       $175 = (($R7$0) + 20|0);
       $176 = HEAP32[$175>>2]|0;
       $177 = ($176|0)==(0|0);
       if (!($177)) {
        $R7$0 = $176;$RP9$0 = $175;
        continue;
       }
       $178 = (($R7$0) + 16|0);
       $179 = HEAP32[$178>>2]|0;
       $180 = ($179|0)==(0|0);
       if ($180) {
        break;
       } else {
        $R7$0 = $179;$RP9$0 = $178;
       }
      }
      $181 = ($RP9$0>>>0)<($108>>>0);
      if ($181) {
       _abort();
       // unreachable;
      } else {
       HEAP32[$RP9$0>>2] = 0;
       $R7$1 = $R7$0;
       break;
      }
     } else {
      $$sum17 = (($psize) + 8)|0;
      $160 = (($p) + ($$sum17)|0);
      $161 = HEAP32[$160>>2]|0;
      $162 = ($161>>>0)<($108>>>0);
      if ($162) {
       _abort();
       // unreachable;
      }
      $163 = (($161) + 12|0);
      $164 = HEAP32[$163>>2]|0;
      $165 = ($164|0)==($0|0);
      if (!($165)) {
       _abort();
       // unreachable;
      }
      $166 = (($158) + 8|0);
      $167 = HEAP32[$166>>2]|0;
      $168 = ($167|0)==($0|0);
      if ($168) {
       HEAP32[$163>>2] = $158;
       HEAP32[$166>>2] = $161;
       $R7$1 = $158;
       break;
      } else {
       _abort();
       // unreachable;
      }
     }
    } while(0);
    $182 = ($156|0)==(0|0);
    if (!($182)) {
     $$sum14 = (($psize) + 28)|0;
     $183 = (($p) + ($$sum14)|0);
     $184 = HEAP32[$183>>2]|0;
     $185 = ((143912 + ($184<<2)|0) + 304|0);
     $186 = HEAP32[$185>>2]|0;
     $187 = ($0|0)==($186|0);
     if ($187) {
      HEAP32[$185>>2] = $R7$1;
      $cond46 = ($R7$1|0)==(0|0);
      if ($cond46) {
       $188 = 1 << $184;
       $189 = $188 ^ -1;
       $190 = HEAP32[((143912 + 4|0))>>2]|0;
       $191 = $190 & $189;
       HEAP32[((143912 + 4|0))>>2] = $191;
       break;
      }
     } else {
      $192 = HEAP32[((143912 + 16|0))>>2]|0;
      $193 = ($156>>>0)<($192>>>0);
      if ($193) {
       _abort();
       // unreachable;
      }
      $194 = (($156) + 16|0);
      $195 = HEAP32[$194>>2]|0;
      $196 = ($195|0)==($0|0);
      if ($196) {
       HEAP32[$194>>2] = $R7$1;
      } else {
       $197 = (($156) + 20|0);
       HEAP32[$197>>2] = $R7$1;
      }
      $198 = ($R7$1|0)==(0|0);
      if ($198) {
       break;
      }
     }
     $199 = HEAP32[((143912 + 16|0))>>2]|0;
     $200 = ($R7$1>>>0)<($199>>>0);
     if ($200) {
      _abort();
      // unreachable;
     }
     $201 = (($R7$1) + 24|0);
     HEAP32[$201>>2] = $156;
     $$sum15 = (($psize) + 16)|0;
     $202 = (($p) + ($$sum15)|0);
     $203 = HEAP32[$202>>2]|0;
     $204 = ($203|0)==(0|0);
     do {
      if (!($204)) {
       $205 = HEAP32[((143912 + 16|0))>>2]|0;
       $206 = ($203>>>0)<($205>>>0);
       if ($206) {
        _abort();
        // unreachable;
       } else {
        $207 = (($R7$1) + 16|0);
        HEAP32[$207>>2] = $203;
        $208 = (($203) + 24|0);
        HEAP32[$208>>2] = $R7$1;
        break;
       }
      }
     } while(0);
     $$sum16 = (($psize) + 20)|0;
     $209 = (($p) + ($$sum16)|0);
     $210 = HEAP32[$209>>2]|0;
     $211 = ($210|0)==(0|0);
     if (!($211)) {
      $212 = HEAP32[((143912 + 16|0))>>2]|0;
      $213 = ($210>>>0)<($212>>>0);
      if ($213) {
       _abort();
       // unreachable;
      } else {
       $214 = (($R7$1) + 20|0);
       HEAP32[$214>>2] = $210;
       $215 = (($210) + 24|0);
       HEAP32[$215>>2] = $R7$1;
       break;
      }
     }
    }
   }
  } while(0);
  $216 = $130 | 1;
  $217 = (($$0) + 4|0);
  HEAP32[$217>>2] = $216;
  $218 = (($$0) + ($130)|0);
  HEAP32[$218>>2] = $130;
  $219 = HEAP32[((143912 + 20|0))>>2]|0;
  $220 = ($$0|0)==($219|0);
  if ($220) {
   HEAP32[((143912 + 8|0))>>2] = $130;
   STACKTOP = sp;return;
  } else {
   $$1 = $130;
  }
 } else {
  $221 = $111 & -2;
  HEAP32[$110>>2] = $221;
  $222 = $$02 | 1;
  $223 = (($$0) + 4|0);
  HEAP32[$223>>2] = $222;
  $224 = (($$0) + ($$02)|0);
  HEAP32[$224>>2] = $$02;
  $$1 = $$02;
 }
 $225 = $$1 >>> 3;
 $226 = ($$1>>>0)<(256);
 if ($226) {
  $227 = $225 << 1;
  $228 = ((143912 + ($227<<2)|0) + 40|0);
  $229 = HEAP32[143912>>2]|0;
  $230 = 1 << $225;
  $231 = $229 & $230;
  $232 = ($231|0)==(0);
  if ($232) {
   $233 = $229 | $230;
   HEAP32[143912>>2] = $233;
   $$sum12$pre = (($227) + 2)|0;
   $$pre = ((143912 + ($$sum12$pre<<2)|0) + 40|0);
   $$pre$phiZ2D = $$pre;$F16$0 = $228;
  } else {
   $$sum13 = (($227) + 2)|0;
   $234 = ((143912 + ($$sum13<<2)|0) + 40|0);
   $235 = HEAP32[$234>>2]|0;
   $236 = HEAP32[((143912 + 16|0))>>2]|0;
   $237 = ($235>>>0)<($236>>>0);
   if ($237) {
    _abort();
    // unreachable;
   } else {
    $$pre$phiZ2D = $234;$F16$0 = $235;
   }
  }
  HEAP32[$$pre$phiZ2D>>2] = $$0;
  $238 = (($F16$0) + 12|0);
  HEAP32[$238>>2] = $$0;
  $239 = (($$0) + 8|0);
  HEAP32[$239>>2] = $F16$0;
  $240 = (($$0) + 12|0);
  HEAP32[$240>>2] = $228;
  STACKTOP = sp;return;
 }
 $241 = $$1 >>> 8;
 $242 = ($241|0)==(0);
 if ($242) {
  $I19$0 = 0;
 } else {
  $243 = ($$1>>>0)>(16777215);
  if ($243) {
   $I19$0 = 31;
  } else {
   $244 = (($241) + 1048320)|0;
   $245 = $244 >>> 16;
   $246 = $245 & 8;
   $247 = $241 << $246;
   $248 = (($247) + 520192)|0;
   $249 = $248 >>> 16;
   $250 = $249 & 4;
   $251 = $250 | $246;
   $252 = $247 << $250;
   $253 = (($252) + 245760)|0;
   $254 = $253 >>> 16;
   $255 = $254 & 2;
   $256 = $251 | $255;
   $257 = (14 - ($256))|0;
   $258 = $252 << $255;
   $259 = $258 >>> 15;
   $260 = (($257) + ($259))|0;
   $261 = $260 << 1;
   $262 = (($260) + 7)|0;
   $263 = $$1 >>> $262;
   $264 = $263 & 1;
   $265 = $264 | $261;
   $I19$0 = $265;
  }
 }
 $266 = ((143912 + ($I19$0<<2)|0) + 304|0);
 $267 = (($$0) + 28|0);
 $I19$0$c = $I19$0;
 HEAP32[$267>>2] = $I19$0$c;
 $268 = (($$0) + 20|0);
 HEAP32[$268>>2] = 0;
 $269 = (($$0) + 16|0);
 HEAP32[$269>>2] = 0;
 $270 = HEAP32[((143912 + 4|0))>>2]|0;
 $271 = 1 << $I19$0;
 $272 = $270 & $271;
 $273 = ($272|0)==(0);
 if ($273) {
  $274 = $270 | $271;
  HEAP32[((143912 + 4|0))>>2] = $274;
  HEAP32[$266>>2] = $$0;
  $275 = (($$0) + 24|0);
  HEAP32[$275>>2] = $266;
  $276 = (($$0) + 12|0);
  HEAP32[$276>>2] = $$0;
  $277 = (($$0) + 8|0);
  HEAP32[$277>>2] = $$0;
  STACKTOP = sp;return;
 }
 $278 = HEAP32[$266>>2]|0;
 $279 = ($I19$0|0)==(31);
 if ($279) {
  $287 = 0;
 } else {
  $280 = $I19$0 >>> 1;
  $281 = (25 - ($280))|0;
  $287 = $281;
 }
 $282 = (($278) + 4|0);
 $283 = HEAP32[$282>>2]|0;
 $284 = $283 & -8;
 $285 = ($284|0)==($$1|0);
 L194: do {
  if ($285) {
   $T$0$lcssa = $278;
  } else {
   $286 = $$1 << $287;
   $K20$049 = $286;$T$048 = $278;
   while(1) {
    $294 = $K20$049 >>> 31;
    $295 = ((($T$048) + ($294<<2)|0) + 16|0);
    $290 = HEAP32[$295>>2]|0;
    $296 = ($290|0)==(0|0);
    if ($296) {
     break;
    }
    $288 = $K20$049 << 1;
    $289 = (($290) + 4|0);
    $291 = HEAP32[$289>>2]|0;
    $292 = $291 & -8;
    $293 = ($292|0)==($$1|0);
    if ($293) {
     $T$0$lcssa = $290;
     break L194;
    } else {
     $K20$049 = $288;$T$048 = $290;
    }
   }
   $297 = HEAP32[((143912 + 16|0))>>2]|0;
   $298 = ($295>>>0)<($297>>>0);
   if ($298) {
    _abort();
    // unreachable;
   }
   HEAP32[$295>>2] = $$0;
   $299 = (($$0) + 24|0);
   HEAP32[$299>>2] = $T$048;
   $300 = (($$0) + 12|0);
   HEAP32[$300>>2] = $$0;
   $301 = (($$0) + 8|0);
   HEAP32[$301>>2] = $$0;
   STACKTOP = sp;return;
  }
 } while(0);
 $302 = (($T$0$lcssa) + 8|0);
 $303 = HEAP32[$302>>2]|0;
 $304 = HEAP32[((143912 + 16|0))>>2]|0;
 $305 = ($T$0$lcssa>>>0)<($304>>>0);
 if ($305) {
  _abort();
  // unreachable;
 }
 $306 = ($303>>>0)<($304>>>0);
 if ($306) {
  _abort();
  // unreachable;
 }
 $307 = (($303) + 12|0);
 HEAP32[$307>>2] = $$0;
 HEAP32[$302>>2] = $$0;
 $308 = (($$0) + 8|0);
 HEAP32[$308>>2] = $303;
 $309 = (($$0) + 12|0);
 HEAP32[$309>>2] = $T$0$lcssa;
 $310 = (($$0) + 24|0);
 HEAP32[$310>>2] = 0;
 STACKTOP = sp;return;
}
function _isspace($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($c|0)==(32);
 if ($0) {
  $4 = 1;
 } else {
  $1 = (($c) + -9)|0;
  $2 = ($1>>>0)<(5);
  $4 = $2;
 }
 $3 = $4&1;
 STACKTOP = sp;return ($3|0);
}
function ___intscan($f,$base,$pok,$0,$1) {
 $f = $f|0;
 $base = $base|0;
 $pok = $pok|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$1 = 0, $$121 = 0, $$122 = 0, $$18 = 0, $$19 = 0, $$base = 0, $$base16 = 0, $$lcssa = 0, $$sum = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum1352 = 0, $$sum14 = 0, $$sum15 = 0, $$sum9 = 0, $$sum934 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $c$0 = 0, $c$1 = 0, $c$123 = 0, $c$2$be = 0, $c$2$lcssa = 0, $c$3$be = 0, $c$3$lcssa = 0, $c$359 = 0, $c$4$be = 0, $c$4$lcssa = 0, $c$5$be = 0, $c$6$be = 0, $c$6$lcssa = 0, $c$7$be = 0, $c$744 = 0;
 var $c$8 = 0, $c$9$be = 0, $neg$0 = 0, $or$cond = 0, $or$cond17 = 0, $or$cond20 = 0, $or$cond26 = 0, $or$cond2628 = 0, $phitmp93 = 0, $x$068 = 0, $x$135 = 0, $x$253 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($base>>>0)>(36);
 if ($2) {
  $5 = (___errno_location()|0);
  HEAP32[$5>>2] = 22;
  $278 = 0;$279 = 0;
  tempRet0 = $278;
  STACKTOP = sp;return ($279|0);
 }
 $3 = (($f) + 4|0);
 $4 = (($f) + 100|0);
 while(1) {
  $6 = HEAP32[$3>>2]|0;
  $7 = HEAP32[$4>>2]|0;
  $8 = ($6>>>0)<($7>>>0);
  if ($8) {
   $9 = (($6) + 1|0);
   HEAP32[$3>>2] = $9;
   $10 = HEAP8[$6>>0]|0;
   $11 = $10&255;
   $13 = $11;
  } else {
   $12 = (___shgetc($f)|0);
   $13 = $12;
  }
  $14 = (_isspace($13)|0);
  $15 = ($14|0)==(0);
  if ($15) {
   break;
  }
 }
 $16 = ($13|0)==(45);
 do {
  if ((($13|0) == 43) | (($13|0) == 45)) {
   $17 = $16 << 31 >> 31;
   $18 = HEAP32[$3>>2]|0;
   $19 = HEAP32[$4>>2]|0;
   $20 = ($18>>>0)<($19>>>0);
   if ($20) {
    $21 = (($18) + 1|0);
    HEAP32[$3>>2] = $21;
    $22 = HEAP8[$18>>0]|0;
    $23 = $22&255;
    $c$0 = $23;$neg$0 = $17;
    break;
   } else {
    $24 = (___shgetc($f)|0);
    $c$0 = $24;$neg$0 = $17;
    break;
   }
  } else {
   $c$0 = $13;$neg$0 = 0;
  }
 } while(0);
 $25 = ($base|0)==(0);
 $26 = $base & -17;
 $27 = ($26|0)==(0);
 $28 = ($c$0|0)==(48);
 $or$cond = $27 & $28;
 do {
  if ($or$cond) {
   $29 = HEAP32[$3>>2]|0;
   $30 = HEAP32[$4>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    $32 = (($29) + 1|0);
    HEAP32[$3>>2] = $32;
    $33 = HEAP8[$29>>0]|0;
    $34 = $33&255;
    $37 = $34;
   } else {
    $35 = (___shgetc($f)|0);
    $37 = $35;
   }
   $36 = $37 | 32;
   $38 = ($36|0)==(120);
   if (!($38)) {
    $$base = $25 ? 8 : $base;
    $$1 = $$base;$c$1 = $37;
    label = 32;
    break;
   }
   $39 = HEAP32[$3>>2]|0;
   $40 = HEAP32[$4>>2]|0;
   $41 = ($39>>>0)<($40>>>0);
   if ($41) {
    $42 = (($39) + 1|0);
    HEAP32[$3>>2] = $42;
    $43 = HEAP8[$39>>0]|0;
    $44 = $43&255;
    $46 = $44;
   } else {
    $45 = (___shgetc($f)|0);
    $46 = $45;
   }
   $$sum15 = (($46) + 1)|0;
   $47 = (144408 + ($$sum15)|0);
   $48 = HEAP8[$47>>0]|0;
   $49 = ($48&255)>(15);
   if ($49) {
    $50 = HEAP32[$4>>2]|0;
    $51 = ($50|0)==(0|0);
    if (!($51)) {
     $52 = HEAP32[$3>>2]|0;
     $53 = (($52) + -1|0);
     HEAP32[$3>>2] = $53;
    }
    $54 = ($pok|0)==(0);
    if ($54) {
     ___shlim($f,0);
     $278 = 0;$279 = 0;
     tempRet0 = $278;
     STACKTOP = sp;return ($279|0);
    }
    if ($51) {
     $278 = 0;$279 = 0;
     tempRet0 = $278;
     STACKTOP = sp;return ($279|0);
    }
    $55 = HEAP32[$3>>2]|0;
    $56 = (($55) + -1|0);
    HEAP32[$3>>2] = $56;
    $278 = 0;$279 = 0;
    tempRet0 = $278;
    STACKTOP = sp;return ($279|0);
   } else {
    $$122 = 16;$c$123 = $46;
    label = 47;
   }
  } else {
   $$base16 = $25 ? 10 : $base;
   $$sum = (($c$0) + 1)|0;
   $57 = (144408 + ($$sum)|0);
   $58 = HEAP8[$57>>0]|0;
   $59 = $58&255;
   $60 = ($59>>>0)<($$base16>>>0);
   if ($60) {
    $$1 = $$base16;$c$1 = $c$0;
    label = 32;
   } else {
    $61 = HEAP32[$4>>2]|0;
    $62 = ($61|0)==(0|0);
    if (!($62)) {
     $63 = HEAP32[$3>>2]|0;
     $64 = (($63) + -1|0);
     HEAP32[$3>>2] = $64;
    }
    ___shlim($f,0);
    $65 = (___errno_location()|0);
    HEAP32[$65>>2] = 22;
    $278 = 0;$279 = 0;
    tempRet0 = $278;
    STACKTOP = sp;return ($279|0);
   }
  }
 } while(0);
 if ((label|0) == 32) {
  $66 = ($$1|0)==(10);
  if ($66) {
   $67 = (($c$1) + -48)|0;
   $68 = ($67>>>0)<(10);
   if ($68) {
    $70 = $67;$x$068 = 0;
    while(1) {
     $69 = (($x$068) + ($70))|0;
     $71 = HEAP32[$3>>2]|0;
     $72 = HEAP32[$4>>2]|0;
     $73 = ($71>>>0)<($72>>>0);
     if ($73) {
      $74 = (($71) + 1|0);
      HEAP32[$3>>2] = $74;
      $75 = HEAP8[$71>>0]|0;
      $76 = $75&255;
      $c$2$be = $76;
     } else {
      $77 = (___shgetc($f)|0);
      $c$2$be = $77;
     }
     $78 = (($c$2$be) + -48)|0;
     $79 = ($78>>>0)<(10);
     $80 = ($69>>>0)<(429496729);
     $$ = $79 & $80;
     if (!($$)) {
      break;
     }
     $phitmp93 = ($69*10)|0;
     $70 = $78;$x$068 = $phitmp93;
    }
    $280 = $69;$281 = 0;$c$2$lcssa = $c$2$be;
   } else {
    $280 = 0;$281 = 0;$c$2$lcssa = $c$1;
   }
   $81 = (($c$2$lcssa) + -48)|0;
   $82 = ($81>>>0)<(10);
   if ($82) {
    $83 = $280;$84 = $281;$87 = $81;$c$359 = $c$2$lcssa;
    while(1) {
     $85 = (___muldi3(($83|0),($84|0),10,0)|0);
     $86 = tempRet0;
     $88 = ($87|0)<(0);
     $89 = $88 << 31 >> 31;
     $90 = $87 ^ -1;
     $91 = $89 ^ -1;
     $92 = ($86>>>0)>($91>>>0);
     $93 = ($86|0)==($91|0);
     $94 = ($85>>>0)>($90>>>0);
     $95 = $93 & $94;
     $96 = $92 | $95;
     if ($96) {
      $$lcssa = $87;$282 = $83;$283 = $84;$c$3$lcssa = $c$359;
      break;
     }
     $97 = (_i64Add(($85|0),($86|0),($87|0),($89|0))|0);
     $98 = tempRet0;
     $99 = HEAP32[$3>>2]|0;
     $100 = HEAP32[$4>>2]|0;
     $101 = ($99>>>0)<($100>>>0);
     if ($101) {
      $102 = (($99) + 1|0);
      HEAP32[$3>>2] = $102;
      $103 = HEAP8[$99>>0]|0;
      $104 = $103&255;
      $c$3$be = $104;
     } else {
      $105 = (___shgetc($f)|0);
      $c$3$be = $105;
     }
     $106 = (($c$3$be) + -48)|0;
     $107 = ($106>>>0)<(10);
     $108 = ($98>>>0)<(429496729);
     $109 = ($98|0)==(429496729);
     $110 = ($97>>>0)<(2576980378);
     $111 = $109 & $110;
     $112 = $108 | $111;
     $or$cond17 = $107 & $112;
     if ($or$cond17) {
      $83 = $97;$84 = $98;$87 = $106;$c$359 = $c$3$be;
     } else {
      $$lcssa = $106;$282 = $97;$283 = $98;$c$3$lcssa = $c$3$be;
      break;
     }
    }
    $113 = ($$lcssa>>>0)>(9);
    if ($113) {
     $251 = $283;$254 = $282;
    } else {
     $$121 = 10;$284 = $282;$285 = $283;$c$8 = $c$3$lcssa;
     label = 73;
    }
   } else {
    $251 = $281;$254 = $280;
   }
  } else {
   $$122 = $$1;$c$123 = $c$1;
   label = 47;
  }
 }
 L70: do {
  if ((label|0) == 47) {
   $114 = (($$122) + -1)|0;
   $115 = $114 & $$122;
   $116 = ($115|0)==(0);
   if ($116) {
    $121 = ($$122*23)|0;
    $122 = $121 >>> 5;
    $123 = $122 & 7;
    $124 = (144672 + ($123)|0);
    $125 = HEAP8[$124>>0]|0;
    $126 = $125 << 24 >> 24;
    $$sum934 = (($c$123) + 1)|0;
    $127 = (144408 + ($$sum934)|0);
    $128 = HEAP8[$127>>0]|0;
    $129 = $128&255;
    $130 = ($129>>>0)<($$122>>>0);
    if ($130) {
     $133 = $129;$x$135 = 0;
     while(1) {
      $131 = $x$135 << $126;
      $132 = $133 | $131;
      $134 = HEAP32[$3>>2]|0;
      $135 = HEAP32[$4>>2]|0;
      $136 = ($134>>>0)<($135>>>0);
      if ($136) {
       $137 = (($134) + 1|0);
       HEAP32[$3>>2] = $137;
       $138 = HEAP8[$134>>0]|0;
       $139 = $138&255;
       $c$4$be = $139;
      } else {
       $140 = (___shgetc($f)|0);
       $c$4$be = $140;
      }
      $$sum9 = (($c$4$be) + 1)|0;
      $141 = (144408 + ($$sum9)|0);
      $142 = HEAP8[$141>>0]|0;
      $143 = $142&255;
      $144 = ($143>>>0)<($$122>>>0);
      $145 = ($132>>>0)<(134217728);
      $$18 = $144 & $145;
      if ($$18) {
       $133 = $143;$x$135 = $132;
      } else {
       break;
      }
     }
     $149 = $142;$151 = 0;$154 = $132;$c$4$lcssa = $c$4$be;
    } else {
     $149 = $128;$151 = 0;$154 = 0;$c$4$lcssa = $c$123;
    }
    $146 = (_bitshift64Lshr(-1,-1,($126|0))|0);
    $147 = tempRet0;
    $148 = $149&255;
    $150 = ($148>>>0)>=($$122>>>0);
    $152 = ($151>>>0)>($147>>>0);
    $153 = ($151|0)==($147|0);
    $155 = ($154>>>0)>($146>>>0);
    $156 = $153 & $155;
    $157 = $152 | $156;
    $or$cond2628 = $150 | $157;
    if ($or$cond2628) {
     $$121 = $$122;$284 = $154;$285 = $151;$c$8 = $c$4$lcssa;
     label = 73;
     break;
    } else {
     $158 = $154;$159 = $151;$163 = $149;
    }
    while(1) {
     $160 = (_bitshift64Shl(($158|0),($159|0),($126|0))|0);
     $161 = tempRet0;
     $162 = $163&255;
     $164 = $162 | $160;
     $165 = HEAP32[$3>>2]|0;
     $166 = HEAP32[$4>>2]|0;
     $167 = ($165>>>0)<($166>>>0);
     if ($167) {
      $168 = (($165) + 1|0);
      HEAP32[$3>>2] = $168;
      $169 = HEAP8[$165>>0]|0;
      $170 = $169&255;
      $c$5$be = $170;
     } else {
      $171 = (___shgetc($f)|0);
      $c$5$be = $171;
     }
     $$sum10 = (($c$5$be) + 1)|0;
     $172 = (144408 + ($$sum10)|0);
     $173 = HEAP8[$172>>0]|0;
     $174 = $173&255;
     $175 = ($174>>>0)>=($$122>>>0);
     $176 = ($161>>>0)>($147>>>0);
     $177 = ($161|0)==($147|0);
     $178 = ($164>>>0)>($146>>>0);
     $179 = $177 & $178;
     $180 = $176 | $179;
     $or$cond26 = $175 | $180;
     if ($or$cond26) {
      $$121 = $$122;$284 = $164;$285 = $161;$c$8 = $c$5$be;
      label = 73;
      break L70;
     } else {
      $158 = $164;$159 = $161;$163 = $173;
     }
    }
   }
   $$sum1352 = (($c$123) + 1)|0;
   $117 = (144408 + ($$sum1352)|0);
   $118 = HEAP8[$117>>0]|0;
   $119 = $118&255;
   $120 = ($119>>>0)<($$122>>>0);
   if ($120) {
    $183 = $119;$x$253 = 0;
    while(1) {
     $181 = Math_imul($x$253, $$122)|0;
     $182 = (($183) + ($181))|0;
     $184 = HEAP32[$3>>2]|0;
     $185 = HEAP32[$4>>2]|0;
     $186 = ($184>>>0)<($185>>>0);
     if ($186) {
      $187 = (($184) + 1|0);
      HEAP32[$3>>2] = $187;
      $188 = HEAP8[$184>>0]|0;
      $189 = $188&255;
      $c$6$be = $189;
     } else {
      $190 = (___shgetc($f)|0);
      $c$6$be = $190;
     }
     $$sum13 = (($c$6$be) + 1)|0;
     $191 = (144408 + ($$sum13)|0);
     $192 = HEAP8[$191>>0]|0;
     $193 = $192&255;
     $194 = ($193>>>0)<($$122>>>0);
     $195 = ($182>>>0)<(119304647);
     $$19 = $194 & $195;
     if ($$19) {
      $183 = $193;$x$253 = $182;
     } else {
      break;
     }
    }
    $197 = $192;$286 = $182;$287 = 0;$c$6$lcssa = $c$6$be;
   } else {
    $197 = $118;$286 = 0;$287 = 0;$c$6$lcssa = $c$123;
   }
   $196 = $197&255;
   $198 = ($196>>>0)<($$122>>>0);
   if ($198) {
    $199 = (___udivdi3(-1,-1,($$122|0),0)|0);
    $200 = tempRet0;
    $201 = $287;$204 = $286;$211 = $197;$c$744 = $c$6$lcssa;
    while(1) {
     $202 = ($201>>>0)>($200>>>0);
     $203 = ($201|0)==($200|0);
     $205 = ($204>>>0)>($199>>>0);
     $206 = $203 & $205;
     $207 = $202 | $206;
     if ($207) {
      $$121 = $$122;$284 = $204;$285 = $201;$c$8 = $c$744;
      label = 73;
      break L70;
     }
     $208 = (___muldi3(($204|0),($201|0),($$122|0),0)|0);
     $209 = tempRet0;
     $210 = $211&255;
     $212 = $210 ^ -1;
     $213 = ($209>>>0)>(4294967295);
     $214 = ($209|0)==(-1);
     $215 = ($208>>>0)>($212>>>0);
     $216 = $214 & $215;
     $217 = $213 | $216;
     if ($217) {
      $$121 = $$122;$284 = $204;$285 = $201;$c$8 = $c$744;
      label = 73;
      break L70;
     }
     $218 = (_i64Add(($210|0),0,($208|0),($209|0))|0);
     $219 = tempRet0;
     $220 = HEAP32[$3>>2]|0;
     $221 = HEAP32[$4>>2]|0;
     $222 = ($220>>>0)<($221>>>0);
     if ($222) {
      $223 = (($220) + 1|0);
      HEAP32[$3>>2] = $223;
      $224 = HEAP8[$220>>0]|0;
      $225 = $224&255;
      $c$7$be = $225;
     } else {
      $226 = (___shgetc($f)|0);
      $c$7$be = $226;
     }
     $$sum14 = (($c$7$be) + 1)|0;
     $227 = (144408 + ($$sum14)|0);
     $228 = HEAP8[$227>>0]|0;
     $229 = $228&255;
     $230 = ($229>>>0)<($$122>>>0);
     if ($230) {
      $201 = $219;$204 = $218;$211 = $228;$c$744 = $c$7$be;
     } else {
      $$121 = $$122;$284 = $218;$285 = $219;$c$8 = $c$7$be;
      label = 73;
      break;
     }
    }
   } else {
    $$121 = $$122;$284 = $286;$285 = $287;$c$8 = $c$6$lcssa;
    label = 73;
   }
  }
 } while(0);
 if ((label|0) == 73) {
  $$sum11 = (($c$8) + 1)|0;
  $231 = (144408 + ($$sum11)|0);
  $232 = HEAP8[$231>>0]|0;
  $233 = $232&255;
  $234 = ($233>>>0)<($$121>>>0);
  if ($234) {
   while(1) {
    $235 = HEAP32[$3>>2]|0;
    $236 = HEAP32[$4>>2]|0;
    $237 = ($235>>>0)<($236>>>0);
    if ($237) {
     $238 = (($235) + 1|0);
     HEAP32[$3>>2] = $238;
     $239 = HEAP8[$235>>0]|0;
     $240 = $239&255;
     $c$9$be = $240;
    } else {
     $241 = (___shgetc($f)|0);
     $c$9$be = $241;
    }
    $$sum12 = (($c$9$be) + 1)|0;
    $242 = (144408 + ($$sum12)|0);
    $243 = HEAP8[$242>>0]|0;
    $244 = $243&255;
    $245 = ($244>>>0)<($$121>>>0);
    if (!($245)) {
     break;
    }
   }
   $246 = (___errno_location()|0);
   HEAP32[$246>>2] = 34;
   $251 = $1;$254 = $0;
  } else {
   $251 = $285;$254 = $284;
  }
 }
 $247 = HEAP32[$4>>2]|0;
 $248 = ($247|0)==(0|0);
 if (!($248)) {
  $249 = HEAP32[$3>>2]|0;
  $250 = (($249) + -1|0);
  HEAP32[$3>>2] = $250;
 }
 $252 = ($251>>>0)<($1>>>0);
 $253 = ($251|0)==($1|0);
 $255 = ($254>>>0)<($0>>>0);
 $256 = $253 & $255;
 $257 = $252 | $256;
 if (!($257)) {
  $258 = $0 & 1;
  $259 = ($258|0)==(0);
  $260 = (0)==(0);
  $261 = $259 & $260;
  $262 = ($neg$0|0)==(0);
  $or$cond20 = $261 & $262;
  if ($or$cond20) {
   $263 = (___errno_location()|0);
   HEAP32[$263>>2] = 34;
   $264 = (_i64Add(($0|0),($1|0),-1,-1)|0);
   $265 = tempRet0;
   $278 = $265;$279 = $264;
   tempRet0 = $278;
   STACKTOP = sp;return ($279|0);
  }
  $266 = ($251>>>0)>($1>>>0);
  $267 = ($251|0)==($1|0);
  $268 = ($254>>>0)>($0>>>0);
  $269 = $267 & $268;
  $270 = $266 | $269;
  if ($270) {
   $271 = (___errno_location()|0);
   HEAP32[$271>>2] = 34;
   $278 = $1;$279 = $0;
   tempRet0 = $278;
   STACKTOP = sp;return ($279|0);
  }
 }
 $272 = ($neg$0|0)<(0);
 $273 = $272 << 31 >> 31;
 $274 = $254 ^ $neg$0;
 $275 = $251 ^ $273;
 $276 = (_i64Subtract(($274|0),($275|0),($neg$0|0),($273|0))|0);
 $277 = tempRet0;
 $278 = $277;$279 = $276;
 tempRet0 = $278;
 STACKTOP = sp;return ($279|0);
}
function ___floatscan($f,$prec,$pok) {
 $f = $f|0;
 $prec = $prec|0;
 $pok = $pok|0;
 var $$$i = 0, $$$i22 = 0, $$0 = 0.0, $$02$i = 0, $$08$i = 0, $$09$i = 0, $$1$be$i = 0, $$1$ph$i = 0, $$10$i = 0, $$14$i = 0, $$2$i = 0, $$3$be$i = 0, $$3$lcssa$i = 0, $$38$i = 0, $$388$i = 0, $$397$i = 0, $$in = 0, $$k$0$i = 0, $$lcssa43$i = 0, $$lnz$0$i = 0;
 var $$neg20$i = 0, $$pn$i = 0.0, $$pre$i = 0.0, $$pre$i17 = 0, $$pre$phi$iZ2D = 0.0, $$promoted$i = 0, $$sink$off0$us$i = 0, $$sink$off0$us53$i = 0, $$x$4$i = 0, $$y$3$i = 0.0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0, $187 = 0, $188 = 0.0, $189 = 0.0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0.0, $209 = 0.0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0.0, $255 = 0.0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0.0, $264 = 0.0, $265 = 0.0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0.0, $277 = 0.0, $278 = 0.0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0.0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0.0;
 var $305 = 0.0, $306 = 0.0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0.0, $313 = 0.0, $314 = 0.0, $315 = 0.0, $316 = 0.0, $317 = 0.0, $318 = 0, $319 = 0, $32 = 0, $320 = 0.0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0;
 var $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0;
 var $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0;
 var $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0;
 var $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0.0, $418 = 0.0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0;
 var $431 = 0, $432 = 0, $433 = 0, $434 = 0.0, $435 = 0.0, $436 = 0.0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0.0, $447 = 0.0, $448 = 0.0, $449 = 0;
 var $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0.0, $459 = 0.0, $46 = 0, $460 = 0.0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0;
 var $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0.0, $473 = 0, $474 = 0.0, $475 = 0.0, $476 = 0, $477 = 0.0, $478 = 0, $479 = 0.0, $48 = 0, $480 = 0.0, $481 = 0, $482 = 0, $483 = 0, $484 = 0.0, $485 = 0.0;
 var $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0.0, $490 = 0, $491 = 0.0, $492 = 0.0, $493 = 0.0, $494 = 0, $495 = 0, $496 = 0, $497 = 0.0, $498 = 0.0, $499 = 0, $5 = 0, $50 = 0.0, $500 = 0, $501 = 0, $502 = 0;
 var $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0.0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0;
 var $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0;
 var $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0;
 var $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0;
 var $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0;
 var $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0;
 var $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0;
 var $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0.0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0;
 var $648 = 0.0, $649 = 0.0, $65 = 0, $650 = 0.0, $651 = 0, $652 = 0.0, $653 = 0.0, $654 = 0.0, $655 = 0.0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0;
 var $666 = 0.0, $667 = 0.0, $668 = 0.0, $669 = 0, $67 = 0, $670 = 0.0, $671 = 0.0, $672 = 0, $673 = 0, $674 = 0, $675 = 0.0, $676 = 0.0, $677 = 0.0, $678 = 0.0, $679 = 0, $68 = 0, $680 = 0, $681 = 0.0, $682 = 0, $683 = 0.0;
 var $684 = 0.0, $685 = 0.0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0.0, $691 = 0, $692 = 0, $693 = 0, $694 = 0.0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0;
 var $701 = 0.0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0.0, $707 = 0, $708 = 0, $709 = 0.0, $71 = 0, $710 = 0.0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0;
 var $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$0$lcssa161$i = 0, $a$061$i = 0, $a$1$i = 0, $a$2$ph40$i = 0;
 var $a$3$i = 0, $a$3$i$ph = 0, $a$3$ph$i = 0, $a$427$i = 0, $a$5$i = 0, $bias$0$i = 0.0, $bias$07$i = 0.0, $bits$0$ph = 0, $brmerge = 0, $brmerge107 = 0, $c$0 = 0, $c$0$i = 0, $c$1$lcssa = 0, $c$1$ph$i = 0, $c$169 = 0, $c$2 = 0, $c$2$i = 0, $c$2$lcssa$i = 0, $c$364 = 0, $c$4 = 0;
 var $c$5 = 0, $c$6 = 0, $carry$063$i = 0, $carry1$0$us$i = 0, $carry1$0$us49$i = 0, $carry1$1$lcssa$lcssa$i = 0, $carry1$1$us$i = 0, $carry1$1$us54$i = 0, $carry3$030$i = 0, $cond$i = 0, $d$0$i = 0, $denormal$0$i = 0, $denormal$1$i = 0, $denormal$2$i = 0, $e2$0$ph$i = 0, $e2$0$us$i = 0, $e2$0$us44$i = 0, $e2$1$i = 0, $e2$1$i$ph = 0, $e2$1$ph$i = 0;
 var $e2$2$i = 0, $e2$3$i = 0, $emin$0$ph = 0, $exitcond$i = 0, $frac$0$i = 0.0, $frac$1$i = 0.0, $frac$2$i = 0.0, $gotdig$0$i = 0, $gotdig$0$i9 = 0, $gotdig$2$i = 0, $gotdig$2$i11 = 0, $gotdig$3$i = 0, $gotdig$3$lcssa$i = 0, $gotdig$381$i = 0, $gotdig$393$i = 0, $gotdig$4$i = 0, $gotrad$0$i = 0, $gotrad$0$i12 = 0, $gotrad$1$i = 0, $gotrad$1$lcssa$i = 0;
 var $gotrad$194$i = 0, $gotrad$2$i = 0, $gottail$0$i = 0, $gottail$1$i = 0, $gottail$2$i = 0, $i$0$lcssa = 0, $i$025$i = 0, $i$068 = 0, $i$1$i = 0, $i$166 = 0, $i$263 = 0, $i$3 = 0, $i$4 = 0, $j$0$lcssa$i = 0, $j$086$i = 0, $j$096$i = 0, $j$2$i = 0, $j$371$i = 0, $k$0$lcssa$i = 0, $k$084$i = 0;
 var $k$095$i = 0, $k$2$i = 0, $k$3$i = 0, $k$462$i = 0, $k$5$in$us$i = 0, $k$5$in$us48$i = 0, $k$5$us$i = 0, $k$5$us50$i = 0, $k$5$z$2$us$i = 0, $k$5$z$2$us56$i = 0, $k$628$i = 0, $lnz$0$lcssa$i = 0, $lnz$079$i = 0, $lnz$092$i = 0, $lnz$2$i = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i15 = 0;
 var $or$cond106$not = 0, $or$cond11$i = 0, $or$cond12$us$i = 0, $or$cond12$us55$i = 0, $or$cond13$i = 0, $or$cond15$i = 0, $or$cond16$i = 0, $or$cond17$i = 0, $or$cond3$i = 0, $or$cond3$i16 = 0, $or$cond4$i = 0, $or$cond5 = 0, $or$cond7$i = 0, $or$cond789$i = 0, $or$cond8 = 0, $rp$0$lcssa162$i = 0, $rp$060$i = 0, $rp$1$i18 = 0, $rp$2$ph38$i = 0, $rp$3$i$ph = 0;
 var $rp$3$ph33$i = 0, $rp$426$i = 0, $rp$5$i = 0, $scale$0$i = 0.0, $scale$1$i = 0.0, $scale$2$i = 0.0, $sign$0 = 0, $storemerge$i = 0, $sum$i = 0, $x$0$i = 0, $x$1$i = 0, $x$2$i = 0, $x$3$lcssa$i = 0, $x$313$i = 0, $x$4$lcssa$i = 0, $x$48$i = 0, $x$5$i = 0, $x$6$i = 0, $x$i = 0, $y$0$i = 0.0;
 var $y$1$i = 0.0, $y$1$i23 = 0.0, $y$2$i = 0.0, $y$2$i24 = 0.0, $y$3$i = 0.0, $y$3$lcssa$i = 0.0, $y$39$i = 0.0, $y$4$i = 0.0, $y$5$i = 0.0, $z$0$i = 0, $z$1$ph39$i = 0, $z$1$us$i = 0, $z$1$us45$i = 0, $z$2$us$i = 0, $z$2$us47$i = 0, $z$3$lcssa$lcssa$i = 0, $z$3$us$i = 0, $z$3$us57$i = 0, $z$4$i = 0, $z$5$ph$i = 0;
 var $z$7$1$i = 0, $z$7$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $x$i = sp;
 if ((($prec|0) == 1)) {
  $bits$0$ph = 53;$emin$0$ph = -1074;
 } else if ((($prec|0) == 0)) {
  $bits$0$ph = 24;$emin$0$ph = -149;
 } else if ((($prec|0) == 2)) {
  $bits$0$ph = 53;$emin$0$ph = -1074;
 } else {
  $$0 = 0.0;
  STACKTOP = sp;return (+$$0);
 }
 $0 = (($f) + 4|0);
 $1 = (($f) + 100|0);
 while(1) {
  $2 = HEAP32[$0>>2]|0;
  $3 = HEAP32[$1>>2]|0;
  $4 = ($2>>>0)<($3>>>0);
  if ($4) {
   $5 = (($2) + 1|0);
   HEAP32[$0>>2] = $5;
   $6 = HEAP8[$2>>0]|0;
   $7 = $6&255;
   $9 = $7;
  } else {
   $8 = (___shgetc($f)|0);
   $9 = $8;
  }
  $10 = (_isspace($9)|0);
  $11 = ($10|0)==(0);
  if ($11) {
   break;
  }
 }
 $12 = ($9|0)==(45);
 do {
  if ((($9|0) == 43) | (($9|0) == 45)) {
   $13 = $12&1;
   $14 = $13 << 1;
   $15 = (1 - ($14))|0;
   $16 = HEAP32[$0>>2]|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ($16>>>0)<($17>>>0);
   if ($18) {
    $19 = (($16) + 1|0);
    HEAP32[$0>>2] = $19;
    $20 = HEAP8[$16>>0]|0;
    $21 = $20&255;
    $c$0 = $21;$sign$0 = $15;
    break;
   } else {
    $22 = (___shgetc($f)|0);
    $c$0 = $22;$sign$0 = $15;
    break;
   }
  } else {
   $c$0 = $9;$sign$0 = 1;
  }
 } while(0);
 $c$169 = $c$0;$i$068 = 0;
 while(1) {
  $23 = $c$169 | 32;
  $24 = (144688 + ($i$068)|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = $25 << 24 >> 24;
  $27 = ($23|0)==($26|0);
  if (!($27)) {
   $c$1$lcssa = $c$169;$i$0$lcssa = $i$068;
   break;
  }
  $28 = ($i$068>>>0)<(7);
  do {
   if ($28) {
    $29 = HEAP32[$0>>2]|0;
    $30 = HEAP32[$1>>2]|0;
    $31 = ($29>>>0)<($30>>>0);
    if ($31) {
     $32 = (($29) + 1|0);
     HEAP32[$0>>2] = $32;
     $33 = HEAP8[$29>>0]|0;
     $34 = $33&255;
     $c$2 = $34;
     break;
    } else {
     $35 = (___shgetc($f)|0);
     $c$2 = $35;
     break;
    }
   } else {
    $c$2 = $c$169;
   }
  } while(0);
  $36 = (($i$068) + 1)|0;
  $37 = ($36>>>0)<(8);
  if ($37) {
   $c$169 = $c$2;$i$068 = $36;
  } else {
   $c$1$lcssa = $c$2;$i$0$lcssa = $36;
   break;
  }
 }
 do {
  if ((($i$0$lcssa|0) == 3)) {
   label = 23;
  } else if (!((($i$0$lcssa|0) == 8))) {
   $38 = ($i$0$lcssa>>>0)<(4);
   $39 = ($pok|0)==(0);
   $or$cond = $38 | $39;
   if (!($or$cond)) {
    $40 = ($i$0$lcssa|0)==(8);
    if ($40) {
     break;
    } else {
     label = 23;
     break;
    }
   }
   $52 = ($i$0$lcssa|0)==(0);
   L34: do {
    if ($52) {
     $c$364 = $c$1$lcssa;$i$263 = 0;
     while(1) {
      $53 = $c$364 | 32;
      $54 = (144704 + ($i$263)|0);
      $55 = HEAP8[$54>>0]|0;
      $56 = $55 << 24 >> 24;
      $57 = ($53|0)==($56|0);
      if (!($57)) {
       $c$5 = $c$364;$i$3 = $i$263;
       break L34;
      }
      $58 = ($i$263>>>0)<(2);
      do {
       if ($58) {
        $59 = HEAP32[$0>>2]|0;
        $60 = HEAP32[$1>>2]|0;
        $61 = ($59>>>0)<($60>>>0);
        if ($61) {
         $62 = (($59) + 1|0);
         HEAP32[$0>>2] = $62;
         $63 = HEAP8[$59>>0]|0;
         $64 = $63&255;
         $c$4 = $64;
         break;
        } else {
         $65 = (___shgetc($f)|0);
         $c$4 = $65;
         break;
        }
       } else {
        $c$4 = $c$364;
       }
      } while(0);
      $66 = (($i$263) + 1)|0;
      $67 = ($66>>>0)<(3);
      if ($67) {
       $c$364 = $c$4;$i$263 = $66;
      } else {
       $c$5 = $c$4;$i$3 = $66;
       break;
      }
     }
    } else {
     $c$5 = $c$1$lcssa;$i$3 = $i$0$lcssa;
    }
   } while(0);
   if ((($i$3|0) == 3)) {
    $68 = HEAP32[$0>>2]|0;
    $69 = HEAP32[$1>>2]|0;
    $70 = ($68>>>0)<($69>>>0);
    if ($70) {
     $71 = (($68) + 1|0);
     HEAP32[$0>>2] = $71;
     $72 = HEAP8[$68>>0]|0;
     $73 = $72&255;
     $75 = $73;
    } else {
     $74 = (___shgetc($f)|0);
     $75 = $74;
    }
    $76 = ($75|0)==(40);
    if ($76) {
     $i$4 = 1;
    } else {
     $77 = HEAP32[$1>>2]|0;
     $78 = ($77|0)==(0|0);
     if ($78) {
      $$0 = nan;
      STACKTOP = sp;return (+$$0);
     }
     $79 = HEAP32[$0>>2]|0;
     $80 = (($79) + -1|0);
     HEAP32[$0>>2] = $80;
     $$0 = nan;
     STACKTOP = sp;return (+$$0);
    }
    while(1) {
     $81 = HEAP32[$0>>2]|0;
     $82 = HEAP32[$1>>2]|0;
     $83 = ($81>>>0)<($82>>>0);
     if ($83) {
      $84 = (($81) + 1|0);
      HEAP32[$0>>2] = $84;
      $85 = HEAP8[$81>>0]|0;
      $86 = $85&255;
      $89 = $86;
     } else {
      $87 = (___shgetc($f)|0);
      $89 = $87;
     }
     $88 = (($89) + -48)|0;
     $90 = ($88>>>0)<(10);
     $91 = (($89) + -65)|0;
     $92 = ($91>>>0)<(26);
     $or$cond8 = $90 | $92;
     if (!($or$cond8)) {
      $93 = (($89) + -97)|0;
      $94 = ($93>>>0)<(26);
      $95 = ($89|0)==(95);
      $or$cond5 = $94 | $95;
      if (!($or$cond5)) {
       break;
      }
     }
     $107 = (($i$4) + 1)|0;
     $i$4 = $107;
    }
    $96 = ($89|0)==(41);
    if ($96) {
     $$0 = nan;
     STACKTOP = sp;return (+$$0);
    }
    $97 = HEAP32[$1>>2]|0;
    $98 = ($97|0)==(0|0);
    if (!($98)) {
     $99 = HEAP32[$0>>2]|0;
     $100 = (($99) + -1|0);
     HEAP32[$0>>2] = $100;
    }
    if ($39) {
     $102 = (___errno_location()|0);
     HEAP32[$102>>2] = 22;
     ___shlim($f,0);
     $$0 = 0.0;
     STACKTOP = sp;return (+$$0);
    }
    $101 = ($i$4|0)==(0);
    $brmerge107 = $101 | $98;
    if ($brmerge107) {
     $$0 = nan;
     STACKTOP = sp;return (+$$0);
    } else {
     $$in = $i$4;
    }
    while(1) {
     $103 = (($$in) + -1)|0;
     $104 = HEAP32[$0>>2]|0;
     $105 = (($104) + -1|0);
     HEAP32[$0>>2] = $105;
     $106 = ($103|0)==(0);
     if ($106) {
      $$0 = nan;
      break;
     } else {
      $$in = $103;
     }
    }
    STACKTOP = sp;return (+$$0);
   } else if ((($i$3|0) == 0)) {
    $113 = ($c$5|0)==(48);
    do {
     if ($113) {
      $114 = HEAP32[$0>>2]|0;
      $115 = HEAP32[$1>>2]|0;
      $116 = ($114>>>0)<($115>>>0);
      if ($116) {
       $117 = (($114) + 1|0);
       HEAP32[$0>>2] = $117;
       $118 = HEAP8[$114>>0]|0;
       $119 = $118&255;
       $122 = $119;
      } else {
       $120 = (___shgetc($f)|0);
       $122 = $120;
      }
      $121 = $122 | 32;
      $123 = ($121|0)==(120);
      if (!($123)) {
       $321 = HEAP32[$1>>2]|0;
       $322 = ($321|0)==(0|0);
       if ($322) {
        $c$6 = 48;
        break;
       }
       $323 = HEAP32[$0>>2]|0;
       $324 = (($323) + -1|0);
       HEAP32[$0>>2] = $324;
       $c$6 = 48;
       break;
      }
      $124 = HEAP32[$0>>2]|0;
      $125 = HEAP32[$1>>2]|0;
      $126 = ($124>>>0)<($125>>>0);
      if ($126) {
       $127 = (($124) + 1|0);
       HEAP32[$0>>2] = $127;
       $128 = HEAP8[$124>>0]|0;
       $129 = $128&255;
       $c$0$i = $129;$gotdig$0$i = 0;
      } else {
       $130 = (___shgetc($f)|0);
       $c$0$i = $130;$gotdig$0$i = 0;
      }
      while(1) {
       if ((($c$0$i|0) == 46)) {
        label = 70;
        break;
       } else if (!((($c$0$i|0) == 48))) {
        $168 = 0;$171 = 0;$211 = 0;$213 = 0;$c$2$i = $c$0$i;$gotdig$2$i = $gotdig$0$i;$gotrad$0$i = 0;$gottail$0$i = 0;$scale$0$i = 1.0;$x$0$i = 0;$y$0$i = 0.0;
        break;
       }
       $131 = HEAP32[$0>>2]|0;
       $132 = HEAP32[$1>>2]|0;
       $133 = ($131>>>0)<($132>>>0);
       if ($133) {
        $134 = (($131) + 1|0);
        HEAP32[$0>>2] = $134;
        $135 = HEAP8[$131>>0]|0;
        $136 = $135&255;
        $c$0$i = $136;$gotdig$0$i = 1;
        continue;
       } else {
        $137 = (___shgetc($f)|0);
        $c$0$i = $137;$gotdig$0$i = 1;
        continue;
       }
      }
      L107: do {
       if ((label|0) == 70) {
        $138 = HEAP32[$0>>2]|0;
        $139 = HEAP32[$1>>2]|0;
        $140 = ($138>>>0)<($139>>>0);
        if ($140) {
         $141 = (($138) + 1|0);
         HEAP32[$0>>2] = $141;
         $142 = HEAP8[$138>>0]|0;
         $143 = $142&255;
         $c$1$ph$i = $143;
        } else {
         $144 = (___shgetc($f)|0);
         $c$1$ph$i = $144;
        }
        $145 = ($c$1$ph$i|0)==(48);
        if ($145) {
         $155 = -1;$156 = -1;
         while(1) {
          $146 = HEAP32[$0>>2]|0;
          $147 = HEAP32[$1>>2]|0;
          $148 = ($146>>>0)<($147>>>0);
          if ($148) {
           $149 = (($146) + 1|0);
           HEAP32[$0>>2] = $149;
           $150 = HEAP8[$146>>0]|0;
           $151 = $150&255;
           $153 = $151;
          } else {
           $152 = (___shgetc($f)|0);
           $153 = $152;
          }
          $154 = ($153|0)==(48);
          if (!($154)) {
           $168 = 0;$171 = 0;$211 = $155;$213 = $156;$c$2$i = $153;$gotdig$2$i = 1;$gotrad$0$i = 1;$gottail$0$i = 0;$scale$0$i = 1.0;$x$0$i = 0;$y$0$i = 0.0;
           break L107;
          }
          $157 = (_i64Add(($155|0),($156|0),-1,-1)|0);
          $158 = tempRet0;
          $155 = $157;$156 = $158;
         }
        } else {
         $168 = 0;$171 = 0;$211 = 0;$213 = 0;$c$2$i = $c$1$ph$i;$gotdig$2$i = $gotdig$0$i;$gotrad$0$i = 1;$gottail$0$i = 0;$scale$0$i = 1.0;$x$0$i = 0;$y$0$i = 0.0;
        }
       }
      } while(0);
      L120: while(1) {
       $159 = (($c$2$i) + -48)|0;
       $160 = ($159>>>0)<(10);
       do {
        if ($160) {
         $d$0$i = $159;
         label = 84;
        } else {
         $161 = $c$2$i | 32;
         $162 = (($161) + -97)|0;
         $163 = ($162>>>0)<(6);
         $164 = ($c$2$i|0)==(46);
         $or$cond$i = $163 | $164;
         if (!($or$cond$i)) {
          $c$2$lcssa$i = $c$2$i;
          break L120;
         }
         if ($164) {
          $165 = ($gotrad$0$i|0)==(0);
          if ($165) {
           $712 = $171;$713 = $168;$714 = $171;$715 = $168;$gotdig$3$i = $gotdig$2$i;$gotrad$1$i = 1;$gottail$2$i = $gottail$0$i;$scale$2$i = $scale$0$i;$x$2$i = $x$0$i;$y$2$i = $y$0$i;
           break;
          } else {
           $c$2$lcssa$i = 46;
           break L120;
          }
         } else {
          $166 = ($c$2$i|0)>(57);
          $167 = (($161) + -87)|0;
          $$38$i = $166 ? $167 : $159;
          $d$0$i = $$38$i;
          label = 84;
          break;
         }
        }
       } while(0);
       if ((label|0) == 84) {
        label = 0;
        $169 = ($168|0)<(0);
        $170 = ($168|0)==(0);
        $172 = ($171>>>0)<(8);
        $173 = $170 & $172;
        $174 = $169 | $173;
        do {
         if ($174) {
          $175 = $x$0$i << 4;
          $176 = (($d$0$i) + ($175))|0;
          $gottail$1$i = $gottail$0$i;$scale$1$i = $scale$0$i;$x$1$i = $176;$y$1$i = $y$0$i;
         } else {
          $177 = ($168|0)<(0);
          $178 = ($168|0)==(0);
          $179 = ($171>>>0)<(14);
          $180 = $178 & $179;
          $181 = $177 | $180;
          if ($181) {
           $182 = (+($d$0$i|0));
           $183 = $scale$0$i * 0.0625;
           $184 = $183 * $182;
           $185 = $y$0$i + $184;
           $gottail$1$i = $gottail$0$i;$scale$1$i = $183;$x$1$i = $x$0$i;$y$1$i = $185;
           break;
          }
          $186 = ($d$0$i|0)!=(0);
          $187 = ($gottail$0$i|0)==(0);
          $or$cond3$i = $186 & $187;
          if ($or$cond3$i) {
           $188 = $scale$0$i * 0.5;
           $189 = $y$0$i + $188;
           $gottail$1$i = 1;$scale$1$i = $scale$0$i;$x$1$i = $x$0$i;$y$1$i = $189;
          } else {
           $gottail$1$i = $gottail$0$i;$scale$1$i = $scale$0$i;$x$1$i = $x$0$i;$y$1$i = $y$0$i;
          }
         }
        } while(0);
        $190 = (_i64Add(($171|0),($168|0),1,0)|0);
        $191 = tempRet0;
        $712 = $211;$713 = $213;$714 = $190;$715 = $191;$gotdig$3$i = 1;$gotrad$1$i = $gotrad$0$i;$gottail$2$i = $gottail$1$i;$scale$2$i = $scale$1$i;$x$2$i = $x$1$i;$y$2$i = $y$1$i;
       }
       $192 = HEAP32[$0>>2]|0;
       $193 = HEAP32[$1>>2]|0;
       $194 = ($192>>>0)<($193>>>0);
       if ($194) {
        $195 = (($192) + 1|0);
        HEAP32[$0>>2] = $195;
        $196 = HEAP8[$192>>0]|0;
        $197 = $196&255;
        $168 = $715;$171 = $714;$211 = $712;$213 = $713;$c$2$i = $197;$gotdig$2$i = $gotdig$3$i;$gotrad$0$i = $gotrad$1$i;$gottail$0$i = $gottail$2$i;$scale$0$i = $scale$2$i;$x$0$i = $x$2$i;$y$0$i = $y$2$i;
        continue;
       } else {
        $198 = (___shgetc($f)|0);
        $168 = $715;$171 = $714;$211 = $712;$213 = $713;$c$2$i = $198;$gotdig$2$i = $gotdig$3$i;$gotrad$0$i = $gotrad$1$i;$gottail$0$i = $gottail$2$i;$scale$0$i = $scale$2$i;$x$0$i = $x$2$i;$y$0$i = $y$2$i;
        continue;
       }
      }
      $199 = ($gotdig$2$i|0)==(0);
      if ($199) {
       $200 = HEAP32[$1>>2]|0;
       $201 = ($200|0)==(0|0);
       if (!($201)) {
        $202 = HEAP32[$0>>2]|0;
        $203 = (($202) + -1|0);
        HEAP32[$0>>2] = $203;
       }
       if ($39) {
        ___shlim($f,0);
       } else {
        if (!($201)) {
         $204 = HEAP32[$0>>2]|0;
         $205 = (($204) + -1|0);
         HEAP32[$0>>2] = $205;
         $206 = ($gotrad$0$i|0)==(0);
         if (!($206)) {
          $207 = (($204) + -2|0);
          HEAP32[$0>>2] = $207;
         }
        }
       }
       $208 = (+($sign$0|0));
       $209 = $208 * 0.0;
       $$0 = $209;
       STACKTOP = sp;return (+$$0);
      }
      $210 = ($gotrad$0$i|0)==(0);
      $212 = $210 ? $171 : $211;
      $214 = $210 ? $168 : $213;
      $215 = ($168|0)<(0);
      $216 = ($168|0)==(0);
      $217 = ($171>>>0)<(8);
      $218 = $216 & $217;
      $219 = $215 | $218;
      if ($219) {
       $221 = $171;$222 = $168;$x$313$i = $x$0$i;
       while(1) {
        $220 = $x$313$i << 4;
        $223 = (_i64Add(($221|0),($222|0),1,0)|0);
        $224 = tempRet0;
        $225 = ($224|0)<(0);
        $226 = ($224|0)==(0);
        $227 = ($223>>>0)<(8);
        $228 = $226 & $227;
        $229 = $225 | $228;
        if ($229) {
         $221 = $223;$222 = $224;$x$313$i = $220;
        } else {
         $x$3$lcssa$i = $220;
         break;
        }
       }
      } else {
       $x$3$lcssa$i = $x$0$i;
      }
      $230 = $c$2$lcssa$i | 32;
      $231 = ($230|0)==(112);
      do {
       if ($231) {
        $232 = (_scanexp($f,$pok)|0);
        $233 = tempRet0;
        $234 = ($232|0)==(0);
        $235 = ($233|0)==(-2147483648);
        $236 = $234 & $235;
        if ($236) {
         if ($39) {
          ___shlim($f,0);
          $$0 = 0.0;
          STACKTOP = sp;return (+$$0);
         } else {
          $237 = HEAP32[$1>>2]|0;
          $238 = ($237|0)==(0|0);
          if ($238) {
           $249 = 0;$250 = 0;
           break;
          }
          $239 = HEAP32[$0>>2]|0;
          $240 = (($239) + -1|0);
          HEAP32[$0>>2] = $240;
          $249 = 0;$250 = 0;
          break;
         }
        } else {
         $249 = $232;$250 = $233;
        }
       } else {
        $241 = HEAP32[$1>>2]|0;
        $242 = ($241|0)==(0|0);
        if ($242) {
         $249 = 0;$250 = 0;
        } else {
         $243 = HEAP32[$0>>2]|0;
         $244 = (($243) + -1|0);
         HEAP32[$0>>2] = $244;
         $249 = 0;$250 = 0;
        }
       }
      } while(0);
      $245 = (_bitshift64Shl(($212|0),($214|0),2)|0);
      $246 = tempRet0;
      $247 = (_i64Add(($245|0),($246|0),-32,-1)|0);
      $248 = tempRet0;
      $251 = (_i64Add(($247|0),($248|0),($249|0),($250|0))|0);
      $252 = tempRet0;
      $253 = ($x$3$lcssa$i|0)==(0);
      if ($253) {
       $254 = (+($sign$0|0));
       $255 = $254 * 0.0;
       $$0 = $255;
       STACKTOP = sp;return (+$$0);
      }
      $256 = (0 - ($emin$0$ph))|0;
      $257 = ($252|0)>(0);
      $258 = ($252|0)==(0);
      $259 = ($251>>>0)>($256>>>0);
      $260 = $258 & $259;
      $261 = $257 | $260;
      if ($261) {
       $262 = (___errno_location()|0);
       HEAP32[$262>>2] = 34;
       $263 = (+($sign$0|0));
       $264 = $263 * 1.7976931348623157E+308;
       $265 = $264 * 1.7976931348623157E+308;
       $$0 = $265;
       STACKTOP = sp;return (+$$0);
      }
      $266 = (($emin$0$ph) + -106)|0;
      $267 = ($266|0)<(0);
      $268 = $267 << 31 >> 31;
      $269 = ($252|0)<($268|0);
      $270 = ($252|0)==($268|0);
      $271 = ($251>>>0)<($266>>>0);
      $272 = $270 & $271;
      $273 = $269 | $272;
      if ($273) {
       $275 = (___errno_location()|0);
       HEAP32[$275>>2] = 34;
       $276 = (+($sign$0|0));
       $277 = $276 * 2.2250738585072014E-308;
       $278 = $277 * 2.2250738585072014E-308;
       $$0 = $278;
       STACKTOP = sp;return (+$$0);
      }
      $274 = ($x$3$lcssa$i|0)>(-1);
      if ($274) {
       $283 = $251;$284 = $252;$x$48$i = $x$3$lcssa$i;$y$39$i = $y$0$i;
       while(1) {
        $279 = !($y$39$i >= 0.5);
        $280 = $x$48$i << 1;
        if ($279) {
         $$pn$i = $y$39$i;$x$5$i = $280;
        } else {
         $281 = $280 | 1;
         $282 = $y$39$i + -1.0;
         $$pn$i = $282;$x$5$i = $281;
        }
        $y$4$i = $y$39$i + $$pn$i;
        $285 = (_i64Add(($283|0),($284|0),-1,-1)|0);
        $286 = tempRet0;
        $287 = ($x$5$i|0)>(-1);
        if ($287) {
         $283 = $285;$284 = $286;$x$48$i = $x$5$i;$y$39$i = $y$4$i;
        } else {
         $292 = $285;$293 = $286;$x$4$lcssa$i = $x$5$i;$y$3$lcssa$i = $y$4$i;
         break;
        }
       }
      } else {
       $292 = $251;$293 = $252;$x$4$lcssa$i = $x$3$lcssa$i;$y$3$lcssa$i = $y$0$i;
      }
      $288 = ($emin$0$ph|0)<(0);
      $289 = $288 << 31 >> 31;
      $290 = (_i64Subtract(32,0,($emin$0$ph|0),($289|0))|0);
      $291 = tempRet0;
      $294 = (_i64Add(($292|0),($293|0),($290|0),($291|0))|0);
      $295 = tempRet0;
      $296 = (0)>($295|0);
      $297 = (0)==($295|0);
      $298 = ($bits$0$ph>>>0)>($294>>>0);
      $299 = $297 & $298;
      $300 = $296 | $299;
      if ($300) {
       $301 = ($294|0)<(0);
       $$$i = $301 ? 0 : $294;
       $$02$i = $$$i;
      } else {
       $$02$i = $bits$0$ph;
      }
      $302 = ($$02$i|0)<(53);
      do {
       if ($302) {
        $303 = (84 - ($$02$i))|0;
        $304 = (+_scalbn(1.0,$303));
        $305 = (+($sign$0|0));
        $306 = (+_copysignl((+$304),(+$305)));
        $307 = ($$02$i|0)<(32);
        $308 = $y$3$lcssa$i != 0.0;
        $or$cond4$i = $307 & $308;
        if (!($or$cond4$i)) {
         $$pre$phi$iZ2D = $305;$bias$07$i = $306;$x$6$i = $x$4$lcssa$i;$y$5$i = $y$3$lcssa$i;
         break;
        }
        $309 = $x$4$lcssa$i & 1;
        $310 = ($309|0)==(0);
        $311 = $309 ^ 1;
        $$x$4$i = (($311) + ($x$4$lcssa$i))|0;
        $$y$3$i = $310 ? 0.0 : $y$3$lcssa$i;
        $$pre$phi$iZ2D = $305;$bias$07$i = $306;$x$6$i = $$x$4$i;$y$5$i = $$y$3$i;
       } else {
        $$pre$i = (+($sign$0|0));
        $$pre$phi$iZ2D = $$pre$i;$bias$07$i = 0.0;$x$6$i = $x$4$lcssa$i;$y$5$i = $y$3$lcssa$i;
       }
      } while(0);
      $312 = (+($x$6$i>>>0));
      $313 = $$pre$phi$iZ2D * $312;
      $314 = $bias$07$i + $313;
      $315 = $$pre$phi$iZ2D * $y$5$i;
      $316 = $315 + $314;
      $317 = $316 - $bias$07$i;
      $318 = $317 != 0.0;
      if (!($318)) {
       $319 = (___errno_location()|0);
       HEAP32[$319>>2] = 34;
      }
      $320 = (+_scalbnl($317,$292));
      $$0 = $320;
      STACKTOP = sp;return (+$$0);
     } else {
      $c$6 = $c$5;
     }
    } while(0);
    $sum$i = (($emin$0$ph) + ($bits$0$ph))|0;
    $325 = (0 - ($sum$i))|0;
    $$08$i = $c$6;$gotdig$0$i9 = 0;
    while(1) {
     if ((($$08$i|0) == 46)) {
      label = 139;
      break;
     } else if (!((($$08$i|0) == 48))) {
      $$2$i = $$08$i;$716 = 0;$717 = 0;$gotdig$2$i11 = $gotdig$0$i9;$gotrad$0$i12 = 0;
      break;
     }
     $326 = HEAP32[$0>>2]|0;
     $327 = HEAP32[$1>>2]|0;
     $328 = ($326>>>0)<($327>>>0);
     if ($328) {
      $329 = (($326) + 1|0);
      HEAP32[$0>>2] = $329;
      $330 = HEAP8[$326>>0]|0;
      $331 = $330&255;
      $$08$i = $331;$gotdig$0$i9 = 1;
      continue;
     } else {
      $332 = (___shgetc($f)|0);
      $$08$i = $332;$gotdig$0$i9 = 1;
      continue;
     }
    }
    L209: do {
     if ((label|0) == 139) {
      $333 = HEAP32[$0>>2]|0;
      $334 = HEAP32[$1>>2]|0;
      $335 = ($333>>>0)<($334>>>0);
      if ($335) {
       $336 = (($333) + 1|0);
       HEAP32[$0>>2] = $336;
       $337 = HEAP8[$333>>0]|0;
       $338 = $337&255;
       $$1$ph$i = $338;
      } else {
       $339 = (___shgetc($f)|0);
       $$1$ph$i = $339;
      }
      $340 = ($$1$ph$i|0)==(48);
      if ($340) {
       $349 = -1;$350 = -1;
       while(1) {
        $341 = HEAP32[$0>>2]|0;
        $342 = HEAP32[$1>>2]|0;
        $343 = ($341>>>0)<($342>>>0);
        if ($343) {
         $344 = (($341) + 1|0);
         HEAP32[$0>>2] = $344;
         $345 = HEAP8[$341>>0]|0;
         $346 = $345&255;
         $$1$be$i = $346;
        } else {
         $347 = (___shgetc($f)|0);
         $$1$be$i = $347;
        }
        $348 = ($$1$be$i|0)==(48);
        if (!($348)) {
         $$2$i = $$1$be$i;$716 = $349;$717 = $350;$gotdig$2$i11 = 1;$gotrad$0$i12 = 1;
         break L209;
        }
        $351 = (_i64Add(($349|0),($350|0),-1,-1)|0);
        $352 = tempRet0;
        $349 = $351;$350 = $352;
       }
      } else {
       $$2$i = $$1$ph$i;$716 = 0;$717 = 0;$gotdig$2$i11 = $gotdig$0$i9;$gotrad$0$i12 = 1;
      }
     }
    } while(0);
    HEAP32[$x$i>>2] = 0;
    $353 = (($$2$i) + -48)|0;
    $354 = ($353>>>0)<(10);
    $355 = ($$2$i|0)==(46);
    $or$cond789$i = $354 | $355;
    L223: do {
     if ($or$cond789$i) {
      $356 = (($x$i) + 496|0);
      $$397$i = $$2$i;$358 = 0;$359 = 0;$718 = $355;$719 = $353;$720 = $716;$721 = $717;$gotdig$393$i = $gotdig$2$i11;$gotrad$194$i = $gotrad$0$i12;$j$096$i = 0;$k$095$i = 0;$lnz$092$i = 0;
      while(1) {
       do {
        if ($718) {
         $cond$i = ($gotrad$194$i|0)==(0);
         if ($cond$i) {
          $722 = $358;$723 = $359;$724 = $358;$725 = $359;$gotdig$4$i = $gotdig$393$i;$gotrad$2$i = 1;$j$2$i = $j$096$i;$k$2$i = $k$095$i;$lnz$2$i = $lnz$092$i;
         } else {
          $$388$i = $$397$i;$405 = $720;$406 = $721;$421 = $358;$424 = $359;$gotdig$381$i = $gotdig$393$i;$j$086$i = $j$096$i;$k$084$i = $k$095$i;$lnz$079$i = $lnz$092$i;
          break L223;
         }
        } else {
         $357 = ($k$095$i|0)<(125);
         $360 = (_i64Add(($358|0),($359|0),1,0)|0);
         $361 = tempRet0;
         $362 = ($$397$i|0)!=(48);
         if (!($357)) {
          if (!($362)) {
           $722 = $720;$723 = $721;$724 = $360;$725 = $361;$gotdig$4$i = $gotdig$393$i;$gotrad$2$i = $gotrad$194$i;$j$2$i = $j$096$i;$k$2$i = $k$095$i;$lnz$2$i = $lnz$092$i;
           break;
          }
          $372 = HEAP32[$356>>2]|0;
          $373 = $372 | 1;
          HEAP32[$356>>2] = $373;
          $722 = $720;$723 = $721;$724 = $360;$725 = $361;$gotdig$4$i = $gotdig$393$i;$gotrad$2$i = $gotrad$194$i;$j$2$i = $j$096$i;$k$2$i = $k$095$i;$lnz$2$i = $lnz$092$i;
          break;
         }
         $$lnz$0$i = $362 ? $360 : $lnz$092$i;
         $363 = ($j$096$i|0)==(0);
         $364 = (($x$i) + ($k$095$i<<2)|0);
         if ($363) {
          $storemerge$i = $719;
         } else {
          $365 = HEAP32[$364>>2]|0;
          $366 = ($365*10)|0;
          $367 = (($$397$i) + -48)|0;
          $368 = (($367) + ($366))|0;
          $storemerge$i = $368;
         }
         HEAP32[$364>>2] = $storemerge$i;
         $369 = (($j$096$i) + 1)|0;
         $370 = ($369|0)==(9);
         $371 = $370&1;
         $$k$0$i = (($371) + ($k$095$i))|0;
         $$10$i = $370 ? 0 : $369;
         $722 = $720;$723 = $721;$724 = $360;$725 = $361;$gotdig$4$i = 1;$gotrad$2$i = $gotrad$194$i;$j$2$i = $$10$i;$k$2$i = $$k$0$i;$lnz$2$i = $$lnz$0$i;
        }
       } while(0);
       $374 = HEAP32[$0>>2]|0;
       $375 = HEAP32[$1>>2]|0;
       $376 = ($374>>>0)<($375>>>0);
       if ($376) {
        $377 = (($374) + 1|0);
        HEAP32[$0>>2] = $377;
        $378 = HEAP8[$374>>0]|0;
        $379 = $378&255;
        $$3$be$i = $379;
       } else {
        $380 = (___shgetc($f)|0);
        $$3$be$i = $380;
       }
       $381 = (($$3$be$i) + -48)|0;
       $382 = ($381>>>0)<(10);
       $383 = ($$3$be$i|0)==(46);
       $or$cond7$i = $382 | $383;
       if ($or$cond7$i) {
        $$397$i = $$3$be$i;$358 = $724;$359 = $725;$718 = $383;$719 = $381;$720 = $722;$721 = $723;$gotdig$393$i = $gotdig$4$i;$gotrad$194$i = $gotrad$2$i;$j$096$i = $j$2$i;$k$095$i = $k$2$i;$lnz$092$i = $lnz$2$i;
       } else {
        $$3$lcssa$i = $$3$be$i;$385 = $722;$386 = $724;$388 = $723;$389 = $725;$gotdig$3$lcssa$i = $gotdig$4$i;$gotrad$1$lcssa$i = $gotrad$2$i;$j$0$lcssa$i = $j$2$i;$k$0$lcssa$i = $k$2$i;$lnz$0$lcssa$i = $lnz$2$i;
        label = 162;
        break;
       }
      }
     } else {
      $$3$lcssa$i = $$2$i;$385 = $716;$386 = 0;$388 = $717;$389 = 0;$gotdig$3$lcssa$i = $gotdig$2$i11;$gotrad$1$lcssa$i = $gotrad$0$i12;$j$0$lcssa$i = 0;$k$0$lcssa$i = 0;$lnz$0$lcssa$i = 0;
      label = 162;
     }
    } while(0);
    if ((label|0) == 162) {
     $384 = ($gotrad$1$lcssa$i|0)==(0);
     $387 = $384 ? $386 : $385;
     $390 = $384 ? $389 : $388;
     $$388$i = $$3$lcssa$i;$405 = $387;$406 = $390;$421 = $386;$424 = $389;$gotdig$381$i = $gotdig$3$lcssa$i;$j$086$i = $j$0$lcssa$i;$k$084$i = $k$0$lcssa$i;$lnz$079$i = $lnz$0$lcssa$i;
    }
    $391 = ($gotdig$381$i|0)!=(0);
    if ($391) {
     $392 = $$388$i | 32;
     $393 = ($392|0)==(101);
     if ($393) {
      $394 = (_scanexp($f,$pok)|0);
      $395 = tempRet0;
      $396 = ($394|0)==(0);
      $397 = ($395|0)==(-2147483648);
      $398 = $396 & $397;
      do {
       if ($398) {
        if ($39) {
         ___shlim($f,0);
         $$0 = 0.0;
         STACKTOP = sp;return (+$$0);
        } else {
         $399 = HEAP32[$1>>2]|0;
         $400 = ($399|0)==(0|0);
         if ($400) {
          $403 = 0;$404 = 0;
          break;
         }
         $401 = HEAP32[$0>>2]|0;
         $402 = (($401) + -1|0);
         HEAP32[$0>>2] = $402;
         $403 = 0;$404 = 0;
         break;
        }
       } else {
        $403 = $394;$404 = $395;
       }
      } while(0);
      $407 = (_i64Add(($403|0),($404|0),($405|0),($406|0))|0);
      $408 = tempRet0;
      $419 = $407;$422 = $408;
     } else {
      label = 171;
     }
    } else {
     label = 171;
    }
    if ((label|0) == 171) {
     $409 = ($$388$i|0)>(-1);
     if ($409) {
      $410 = HEAP32[$1>>2]|0;
      $411 = ($410|0)==(0|0);
      if ($411) {
       $419 = $405;$422 = $406;
      } else {
       $412 = HEAP32[$0>>2]|0;
       $413 = (($412) + -1|0);
       HEAP32[$0>>2] = $413;
       $419 = $405;$422 = $406;
      }
     } else {
      $419 = $405;$422 = $406;
     }
    }
    if (!($391)) {
     $414 = (___errno_location()|0);
     HEAP32[$414>>2] = 22;
     ___shlim($f,0);
     $$0 = 0.0;
     STACKTOP = sp;return (+$$0);
    }
    $415 = HEAP32[$x$i>>2]|0;
    $416 = ($415|0)==(0);
    if ($416) {
     $417 = (+($sign$0|0));
     $418 = $417 * 0.0;
     $$0 = $418;
     STACKTOP = sp;return (+$$0);
    }
    $420 = ($419|0)==($421|0);
    $423 = ($422|0)==($424|0);
    $425 = $420 & $423;
    $426 = ($424|0)<(0);
    $427 = ($424|0)==(0);
    $428 = ($421>>>0)<(10);
    $429 = $427 & $428;
    $430 = $426 | $429;
    $or$cond$i15 = $425 & $430;
    do {
     if ($or$cond$i15) {
      $431 = ($bits$0$ph>>>0)>(30);
      if (!($431)) {
       $432 = $415 >>> $bits$0$ph;
       $433 = ($432|0)==(0);
       if (!($433)) {
        break;
       }
      }
      $434 = (+($sign$0|0));
      $435 = (+($415>>>0));
      $436 = $434 * $435;
      $$0 = $436;
      STACKTOP = sp;return (+$$0);
     }
    } while(0);
    $437 = (($emin$0$ph|0) / -2)&-1;
    $438 = ($437|0)<(0);
    $439 = $438 << 31 >> 31;
    $440 = ($422|0)>($439|0);
    $441 = ($422|0)==($439|0);
    $442 = ($419>>>0)>($437>>>0);
    $443 = $441 & $442;
    $444 = $440 | $443;
    if ($444) {
     $445 = (___errno_location()|0);
     HEAP32[$445>>2] = 34;
     $446 = (+($sign$0|0));
     $447 = $446 * 1.7976931348623157E+308;
     $448 = $447 * 1.7976931348623157E+308;
     $$0 = $448;
     STACKTOP = sp;return (+$$0);
    }
    $449 = (($emin$0$ph) + -106)|0;
    $450 = ($449|0)<(0);
    $451 = $450 << 31 >> 31;
    $452 = ($422|0)<($451|0);
    $453 = ($422|0)==($451|0);
    $454 = ($419>>>0)<($449>>>0);
    $455 = $453 & $454;
    $456 = $452 | $455;
    if ($456) {
     $457 = (___errno_location()|0);
     HEAP32[$457>>2] = 34;
     $458 = (+($sign$0|0));
     $459 = $458 * 2.2250738585072014E-308;
     $460 = $459 * 2.2250738585072014E-308;
     $$0 = $460;
     STACKTOP = sp;return (+$$0);
    }
    $461 = ($j$086$i|0)==(0);
    if ($461) {
     $k$3$i = $k$084$i;
    } else {
     $462 = ($j$086$i|0)<(9);
     if ($462) {
      $463 = (($x$i) + ($k$084$i<<2)|0);
      $$promoted$i = HEAP32[$463>>2]|0;
      $465 = $$promoted$i;$j$371$i = $j$086$i;
      while(1) {
       $464 = ($465*10)|0;
       $466 = (($j$371$i) + 1)|0;
       $exitcond$i = ($466|0)==(9);
       if ($exitcond$i) {
        break;
       } else {
        $465 = $464;$j$371$i = $466;
       }
      }
      HEAP32[$463>>2] = $464;
     }
     $467 = (($k$084$i) + 1)|0;
     $k$3$i = $467;
    }
    $468 = ($lnz$079$i|0)<(9);
    do {
     if ($468) {
      $469 = ($lnz$079$i|0)<=($419|0);
      $470 = ($419|0)<(18);
      $or$cond3$i16 = $469 & $470;
      if ($or$cond3$i16) {
       $471 = ($419|0)==(9);
       if ($471) {
        $472 = (+($sign$0|0));
        $473 = HEAP32[$x$i>>2]|0;
        $474 = (+($473>>>0));
        $475 = $472 * $474;
        $$0 = $475;
        STACKTOP = sp;return (+$$0);
       }
       $476 = ($419|0)<(9);
       if ($476) {
        $477 = (+($sign$0|0));
        $478 = HEAP32[$x$i>>2]|0;
        $479 = (+($478>>>0));
        $480 = $477 * $479;
        $481 = (8 - ($419))|0;
        $482 = (144720 + ($481<<2)|0);
        $483 = HEAP32[$482>>2]|0;
        $484 = (+($483|0));
        $485 = $480 / $484;
        $$0 = $485;
        STACKTOP = sp;return (+$$0);
       }
       $486 = Math_imul($419, -3)|0;
       $$neg20$i = (($bits$0$ph) + 27)|0;
       $487 = (($$neg20$i) + ($486))|0;
       $488 = ($487|0)>(30);
       $$pre$i17 = HEAP32[$x$i>>2]|0;
       if (!($488)) {
        $489 = $$pre$i17 >>> $487;
        $490 = ($489|0)==(0);
        if (!($490)) {
         break;
        }
       }
       $491 = (+($sign$0|0));
       $492 = (+($$pre$i17>>>0));
       $493 = $491 * $492;
       $494 = (($419) + -10)|0;
       $495 = (144720 + ($494<<2)|0);
       $496 = HEAP32[$495>>2]|0;
       $497 = (+($496|0));
       $498 = $493 * $497;
       $$0 = $498;
       STACKTOP = sp;return (+$$0);
      }
     }
    } while(0);
    $499 = (($419|0) % 9)&-1;
    $500 = ($499|0)==(0);
    if ($500) {
     $a$2$ph40$i = 0;$e2$0$ph$i = 0;$rp$2$ph38$i = $419;$z$1$ph39$i = $k$3$i;
    } else {
     $501 = ($419|0)>(-1);
     $502 = (($499) + 9)|0;
     $503 = $501 ? $499 : $502;
     $504 = (8 - ($503))|0;
     $505 = (144720 + ($504<<2)|0);
     $506 = HEAP32[$505>>2]|0;
     $507 = ($k$3$i|0)==(0);
     if ($507) {
      $a$0$lcssa161$i = 0;$rp$0$lcssa162$i = $419;$z$0$i = 0;
     } else {
      $508 = (1000000000 / ($506|0))&-1;
      $a$061$i = 0;$carry$063$i = 0;$k$462$i = 0;$rp$060$i = $419;
      while(1) {
       $509 = (($x$i) + ($k$462$i<<2)|0);
       $510 = HEAP32[$509>>2]|0;
       $511 = (($510>>>0) % ($506>>>0))&-1;
       $512 = (($510>>>0) / ($506>>>0))&-1;
       $513 = (($512) + ($carry$063$i))|0;
       HEAP32[$509>>2] = $513;
       $514 = Math_imul($511, $508)|0;
       $515 = ($k$462$i|0)==($a$061$i|0);
       $516 = ($513|0)==(0);
       $or$cond11$i = $515 & $516;
       $517 = (($k$462$i) + 1)|0;
       if ($or$cond11$i) {
        $518 = $517 & 127;
        $519 = (($rp$060$i) + -9)|0;
        $a$1$i = $518;$rp$1$i18 = $519;
       } else {
        $a$1$i = $a$061$i;$rp$1$i18 = $rp$060$i;
       }
       $520 = ($517|0)==($k$3$i|0);
       if ($520) {
        break;
       } else {
        $a$061$i = $a$1$i;$carry$063$i = $514;$k$462$i = $517;$rp$060$i = $rp$1$i18;
       }
      }
      $521 = ($514|0)==(0);
      if ($521) {
       $a$0$lcssa161$i = $a$1$i;$rp$0$lcssa162$i = $rp$1$i18;$z$0$i = $k$3$i;
      } else {
       $522 = (($k$3$i) + 1)|0;
       $523 = (($x$i) + ($k$3$i<<2)|0);
       HEAP32[$523>>2] = $514;
       $a$0$lcssa161$i = $a$1$i;$rp$0$lcssa162$i = $rp$1$i18;$z$0$i = $522;
      }
     }
     $524 = (9 - ($503))|0;
     $525 = (($524) + ($rp$0$lcssa162$i))|0;
     $a$2$ph40$i = $a$0$lcssa161$i;$e2$0$ph$i = 0;$rp$2$ph38$i = $525;$z$1$ph39$i = $z$0$i;
    }
    L321: while(1) {
     $526 = ($rp$2$ph38$i|0)<(18);
     $527 = (($x$i) + ($a$2$ph40$i<<2)|0);
     if ($526) {
      $e2$0$us$i = $e2$0$ph$i;$z$1$us$i = $z$1$ph39$i;
      while(1) {
       $529 = (($z$1$us$i) + 127)|0;
       $carry1$0$us$i = 0;$k$5$in$us$i = $529;$z$2$us$i = $z$1$us$i;
       while(1) {
        $k$5$us$i = $k$5$in$us$i & 127;
        $530 = (($x$i) + ($k$5$us$i<<2)|0);
        $531 = HEAP32[$530>>2]|0;
        $532 = (_bitshift64Shl(($531|0),0,29)|0);
        $533 = tempRet0;
        $534 = (_i64Add(($532|0),($533|0),($carry1$0$us$i|0),0)|0);
        $535 = tempRet0;
        $536 = ($535>>>0)>(0);
        $537 = ($535|0)==(0);
        $538 = ($534>>>0)>(1000000000);
        $539 = $537 & $538;
        $540 = $536 | $539;
        if ($540) {
         $541 = (___udivdi3(($534|0),($535|0),1000000000,0)|0);
         $542 = tempRet0;
         $543 = (___uremdi3(($534|0),($535|0),1000000000,0)|0);
         $544 = tempRet0;
         $$sink$off0$us$i = $543;$carry1$1$us$i = $541;
        } else {
         $$sink$off0$us$i = $534;$carry1$1$us$i = 0;
        }
        HEAP32[$530>>2] = $$sink$off0$us$i;
        $545 = (($z$2$us$i) + 127)|0;
        $546 = $545 & 127;
        $547 = ($k$5$us$i|0)!=($546|0);
        $548 = ($k$5$us$i|0)==($a$2$ph40$i|0);
        $or$cond12$us$i = $547 | $548;
        if ($or$cond12$us$i) {
         $z$3$us$i = $z$2$us$i;
        } else {
         $549 = ($$sink$off0$us$i|0)==(0);
         $k$5$z$2$us$i = $549 ? $k$5$us$i : $z$2$us$i;
         $z$3$us$i = $k$5$z$2$us$i;
        }
        $550 = (($k$5$us$i) + -1)|0;
        if ($548) {
         break;
        } else {
         $carry1$0$us$i = $carry1$1$us$i;$k$5$in$us$i = $550;$z$2$us$i = $z$3$us$i;
        }
       }
       $551 = (($e2$0$us$i) + -29)|0;
       $552 = ($carry1$1$us$i|0)==(0);
       if ($552) {
        $e2$0$us$i = $551;$z$1$us$i = $z$3$us$i;
       } else {
        $$lcssa43$i = $551;$carry1$1$lcssa$lcssa$i = $carry1$1$us$i;$z$3$lcssa$lcssa$i = $z$3$us$i;
        break;
       }
      }
     } else {
      $528 = ($rp$2$ph38$i|0)==(18);
      if ($528) {
       $e2$0$us44$i = $e2$0$ph$i;$z$1$us45$i = $z$1$ph39$i;
      } else {
       $a$3$ph$i = $a$2$ph40$i;$e2$1$ph$i = $e2$0$ph$i;$rp$3$ph33$i = $rp$2$ph38$i;$z$5$ph$i = $z$1$ph39$i;
       break;
      }
      while(1) {
       $553 = HEAP32[$527>>2]|0;
       $554 = ($553>>>0)<(9007199);
       if (!($554)) {
        $a$3$ph$i = $a$2$ph40$i;$e2$1$ph$i = $e2$0$us44$i;$rp$3$ph33$i = 18;$z$5$ph$i = $z$1$us45$i;
        break L321;
       }
       $555 = (($z$1$us45$i) + 127)|0;
       $carry1$0$us49$i = 0;$k$5$in$us48$i = $555;$z$2$us47$i = $z$1$us45$i;
       while(1) {
        $k$5$us50$i = $k$5$in$us48$i & 127;
        $556 = (($x$i) + ($k$5$us50$i<<2)|0);
        $557 = HEAP32[$556>>2]|0;
        $558 = (_bitshift64Shl(($557|0),0,29)|0);
        $559 = tempRet0;
        $560 = (_i64Add(($558|0),($559|0),($carry1$0$us49$i|0),0)|0);
        $561 = tempRet0;
        $562 = ($561>>>0)>(0);
        $563 = ($561|0)==(0);
        $564 = ($560>>>0)>(1000000000);
        $565 = $563 & $564;
        $566 = $562 | $565;
        if ($566) {
         $567 = (___udivdi3(($560|0),($561|0),1000000000,0)|0);
         $568 = tempRet0;
         $569 = (___uremdi3(($560|0),($561|0),1000000000,0)|0);
         $570 = tempRet0;
         $$sink$off0$us53$i = $569;$carry1$1$us54$i = $567;
        } else {
         $$sink$off0$us53$i = $560;$carry1$1$us54$i = 0;
        }
        HEAP32[$556>>2] = $$sink$off0$us53$i;
        $571 = (($z$2$us47$i) + 127)|0;
        $572 = $571 & 127;
        $573 = ($k$5$us50$i|0)!=($572|0);
        $574 = ($k$5$us50$i|0)==($a$2$ph40$i|0);
        $or$cond12$us55$i = $573 | $574;
        if ($or$cond12$us55$i) {
         $z$3$us57$i = $z$2$us47$i;
        } else {
         $575 = ($$sink$off0$us53$i|0)==(0);
         $k$5$z$2$us56$i = $575 ? $k$5$us50$i : $z$2$us47$i;
         $z$3$us57$i = $k$5$z$2$us56$i;
        }
        $576 = (($k$5$us50$i) + -1)|0;
        if ($574) {
         break;
        } else {
         $carry1$0$us49$i = $carry1$1$us54$i;$k$5$in$us48$i = $576;$z$2$us47$i = $z$3$us57$i;
        }
       }
       $577 = (($e2$0$us44$i) + -29)|0;
       $578 = ($carry1$1$us54$i|0)==(0);
       if ($578) {
        $e2$0$us44$i = $577;$z$1$us45$i = $z$3$us57$i;
       } else {
        $$lcssa43$i = $577;$carry1$1$lcssa$lcssa$i = $carry1$1$us54$i;$z$3$lcssa$lcssa$i = $z$3$us57$i;
        break;
       }
      }
     }
     $579 = (($rp$2$ph38$i) + 9)|0;
     $580 = (($a$2$ph40$i) + 127)|0;
     $581 = $580 & 127;
     $582 = ($581|0)==($z$3$lcssa$lcssa$i|0);
     if ($582) {
      $583 = (($z$3$lcssa$lcssa$i) + 127)|0;
      $584 = $583 & 127;
      $585 = (($x$i) + ($584<<2)|0);
      $586 = HEAP32[$585>>2]|0;
      $587 = (($z$3$lcssa$lcssa$i) + 126)|0;
      $588 = $587 & 127;
      $589 = (($x$i) + ($588<<2)|0);
      $590 = HEAP32[$589>>2]|0;
      $591 = $590 | $586;
      HEAP32[$589>>2] = $591;
      $z$4$i = $584;
     } else {
      $z$4$i = $z$3$lcssa$lcssa$i;
     }
     $592 = (($x$i) + ($581<<2)|0);
     HEAP32[$592>>2] = $carry1$1$lcssa$lcssa$i;
     $a$2$ph40$i = $581;$e2$0$ph$i = $$lcssa43$i;$rp$2$ph38$i = $579;$z$1$ph39$i = $z$4$i;
    }
    L352: while(1) {
     $629 = (($z$5$ph$i) + 1)|0;
     $626 = $629 & 127;
     $630 = (($z$5$ph$i) + 127)|0;
     $631 = $630 & 127;
     $632 = (($x$i) + ($631<<2)|0);
     $a$3$i$ph = $a$3$ph$i;$e2$1$i$ph = $e2$1$ph$i;$rp$3$i$ph = $rp$3$ph33$i;
     while(1) {
      $605 = ($rp$3$i$ph|0)==(18);
      $633 = ($rp$3$i$ph|0)>(27);
      $$14$i = $633 ? 9 : 1;
      $a$3$i = $a$3$i$ph;$e2$1$i = $e2$1$i$ph;
      while(1) {
       $i$025$i = 0;
       while(1) {
        $595 = (($i$025$i) + ($a$3$i))|0;
        $596 = $595 & 127;
        $597 = ($596|0)==($z$5$ph$i|0);
        if ($597) {
         $i$1$i = 2;
         break;
        }
        $598 = (($x$i) + ($596<<2)|0);
        $599 = HEAP32[$598>>2]|0;
        $600 = (144712 + ($i$025$i<<2)|0);
        $601 = HEAP32[$600>>2]|0;
        $602 = ($599>>>0)<($601>>>0);
        if ($602) {
         $i$1$i = 2;
         break;
        }
        $603 = ($599>>>0)>($601>>>0);
        $593 = (($i$025$i) + 1)|0;
        if ($603) {
         $i$1$i = $i$025$i;
         break;
        }
        $594 = ($593|0)<(2);
        if ($594) {
         $i$025$i = $593;
        } else {
         $i$1$i = $593;
         break;
        }
       }
       $604 = ($i$1$i|0)==(2);
       $or$cond13$i = $604 & $605;
       if ($or$cond13$i) {
        break L352;
       }
       $608 = (($$14$i) + ($e2$1$i))|0;
       $609 = ($a$3$i|0)==($z$5$ph$i|0);
       if ($609) {
        $a$3$i = $z$5$ph$i;$e2$1$i = $608;
       } else {
        break;
       }
      }
      $610 = 1 << $$14$i;
      $611 = (($610) + -1)|0;
      $612 = 1000000000 >>> $$14$i;
      $a$427$i = $a$3$i;$carry3$030$i = 0;$k$628$i = $a$3$i;$rp$426$i = $rp$3$i$ph;
      while(1) {
       $613 = (($x$i) + ($k$628$i<<2)|0);
       $614 = HEAP32[$613>>2]|0;
       $615 = $614 & $611;
       $616 = $614 >>> $$14$i;
       $617 = (($616) + ($carry3$030$i))|0;
       HEAP32[$613>>2] = $617;
       $618 = Math_imul($615, $612)|0;
       $619 = ($k$628$i|0)==($a$427$i|0);
       $620 = ($617|0)==(0);
       $or$cond15$i = $619 & $620;
       $621 = (($k$628$i) + 1)|0;
       $622 = $621 & 127;
       $623 = (($rp$426$i) + -9)|0;
       $rp$5$i = $or$cond15$i ? $623 : $rp$426$i;
       $a$5$i = $or$cond15$i ? $622 : $a$427$i;
       $624 = ($622|0)==($z$5$ph$i|0);
       if ($624) {
        break;
       } else {
        $a$427$i = $a$5$i;$carry3$030$i = $618;$k$628$i = $622;$rp$426$i = $rp$5$i;
       }
      }
      $625 = ($618|0)==(0);
      if ($625) {
       $a$3$i$ph = $a$5$i;$e2$1$i$ph = $608;$rp$3$i$ph = $rp$5$i;
       continue;
      }
      $627 = ($626|0)==($a$5$i|0);
      if (!($627)) {
       break;
      }
      $634 = HEAP32[$632>>2]|0;
      $635 = $634 | 1;
      HEAP32[$632>>2] = $635;
      $a$3$i$ph = $a$5$i;$e2$1$i$ph = $608;$rp$3$i$ph = $rp$5$i;
     }
     $628 = (($x$i) + ($z$5$ph$i<<2)|0);
     HEAP32[$628>>2] = $618;
     $a$3$ph$i = $a$5$i;$e2$1$ph$i = $608;$rp$3$ph33$i = $rp$5$i;$z$5$ph$i = $626;
    }
    $606 = $a$3$i & 127;
    $607 = ($606|0)==($z$5$ph$i|0);
    if ($607) {
     $636 = (($626) + -1)|0;
     $637 = (($x$i) + ($636<<2)|0);
     HEAP32[$637>>2] = 0;
     $z$7$i = $626;
    } else {
     $z$7$i = $z$5$ph$i;
    }
    $638 = (($x$i) + ($606<<2)|0);
    $639 = HEAP32[$638>>2]|0;
    $640 = (+($639>>>0));
    $641 = (($a$3$i) + 1)|0;
    $642 = $641 & 127;
    $643 = ($642|0)==($z$7$i|0);
    if ($643) {
     $702 = (($z$7$i) + 1)|0;
     $703 = $702 & 127;
     $704 = (($703) + -1)|0;
     $705 = (($x$i) + ($704<<2)|0);
     HEAP32[$705>>2] = 0;
     $z$7$1$i = $703;
    } else {
     $z$7$1$i = $z$7$i;
    }
    $706 = $640 * 1.0E+9;
    $707 = (($x$i) + ($642<<2)|0);
    $708 = HEAP32[$707>>2]|0;
    $709 = (+($708>>>0));
    $710 = $706 + $709;
    $667 = (+($sign$0|0));
    $649 = $667 * $710;
    $687 = (($e2$1$i) + 53)|0;
    $644 = (($687) - ($emin$0$ph))|0;
    $711 = ($644|0)<($bits$0$ph|0);
    if ($711) {
     $645 = ($644|0)<(0);
     $$$i22 = $645 ? 0 : $644;
     $$09$i = $$$i22;$denormal$0$i = 1;
    } else {
     $$09$i = $bits$0$ph;$denormal$0$i = 0;
    }
    $646 = ($$09$i|0)<(53);
    if ($646) {
     $647 = (105 - ($$09$i))|0;
     $648 = (+_scalbn(1.0,$647));
     $650 = (+_copysignl((+$648),(+$649)));
     $651 = (53 - ($$09$i))|0;
     $652 = (+_scalbn(1.0,$651));
     $653 = (+_fmodl((+$649),(+$652)));
     $654 = $649 - $653;
     $655 = $650 + $654;
     $bias$0$i = $650;$frac$0$i = $653;$y$1$i23 = $655;
    } else {
     $bias$0$i = 0.0;$frac$0$i = 0.0;$y$1$i23 = $649;
    }
    $656 = (($a$3$i) + 2)|0;
    $657 = $656 & 127;
    $658 = ($657|0)==($z$7$1$i|0);
    do {
     if ($658) {
      $frac$2$i = $frac$0$i;
     } else {
      $659 = (($x$i) + ($657<<2)|0);
      $660 = HEAP32[$659>>2]|0;
      $661 = ($660>>>0)<(500000000);
      do {
       if ($661) {
        $662 = ($660|0)==(0);
        if ($662) {
         $663 = (($a$3$i) + 3)|0;
         $664 = $663 & 127;
         $665 = ($664|0)==($z$7$1$i|0);
         if ($665) {
          $frac$1$i = $frac$0$i;
          break;
         }
        }
        $666 = $667 * 0.25;
        $668 = $666 + $frac$0$i;
        $frac$1$i = $668;
       } else {
        $669 = ($660>>>0)>(500000000);
        if ($669) {
         $670 = $667 * 0.75;
         $671 = $670 + $frac$0$i;
         $frac$1$i = $671;
         break;
        }
        $672 = (($a$3$i) + 3)|0;
        $673 = $672 & 127;
        $674 = ($673|0)==($z$7$1$i|0);
        if ($674) {
         $675 = $667 * 0.5;
         $676 = $675 + $frac$0$i;
         $frac$1$i = $676;
         break;
        } else {
         $677 = $667 * 0.75;
         $678 = $677 + $frac$0$i;
         $frac$1$i = $678;
         break;
        }
       }
      } while(0);
      $679 = (53 - ($$09$i))|0;
      $680 = ($679|0)>(1);
      if (!($680)) {
       $frac$2$i = $frac$1$i;
       break;
      }
      $681 = (+_fmodl((+$frac$1$i),1.0));
      $682 = $681 != 0.0;
      if ($682) {
       $frac$2$i = $frac$1$i;
       break;
      }
      $683 = $frac$1$i + 1.0;
      $frac$2$i = $683;
     }
    } while(0);
    $684 = $y$1$i23 + $frac$2$i;
    $685 = $684 - $bias$0$i;
    $686 = $687 & 2147483647;
    $688 = (-2 - ($sum$i))|0;
    $689 = ($686|0)>($688|0);
    do {
     if ($689) {
      $690 = (+Math_abs((+$685)));
      $691 = !($690 >= 9007199254740992.0);
      if ($691) {
       $denormal$2$i = $denormal$0$i;$e2$2$i = $e2$1$i;$y$2$i24 = $685;
      } else {
       $692 = ($denormal$0$i|0)!=(0);
       $693 = ($$09$i|0)==($644|0);
       $or$cond16$i = $692 & $693;
       $denormal$1$i = $or$cond16$i ? 0 : $denormal$0$i;
       $694 = $685 * 0.5;
       $695 = (($e2$1$i) + 1)|0;
       $denormal$2$i = $denormal$1$i;$e2$2$i = $695;$y$2$i24 = $694;
      }
      $696 = (($e2$2$i) + 50)|0;
      $697 = ($696|0)>($325|0);
      if (!($697)) {
       $698 = ($denormal$2$i|0)!=(0);
       $699 = $frac$2$i != 0.0;
       $or$cond17$i = $698 & $699;
       if (!($or$cond17$i)) {
        $e2$3$i = $e2$2$i;$y$3$i = $y$2$i24;
        break;
       }
      }
      $700 = (___errno_location()|0);
      HEAP32[$700>>2] = 34;
      $e2$3$i = $e2$2$i;$y$3$i = $y$2$i24;
     } else {
      $e2$3$i = $e2$1$i;$y$3$i = $685;
     }
    } while(0);
    $701 = (+_scalbnl($y$3$i,$e2$3$i));
    $$0 = $701;
    STACKTOP = sp;return (+$$0);
   } else {
    $108 = HEAP32[$1>>2]|0;
    $109 = ($108|0)==(0|0);
    if (!($109)) {
     $110 = HEAP32[$0>>2]|0;
     $111 = (($110) + -1|0);
     HEAP32[$0>>2] = $111;
    }
    $112 = (___errno_location()|0);
    HEAP32[$112>>2] = 22;
    ___shlim($f,0);
    $$0 = 0.0;
    STACKTOP = sp;return (+$$0);
   }
  }
 } while(0);
 if ((label|0) == 23) {
  $41 = HEAP32[$1>>2]|0;
  $42 = ($41|0)==(0|0);
  if (!($42)) {
   $43 = HEAP32[$0>>2]|0;
   $44 = (($43) + -1|0);
   HEAP32[$0>>2] = $44;
  }
  $notlhs = ($pok|0)==(0);
  $notrhs = ($i$0$lcssa>>>0)<(4);
  $or$cond106$not = $notrhs | $notlhs;
  $brmerge = $or$cond106$not | $42;
  if (!($brmerge)) {
   $i$166 = $i$0$lcssa;
   while(1) {
    $45 = HEAP32[$0>>2]|0;
    $46 = (($45) + -1|0);
    HEAP32[$0>>2] = $46;
    $47 = (($i$166) + -1)|0;
    $48 = ($47>>>0)>(3);
    if ($48) {
     $i$166 = $47;
    } else {
     break;
    }
   }
  }
 }
 $49 = (+($sign$0|0));
 $50 = $49 * inf;
 $51 = $50;
 $$0 = $51;
 STACKTOP = sp;return (+$$0);
}
function _scanexp($f,$pok) {
 $f = $f|0;
 $pok = $pok|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $c$0 = 0, $c$1$be = 0;
 var $c$18 = 0, $c$2$be = 0, $c$2$lcssa = 0, $c$23 = 0, $c$3$be = 0, $neg$0 = 0, $or$cond = 0, $or$cond2 = 0, $phitmp16 = 0, $x$09 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($f) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($f) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)<($3>>>0);
 if ($4) {
  $5 = (($1) + 1|0);
  HEAP32[$0>>2] = $5;
  $6 = HEAP8[$1>>0]|0;
  $7 = $6&255;
  $9 = $7;
 } else {
  $8 = (___shgetc($f)|0);
  $9 = $8;
 }
 $10 = ($9|0)==(45);
 if ((($9|0) == 43) | (($9|0) == 45)) {
  $11 = $10&1;
  $12 = HEAP32[$0>>2]|0;
  $13 = HEAP32[$2>>2]|0;
  $14 = ($12>>>0)<($13>>>0);
  if ($14) {
   $15 = (($12) + 1|0);
   HEAP32[$0>>2] = $15;
   $16 = HEAP8[$12>>0]|0;
   $17 = $16&255;
   $20 = $17;
  } else {
   $18 = (___shgetc($f)|0);
   $20 = $18;
  }
  $19 = (($20) + -48)|0;
  $21 = ($19>>>0)<(10);
  $22 = ($pok|0)==(0);
  $or$cond = $21 | $22;
  if ($or$cond) {
   $c$0 = $20;$neg$0 = $11;
  } else {
   $23 = HEAP32[$2>>2]|0;
   $24 = ($23|0)==(0|0);
   if ($24) {
    $c$0 = $20;$neg$0 = $11;
   } else {
    $25 = HEAP32[$0>>2]|0;
    $26 = (($25) + -1|0);
    HEAP32[$0>>2] = $26;
    $c$0 = $20;$neg$0 = $11;
   }
  }
 } else {
  $c$0 = $9;$neg$0 = 0;
 }
 $27 = (($c$0) + -48)|0;
 $28 = ($27>>>0)>(9);
 if ($28) {
  $29 = HEAP32[$2>>2]|0;
  $30 = ($29|0)==(0|0);
  if ($30) {
   $95 = -2147483648;$96 = 0;
   tempRet0 = $95;
   STACKTOP = sp;return ($96|0);
  }
  $31 = HEAP32[$0>>2]|0;
  $32 = (($31) + -1|0);
  HEAP32[$0>>2] = $32;
  $95 = -2147483648;$96 = 0;
  tempRet0 = $95;
  STACKTOP = sp;return ($96|0);
 } else {
  $c$18 = $c$0;$x$09 = 0;
 }
 while(1) {
  $33 = (($c$18) + -48)|0;
  $34 = (($33) + ($x$09))|0;
  $35 = HEAP32[$0>>2]|0;
  $36 = HEAP32[$2>>2]|0;
  $37 = ($35>>>0)<($36>>>0);
  if ($37) {
   $38 = (($35) + 1|0);
   HEAP32[$0>>2] = $38;
   $39 = HEAP8[$35>>0]|0;
   $40 = $39&255;
   $c$1$be = $40;
  } else {
   $41 = (___shgetc($f)|0);
   $c$1$be = $41;
  }
  $42 = (($c$1$be) + -48)|0;
  $43 = ($42>>>0)<(10);
  $44 = ($34|0)<(214748364);
  $$ = $43 & $44;
  if (!($$)) {
   break;
  }
  $phitmp16 = ($34*10)|0;
  $c$18 = $c$1$be;$x$09 = $phitmp16;
 }
 $45 = ($34|0)<(0);
 $46 = $45 << 31 >> 31;
 $47 = (($c$1$be) + -48)|0;
 $48 = ($47>>>0)<(10);
 if ($48) {
  $51 = $34;$52 = $46;$c$23 = $c$1$be;
  while(1) {
   $53 = (___muldi3(($51|0),($52|0),10,0)|0);
   $54 = tempRet0;
   $55 = ($c$23|0)<(0);
   $56 = $55 << 31 >> 31;
   $57 = (_i64Add(($c$23|0),($56|0),-48,-1)|0);
   $58 = tempRet0;
   $59 = (_i64Add(($57|0),($58|0),($53|0),($54|0))|0);
   $60 = tempRet0;
   $61 = HEAP32[$0>>2]|0;
   $62 = HEAP32[$2>>2]|0;
   $63 = ($61>>>0)<($62>>>0);
   if ($63) {
    $64 = (($61) + 1|0);
    HEAP32[$0>>2] = $64;
    $65 = HEAP8[$61>>0]|0;
    $66 = $65&255;
    $c$2$be = $66;
   } else {
    $67 = (___shgetc($f)|0);
    $c$2$be = $67;
   }
   $68 = (($c$2$be) + -48)|0;
   $69 = ($68>>>0)<(10);
   $70 = ($60|0)<(21474836);
   $71 = ($60|0)==(21474836);
   $72 = ($59>>>0)<(2061584302);
   $73 = $71 & $72;
   $74 = $70 | $73;
   $or$cond2 = $69 & $74;
   if ($or$cond2) {
    $51 = $59;$52 = $60;$c$23 = $c$2$be;
   } else {
    $89 = $59;$90 = $60;$c$2$lcssa = $c$2$be;
    break;
   }
  }
 } else {
  $89 = $34;$90 = $46;$c$2$lcssa = $c$1$be;
 }
 $49 = (($c$2$lcssa) + -48)|0;
 $50 = ($49>>>0)<(10);
 if ($50) {
  while(1) {
   $75 = HEAP32[$0>>2]|0;
   $76 = HEAP32[$2>>2]|0;
   $77 = ($75>>>0)<($76>>>0);
   if ($77) {
    $78 = (($75) + 1|0);
    HEAP32[$0>>2] = $78;
    $79 = HEAP8[$75>>0]|0;
    $80 = $79&255;
    $c$3$be = $80;
   } else {
    $81 = (___shgetc($f)|0);
    $c$3$be = $81;
   }
   $82 = (($c$3$be) + -48)|0;
   $83 = ($82>>>0)<(10);
   if (!($83)) {
    break;
   }
  }
 }
 $84 = HEAP32[$2>>2]|0;
 $85 = ($84|0)==(0|0);
 if (!($85)) {
  $86 = HEAP32[$0>>2]|0;
  $87 = (($86) + -1|0);
  HEAP32[$0>>2] = $87;
 }
 $88 = ($neg$0|0)!=(0);
 $91 = (_i64Subtract(0,0,($89|0),($90|0))|0);
 $92 = tempRet0;
 $93 = $88 ? $91 : $89;
 $94 = $88 ? $92 : $90;
 $95 = $94;$96 = $93;
 tempRet0 = $95;
 STACKTOP = sp;return ($96|0);
}
function ___shlim($f,$lim) {
 $f = $f|0;
 $lim = $lim|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($f) + 104|0);
 HEAP32[$0>>2] = $lim;
 $1 = (($f) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($f) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($f) + 108|0);
 HEAP32[$8>>2] = $7;
 $9 = ($lim|0)!=(0);
 $10 = ($7|0)>($lim|0);
 $or$cond = $9 & $10;
 if ($or$cond) {
  $11 = (($4) + ($lim)|0);
  $12 = (($f) + 100|0);
  HEAP32[$12>>2] = $11;
  STACKTOP = sp;return;
 } else {
  $13 = (($f) + 100|0);
  HEAP32[$13>>2] = $2;
  STACKTOP = sp;return;
 }
}
function ___shgetc($f) {
 $f = $f|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$phi$trans$insert2 = 0, $$pre = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($f) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  label = 3;
 } else {
  $3 = (($f) + 108|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)<($1|0);
  if ($5) {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $6 = (___uflow($f)|0);
  $7 = ($6|0)<(0);
  if (!($7)) {
   $9 = HEAP32[$0>>2]|0;
   $10 = ($9|0)==(0);
   $$phi$trans$insert = (($f) + 8|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   if ($10) {
    label = 8;
   } else {
    $11 = (($f) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = $$pre;
    $14 = $12;
    $15 = (($13) - ($14))|0;
    $16 = (($f) + 108|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($9) - ($17))|0;
    $19 = (($18) + -1)|0;
    $20 = ($15|0)>($19|0);
    if ($20) {
     $21 = (($12) + ($19)|0);
     $22 = (($f) + 100|0);
     HEAP32[$22>>2] = $21;
    } else {
     label = 8;
    }
   }
   if ((label|0) == 8) {
    $23 = (($f) + 100|0);
    HEAP32[$23>>2] = $$pre;
   }
   $24 = ($$pre|0)==(0|0);
   $$phi$trans$insert2 = (($f) + 4|0);
   $$pre3 = HEAP32[$$phi$trans$insert2>>2]|0;
   if (!($24)) {
    $25 = $$pre;
    $26 = $$pre3;
    $27 = (($f) + 108|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($25) + 1)|0;
    $30 = (($29) - ($26))|0;
    $31 = (($30) + ($28))|0;
    HEAP32[$27>>2] = $31;
   }
   $32 = (($$pre3) + -1|0);
   $33 = HEAP8[$32>>0]|0;
   $34 = $33&255;
   $35 = ($34|0)==($6|0);
   if ($35) {
    $$0 = $6;
    STACKTOP = sp;return ($$0|0);
   }
   $36 = $6&255;
   HEAP8[$32>>0] = $36;
   $$0 = $6;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $8 = (($f) + 100|0);
 HEAP32[$8>>2] = 0;
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _frexp($x,$e) {
 $x = +$x;
 $e = $e|0;
 var $$0 = 0.0, $$01 = 0.0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $x;$0 = HEAP32[tempDoublePtr>>2]|0;
 $1 = HEAP32[tempDoublePtr+4>>2]|0;
 $2 = (_bitshift64Lshr(($0|0),($1|0),52)|0);
 $3 = tempRet0;
 $4 = $2 & 2047;
 if ((($4|0) == 0)) {
  $5 = $x != 0.0;
  if ($5) {
   $6 = $x * 1.8446744073709552E+19;
   $7 = (+_frexp($6,$e));
   $8 = HEAP32[$e>>2]|0;
   $9 = (($8) + -64)|0;
   $$01 = $7;$storemerge = $9;
  } else {
   $$01 = $x;$storemerge = 0;
  }
  HEAP32[$e>>2] = $storemerge;
  $$0 = $$01;
  STACKTOP = sp;return (+$$0);
 } else if ((($4|0) == 2047)) {
  $$0 = $x;
  STACKTOP = sp;return (+$$0);
 } else {
  $10 = (($4) + -1022)|0;
  HEAP32[$e>>2] = $10;
  $11 = $1 & -2146435073;
  $12 = $11 | 1071644672;
  HEAP32[tempDoublePtr>>2] = $0;HEAP32[tempDoublePtr+4>>2] = $12;$13 = +HEAPF64[tempDoublePtr>>3];
  $$0 = $13;
  STACKTOP = sp;return (+$$0);
 }
 return +0;
}
function _frexpl($x,$e) {
 $x = +$x;
 $e = $e|0;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_frexp($x,$e));
 STACKTOP = sp;return (+$0);
}
function _scalbn($x,$n) {
 $x = +$x;
 $n = $n|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $0 = 0, $1 = 0.0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0.0, $9 = 0, $y$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n|0)>(1023);
 if ($0) {
  $1 = $x * 8.9884656743115795E+307;
  $2 = (($n) + -1023)|0;
  $3 = ($2|0)>(1023);
  if ($3) {
   $4 = $1 * 8.9884656743115795E+307;
   $5 = (($n) + -2046)|0;
   $6 = ($5|0)>(1023);
   $$ = $6 ? 1023 : $5;
   $$0 = $$;$y$0 = $4;
  } else {
   $$0 = $2;$y$0 = $1;
  }
 } else {
  $7 = ($n|0)<(-1022);
  if ($7) {
   $8 = $x * 2.2250738585072014E-308;
   $9 = (($n) + 1022)|0;
   $10 = ($9|0)<(-1022);
   if ($10) {
    $11 = $8 * 2.2250738585072014E-308;
    $12 = (($n) + 2044)|0;
    $13 = ($12|0)<(-1022);
    $$1 = $13 ? -1022 : $12;
    $$0 = $$1;$y$0 = $11;
   } else {
    $$0 = $9;$y$0 = $8;
   }
  } else {
   $$0 = $n;$y$0 = $x;
  }
 }
 $14 = (($$0) + 1023)|0;
 $15 = (_bitshift64Shl(($14|0),0,52)|0);
 $16 = tempRet0;
 HEAP32[tempDoublePtr>>2] = $15;HEAP32[tempDoublePtr+4>>2] = $16;$17 = +HEAPF64[tempDoublePtr>>3];
 $18 = $y$0 * $17;
 STACKTOP = sp;return (+$18);
}
function _scalbnl($x,$n) {
 $x = +$x;
 $n = $n|0;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_scalbn($x,$n));
 STACKTOP = sp;return (+$0);
}
function _wctomb($s,$wc) {
 $s = $s|0;
 $wc = $wc|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($s|0)==(0|0);
 if ($0) {
  $$0 = 0;
 } else {
  $1 = (_wcrtomb($s,$wc,0)|0);
  $$0 = $1;
 }
 STACKTOP = sp;return ($$0|0);
}
function _wcrtomb($s,$wc,$st) {
 $s = $s|0;
 $wc = $wc|0;
 $st = $st|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($s|0)==(0|0);
 if ($0) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ($wc>>>0)<(128);
 if ($1) {
  $2 = $wc&255;
  HEAP8[$s>>0] = $2;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = ($wc>>>0)<(2048);
 if ($3) {
  $4 = $wc >>> 6;
  $5 = $4 | 192;
  $6 = $5&255;
  $7 = (($s) + 1|0);
  HEAP8[$s>>0] = $6;
  $8 = $wc & 63;
  $9 = $8 | 128;
  $10 = $9&255;
  HEAP8[$7>>0] = $10;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = ($wc>>>0)<(55296);
 $12 = (($wc) + -57344)|0;
 $13 = ($12>>>0)<(8192);
 $or$cond = $11 | $13;
 if ($or$cond) {
  $14 = $wc >>> 12;
  $15 = $14 | 224;
  $16 = $15&255;
  $17 = (($s) + 1|0);
  HEAP8[$s>>0] = $16;
  $18 = $wc >>> 6;
  $19 = $18 & 63;
  $20 = $19 | 128;
  $21 = $20&255;
  $22 = (($s) + 2|0);
  HEAP8[$17>>0] = $21;
  $23 = $wc & 63;
  $24 = $23 | 128;
  $25 = $24&255;
  HEAP8[$22>>0] = $25;
  $$0 = 3;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = (($wc) + -65536)|0;
 $27 = ($26>>>0)<(1048576);
 if ($27) {
  $28 = $wc >>> 18;
  $29 = $28 | 240;
  $30 = $29&255;
  $31 = (($s) + 1|0);
  HEAP8[$s>>0] = $30;
  $32 = $wc >>> 12;
  $33 = $32 & 63;
  $34 = $33 | 128;
  $35 = $34&255;
  $36 = (($s) + 2|0);
  HEAP8[$31>>0] = $35;
  $37 = $wc >>> 6;
  $38 = $37 & 63;
  $39 = $38 | 128;
  $40 = $39&255;
  $41 = (($s) + 3|0);
  HEAP8[$36>>0] = $40;
  $42 = $wc & 63;
  $43 = $42 | 128;
  $44 = $43&255;
  HEAP8[$41>>0] = $44;
  $$0 = 4;
  STACKTOP = sp;return ($$0|0);
 } else {
  $45 = (___errno_location()|0);
  HEAP32[$45>>2] = 84;
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function ___toread($f) {
 $f = $f|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($f) + 74|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 << 24 >> 24;
 $3 = (($2) + 255)|0;
 $4 = $3 | $2;
 $5 = $4&255;
 HEAP8[$0>>0] = $5;
 $6 = (($f) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($f) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if ($10) {
  $11 = (($f) + 36|0);
  $12 = HEAP32[$11>>2]|0;
  (FUNCTION_TABLE_iiii[$12 & 7]($f,0,0)|0);
 }
 $13 = (($f) + 16|0);
 HEAP32[$13>>2] = 0;
 $14 = (($f) + 28|0);
 HEAP32[$14>>2] = 0;
 HEAP32[$6>>2] = 0;
 $15 = HEAP32[$f>>2]|0;
 $16 = $15 & 20;
 $17 = ($16|0)==(0);
 if ($17) {
  $21 = HEAP32[$8>>2]|0;
  $22 = (($f) + 8|0);
  HEAP32[$22>>2] = $21;
  $23 = (($f) + 4|0);
  HEAP32[$23>>2] = $21;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = $15 & 4;
 $19 = ($18|0)==(0);
 if ($19) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = $15 | 32;
 HEAP32[$f>>2] = $20;
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function ___towrite($f) {
 $f = $f|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($f) + 74|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 << 24 >> 24;
 $3 = (($2) + 255)|0;
 $4 = $3 | $2;
 $5 = $4&255;
 HEAP8[$0>>0] = $5;
 $6 = HEAP32[$f>>2]|0;
 $7 = $6 & 8;
 $8 = ($7|0)==(0);
 if ($8) {
  $10 = (($f) + 8|0);
  HEAP32[$10>>2] = 0;
  $11 = (($f) + 4|0);
  HEAP32[$11>>2] = 0;
  $12 = (($f) + 44|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($f) + 28|0);
  HEAP32[$14>>2] = $13;
  $15 = (($f) + 20|0);
  HEAP32[$15>>2] = $13;
  $16 = (($f) + 48|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($13) + ($17)|0);
  $19 = (($f) + 16|0);
  HEAP32[$19>>2] = $18;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $9 = $6 | 32;
  HEAP32[$f>>2] = $9;
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function ___uflow($f) {
 $f = $f|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $c = sp;
 $0 = (($f) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (___toread($f)|0);
  $4 = ($3|0)==(0);
  if ($4) {
   label = 3;
  } else {
   $$0 = -1;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $5 = (($f) + 32|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_iiii[$6 & 7]($f,$c,1)|0);
  $8 = ($7|0)==(1);
  if ($8) {
   $9 = HEAP8[$c>>0]|0;
   $10 = $9&255;
   $$0 = $10;
  } else {
   $$0 = -1;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function ___fwritex($s,$l,$f) {
 $s = $s|0;
 $l = $l|0;
 $f = $f|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$pre = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0 = 0, $i$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($f) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $3 = (___towrite($f)|0);
   $4 = ($3|0)==(0);
   if ($4) {
    $$pre6 = HEAP32[$0>>2]|0;
    $7 = $$pre6;
    break;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $7 = $1;
  }
 } while(0);
 $5 = (($f) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $8 = $7;
 $9 = $6;
 $10 = (($8) - ($9))|0;
 $11 = ($10>>>0)<($l>>>0);
 if ($11) {
  $12 = (($f) + 36|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_iiii[$13 & 7]($f,$s,$l)|0);
  $$0 = $14;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = (($f) + 75|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)>(-1);
 L11: do {
  if ($17) {
   $i$0 = $l;
   while(1) {
    $18 = ($i$0|0)==(0);
    if ($18) {
     $$01 = $l;$$02 = $s;$29 = $6;$i$1 = 0;
     break L11;
    }
    $19 = (($i$0) + -1)|0;
    $20 = (($s) + ($19)|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = ($21<<24>>24)==(10);
    if ($22) {
     break;
    } else {
     $i$0 = $19;
    }
   }
   $23 = (($f) + 36|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (FUNCTION_TABLE_iiii[$24 & 7]($f,$s,$i$0)|0);
   $26 = ($25>>>0)<($i$0>>>0);
   if ($26) {
    $$0 = $i$0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $27 = (($s) + ($i$0)|0);
    $28 = (($l) - ($i$0))|0;
    $$pre = HEAP32[$5>>2]|0;
    $$01 = $28;$$02 = $27;$29 = $$pre;$i$1 = $i$0;
    break;
   }
  } else {
   $$01 = $l;$$02 = $s;$29 = $6;$i$1 = 0;
  }
 } while(0);
 _memcpy(($29|0),($$02|0),($$01|0))|0;
 $30 = HEAP32[$5>>2]|0;
 $31 = (($30) + ($$01)|0);
 HEAP32[$5>>2] = $31;
 $32 = (($i$1) + ($$01))|0;
 $$0 = $32;
 STACKTOP = sp;return ($$0|0);
}
function _snprintf($s,$n,$fmt,$varargs) {
 $s = $s|0;
 $n = $n|0;
 $fmt = $fmt|0;
 $varargs = $varargs|0;
 var $0 = 0, $ap = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ap = sp;
 HEAP32[$ap>>2] = $varargs;
 $0 = (_vsnprintf($s,$n,$fmt,$ap)|0);
 STACKTOP = sp;return ($0|0);
}
function _sprintf($s,$fmt,$varargs) {
 $s = $s|0;
 $fmt = $fmt|0;
 $varargs = $varargs|0;
 var $0 = 0, $ap = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ap = sp;
 HEAP32[$ap>>2] = $varargs;
 $0 = (_vsprintf($s,$fmt,$ap)|0);
 STACKTOP = sp;return ($0|0);
}
function _MUSL_vfprintf($f,$fmt,$ap) {
 $f = $f|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $ap2 = 0, $internal_buf = 0, $nl_arg = 0, $nl_type = 0, $ret$1 = 0, $vacopy_currentptr = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $ap2 = sp + 120|0;
 $nl_type = sp + 80|0;
 $nl_arg = sp;
 $internal_buf = sp + 136|0;
 dest=$nl_type+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $vacopy_currentptr = HEAP32[$ap>>2]|0;
 HEAP32[$ap2>>2] = $vacopy_currentptr;
 $0 = (_printf_core(0,$fmt,$ap2,$nl_arg,$nl_type)|0);
 $1 = ($0|0)<(0);
 if ($1) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($f) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $6 = (($f) + 44|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$6>>2] = $internal_buf;
  $8 = (($f) + 28|0);
  HEAP32[$8>>2] = $internal_buf;
  $9 = (($f) + 20|0);
  HEAP32[$9>>2] = $internal_buf;
  HEAP32[$2>>2] = 80;
  $10 = (($internal_buf) + 80|0);
  $11 = (($f) + 16|0);
  HEAP32[$11>>2] = $10;
  $12 = (_printf_core($f,$fmt,$ap2,$nl_arg,$nl_type)|0);
  $13 = ($7|0)==(0|0);
  if ($13) {
   $ret$1 = $12;
  } else {
   $14 = (($f) + 36|0);
   $15 = HEAP32[$14>>2]|0;
   (FUNCTION_TABLE_iiii[$15 & 7]($f,0,0)|0);
   $16 = HEAP32[$9>>2]|0;
   $17 = ($16|0)==(0|0);
   $$ = $17 ? -1 : $12;
   HEAP32[$6>>2] = $7;
   HEAP32[$2>>2] = 0;
   HEAP32[$11>>2] = 0;
   HEAP32[$8>>2] = 0;
   HEAP32[$9>>2] = 0;
   $ret$1 = $$;
  }
 } else {
  $5 = (_printf_core($f,$fmt,$ap2,$nl_arg,$nl_type)|0);
  $ret$1 = $5;
 }
 $$0 = $ret$1;
 STACKTOP = sp;return ($$0|0);
}
function _printf_core($f,$fmt,$ap,$nl_arg,$nl_type) {
 $f = $f|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 $nl_arg = $nl_arg|0;
 $nl_type = $nl_type|0;
 var $$ = 0, $$$5$i = 0, $$$i = 0, $$$p$i = 0, $$0 = 0, $$0$lcssa$i = 0, $$0$lcssa$i$i = 0, $$0$lcssa$i103$i = 0, $$0$lcssa$i127$i = 0, $$0$lcssa$i142$i = 0, $$0$lcssa$i37 = 0, $$0$lcssa$i38$i = 0, $$0$lcssa$i43 = 0, $$0$lcssa$i45 = 0, $$0$lcssa$i45$i = 0, $$0$lcssa$i48$i = 0, $$0$lcssa$i52 = 0, $$0$lcssa$i55$i = 0, $$0$lcssa$i59 = 0, $$0$lcssa$i62$i = 0;
 var $$0$lcssa$i66 = 0, $$0$lcssa$i68$i = 0, $$0$lcssa$i75$i = 0, $$0$lcssa$i76 = 0, $$0$lcssa$i84$i = 0, $$0$lcssa$i96$i = 0, $$01$i = 0, $$01$i$i = 0, $$01$i101$i = 0, $$01$i125$i = 0, $$01$i140$i = 0, $$01$i35 = 0, $$01$i36$i = 0, $$01$i43$i = 0, $$01$i50 = 0, $$01$i53$i = 0, $$01$i57 = 0, $$01$i60$i = 0, $$01$i64 = 0, $$01$i66$i = 0;
 var $$01$i73$i = 0, $$01$i74 = 0, $$01$i94$i = 0, $$01$lcssa$off0$i = 0, $$01$lcssa$off0$i$i = 0, $$01$lcssa$off0$i85$i = 0, $$012$i = 0, $$013$i = 0, $$03$i40 = 0, $$05$i = 0, $$05$i$i = 0, $$05$i79$i = 0, $$07$i = 0.0, $$1$i = 0.0, $$1$lcssa$i$i = 0, $$1$lcssa$i112$i = 0, $$114$i = 0, $$12$i = 0, $$12$i$i = 0, $$12$i110$i = 0;
 var $$12$i119$i = 0, $$12$i134$i = 0, $$12$i87$i = 0, $$13 = 0, $$14 = 0, $$15 = 0, $$17 = 0, $$2$i = 0.0, $$2$us$i = 0.0, $$2$us$us$i = 0.0, $$2$us159$i = 0.0, $$20$i = 0, $$20$us$i = 0, $$21$i = 0, $$210$$23$i = 0, $$210$$25$i = 0, $$210$i = 0, $$22$i = 0.0, $$23$i = 0, $$25$i = 0;
 var $$3$i = 0.0, $$31$i = 0, $$311$i = 0, $$4$i = 0.0, $$412$lcssa$i = 0, $$412175$i = 0, $$5193$i = 0, $$a$3$i = 0, $$a$3$us$i = 0, $$a$3$us322$i = 0, $$a$3$us323$i = 0, $$a$3324$i = 0, $$a$3325$i = 0, $$fl$4 = 0, $$lcssa300$i = 0, $$lcssa92 = 0, $$mask$i = 0, $$mask$i30 = 0, $$mask1$i = 0, $$mask1$i29 = 0;
 var $$neg151$i = 0, $$neg152$i = 0, $$not$i = 0, $$p$5 = 0, $$p$i = 0, $$pn$i = 0, $$pr$i = 0, $$pr146$i = 0, $$pre = 0, $$pre$i = 0, $$pre290 = 0, $$pre292 = 0, $$pre319$i = 0, $$sum$i = 0, $$sum15$i = 0, $$sum16$i = 0, $$z$3$i = 0, $$z$4$us$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0;
 var $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0;
 var $1035 = 0, $1036 = 0.0, $1037 = 0.0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1045$phi = 0, $1046 = 0, $1046$phi = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0;
 var $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0.0, $191 = 0, $192 = 0, $193 = 0, $194 = 0.0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0.0;
 var $37 = 0, $370 = 0, $371 = 0.0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $405 = 0, $406 = 0, $407 = 0.0, $408 = 0.0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0.0;
 var $423 = 0, $424 = 0, $425 = 0, $426 = 0.0, $427 = 0.0, $428 = 0.0, $429 = 0.0, $43 = 0, $430 = 0.0, $431 = 0.0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0;
 var $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0;
 var $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0;
 var $478 = 0, $479 = 0, $48 = 0, $480 = 0.0, $481 = 0.0, $482 = 0.0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0.0;
 var $496 = 0.0, $497 = 0.0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0.0, $511 = 0.0, $512 = 0.0;
 var $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0.0, $526 = 0.0, $527 = 0.0, $528 = 0, $529 = 0, $53 = 0, $530 = 0;
 var $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0;
 var $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0;
 var $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0.0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0.0;
 var $586 = 0.0, $587 = 0.0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0;
 var $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0;
 var $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0;
 var $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0;
 var $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0;
 var $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0;
 var $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0;
 var $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0.0, $726 = 0.0, $727 = 0, $728 = 0.0, $729 = 0;
 var $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0;
 var $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0;
 var $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0;
 var $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0;
 var $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0;
 var $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0;
 var $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0;
 var $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0;
 var $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0;
 var $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0;
 var $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0;
 var $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0;
 var $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0;
 var $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0;
 var $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $a$0 = 0;
 var $a$1 = 0, $a$1$lcssa$i = 0, $a$1263$i = 0, $a$2 = 0, $a$2$ph$i = 0, $a$3$lcssa$i = 0, $a$3249$i = 0, $a$3249$us$i = 0, $a$5$lcssa$i = 0, $a$5223$i = 0, $a$6$i = 0, $a$7$i = 0, $a$8$ph$i = 0, $arglist_current = 0, $arglist_current11 = 0, $arglist_current14 = 0, $arglist_current17 = 0, $arglist_current2 = 0, $arglist_current20 = 0, $arglist_current23 = 0;
 var $arglist_current26 = 0, $arglist_current29 = 0, $arglist_current32 = 0, $arglist_current35 = 0, $arglist_current38 = 0, $arglist_current41 = 0, $arglist_current44 = 0, $arglist_current47 = 0, $arglist_current5 = 0, $arglist_current50 = 0, $arglist_current53 = 0, $arglist_current56 = 0, $arglist_current59 = 0, $arglist_current62 = 0, $arglist_current8 = 0, $arglist_next = 0, $arglist_next12 = 0, $arglist_next15 = 0, $arglist_next18 = 0, $arglist_next21 = 0;
 var $arglist_next24 = 0, $arglist_next27 = 0, $arglist_next3 = 0, $arglist_next30 = 0, $arglist_next33 = 0, $arglist_next36 = 0, $arglist_next39 = 0, $arglist_next42 = 0, $arglist_next45 = 0, $arglist_next48 = 0, $arglist_next51 = 0, $arglist_next54 = 0, $arglist_next57 = 0, $arglist_next6 = 0, $arglist_next60 = 0, $arglist_next63 = 0, $arglist_next9 = 0, $argpos$0 = 0, $big$i = 0, $brmerge$i = 0;
 var $buf = 0, $buf$i = 0, $carry$0255$i = 0, $carry3$0243$i = 0, $carry3$0243$us$i = 0, $cnt$0 = 0, $cnt$1 = 0, $d$0$i = 0, $d$0254$i = 0, $d$0256$i = 0, $d$1242$i = 0, $d$1242$us$i = 0, $d$2$lcssa$i = 0, $d$2222$i = 0, $d$3$i = 0, $d$4183$i = 0, $d$5174$i = 0, $d$6192$i = 0, $e$0238$i = 0, $e$1$i = 0;
 var $e$2218$i = 0, $e$3$i = 0, $e$4$ph$i = 0, $e2$i = 0, $ebuf0$i = 0, $estr$0$i = 0, $estr$1$lcssa$i = 0, $estr$1$ph$i = 0, $estr$1200$i = 0, $estr$2$i = 0, $exitcond$i = 0, $fl$0100 = 0, $fl$0104 = 0, $fl$1 = 0, $fl$1$ = 0, $fl$3 = 0, $fl$4 = 0, $fl$6 = 0, $i$0$lcssa = 0, $i$0166 = 0;
 var $i$0168 = 0, $i$0237$i = 0, $i$03$i = 0, $i$03$i22 = 0, $i$1$lcssa$i = 0, $i$1174 = 0, $i$1230$i = 0, $i$2217$i = 0, $i$289 = 0, $i$3209$i = 0, $i$388 = 0, $isdigit = 0, $isdigit$i = 0, $isdigit$i24 = 0, $isdigit11 = 0, $isdigit2$i = 0, $isdigit2$i21 = 0, $isdigit9 = 0, $isdigittmp = 0, $isdigittmp$i = 0;
 var $isdigittmp$i23 = 0, $isdigittmp1$i = 0, $isdigittmp1$i20 = 0, $isdigittmp10 = 0, $isdigittmp8 = 0, $j$0$i = 0, $j$0229$i = 0, $j$0231$i = 0, $j$1210$i = 0, $j$2$i = 0, $l$0 = 0, $l$0$i = 0, $l$1$i = 0, $l$1$lcssa = 0, $l$1167 = 0, $l10n$0 = 0, $l10n$0$phi = 0, $l10n$1 = 0, $l10n$2 = 0, $l10n$3 = 0;
 var $mb = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond$i100$i = 0, $or$cond$i35$i = 0, $or$cond$i42$i = 0, $or$cond$i49 = 0, $or$cond$i52$i = 0, $or$cond$i56 = 0, $or$cond$i59$i = 0, $or$cond$i63 = 0, $or$cond$i71 = 0, $or$cond$i72$i = 0, $or$cond$i73 = 0, $or$cond$i93$i = 0, $or$cond28$i = 0, $or$cond28173$i = 0, $or$cond29$i = 0, $or$cond4$i = 0;
 var $p$0 = 0, $p$1 = 0, $p$2 = 0, $p$2$ = 0, $p$4296 = 0, $p$5 = 0, $pad$i = 0, $pl$0 = 0, $pl$0$i = 0, $pl$1 = 0, $pl$1$i = 0, $pl$2 = 0, $prefix$0 = 0, $prefix$0$$i = 0, $prefix$0$i = 0, $prefix$1 = 0, $prefix$2 = 0, $r$0$a$8$i = 0, $re$0$i = 0, $re$1165$i = 0;
 var $round$0164$i = 0.0, $round6$1$i = 0.0, $s$0$i = 0, $s$0$us$i = 0, $s$0$us$us$i = 0, $s$0$us158$i = 0, $s$1$i = 0, $s$1$lcssa$i = 0, $s$1$us$i = 0, $s$1$us$us$i = 0, $s$1$us160$i = 0, $s1$0$i = 0, $s7$0180$i = 0, $s7$1$i = 0, $s8$0$lcssa$i = 0, $s8$0169$i = 0, $s9$0$i = 0, $s9$1188$i = 0, $s9$2$i = 0, $sext = 0;
 var $sext84 = 0, $small$0$i = 0.0, $small$1$i = 0.0, $st$0 = 0, $storemerge = 0, $storemerge12 = 0, $storemerge7103 = 0, $storemerge798 = 0, $t$0 = 0, $t$1 = 0, $w$$i = 0, $w$0 = 0, $w$1 = 0, $w$18$i = 0, $w$2 = 0, $w$30$i = 0, $wc = 0, $ws$0169 = 0, $ws$1175 = 0, $y$03$i = 0;
 var $y$03$i$i = 0, $y$03$i109$i = 0, $y$03$i118$i = 0, $y$03$i133$i = 0, $y$03$i86$i = 0, $z$0$i = 0, $z$0$lcssa = 0, $z$093 = 0, $z$1$lcssa$i = 0, $z$1262$i = 0, $z$2 = 0, $z$2$i = 0, $z$3$lcssa$i = 0, $z$3248$i = 0, $z$3248$us$i = 0, $z$4$i = 0, $z$4$us$i = 0, $z$5$i = 0, $z$6$$i = 0, $z$6$i = 0;
 var $z$6$ph$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 864|0;
 $big$i = sp + 16|0;
 $e2$i = sp + 8|0;
 $buf$i = sp + 836|0;
 $0 = $buf$i;
 $ebuf0$i = sp + 824|0;
 $pad$i = sp + 568|0;
 $buf = sp + 528|0;
 $wc = sp;
 $mb = sp + 520|0;
 $1 = ($f|0)!=(0|0);
 $2 = (($buf) + 40|0);
 $3 = $2;
 $4 = (($buf) + 39|0);
 $5 = (($wc) + 4|0);
 $6 = (($ebuf0$i) + 12|0);
 $7 = (($ebuf0$i) + 11|0);
 $8 = $6;
 $9 = (($8) - ($0))|0;
 $10 = (-2 - ($0))|0;
 $11 = (($8) + 2)|0;
 $12 = (($big$i) + 288|0);
 $13 = (($buf$i) + 9|0);
 $14 = $13;
 $15 = (($buf$i) + 8|0);
 $1045 = 0;$1046 = 0;$22 = $fmt;$cnt$0 = 0;$l$0 = 0;$l10n$0 = 0;
 L1: while(1) {
  $16 = ($cnt$0|0)>(-1);
  do {
   if ($16) {
    $17 = (2147483647 - ($cnt$0))|0;
    $18 = ($l$0|0)>($17|0);
    if ($18) {
     $19 = (___errno_location()|0);
     HEAP32[$19>>2] = 75;
     $cnt$1 = -1;
     break;
    } else {
     $20 = (($l$0) + ($cnt$0))|0;
     $cnt$1 = $20;
     break;
    }
   } else {
    $cnt$1 = $cnt$0;
   }
  } while(0);
  $21 = HEAP8[$22>>0]|0;
  $23 = ($21<<24>>24)==(0);
  if ($23) {
   label = 344;
   break;
  } else {
   $1047 = $21;$25 = $22;
  }
  while(1) {
   if ((($1047<<24>>24) == 0)) {
    $$lcssa92 = $25;$z$0$lcssa = $25;
    break;
   } else if ((($1047<<24>>24) == 37)) {
    $27 = $25;$z$093 = $25;
    label = 9;
    break;
   }
   $24 = (($25) + 1|0);
   $$pre = HEAP8[$24>>0]|0;
   $1047 = $$pre;$25 = $24;
  }
  L12: do {
   if ((label|0) == 9) {
    while(1) {
     label = 0;
     $26 = (($27) + 1|0);
     $28 = HEAP8[$26>>0]|0;
     $29 = ($28<<24>>24)==(37);
     if (!($29)) {
      $$lcssa92 = $27;$z$0$lcssa = $z$093;
      break L12;
     }
     $30 = (($z$093) + 1|0);
     $31 = (($27) + 2|0);
     $32 = HEAP8[$31>>0]|0;
     $33 = ($32<<24>>24)==(37);
     if ($33) {
      $27 = $31;$z$093 = $30;
      label = 9;
     } else {
      $$lcssa92 = $31;$z$0$lcssa = $30;
      break;
     }
    }
   }
  } while(0);
  $34 = $z$0$lcssa;
  $35 = $22;
  $36 = (($34) - ($35))|0;
  if ($1) {
   (___fwritex($22,$36,$f)|0);
  }
  $37 = ($z$0$lcssa|0)==($22|0);
  if (!($37)) {
   $l10n$0$phi = $l10n$0;$1046$phi = $1046;$1045$phi = $1045;$22 = $$lcssa92;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$0$phi;$1046 = $1046$phi;$1045 = $1045$phi;
   continue;
  }
  $38 = (($$lcssa92) + 1|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39 << 24 >> 24;
  $isdigittmp = (($40) + -48)|0;
  $isdigit = ($isdigittmp>>>0)<(10);
  if ($isdigit) {
   $41 = (($$lcssa92) + 2|0);
   $42 = HEAP8[$41>>0]|0;
   $43 = ($42<<24>>24)==(36);
   if ($43) {
    $44 = (($$lcssa92) + 3|0);
    $$pre290 = HEAP8[$44>>0]|0;
    $46 = $$pre290;$argpos$0 = $isdigittmp;$l10n$1 = 1;$storemerge = $44;
   } else {
    $46 = $39;$argpos$0 = -1;$l10n$1 = $l10n$0;$storemerge = $38;
   }
  } else {
   $46 = $39;$argpos$0 = -1;$l10n$1 = $l10n$0;$storemerge = $38;
  }
  $45 = $46 << 24 >> 24;
  $47 = (($45) + -32)|0;
  $48 = ($47>>>0)<(32);
  L25: do {
   if ($48) {
    $50 = $45;$55 = $46;$fl$0104 = 0;$storemerge7103 = $storemerge;
    while(1) {
     $49 = (($50) + -32)|0;
     $51 = 1 << $49;
     $52 = $51 & 75913;
     $53 = ($52|0)==(0);
     if ($53) {
      $64 = $55;$fl$0100 = $fl$0104;$storemerge798 = $storemerge7103;
      break L25;
     }
     $54 = $55 << 24 >> 24;
     $56 = (($54) + -32)|0;
     $57 = 1 << $56;
     $58 = $57 | $fl$0104;
     $59 = (($storemerge7103) + 1|0);
     $60 = HEAP8[$59>>0]|0;
     $61 = $60 << 24 >> 24;
     $62 = (($61) + -32)|0;
     $63 = ($62>>>0)<(32);
     if ($63) {
      $50 = $61;$55 = $60;$fl$0104 = $58;$storemerge7103 = $59;
     } else {
      $64 = $60;$fl$0100 = $58;$storemerge798 = $59;
      break;
     }
    }
   } else {
    $64 = $46;$fl$0100 = 0;$storemerge798 = $storemerge;
   }
  } while(0);
  $65 = ($64<<24>>24)==(42);
  do {
   if ($65) {
    $66 = (($storemerge798) + 1|0);
    $67 = HEAP8[$66>>0]|0;
    $68 = $67 << 24 >> 24;
    $isdigittmp10 = (($68) + -48)|0;
    $isdigit11 = ($isdigittmp10>>>0)<(10);
    if ($isdigit11) {
     $69 = (($storemerge798) + 2|0);
     $70 = HEAP8[$69>>0]|0;
     $71 = ($70<<24>>24)==(36);
     if ($71) {
      $72 = (($nl_type) + ($isdigittmp10<<2)|0);
      HEAP32[$72>>2] = 10;
      $73 = HEAP8[$66>>0]|0;
      $74 = $73 << 24 >> 24;
      $75 = (($74) + -48)|0;
      $76 = (($nl_arg) + ($75<<3)|0);
      $77 = $76;
      $78 = $77;
      $79 = HEAP32[$78>>2]|0;
      $80 = (($77) + 4)|0;
      $81 = $80;
      $82 = HEAP32[$81>>2]|0;
      $83 = (($storemerge798) + 3|0);
      $l10n$2 = 1;$storemerge12 = $83;$w$0 = $79;
     } else {
      label = 24;
     }
    } else {
     label = 24;
    }
    if ((label|0) == 24) {
     label = 0;
     $84 = ($l10n$1|0)==(0);
     if (!($84)) {
      $$0 = -1;
      label = 362;
      break L1;
     }
     if (!($1)) {
      $100 = $66;$fl$1 = $fl$0100;$l10n$3 = 0;$w$1 = 0;
      break;
     }
     $arglist_current = HEAP32[$ap>>2]|0;
     $85 = HEAP32[$arglist_current>>2]|0;
     $arglist_next = (($arglist_current) + 4|0);
     HEAP32[$ap>>2] = $arglist_next;
     $l10n$2 = 0;$storemerge12 = $66;$w$0 = $85;
    }
    $86 = ($w$0|0)<(0);
    if ($86) {
     $87 = $fl$0100 | 8192;
     $88 = (0 - ($w$0))|0;
     $100 = $storemerge12;$fl$1 = $87;$l10n$3 = $l10n$2;$w$1 = $88;
    } else {
     $100 = $storemerge12;$fl$1 = $fl$0100;$l10n$3 = $l10n$2;$w$1 = $w$0;
    }
   } else {
    $89 = $64 << 24 >> 24;
    $isdigittmp1$i = (($89) + -48)|0;
    $isdigit2$i = ($isdigittmp1$i>>>0)<(10);
    if ($isdigit2$i) {
     $92 = $89;$95 = $storemerge798;$i$03$i = 0;
     while(1) {
      $90 = ($i$03$i*10)|0;
      $91 = (($92) + -48)|0;
      $93 = (($91) + ($90))|0;
      $94 = (($95) + 1|0);
      $96 = HEAP8[$94>>0]|0;
      $97 = $96 << 24 >> 24;
      $isdigittmp$i = (($97) + -48)|0;
      $isdigit$i = ($isdigittmp$i>>>0)<(10);
      if ($isdigit$i) {
       $92 = $97;$95 = $94;$i$03$i = $93;
      } else {
       break;
      }
     }
     $98 = ($93|0)<(0);
     if ($98) {
      $$0 = -1;
      label = 362;
      break L1;
     } else {
      $100 = $94;$fl$1 = $fl$0100;$l10n$3 = $l10n$1;$w$1 = $93;
     }
    } else {
     $100 = $storemerge798;$fl$1 = $fl$0100;$l10n$3 = $l10n$1;$w$1 = 0;
    }
   }
  } while(0);
  $99 = HEAP8[$100>>0]|0;
  $101 = ($99<<24>>24)==(46);
  L46: do {
   if ($101) {
    $102 = (($100) + 1|0);
    $103 = HEAP8[$102>>0]|0;
    $104 = ($103<<24>>24)==(42);
    if (!($104)) {
     $125 = $103 << 24 >> 24;
     $isdigittmp1$i20 = (($125) + -48)|0;
     $isdigit2$i21 = ($isdigittmp1$i20>>>0)<(10);
     if ($isdigit2$i21) {
      $128 = $125;$131 = $102;$i$03$i22 = 0;
     } else {
      $1048 = $102;$p$0 = 0;
      break;
     }
     while(1) {
      $126 = ($i$03$i22*10)|0;
      $127 = (($128) + -48)|0;
      $129 = (($127) + ($126))|0;
      $130 = (($131) + 1|0);
      $132 = HEAP8[$130>>0]|0;
      $133 = $132 << 24 >> 24;
      $isdigittmp$i23 = (($133) + -48)|0;
      $isdigit$i24 = ($isdigittmp$i23>>>0)<(10);
      if ($isdigit$i24) {
       $128 = $133;$131 = $130;$i$03$i22 = $129;
      } else {
       $1048 = $130;$p$0 = $129;
       break L46;
      }
     }
    }
    $105 = (($100) + 2|0);
    $106 = HEAP8[$105>>0]|0;
    $107 = $106 << 24 >> 24;
    $isdigittmp8 = (($107) + -48)|0;
    $isdigit9 = ($isdigittmp8>>>0)<(10);
    if ($isdigit9) {
     $108 = (($100) + 3|0);
     $109 = HEAP8[$108>>0]|0;
     $110 = ($109<<24>>24)==(36);
     if ($110) {
      $111 = (($nl_type) + ($isdigittmp8<<2)|0);
      HEAP32[$111>>2] = 10;
      $112 = HEAP8[$105>>0]|0;
      $113 = $112 << 24 >> 24;
      $114 = (($113) + -48)|0;
      $115 = (($nl_arg) + ($114<<3)|0);
      $116 = $115;
      $117 = $116;
      $118 = HEAP32[$117>>2]|0;
      $119 = (($116) + 4)|0;
      $120 = $119;
      $121 = HEAP32[$120>>2]|0;
      $122 = (($100) + 4|0);
      $1048 = $122;$p$0 = $118;
      break;
     }
    }
    $123 = ($l10n$3|0)==(0);
    if (!($123)) {
     $$0 = -1;
     label = 362;
     break L1;
    }
    if ($1) {
     $arglist_current2 = HEAP32[$ap>>2]|0;
     $124 = HEAP32[$arglist_current2>>2]|0;
     $arglist_next3 = (($arglist_current2) + 4|0);
     HEAP32[$ap>>2] = $arglist_next3;
     $1048 = $105;$p$0 = $124;
    } else {
     $1048 = $105;$p$0 = 0;
    }
   } else {
    $1048 = $100;$p$0 = -1;
   }
  } while(0);
  $135 = $1048;$st$0 = 0;
  while(1) {
   $134 = HEAP8[$135>>0]|0;
   $136 = $134 << 24 >> 24;
   $137 = (($136) + -65)|0;
   $138 = ($137>>>0)>(57);
   if ($138) {
    $$0 = -1;
    label = 362;
    break L1;
   }
   $139 = (($135) + 1|0);
   $140 = ((144752 + (($st$0*58)|0)|0) + ($137)|0);
   $141 = HEAP8[$140>>0]|0;
   $142 = $141&255;
   $143 = (($142) + -1)|0;
   $144 = ($143>>>0)<(8);
   if ($144) {
    $135 = $139;$st$0 = $142;
   } else {
    break;
   }
  }
  $145 = ($141<<24>>24)==(0);
  if ($145) {
   $$0 = -1;
   label = 362;
   break;
  }
  $146 = ($141<<24>>24)==(19);
  $147 = ($argpos$0|0)>(-1);
  L65: do {
   if ($146) {
    if ($147) {
     $$0 = -1;
     label = 362;
     break L1;
    } else {
     $1049 = $1045;$1050 = $1046;
     label = 63;
    }
   } else {
    if ($147) {
     $148 = (($nl_type) + ($argpos$0<<2)|0);
     HEAP32[$148>>2] = $142;
     $149 = (($nl_arg) + ($argpos$0<<3)|0);
     $150 = $149;
     $151 = $150;
     $152 = HEAP32[$151>>2]|0;
     $153 = (($150) + 4)|0;
     $154 = $153;
     $155 = HEAP32[$154>>2]|0;
     $156 = $152;
     $1049 = $155;$1050 = $156;
     label = 63;
     break;
    }
    if (!($1)) {
     $$0 = 0;
     label = 362;
     break L1;
    }
    $157 = ($141&255)>(20);
    if ($157) {
     $199 = $134;$207 = $1046;$228 = $1045;
    } else {
     do {
      switch ($142|0) {
      case 11:  {
       $arglist_current11 = HEAP32[$ap>>2]|0;
       $163 = HEAP32[$arglist_current11>>2]|0;
       $arglist_next12 = (($arglist_current11) + 4|0);
       HEAP32[$ap>>2] = $arglist_next12;
       $164 = $163;
       $1051 = $164;$1052 = 0;
       label = 64;
       break L65;
       break;
      }
      case 12:  {
       $arglist_current14 = HEAP32[$ap>>2]|0;
       $165 = $arglist_current14;
       $166 = $165;
       $167 = HEAP32[$166>>2]|0;
       $168 = (($165) + 4)|0;
       $169 = $168;
       $170 = HEAP32[$169>>2]|0;
       $arglist_next15 = (($arglist_current14) + 8|0);
       HEAP32[$ap>>2] = $arglist_next15;
       $171 = $167;
       $1051 = $171;$1052 = $170;
       label = 64;
       break L65;
       break;
      }
      case 18:  {
       $arglist_current32 = HEAP32[$ap>>2]|0;
       HEAP32[tempDoublePtr>>2]=HEAP32[$arglist_current32>>2];HEAP32[tempDoublePtr+4>>2]=HEAP32[$arglist_current32+4>>2];$194 = +HEAPF64[tempDoublePtr>>3];
       $arglist_next33 = (($arglist_current32) + 8|0);
       HEAP32[$ap>>2] = $arglist_next33;
       HEAPF64[tempDoublePtr>>3] = $194;$195 = HEAP32[tempDoublePtr>>2]|0;
       $196 = HEAP32[tempDoublePtr+4>>2]|0;
       $197 = $195;
       $1049 = $196;$1050 = $197;
       label = 63;
       break L65;
       break;
      }
      case 14:  {
       $arglist_current20 = HEAP32[$ap>>2]|0;
       $179 = HEAP32[$arglist_current20>>2]|0;
       $arglist_next21 = (($arglist_current20) + 4|0);
       HEAP32[$ap>>2] = $arglist_next21;
       $$mask1$i29 = $179 & 65535;
       $180 = $$mask1$i29;
       $1051 = $180;$1052 = 0;
       label = 64;
       break L65;
       break;
      }
      case 10:  {
       $arglist_current8 = HEAP32[$ap>>2]|0;
       $159 = HEAP32[$arglist_current8>>2]|0;
       $arglist_next9 = (($arglist_current8) + 4|0);
       HEAP32[$ap>>2] = $arglist_next9;
       $160 = ($159|0)<(0);
       $161 = $160 << 31 >> 31;
       $162 = $159;
       $1051 = $162;$1052 = $161;
       label = 64;
       break L65;
       break;
      }
      case 13:  {
       $arglist_current17 = HEAP32[$ap>>2]|0;
       $172 = HEAP32[$arglist_current17>>2]|0;
       $arglist_next18 = (($arglist_current17) + 4|0);
       HEAP32[$ap>>2] = $arglist_next18;
       $173 = $172&65535;
       $174 = $173 << 16 >> 16;
       $175 = ($174|0)<(0);
       $176 = $175 << 31 >> 31;
       $sext84 = $172 << 16;
       $177 = $sext84 >> 16;
       $178 = $177;
       $1051 = $178;$1052 = $176;
       label = 64;
       break L65;
       break;
      }
      case 9:  {
       $arglist_current5 = HEAP32[$ap>>2]|0;
       $158 = HEAP32[$arglist_current5>>2]|0;
       $arglist_next6 = (($arglist_current5) + 4|0);
       HEAP32[$ap>>2] = $arglist_next6;
       $1051 = $158;$1052 = $1045;
       label = 64;
       break L65;
       break;
      }
      case 15:  {
       $arglist_current23 = HEAP32[$ap>>2]|0;
       $181 = HEAP32[$arglist_current23>>2]|0;
       $arglist_next24 = (($arglist_current23) + 4|0);
       HEAP32[$ap>>2] = $arglist_next24;
       $182 = $181&255;
       $183 = $182 << 24 >> 24;
       $184 = ($183|0)<(0);
       $185 = $184 << 31 >> 31;
       $sext = $181 << 24;
       $186 = $sext >> 24;
       $187 = $186;
       $1051 = $187;$1052 = $185;
       label = 64;
       break L65;
       break;
      }
      case 17:  {
       $arglist_current29 = HEAP32[$ap>>2]|0;
       HEAP32[tempDoublePtr>>2]=HEAP32[$arglist_current29>>2];HEAP32[tempDoublePtr+4>>2]=HEAP32[$arglist_current29+4>>2];$190 = +HEAPF64[tempDoublePtr>>3];
       $arglist_next30 = (($arglist_current29) + 8|0);
       HEAP32[$ap>>2] = $arglist_next30;
       HEAPF64[tempDoublePtr>>3] = $190;$191 = HEAP32[tempDoublePtr>>2]|0;
       $192 = HEAP32[tempDoublePtr+4>>2]|0;
       $193 = $191;
       $1051 = $193;$1052 = $192;
       label = 64;
       break L65;
       break;
      }
      case 16:  {
       $arglist_current26 = HEAP32[$ap>>2]|0;
       $188 = HEAP32[$arglist_current26>>2]|0;
       $arglist_next27 = (($arglist_current26) + 4|0);
       HEAP32[$ap>>2] = $arglist_next27;
       $$mask$i30 = $188 & 255;
       $189 = $$mask$i30;
       $1051 = $189;$1052 = 0;
       label = 64;
       break L65;
       break;
      }
      default: {
       $1051 = $1046;$1052 = $1045;
       label = 64;
       break L65;
      }
      }
     } while(0);
    }
   }
  } while(0);
  if ((label|0) == 63) {
   label = 0;
   if ($1) {
    $1051 = $1050;$1052 = $1049;
    label = 64;
   } else {
    $1045 = $1049;$1046 = $1050;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$3;
    continue;
   }
  }
  if ((label|0) == 64) {
   label = 0;
   $$pre292 = HEAP8[$135>>0]|0;
   $199 = $$pre292;$207 = $1051;$228 = $1052;
  }
  $198 = $199 << 24 >> 24;
  $200 = ($st$0|0)==(0);
  if ($200) {
   $t$0 = $198;
  } else {
   $201 = $198 & 15;
   $202 = ($201|0)==(3);
   $203 = $198 & -33;
   $$ = $202 ? $203 : $198;
   $t$0 = $$;
  }
  $204 = $fl$1 & 8192;
  $205 = ($204|0)==(0);
  $206 = $fl$1 & -65537;
  $fl$1$ = $205 ? $fl$1 : $206;
  L92: do {
   switch ($t$0|0) {
   case 99:  {
    $319 = $207;
    $320 = $319&255;
    HEAP8[$4>>0] = $320;
    $1053 = $228;$1054 = $207;$a$2 = $4;$fl$6 = $206;$p$5 = 1;$pl$2 = 0;$prefix$2 = 145216;$z$2 = $2;
    break;
   }
   case 65: case 71: case 70: case 69: case 97: case 103: case 102: case 101:  {
    $368 = $207;
    HEAP32[tempDoublePtr>>2] = $368;HEAP32[tempDoublePtr+4>>2] = $228;$369 = +HEAPF64[tempDoublePtr>>3];
    HEAP32[$e2$i>>2] = 0;
    $370 = ($228|0)<(0);
    if ($370) {
     $371 = -$369;
     $$07$i = $371;$pl$0$i = 1;$prefix$0$i = 145240;
    } else {
     $372 = $fl$1$ & 2048;
     $373 = ($372|0)==(0);
     if ($373) {
      $374 = $fl$1$ & 1;
      $375 = ($374|0)==(0);
      $$$i = $375 ? ((145240 + 1|0)) : ((145240 + 6|0));
      $$07$i = $369;$pl$0$i = $374;$prefix$0$i = $$$i;
     } else {
      $$07$i = $369;$pl$0$i = 1;$prefix$0$i = ((145240 + 3|0));
     }
    }
    HEAPF64[tempDoublePtr>>3] = $$07$i;$376 = HEAP32[tempDoublePtr>>2]|0;
    $377 = HEAP32[tempDoublePtr+4>>2]|0;
    $378 = $377 & 2146435072;
    $379 = ($378>>>0)<(2146435072);
    $380 = ($378|0)==(2146435072);
    $381 = (0)<(0);
    $382 = $380 & $381;
    $383 = $379 | $382;
    if (!($383)) {
     $384 = $t$0 & 32;
     $385 = ($384|0)!=(0);
     $386 = $385 ? 145264 : 145272;
     $387 = ($$07$i != $$07$i) | (0.0 != 0.0);
     if ($387) {
      $388 = $385 ? 145280 : 145288;
      $pl$1$i = 0;$s1$0$i = $388;
     } else {
      $pl$1$i = $pl$0$i;$s1$0$i = $386;
     }
     $389 = (($pl$1$i) + 3)|0;
     $390 = $fl$1$ & 8192;
     $391 = ($390|0)==(0);
     $392 = ($389|0)<($w$1|0);
     $or$cond$i35$i = $391 & $392;
     if ($or$cond$i35$i) {
      $393 = (($w$1) - ($389))|0;
      $394 = ($393>>>0)>(256);
      $395 = $394 ? 256 : $393;
      _memset(($pad$i|0),32,($395|0))|0;
      $396 = ($393>>>0)>(255);
      if ($396) {
       $$01$i36$i = $393;
       while(1) {
        (___fwritex($pad$i,256,$f)|0);
        $397 = (($$01$i36$i) + -256)|0;
        $398 = ($397>>>0)>(255);
        if ($398) {
         $$01$i36$i = $397;
        } else {
         $$0$lcssa$i38$i = $397;
         break;
        }
       }
      } else {
       $$0$lcssa$i38$i = $393;
      }
      (___fwritex($pad$i,$$0$lcssa$i38$i,$f)|0);
     }
     (___fwritex($prefix$0$i,$pl$1$i,$f)|0);
     (___fwritex($s1$0$i,3,$f)|0);
     $399 = $fl$1$ & 73728;
     $400 = ($399|0)==(8192);
     $or$cond$i42$i = $400 & $392;
     if ($or$cond$i42$i) {
      $401 = (($w$1) - ($389))|0;
      $402 = ($401>>>0)>(256);
      $403 = $402 ? 256 : $401;
      _memset(($pad$i|0),32,($403|0))|0;
      $404 = ($401>>>0)>(255);
      if ($404) {
       $$01$i43$i = $401;
       while(1) {
        (___fwritex($pad$i,256,$f)|0);
        $405 = (($$01$i43$i) + -256)|0;
        $406 = ($405>>>0)>(255);
        if ($406) {
         $$01$i43$i = $405;
        } else {
         $$0$lcssa$i45$i = $405;
         break;
        }
       }
      } else {
       $$0$lcssa$i45$i = $401;
      }
      (___fwritex($pad$i,$$0$lcssa$i45$i,$f)|0);
     }
     $w$$i = $392 ? $w$1 : $389;
     $1045 = $228;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $w$$i;$l10n$0 = $l10n$3;
     continue L1;
    }
    $407 = (+_frexpl($$07$i,$e2$i));
    $408 = $407 * 2.0;
    $409 = $408 != 0.0;
    if ($409) {
     $410 = HEAP32[$e2$i>>2]|0;
     $411 = (($410) + -1)|0;
     HEAP32[$e2$i>>2] = $411;
    }
    $412 = $t$0 | 32;
    $413 = ($412|0)==(97);
    if ($413) {
     $414 = $t$0 & 32;
     $415 = ($414|0)==(0);
     $416 = (($prefix$0$i) + 9|0);
     $prefix$0$$i = $415 ? $prefix$0$i : $416;
     $417 = $pl$0$i | 2;
     $418 = ($p$0>>>0)>(11);
     $419 = (12 - ($p$0))|0;
     $re$0$i = $418 ? 0 : $419;
     $420 = ($re$0$i|0)==(0);
     do {
      if ($420) {
       $$1$i = $408;
      } else {
       $re$1165$i = $re$0$i;$round$0164$i = 8.0;
       while(1) {
        $421 = (($re$1165$i) + -1)|0;
        $422 = $round$0164$i * 16.0;
        $423 = ($421|0)==(0);
        if ($423) {
         break;
        } else {
         $re$1165$i = $421;$round$0164$i = $422;
        }
       }
       $424 = HEAP8[$prefix$0$$i>>0]|0;
       $425 = ($424<<24>>24)==(45);
       if ($425) {
        $426 = -$408;
        $427 = $426 - $422;
        $428 = $422 + $427;
        $429 = -$428;
        $$1$i = $429;
        break;
       } else {
        $430 = $408 + $422;
        $431 = $430 - $422;
        $$1$i = $431;
        break;
       }
      }
     } while(0);
     $432 = HEAP32[$e2$i>>2]|0;
     $433 = ($432|0)<(0);
     $434 = (0 - ($432))|0;
     $435 = $433 ? $434 : $432;
     $436 = ($435|0)<(0);
     if ($436) {
      $437 = ($435|0)<(0);
      $438 = $437 << 31 >> 31;
      $$05$i$i = $6;$439 = $435;$440 = $438;
      while(1) {
       $441 = (___uremdi3(($439|0),($440|0),10,0)|0);
       $442 = tempRet0;
       $443 = $441 | 48;
       $444 = $443&255;
       $445 = (($$05$i$i) + -1|0);
       HEAP8[$445>>0] = $444;
       $446 = (___udivdi3(($439|0),($440|0),10,0)|0);
       $447 = tempRet0;
       $448 = ($440>>>0)>(9);
       $449 = ($440|0)==(9);
       $450 = ($439>>>0)>(4294967295);
       $451 = $449 & $450;
       $452 = $448 | $451;
       if ($452) {
        $$05$i$i = $445;$439 = $446;$440 = $447;
       } else {
        break;
       }
      }
      $$0$lcssa$i48$i = $445;$$01$lcssa$off0$i$i = $446;
     } else {
      $$0$lcssa$i48$i = $6;$$01$lcssa$off0$i$i = $435;
     }
     $453 = ($$01$lcssa$off0$i$i|0)==(0);
     if ($453) {
      $$1$lcssa$i$i = $$0$lcssa$i48$i;
     } else {
      $$12$i$i = $$0$lcssa$i48$i;$y$03$i$i = $$01$lcssa$off0$i$i;
      while(1) {
       $454 = (($y$03$i$i>>>0) % 10)&-1;
       $455 = $454 | 48;
       $456 = $455&255;
       $457 = (($$12$i$i) + -1|0);
       HEAP8[$457>>0] = $456;
       $458 = (($y$03$i$i>>>0) / 10)&-1;
       $459 = ($y$03$i$i>>>0)<(10);
       if ($459) {
        $$1$lcssa$i$i = $457;
        break;
       } else {
        $$12$i$i = $457;$y$03$i$i = $458;
       }
      }
     }
     $460 = ($$1$lcssa$i$i|0)==($6|0);
     if ($460) {
      HEAP8[$7>>0] = 48;
      $estr$0$i = $7;
     } else {
      $estr$0$i = $$1$lcssa$i$i;
     }
     $461 = HEAP32[$e2$i>>2]|0;
     $462 = $461 >> 31;
     $463 = $462 & 2;
     $464 = (($463) + 43)|0;
     $465 = $464&255;
     $466 = (($estr$0$i) + -1|0);
     HEAP8[$466>>0] = $465;
     $467 = (($t$0) + 15)|0;
     $468 = $467&255;
     $469 = (($estr$0$i) + -2|0);
     HEAP8[$469>>0] = $468;
     $470 = ($p$0|0)>(0);
     $471 = $fl$1$ & 8;
     $472 = ($471|0)==(0);
     if ($470) {
      if ($472) {
       $$2$us$us$i = $$1$i;$s$0$us$us$i = $buf$i;
       while(1) {
        $473 = (~~(($$2$us$us$i)));
        $474 = (145296 + ($473)|0);
        $475 = HEAP8[$474>>0]|0;
        $476 = $475&255;
        $477 = $476 | $414;
        $478 = $477&255;
        $479 = (($s$0$us$us$i) + 1|0);
        HEAP8[$s$0$us$us$i>>0] = $478;
        $480 = (+($473|0));
        $481 = $$2$us$us$i - $480;
        $482 = $481 * 16.0;
        $483 = $479;
        $484 = (($483) - ($0))|0;
        $485 = ($484|0)==(1);
        if ($485) {
         $486 = (($s$0$us$us$i) + 2|0);
         HEAP8[$479>>0] = 46;
         $s$1$us$us$i = $486;
        } else {
         $s$1$us$us$i = $479;
        }
        $487 = $482 != 0.0;
        if ($487) {
         $$2$us$us$i = $482;$s$0$us$us$i = $s$1$us$us$i;
        } else {
         $s$1$lcssa$i = $s$1$us$us$i;
         break;
        }
       }
      } else {
       $$2$us$i = $$1$i;$s$0$us$i = $buf$i;
       while(1) {
        $488 = (~~(($$2$us$i)));
        $489 = (145296 + ($488)|0);
        $490 = HEAP8[$489>>0]|0;
        $491 = $490&255;
        $492 = $491 | $414;
        $493 = $492&255;
        $494 = (($s$0$us$i) + 1|0);
        HEAP8[$s$0$us$i>>0] = $493;
        $495 = (+($488|0));
        $496 = $$2$us$i - $495;
        $497 = $496 * 16.0;
        $498 = $494;
        $499 = (($498) - ($0))|0;
        $500 = ($499|0)==(1);
        if ($500) {
         $501 = (($s$0$us$i) + 2|0);
         HEAP8[$494>>0] = 46;
         $s$1$us$i = $501;
        } else {
         $s$1$us$i = $494;
        }
        $502 = $497 != 0.0;
        if ($502) {
         $$2$us$i = $497;$s$0$us$i = $s$1$us$i;
        } else {
         $s$1$lcssa$i = $s$1$us$i;
         break;
        }
       }
      }
     } else {
      if ($472) {
       $$2$us159$i = $$1$i;$s$0$us158$i = $buf$i;
       while(1) {
        $503 = (~~(($$2$us159$i)));
        $504 = (145296 + ($503)|0);
        $505 = HEAP8[$504>>0]|0;
        $506 = $505&255;
        $507 = $506 | $414;
        $508 = $507&255;
        $509 = (($s$0$us158$i) + 1|0);
        HEAP8[$s$0$us158$i>>0] = $508;
        $510 = (+($503|0));
        $511 = $$2$us159$i - $510;
        $512 = $511 * 16.0;
        $513 = $509;
        $514 = (($513) - ($0))|0;
        $515 = ($514|0)==(1);
        $516 = $512 != 0.0;
        $or$cond$i71 = $515 & $516;
        if ($or$cond$i71) {
         $517 = (($s$0$us158$i) + 2|0);
         HEAP8[$509>>0] = 46;
         $s$1$us160$i = $517;
        } else {
         $s$1$us160$i = $509;
        }
        if ($516) {
         $$2$us159$i = $512;$s$0$us158$i = $s$1$us160$i;
        } else {
         $s$1$lcssa$i = $s$1$us160$i;
         break;
        }
       }
      } else {
       $$2$i = $$1$i;$s$0$i = $buf$i;
       while(1) {
        $518 = (~~(($$2$i)));
        $519 = (145296 + ($518)|0);
        $520 = HEAP8[$519>>0]|0;
        $521 = $520&255;
        $522 = $521 | $414;
        $523 = $522&255;
        $524 = (($s$0$i) + 1|0);
        HEAP8[$s$0$i>>0] = $523;
        $525 = (+($518|0));
        $526 = $$2$i - $525;
        $527 = $526 * 16.0;
        $528 = $524;
        $529 = (($528) - ($0))|0;
        $530 = ($529|0)==(1);
        if ($530) {
         $531 = (($s$0$i) + 2|0);
         HEAP8[$524>>0] = 46;
         $s$1$i = $531;
        } else {
         $s$1$i = $524;
        }
        $532 = $527 != 0.0;
        if ($532) {
         $$2$i = $527;$s$0$i = $s$1$i;
        } else {
         $s$1$lcssa$i = $s$1$i;
         break;
        }
       }
      }
     }
     $533 = ($p$0|0)==(0);
     $$pre319$i = $s$1$lcssa$i;
     do {
      if ($533) {
       label = 173;
      } else {
       $534 = (($10) + ($$pre319$i))|0;
       $535 = ($534|0)<($p$0|0);
       if (!($535)) {
        label = 173;
        break;
       }
       $536 = $469;
       $537 = (($11) + ($p$0))|0;
       $538 = (($537) - ($536))|0;
       $l$0$i = $538;
      }
     } while(0);
     if ((label|0) == 173) {
      label = 0;
      $539 = $469;
      $540 = (($9) - ($539))|0;
      $541 = (($540) + ($$pre319$i))|0;
      $l$0$i = $541;
     }
     $542 = (($l$0$i) + ($417))|0;
     $543 = $fl$1$ & 73728;
     $544 = ($543|0)==(0);
     $545 = ($542|0)<($w$1|0);
     $or$cond$i52$i = $544 & $545;
     if ($or$cond$i52$i) {
      $546 = (($w$1) - ($542))|0;
      $547 = ($546>>>0)>(256);
      $548 = $547 ? 256 : $546;
      _memset(($pad$i|0),32,($548|0))|0;
      $549 = ($546>>>0)>(255);
      if ($549) {
       $$01$i53$i = $546;
       while(1) {
        (___fwritex($pad$i,256,$f)|0);
        $550 = (($$01$i53$i) + -256)|0;
        $551 = ($550>>>0)>(255);
        if ($551) {
         $$01$i53$i = $550;
        } else {
         $$0$lcssa$i55$i = $550;
         break;
        }
       }
      } else {
       $$0$lcssa$i55$i = $546;
      }
      (___fwritex($pad$i,$$0$lcssa$i55$i,$f)|0);
     }
     (___fwritex($prefix$0$$i,$417,$f)|0);
     $552 = ($543|0)==(65536);
     $or$cond$i59$i = $552 & $545;
     if ($or$cond$i59$i) {
      $553 = (($w$1) - ($542))|0;
      $554 = ($553>>>0)>(256);
      $555 = $554 ? 256 : $553;
      _memset(($pad$i|0),48,($555|0))|0;
      $556 = ($553>>>0)>(255);
      if ($556) {
       $$01$i60$i = $553;
       while(1) {
        (___fwritex($pad$i,256,$f)|0);
        $557 = (($$01$i60$i) + -256)|0;
        $558 = ($557>>>0)>(255);
        if ($558) {
         $$01$i60$i = $557;
        } else {
         $$0$lcssa$i62$i = $557;
         break;
        }
       }
      } else {
       $$0$lcssa$i62$i = $553;
      }
      (___fwritex($pad$i,$$0$lcssa$i62$i,$f)|0);
     }
     $559 = (($$pre319$i) - ($0))|0;
     (___fwritex($buf$i,$559,$f)|0);
     $560 = $469;
     $561 = (($8) - ($560))|0;
     $562 = (($l$0$i) - ($561))|0;
     $563 = (($562) - ($559))|0;
     $564 = ($563|0)>(0);
     if ($564) {
      $565 = ($563>>>0)>(256);
      $566 = $565 ? 256 : $563;
      _memset(($pad$i|0),48,($566|0))|0;
      $567 = ($563>>>0)>(255);
      if ($567) {
       $$01$i66$i = $563;
       while(1) {
        (___fwritex($pad$i,256,$f)|0);
        $568 = (($$01$i66$i) + -256)|0;
        $569 = ($568>>>0)>(255);
        if ($569) {
         $$01$i66$i = $568;
        } else {
         $$0$lcssa$i68$i = $568;
         break;
        }
       }
      } else {
       $$0$lcssa$i68$i = $563;
      }
      (___fwritex($pad$i,$$0$lcssa$i68$i,$f)|0);
     }
     (___fwritex($469,$561,$f)|0);
     $570 = ($543|0)==(8192);
     $or$cond$i72$i = $570 & $545;
     if ($or$cond$i72$i) {
      $571 = (($w$1) - ($542))|0;
      $572 = ($571>>>0)>(256);
      $573 = $572 ? 256 : $571;
      _memset(($pad$i|0),32,($573|0))|0;
      $574 = ($571>>>0)>(255);
      if ($574) {
       $$01$i73$i = $571;
       while(1) {
        (___fwritex($pad$i,256,$f)|0);
        $575 = (($$01$i73$i) + -256)|0;
        $576 = ($575>>>0)>(255);
        if ($576) {
         $$01$i73$i = $575;
        } else {
         $$0$lcssa$i75$i = $575;
         break;
        }
       }
      } else {
       $$0$lcssa$i75$i = $571;
      }
      (___fwritex($pad$i,$$0$lcssa$i75$i,$f)|0);
     }
     $w$18$i = $545 ? $w$1 : $542;
     $1045 = $228;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $w$18$i;$l10n$0 = $l10n$3;
     continue L1;
    }
    $577 = ($p$0|0)<(0);
    $$p$i = $577 ? 6 : $p$0;
    if ($409) {
     $578 = $408 * 268435456.0;
     $579 = HEAP32[$e2$i>>2]|0;
     $580 = (($579) + -28)|0;
     HEAP32[$e2$i>>2] = $580;
     $$3$i = $578;$581 = $580;
    } else {
     $$pre$i = HEAP32[$e2$i>>2]|0;
     $$3$i = $408;$581 = $$pre$i;
    }
    $582 = ($581|0)<(0);
    $$31$i = $582 ? $big$i : $12;
    $$4$i = $$3$i;$z$0$i = $$31$i;
    while(1) {
     $583 = (~~(($$4$i))>>>0);
     HEAP32[$z$0$i>>2] = $583;
     $584 = (($z$0$i) + 4|0);
     $585 = (+($583>>>0));
     $586 = $$4$i - $585;
     $587 = $586 * 1.0E+9;
     $588 = $587 != 0.0;
     if ($588) {
      $$4$i = $587;$z$0$i = $584;
     } else {
      break;
     }
    }
    $$pr$i = HEAP32[$e2$i>>2]|0;
    $589 = ($$pr$i|0)>(0);
    if ($589) {
     $590 = $$pr$i;$a$1263$i = $$31$i;$z$1262$i = $584;
     while(1) {
      $591 = ($590|0)>(29);
      $592 = $591 ? 29 : $590;
      $d$0254$i = (($z$1262$i) + -4|0);
      $593 = ($d$0254$i>>>0)<($a$1263$i>>>0);
      do {
       if ($593) {
        $a$2$ph$i = $a$1263$i;
       } else {
        $carry$0255$i = 0;$d$0256$i = $d$0254$i;
        while(1) {
         $594 = HEAP32[$d$0256$i>>2]|0;
         $595 = (_bitshift64Shl(($594|0),0,($592|0))|0);
         $596 = tempRet0;
         $597 = (_i64Add(($595|0),($596|0),($carry$0255$i|0),0)|0);
         $598 = tempRet0;
         $599 = (___uremdi3(($597|0),($598|0),1000000000,0)|0);
         $600 = tempRet0;
         HEAP32[$d$0256$i>>2] = $599;
         $601 = (___udivdi3(($597|0),($598|0),1000000000,0)|0);
         $602 = tempRet0;
         $d$0$i = (($d$0256$i) + -4|0);
         $603 = ($d$0$i>>>0)<($a$1263$i>>>0);
         if ($603) {
          break;
         } else {
          $carry$0255$i = $601;$d$0256$i = $d$0$i;
         }
        }
        $604 = ($601|0)==(0);
        if ($604) {
         $a$2$ph$i = $a$1263$i;
         break;
        }
        $605 = (($a$1263$i) + -4|0);
        HEAP32[$605>>2] = $601;
        $a$2$ph$i = $605;
       }
      } while(0);
      $z$2$i = $z$1262$i;
      while(1) {
       $606 = ($z$2$i>>>0)>($a$2$ph$i>>>0);
       if (!($606)) {
        break;
       }
       $607 = (($z$2$i) + -4|0);
       $608 = HEAP32[$607>>2]|0;
       $609 = ($608|0)==(0);
       if ($609) {
        $z$2$i = $607;
       } else {
        break;
       }
      }
      $610 = HEAP32[$e2$i>>2]|0;
      $611 = (($610) - ($592))|0;
      HEAP32[$e2$i>>2] = $611;
      $612 = ($611|0)>(0);
      if ($612) {
       $590 = $611;$a$1263$i = $a$2$ph$i;$z$1262$i = $z$2$i;
      } else {
       $$pr146$i = $611;$a$1$lcssa$i = $a$2$ph$i;$z$1$lcssa$i = $z$2$i;
       break;
      }
     }
    } else {
     $$pr146$i = $$pr$i;$a$1$lcssa$i = $$31$i;$z$1$lcssa$i = $584;
    }
    $613 = ($$pr146$i|0)<(0);
    L229: do {
     if ($613) {
      $614 = (($$p$i) + 25)|0;
      $615 = (($614|0) / 9)&-1;
      $616 = (($615) + 1)|0;
      $617 = ($412|0)==(102);
      if ($617) {
       $618 = $$31$i;
       $619 = (($$31$i) + ($616<<2)|0);
       $621 = $$pr146$i;$a$3249$us$i = $a$1$lcssa$i;$z$3248$us$i = $z$1$lcssa$i;
       while(1) {
        $620 = (0 - ($621))|0;
        $622 = ($620|0)>(9);
        $$20$us$i = $622 ? 9 : $620;
        $623 = ($a$3249$us$i>>>0)<($z$3248$us$i>>>0);
        do {
         if ($623) {
          $648 = 1 << $$20$us$i;
          $642 = (($648) + -1)|0;
          $645 = 1000000000 >>> $$20$us$i;
          $carry3$0243$us$i = 0;$d$1242$us$i = $a$3249$us$i;
          while(1) {
           $640 = HEAP32[$d$1242$us$i>>2]|0;
           $641 = $640 & $642;
           $643 = $640 >>> $$20$us$i;
           $644 = (($643) + ($carry3$0243$us$i))|0;
           HEAP32[$d$1242$us$i>>2] = $644;
           $630 = Math_imul($641, $645)|0;
           $646 = (($d$1242$us$i) + 4|0);
           $647 = ($646>>>0)<($z$3248$us$i>>>0);
           if ($647) {
            $carry3$0243$us$i = $630;$d$1242$us$i = $646;
           } else {
            break;
           }
          }
          $627 = HEAP32[$a$3249$us$i>>2]|0;
          $628 = ($627|0)==(0);
          $629 = (($a$3249$us$i) + 4|0);
          $$a$3$us$i = $628 ? $629 : $a$3249$us$i;
          $631 = ($630|0)==(0);
          if ($631) {
           $$a$3$us323$i = $$a$3$us$i;$z$4$us$i = $z$3248$us$i;
           break;
          }
          $632 = (($z$3248$us$i) + 4|0);
          HEAP32[$z$3248$us$i>>2] = $630;
          $$a$3$us323$i = $$a$3$us$i;$z$4$us$i = $632;
         } else {
          $624 = HEAP32[$a$3249$us$i>>2]|0;
          $625 = ($624|0)==(0);
          $626 = (($a$3249$us$i) + 4|0);
          $$a$3$us322$i = $625 ? $626 : $a$3249$us$i;
          $$a$3$us323$i = $$a$3$us322$i;$z$4$us$i = $z$3248$us$i;
         }
        } while(0);
        $633 = $z$4$us$i;
        $634 = (($633) - ($618))|0;
        $635 = $634 >> 2;
        $636 = ($635|0)>($616|0);
        $$z$4$us$i = $636 ? $619 : $z$4$us$i;
        $637 = HEAP32[$e2$i>>2]|0;
        $638 = (($637) + ($$20$us$i))|0;
        HEAP32[$e2$i>>2] = $638;
        $639 = ($638|0)<(0);
        if ($639) {
         $621 = $638;$a$3249$us$i = $$a$3$us323$i;$z$3248$us$i = $$z$4$us$i;
        } else {
         $a$3$lcssa$i = $$a$3$us323$i;$z$3$lcssa$i = $$z$4$us$i;
         break L229;
        }
       }
      } else {
       $650 = $$pr146$i;$a$3249$i = $a$1$lcssa$i;$z$3248$i = $z$1$lcssa$i;
      }
      while(1) {
       $649 = (0 - ($650))|0;
       $651 = ($649|0)>(9);
       $$20$i = $651 ? 9 : $649;
       $652 = ($a$3249$i>>>0)<($z$3248$i>>>0);
       do {
        if ($652) {
         $656 = 1 << $$20$i;
         $657 = (($656) + -1)|0;
         $658 = 1000000000 >>> $$20$i;
         $carry3$0243$i = 0;$d$1242$i = $a$3249$i;
         while(1) {
          $659 = HEAP32[$d$1242$i>>2]|0;
          $660 = $659 & $657;
          $661 = $659 >>> $$20$i;
          $662 = (($661) + ($carry3$0243$i))|0;
          HEAP32[$d$1242$i>>2] = $662;
          $663 = Math_imul($660, $658)|0;
          $664 = (($d$1242$i) + 4|0);
          $665 = ($664>>>0)<($z$3248$i>>>0);
          if ($665) {
           $carry3$0243$i = $663;$d$1242$i = $664;
          } else {
           break;
          }
         }
         $666 = HEAP32[$a$3249$i>>2]|0;
         $667 = ($666|0)==(0);
         $668 = (($a$3249$i) + 4|0);
         $$a$3$i = $667 ? $668 : $a$3249$i;
         $669 = ($663|0)==(0);
         if ($669) {
          $$a$3325$i = $$a$3$i;$z$4$i = $z$3248$i;
          break;
         }
         $670 = (($z$3248$i) + 4|0);
         HEAP32[$z$3248$i>>2] = $663;
         $$a$3325$i = $$a$3$i;$z$4$i = $670;
        } else {
         $653 = HEAP32[$a$3249$i>>2]|0;
         $654 = ($653|0)==(0);
         $655 = (($a$3249$i) + 4|0);
         $$a$3324$i = $654 ? $655 : $a$3249$i;
         $$a$3325$i = $$a$3324$i;$z$4$i = $z$3248$i;
        }
       } while(0);
       $671 = $z$4$i;
       $672 = $$a$3325$i;
       $673 = (($671) - ($672))|0;
       $674 = $673 >> 2;
       $675 = ($674|0)>($616|0);
       if ($675) {
        $676 = (($$a$3325$i) + ($616<<2)|0);
        $z$5$i = $676;
       } else {
        $z$5$i = $z$4$i;
       }
       $677 = HEAP32[$e2$i>>2]|0;
       $678 = (($677) + ($$20$i))|0;
       HEAP32[$e2$i>>2] = $678;
       $679 = ($678|0)<(0);
       if ($679) {
        $650 = $678;$a$3249$i = $$a$3325$i;$z$3248$i = $z$5$i;
       } else {
        $a$3$lcssa$i = $$a$3325$i;$z$3$lcssa$i = $z$5$i;
        break;
       }
      }
     } else {
      $a$3$lcssa$i = $a$1$lcssa$i;$z$3$lcssa$i = $z$1$lcssa$i;
     }
    } while(0);
    $680 = ($a$3$lcssa$i>>>0)<($z$3$lcssa$i>>>0);
    $681 = $$31$i;
    do {
     if ($680) {
      $682 = $a$3$lcssa$i;
      $683 = (($681) - ($682))|0;
      $684 = $683 >> 2;
      $685 = ($684*9)|0;
      $686 = HEAP32[$a$3$lcssa$i>>2]|0;
      $687 = ($686>>>0)<(10);
      if ($687) {
       $e$1$i = $685;
       break;
      } else {
       $e$0238$i = $685;$i$0237$i = 10;
      }
      while(1) {
       $688 = ($i$0237$i*10)|0;
       $689 = (($e$0238$i) + 1)|0;
       $690 = ($686>>>0)<($688>>>0);
       if ($690) {
        $e$1$i = $689;
        break;
       } else {
        $e$0238$i = $689;$i$0237$i = $688;
       }
      }
     } else {
      $e$1$i = 0;
     }
    } while(0);
    $691 = ($412|0)!=(102);
    $692 = $691 ? $e$1$i : 0;
    $693 = (($$p$i) - ($692))|0;
    $694 = ($412|0)==(103);
    $695 = ($$p$i|0)!=(0);
    $$21$i = $694 & $695;
    $$neg151$i = $$21$i << 31 >> 31;
    $696 = (($693) + ($$neg151$i))|0;
    $697 = $z$3$lcssa$i;
    $698 = (($697) - ($681))|0;
    $699 = $698 >> 2;
    $700 = ($699*9)|0;
    $701 = (($700) + -9)|0;
    $702 = ($696|0)<($701|0);
    if ($702) {
     $703 = (($696) + 9216)|0;
     $704 = (($703|0) / 9)&-1;
     $$sum$i = (($704) + -1023)|0;
     $705 = (($$31$i) + ($$sum$i<<2)|0);
     $706 = (($703|0) % 9)&-1;
     $j$0229$i = (($706) + 1)|0;
     $707 = ($j$0229$i|0)<(9);
     if ($707) {
      $i$1230$i = 10;$j$0231$i = $j$0229$i;
      while(1) {
       $708 = ($i$1230$i*10)|0;
       $j$0$i = (($j$0231$i) + 1)|0;
       $exitcond$i = ($j$0$i|0)==(9);
       if ($exitcond$i) {
        $i$1$lcssa$i = $708;
        break;
       } else {
        $i$1230$i = $708;$j$0231$i = $j$0$i;
       }
      }
     } else {
      $i$1$lcssa$i = 10;
     }
     $709 = HEAP32[$705>>2]|0;
     $710 = (($709>>>0) % ($i$1$lcssa$i>>>0))&-1;
     $711 = ($710|0)==(0);
     if ($711) {
      $$sum15$i = (($704) + -1022)|0;
      $712 = (($$31$i) + ($$sum15$i<<2)|0);
      $713 = ($712|0)==($z$3$lcssa$i|0);
      if ($713) {
       $a$7$i = $a$3$lcssa$i;$d$3$i = $705;$e$3$i = $e$1$i;
      } else {
       label = 233;
      }
     } else {
      label = 233;
     }
     do {
      if ((label|0) == 233) {
       label = 0;
       $714 = (($709>>>0) / ($i$1$lcssa$i>>>0))&-1;
       $715 = $714 & 1;
       $716 = ($715|0)==(0);
       $$22$i = $716 ? 9007199254740992.0 : 9007199254740994.0;
       $717 = (($i$1$lcssa$i|0) / 2)&-1;
       $718 = ($710>>>0)<($717>>>0);
       do {
        if ($718) {
         $small$0$i = 0.5;
        } else {
         $719 = ($710|0)==($717|0);
         if ($719) {
          $$sum16$i = (($704) + -1022)|0;
          $720 = (($$31$i) + ($$sum16$i<<2)|0);
          $721 = ($720|0)==($z$3$lcssa$i|0);
          if ($721) {
           $small$0$i = 1.0;
           break;
          }
         }
         $small$0$i = 1.5;
        }
       } while(0);
       $722 = ($pl$0$i|0)==(0);
       do {
        if ($722) {
         $round6$1$i = $$22$i;$small$1$i = $small$0$i;
        } else {
         $723 = HEAP8[$prefix$0$i>>0]|0;
         $724 = ($723<<24>>24)==(45);
         if (!($724)) {
          $round6$1$i = $$22$i;$small$1$i = $small$0$i;
          break;
         }
         $725 = $$22$i * -1.0;
         $726 = $small$0$i * -1.0;
         $round6$1$i = $725;$small$1$i = $726;
        }
       } while(0);
       $727 = (($709) - ($710))|0;
       HEAP32[$705>>2] = $727;
       $728 = $round6$1$i + $small$1$i;
       $729 = $728 != $round6$1$i;
       if (!($729)) {
        $a$7$i = $a$3$lcssa$i;$d$3$i = $705;$e$3$i = $e$1$i;
        break;
       }
       $730 = (($727) + ($i$1$lcssa$i))|0;
       HEAP32[$705>>2] = $730;
       $731 = ($730>>>0)>(999999999);
       if ($731) {
        $a$5223$i = $a$3$lcssa$i;$d$2222$i = $705;
        while(1) {
         $732 = (($d$2222$i) + -4|0);
         HEAP32[$d$2222$i>>2] = 0;
         $733 = ($732>>>0)<($a$5223$i>>>0);
         if ($733) {
          $734 = (($a$5223$i) + -4|0);
          HEAP32[$734>>2] = 0;
          $a$6$i = $734;
         } else {
          $a$6$i = $a$5223$i;
         }
         $735 = HEAP32[$732>>2]|0;
         $736 = (($735) + 1)|0;
         HEAP32[$732>>2] = $736;
         $737 = ($736>>>0)>(999999999);
         if ($737) {
          $a$5223$i = $a$6$i;$d$2222$i = $732;
         } else {
          $a$5$lcssa$i = $a$6$i;$d$2$lcssa$i = $732;
          break;
         }
        }
       } else {
        $a$5$lcssa$i = $a$3$lcssa$i;$d$2$lcssa$i = $705;
       }
       $738 = $a$5$lcssa$i;
       $739 = (($681) - ($738))|0;
       $740 = $739 >> 2;
       $741 = ($740*9)|0;
       $742 = HEAP32[$a$5$lcssa$i>>2]|0;
       $743 = ($742>>>0)<(10);
       if ($743) {
        $a$7$i = $a$5$lcssa$i;$d$3$i = $d$2$lcssa$i;$e$3$i = $741;
        break;
       } else {
        $e$2218$i = $741;$i$2217$i = 10;
       }
       while(1) {
        $744 = ($i$2217$i*10)|0;
        $745 = (($e$2218$i) + 1)|0;
        $746 = ($742>>>0)<($744>>>0);
        if ($746) {
         $a$7$i = $a$5$lcssa$i;$d$3$i = $d$2$lcssa$i;$e$3$i = $745;
         break;
        } else {
         $e$2218$i = $745;$i$2217$i = $744;
        }
       }
      }
     } while(0);
     $747 = (($d$3$i) + 4|0);
     $748 = ($z$3$lcssa$i>>>0)>($747>>>0);
     $$z$3$i = $748 ? $747 : $z$3$lcssa$i;
     $a$8$ph$i = $a$7$i;$e$4$ph$i = $e$3$i;$z$6$ph$i = $$z$3$i;
    } else {
     $a$8$ph$i = $a$3$lcssa$i;$e$4$ph$i = $e$1$i;$z$6$ph$i = $z$3$lcssa$i;
    }
    $749 = (0 - ($e$4$ph$i))|0;
    $z$6$i = $z$6$ph$i;
    while(1) {
     $750 = ($z$6$i>>>0)>($a$8$ph$i>>>0);
     if (!($750)) {
      $$lcssa300$i = 0;
      break;
     }
     $751 = (($z$6$i) + -4|0);
     $752 = HEAP32[$751>>2]|0;
     $753 = ($752|0)==(0);
     if ($753) {
      $z$6$i = $751;
     } else {
      $$lcssa300$i = 1;
      break;
     }
    }
    do {
     if ($694) {
      $754 = ($$p$i|0)==(0);
      $755 = $754&1;
      $$$p$i = (($755) + ($$p$i))|0;
      $756 = ($$$p$i|0)>($e$4$ph$i|0);
      $757 = ($e$4$ph$i|0)>(-5);
      $or$cond4$i = $756 & $757;
      if ($or$cond4$i) {
       $758 = (($t$0) + -1)|0;
       $$neg152$i = (($$$p$i) + -1)|0;
       $759 = (($$neg152$i) - ($e$4$ph$i))|0;
       $$013$i = $758;$$210$i = $759;
      } else {
       $760 = (($t$0) + -2)|0;
       $761 = (($$$p$i) + -1)|0;
       $$013$i = $760;$$210$i = $761;
      }
      $762 = $fl$1$ & 8;
      $763 = ($762|0)==(0);
      if (!($763)) {
       $$114$i = $$013$i;$$311$i = $$210$i;
       break;
      }
      do {
       if ($$lcssa300$i) {
        $764 = (($z$6$i) + -4|0);
        $765 = HEAP32[$764>>2]|0;
        $766 = ($765|0)==(0);
        if ($766) {
         $j$2$i = 9;
         break;
        }
        $767 = (($765>>>0) % 10)&-1;
        $768 = ($767|0)==(0);
        if ($768) {
         $i$3209$i = 10;$j$1210$i = 0;
        } else {
         $j$2$i = 0;
         break;
        }
        while(1) {
         $769 = ($i$3209$i*10)|0;
         $770 = (($j$1210$i) + 1)|0;
         $771 = (($765>>>0) % ($769>>>0))&-1;
         $772 = ($771|0)==(0);
         if ($772) {
          $i$3209$i = $769;$j$1210$i = $770;
         } else {
          $j$2$i = $770;
          break;
         }
        }
       } else {
        $j$2$i = 9;
       }
      } while(0);
      $773 = $$013$i | 32;
      $774 = ($773|0)==(102);
      $775 = $z$6$i;
      $776 = (($775) - ($681))|0;
      $777 = $776 >> 2;
      $778 = ($777*9)|0;
      $779 = (($778) + -9)|0;
      if ($774) {
       $780 = (($779) - ($j$2$i))|0;
       $781 = ($780|0)<(0);
       $$23$i = $781 ? 0 : $780;
       $782 = ($$210$i|0)<($$23$i|0);
       $$210$$23$i = $782 ? $$210$i : $$23$i;
       $$114$i = $$013$i;$$311$i = $$210$$23$i;
       break;
      } else {
       $783 = (($779) + ($e$4$ph$i))|0;
       $784 = (($783) - ($j$2$i))|0;
       $785 = ($784|0)<(0);
       $$25$i = $785 ? 0 : $784;
       $786 = ($$210$i|0)<($$25$i|0);
       $$210$$25$i = $786 ? $$210$i : $$25$i;
       $$114$i = $$013$i;$$311$i = $$210$$25$i;
       break;
      }
     } else {
      $$114$i = $t$0;$$311$i = $$p$i;
     }
    } while(0);
    $787 = ($$311$i|0)!=(0);
    if ($787) {
     $791 = 1;
    } else {
     $788 = $fl$1$ & 8;
     $789 = ($788|0)!=(0);
     $791 = $789;
    }
    $790 = $791&1;
    $792 = $$114$i | 32;
    $793 = ($792|0)==(102);
    if ($793) {
     $794 = ($e$4$ph$i|0)>(0);
     $795 = $794 ? $e$4$ph$i : 0;
     $$pn$i = $795;$estr$2$i = 0;
    } else {
     $796 = ($e$4$ph$i|0)<(0);
     $797 = $796 ? $749 : $e$4$ph$i;
     $798 = ($797|0)<(0);
     if ($798) {
      $799 = ($797|0)<(0);
      $800 = $799 << 31 >> 31;
      $$05$i79$i = $6;$801 = $797;$802 = $800;
      while(1) {
       $803 = (___uremdi3(($801|0),($802|0),10,0)|0);
       $804 = tempRet0;
       $805 = $803 | 48;
       $806 = $805&255;
       $807 = (($$05$i79$i) + -1|0);
       HEAP8[$807>>0] = $806;
       $808 = (___udivdi3(($801|0),($802|0),10,0)|0);
       $809 = tempRet0;
       $810 = ($802>>>0)>(9);
       $811 = ($802|0)==(9);
       $812 = ($801>>>0)>(4294967295);
       $813 = $811 & $812;
       $814 = $810 | $813;
       if ($814) {
        $$05$i79$i = $807;$801 = $808;$802 = $809;
       } else {
        break;
       }
      }
      $$0$lcssa$i84$i = $807;$$01$lcssa$off0$i85$i = $808;
     } else {
      $$0$lcssa$i84$i = $6;$$01$lcssa$off0$i85$i = $797;
     }
     $815 = ($$01$lcssa$off0$i85$i|0)==(0);
     if ($815) {
      $estr$1$ph$i = $$0$lcssa$i84$i;
     } else {
      $$12$i87$i = $$0$lcssa$i84$i;$y$03$i86$i = $$01$lcssa$off0$i85$i;
      while(1) {
       $816 = (($y$03$i86$i>>>0) % 10)&-1;
       $817 = $816 | 48;
       $818 = $817&255;
       $819 = (($$12$i87$i) + -1|0);
       HEAP8[$819>>0] = $818;
       $820 = (($y$03$i86$i>>>0) / 10)&-1;
       $821 = ($y$03$i86$i>>>0)<(10);
       if ($821) {
        $estr$1$ph$i = $819;
        break;
       } else {
        $$12$i87$i = $819;$y$03$i86$i = $820;
       }
      }
     }
     $822 = $estr$1$ph$i;
     $823 = (($8) - ($822))|0;
     $824 = ($823|0)<(2);
     if ($824) {
      $estr$1200$i = $estr$1$ph$i;
      while(1) {
       $825 = (($estr$1200$i) + -1|0);
       HEAP8[$825>>0] = 48;
       $826 = $825;
       $827 = (($8) - ($826))|0;
       $828 = ($827|0)<(2);
       if ($828) {
        $estr$1200$i = $825;
       } else {
        $estr$1$lcssa$i = $825;
        break;
       }
      }
     } else {
      $estr$1$lcssa$i = $estr$1$ph$i;
     }
     $829 = $e$4$ph$i >> 31;
     $830 = $829 & 2;
     $831 = (($830) + 43)|0;
     $832 = $831&255;
     $833 = (($estr$1$lcssa$i) + -1|0);
     HEAP8[$833>>0] = $832;
     $834 = $$114$i&255;
     $835 = (($estr$1$lcssa$i) + -2|0);
     HEAP8[$835>>0] = $834;
     $836 = $835;
     $837 = (($8) - ($836))|0;
     $$pn$i = $837;$estr$2$i = $835;
    }
    $838 = (($pl$0$i) + 1)|0;
    $839 = (($838) + ($$311$i))|0;
    $l$1$i = (($839) + ($790))|0;
    $840 = (($l$1$i) + ($$pn$i))|0;
    $841 = $fl$1$ & 73728;
    $842 = ($841|0)==(0);
    $843 = ($840|0)<($w$1|0);
    $or$cond$i93$i = $842 & $843;
    if ($or$cond$i93$i) {
     $844 = (($w$1) - ($840))|0;
     $845 = ($844>>>0)>(256);
     $846 = $845 ? 256 : $844;
     _memset(($pad$i|0),32,($846|0))|0;
     $847 = ($844>>>0)>(255);
     if ($847) {
      $$01$i94$i = $844;
      while(1) {
       (___fwritex($pad$i,256,$f)|0);
       $848 = (($$01$i94$i) + -256)|0;
       $849 = ($848>>>0)>(255);
       if ($849) {
        $$01$i94$i = $848;
       } else {
        $$0$lcssa$i96$i = $848;
        break;
       }
      }
     } else {
      $$0$lcssa$i96$i = $844;
     }
     (___fwritex($pad$i,$$0$lcssa$i96$i,$f)|0);
    }
    (___fwritex($prefix$0$i,$pl$0$i,$f)|0);
    $850 = ($841|0)==(65536);
    $or$cond$i100$i = $850 & $843;
    if ($or$cond$i100$i) {
     $851 = (($w$1) - ($840))|0;
     $852 = ($851>>>0)>(256);
     $853 = $852 ? 256 : $851;
     _memset(($pad$i|0),48,($853|0))|0;
     $854 = ($851>>>0)>(255);
     if ($854) {
      $$01$i101$i = $851;
      while(1) {
       (___fwritex($pad$i,256,$f)|0);
       $855 = (($$01$i101$i) + -256)|0;
       $856 = ($855>>>0)>(255);
       if ($856) {
        $$01$i101$i = $855;
       } else {
        $$0$lcssa$i103$i = $855;
        break;
       }
      }
     } else {
      $$0$lcssa$i103$i = $851;
     }
     (___fwritex($pad$i,$$0$lcssa$i103$i,$f)|0);
    }
    do {
     if ($793) {
      $857 = ($a$8$ph$i>>>0)>($$31$i>>>0);
      $r$0$a$8$i = $857 ? $$31$i : $a$8$ph$i;
      $d$4183$i = $r$0$a$8$i;
      while(1) {
       $858 = HEAP32[$d$4183$i>>2]|0;
       $859 = ($858|0)==(0);
       if ($859) {
        $$1$lcssa$i112$i = $13;
       } else {
        $$12$i110$i = $13;$y$03$i109$i = $858;
        while(1) {
         $860 = (($y$03$i109$i>>>0) % 10)&-1;
         $861 = $860 | 48;
         $862 = $861&255;
         $863 = (($$12$i110$i) + -1|0);
         HEAP8[$863>>0] = $862;
         $864 = (($y$03$i109$i>>>0) / 10)&-1;
         $865 = ($y$03$i109$i>>>0)<(10);
         if ($865) {
          $$1$lcssa$i112$i = $863;
          break;
         } else {
          $$12$i110$i = $863;$y$03$i109$i = $864;
         }
        }
       }
       $866 = ($d$4183$i|0)==($r$0$a$8$i|0);
       do {
        if ($866) {
         $870 = ($$1$lcssa$i112$i|0)==($13|0);
         if (!($870)) {
          $s7$1$i = $$1$lcssa$i112$i;
          break;
         }
         HEAP8[$15>>0] = 48;
         $s7$1$i = $15;
        } else {
         $867 = ($$1$lcssa$i112$i>>>0)>($buf$i>>>0);
         if ($867) {
          $s7$0180$i = $$1$lcssa$i112$i;
         } else {
          $s7$1$i = $$1$lcssa$i112$i;
          break;
         }
         while(1) {
          $868 = (($s7$0180$i) + -1|0);
          HEAP8[$868>>0] = 48;
          $869 = ($868>>>0)>($buf$i>>>0);
          if ($869) {
           $s7$0180$i = $868;
          } else {
           $s7$1$i = $868;
           break;
          }
         }
        }
       } while(0);
       $871 = $s7$1$i;
       $872 = (($14) - ($871))|0;
       (___fwritex($s7$1$i,$872,$f)|0);
       $873 = (($d$4183$i) + 4|0);
       $874 = ($873>>>0)>($$31$i>>>0);
       if ($874) {
        break;
       } else {
        $d$4183$i = $873;
       }
      }
      if (!($787)) {
       $875 = $fl$1$ & 8;
       $876 = ($875|0)==(0);
       if ($876) {
        break;
       }
      }
      (___fwritex(145312,1,$f)|0);
      $877 = ($873>>>0)<($z$6$i>>>0);
      $878 = ($$311$i|0)>(0);
      $or$cond28173$i = $877 & $878;
      if ($or$cond28173$i) {
       $$412175$i = $$311$i;$d$5174$i = $873;
       while(1) {
        $879 = HEAP32[$d$5174$i>>2]|0;
        $880 = ($879|0)==(0);
        if ($880) {
         $s8$0169$i = $13;
         label = 300;
        } else {
         $$12$i119$i = $13;$y$03$i118$i = $879;
         while(1) {
          $881 = (($y$03$i118$i>>>0) % 10)&-1;
          $882 = $881 | 48;
          $883 = $882&255;
          $884 = (($$12$i119$i) + -1|0);
          HEAP8[$884>>0] = $883;
          $885 = (($y$03$i118$i>>>0) / 10)&-1;
          $886 = ($y$03$i118$i>>>0)<(10);
          if ($886) {
           break;
          } else {
           $$12$i119$i = $884;$y$03$i118$i = $885;
          }
         }
         $887 = ($884>>>0)>($buf$i>>>0);
         if ($887) {
          $s8$0169$i = $884;
          label = 300;
         } else {
          $s8$0$lcssa$i = $884;
         }
        }
        if ((label|0) == 300) {
         while(1) {
          label = 0;
          $888 = (($s8$0169$i) + -1|0);
          HEAP8[$888>>0] = 48;
          $889 = ($888>>>0)>($buf$i>>>0);
          if ($889) {
           $s8$0169$i = $888;
           label = 300;
          } else {
           $s8$0$lcssa$i = $888;
           break;
          }
         }
        }
        $890 = ($$412175$i|0)>(9);
        $891 = $890 ? 9 : $$412175$i;
        (___fwritex($s8$0$lcssa$i,$891,$f)|0);
        $892 = (($d$5174$i) + 4|0);
        $893 = (($$412175$i) + -9)|0;
        $894 = ($892>>>0)<($z$6$i>>>0);
        $895 = ($893|0)>(0);
        $or$cond28$i = $894 & $895;
        if ($or$cond28$i) {
         $$412175$i = $893;$d$5174$i = $892;
        } else {
         $$412$lcssa$i = $893;
         break;
        }
       }
      } else {
       $$412$lcssa$i = $$311$i;
      }
      $896 = ($$412$lcssa$i|0)>(0);
      if (!($896)) {
       break;
      }
      $897 = ($$412$lcssa$i>>>0)>(256);
      $898 = $897 ? 256 : $$412$lcssa$i;
      _memset(($pad$i|0),48,($898|0))|0;
      $899 = ($$412$lcssa$i>>>0)>(255);
      if ($899) {
       $$01$i125$i = $$412$lcssa$i;
       while(1) {
        (___fwritex($pad$i,256,$f)|0);
        $900 = (($$01$i125$i) + -256)|0;
        $901 = ($900>>>0)>(255);
        if ($901) {
         $$01$i125$i = $900;
        } else {
         $$0$lcssa$i127$i = $900;
         break;
        }
       }
      } else {
       $$0$lcssa$i127$i = $$412$lcssa$i;
      }
      (___fwritex($pad$i,$$0$lcssa$i127$i,$f)|0);
     } else {
      $902 = (($a$8$ph$i) + 4|0);
      $z$6$$i = $$lcssa300$i ? $z$6$i : $902;
      $903 = ($$311$i|0)>(-1);
      do {
       if ($903) {
        $904 = $fl$1$ & 8;
        $$not$i = ($904|0)!=(0);
        $$5193$i = $$311$i;$d$6192$i = $a$8$ph$i;
        while(1) {
         $905 = HEAP32[$d$6192$i>>2]|0;
         $906 = ($905|0)==(0);
         if ($906) {
          label = 311;
         } else {
          $$12$i134$i = $13;$y$03$i133$i = $905;
          while(1) {
           $907 = (($y$03$i133$i>>>0) % 10)&-1;
           $908 = $907 | 48;
           $909 = $908&255;
           $910 = (($$12$i134$i) + -1|0);
           HEAP8[$910>>0] = $909;
           $911 = (($y$03$i133$i>>>0) / 10)&-1;
           $912 = ($y$03$i133$i>>>0)<(10);
           if ($912) {
            break;
           } else {
            $$12$i134$i = $910;$y$03$i133$i = $911;
           }
          }
          $913 = ($910|0)==($13|0);
          if ($913) {
           label = 311;
          } else {
           $s9$0$i = $910;
          }
         }
         if ((label|0) == 311) {
          label = 0;
          HEAP8[$15>>0] = 48;
          $s9$0$i = $15;
         }
         $914 = ($d$6192$i|0)==($a$8$ph$i|0);
         do {
          if ($914) {
           $918 = (($s9$0$i) + 1|0);
           (___fwritex($s9$0$i,1,$f)|0);
           $919 = ($$5193$i|0)>(0);
           $brmerge$i = $919 | $$not$i;
           if (!($brmerge$i)) {
            $s9$2$i = $918;
            break;
           }
           (___fwritex(145312,1,$f)|0);
           $s9$2$i = $918;
          } else {
           $915 = ($s9$0$i>>>0)>($buf$i>>>0);
           if ($915) {
            $s9$1188$i = $s9$0$i;
           } else {
            $s9$2$i = $s9$0$i;
            break;
           }
           while(1) {
            $916 = (($s9$1188$i) + -1|0);
            HEAP8[$916>>0] = 48;
            $917 = ($916>>>0)>($buf$i>>>0);
            if ($917) {
             $s9$1188$i = $916;
            } else {
             $s9$2$i = $916;
             break;
            }
           }
          }
         } while(0);
         $920 = $s9$2$i;
         $921 = (($14) - ($920))|0;
         $922 = ($921|0)<($$5193$i|0);
         $$$5$i = $922 ? $921 : $$5193$i;
         (___fwritex($s9$2$i,$$$5$i,$f)|0);
         $923 = (($$5193$i) - ($921))|0;
         $924 = (($d$6192$i) + 4|0);
         $925 = ($924>>>0)<($z$6$$i>>>0);
         $926 = ($923|0)>(-1);
         $or$cond29$i = $925 & $926;
         if ($or$cond29$i) {
          $$5193$i = $923;$d$6192$i = $924;
         } else {
          break;
         }
        }
        $927 = ($923|0)>(0);
        if (!($927)) {
         break;
        }
        $928 = ($923>>>0)>(256);
        $929 = $928 ? 256 : $923;
        _memset(($pad$i|0),48,($929|0))|0;
        $930 = ($923>>>0)>(255);
        if ($930) {
         $$01$i140$i = $923;
         while(1) {
          (___fwritex($pad$i,256,$f)|0);
          $931 = (($$01$i140$i) + -256)|0;
          $932 = ($931>>>0)>(255);
          if ($932) {
           $$01$i140$i = $931;
          } else {
           $$0$lcssa$i142$i = $931;
           break;
          }
         }
        } else {
         $$0$lcssa$i142$i = $923;
        }
        (___fwritex($pad$i,$$0$lcssa$i142$i,$f)|0);
       }
      } while(0);
      $933 = $estr$2$i;
      $934 = (($8) - ($933))|0;
      (___fwritex($estr$2$i,$934,$f)|0);
     }
    } while(0);
    $935 = ($841|0)==(8192);
    $or$cond$i$i = $935 & $843;
    if ($or$cond$i$i) {
     $936 = (($w$1) - ($840))|0;
     $937 = ($936>>>0)>(256);
     $938 = $937 ? 256 : $936;
     _memset(($pad$i|0),32,($938|0))|0;
     $939 = ($936>>>0)>(255);
     if ($939) {
      $$01$i$i = $936;
      while(1) {
       (___fwritex($pad$i,256,$f)|0);
       $940 = (($$01$i$i) + -256)|0;
       $941 = ($940>>>0)>(255);
       if ($941) {
        $$01$i$i = $940;
       } else {
        $$0$lcssa$i$i = $940;
        break;
       }
      }
     } else {
      $$0$lcssa$i$i = $936;
     }
     (___fwritex($pad$i,$$0$lcssa$i$i,$f)|0);
    }
    $w$30$i = $843 ? $w$1 : $840;
    $1045 = $228;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $w$30$i;$l10n$0 = $l10n$3;
    continue L1;
    break;
   }
   case 112:  {
    $222 = ($p$0>>>0)>(8);
    $223 = $222 ? $p$0 : 8;
    $224 = $fl$1$ | 8;
    $fl$3 = $224;$p$1 = $223;$t$1 = 120;
    label = 77;
    break;
   }
   case 110:  {
    switch ($st$0|0) {
    case 6:  {
     HEAP32[$207>>2] = $cnt$1;
     $1045 = $228;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 3:  {
     $214 = $cnt$1&65535;
     HEAP16[$207>>1] = $214;
     $1045 = $228;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 4:  {
     $215 = $cnt$1&255;
     HEAP8[$207>>0] = $215;
     $1045 = $228;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 2:  {
     $208 = ($cnt$1|0)<(0);
     $209 = $208 << 31 >> 31;
     $210 = $207;
     $211 = $210;
     HEAP32[$211>>2] = $cnt$1;
     $212 = (($210) + 4)|0;
     $213 = $212;
     HEAP32[$213>>2] = $209;
     $1045 = $228;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 0:  {
     HEAP32[$207>>2] = $cnt$1;
     $1045 = $228;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 1:  {
     HEAP32[$207>>2] = $cnt$1;
     $1045 = $228;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 7:  {
     $216 = ($cnt$1|0)<(0);
     $217 = $216 << 31 >> 31;
     $218 = $207;
     $219 = $218;
     HEAP32[$219>>2] = $cnt$1;
     $220 = (($218) + 4)|0;
     $221 = $220;
     HEAP32[$221>>2] = $217;
     $1045 = $228;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    default: {
     $1045 = $228;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$3;
     continue L1;
    }
    }
    break;
   }
   case 88: case 120:  {
    $fl$3 = $fl$1$;$p$1 = $p$0;$t$1 = $t$0;
    label = 77;
    break;
   }
   case 67:  {
    $331 = $207;
    HEAP32[$wc>>2] = $331;
    HEAP32[$5>>2] = 0;
    $1055 = $wc;$1056 = $wc;$p$4296 = -1;
    label = 104;
    break;
   }
   case 83:  {
    $332 = ($p$0|0)==(0);
    if ($332) {
     $1057 = $207;$1058 = $207;$i$0166 = 0;
     label = 110;
    } else {
     $1055 = $207;$1056 = $207;$p$4296 = $p$0;
     label = 104;
    }
    break;
   }
   case 105: case 100:  {
    $267 = $207;
    $268 = ($228|0)<(0);
    if ($268) {
     $269 = (_i64Subtract(0,0,($267|0),($228|0))|0);
     $270 = tempRet0;
     $271 = $269;
     $276 = $271;$278 = $270;$pl$0 = 1;$prefix$0 = 145216;
     label = 89;
     break L92;
    }
    $272 = $fl$1$ & 2048;
    $273 = ($272|0)==(0);
    if ($273) {
     $274 = $fl$1$ & 1;
     $275 = ($274|0)==(0);
     $$15 = $275 ? 145216 : ((145216 + 2|0));
     $276 = $207;$278 = $228;$pl$0 = $274;$prefix$0 = $$15;
     label = 89;
    } else {
     $276 = $207;$278 = $228;$pl$0 = 1;$prefix$0 = ((145216 + 1|0));
     label = 89;
    }
    break;
   }
   case 109:  {
    $321 = (___errno_location()|0);
    $322 = HEAP32[$321>>2]|0;
    $323 = (_strerror(($322|0))|0);
    $a$1 = $323;
    label = 99;
    break;
   }
   case 115:  {
    $324 = ($207|0)==(0|0);
    $$17 = $324 ? 145232 : $207;
    $a$1 = $$17;
    label = 99;
    break;
   }
   case 111:  {
    $249 = $207;
    $250 = ($249|0)==(0);
    $251 = ($228|0)==(0);
    $252 = $250 & $251;
    if ($252) {
     $$0$lcssa$i43 = $2;
    } else {
     $$03$i40 = $2;$254 = $249;$258 = $228;
     while(1) {
      $253 = $254 & 7;
      $255 = $253 | 48;
      $256 = $255&255;
      $257 = (($$03$i40) + -1|0);
      HEAP8[$257>>0] = $256;
      $259 = (_bitshift64Lshr(($254|0),($258|0),3)|0);
      $260 = tempRet0;
      $261 = ($259|0)==(0);
      $262 = ($260|0)==(0);
      $263 = $261 & $262;
      if ($263) {
       $$0$lcssa$i43 = $257;
       break;
      } else {
       $$03$i40 = $257;$254 = $259;$258 = $260;
      }
     }
    }
    $264 = $fl$1$ & 8;
    $265 = ($264|0)==(0);
    if ($265) {
     $307 = $207;$310 = $228;$a$0 = $$0$lcssa$i43;$fl$4 = $fl$1$;$p$2 = $p$0;$pl$1 = 0;$prefix$1 = 145216;
     label = 94;
    } else {
     $$13 = $252 ? 145216 : ((145216 + 5|0));
     $266 = $252&1;
     $$14 = $266 ^ 1;
     $307 = $207;$310 = $228;$a$0 = $$0$lcssa$i43;$fl$4 = $fl$1$;$p$2 = $p$0;$pl$1 = $$14;$prefix$1 = $$13;
     label = 94;
    }
    break;
   }
   case 117:  {
    $276 = $207;$278 = $228;$pl$0 = 0;$prefix$0 = 145216;
    label = 89;
    break;
   }
   default: {
    $1053 = $228;$1054 = $207;$a$2 = $22;$fl$6 = $fl$1$;$p$5 = $p$0;$pl$2 = 0;$prefix$2 = 145216;$z$2 = $2;
   }
   }
  } while(0);
  L445: do {
   if ((label|0) == 77) {
    label = 0;
    $225 = $207;
    $226 = $t$1 & 32;
    $227 = ($225|0)==(0);
    $229 = ($228|0)==(0);
    $230 = $227 & $229;
    if ($230) {
     $307 = $207;$310 = $228;$a$0 = $2;$fl$4 = $fl$3;$p$2 = $p$1;$pl$1 = 0;$prefix$1 = 145216;
     label = 94;
    } else {
     $$012$i = $2;$232 = $225;$239 = $228;
     while(1) {
      $231 = $232 & 15;
      $233 = (145296 + ($231)|0);
      $234 = HEAP8[$233>>0]|0;
      $235 = $234&255;
      $236 = $235 | $226;
      $237 = $236&255;
      $238 = (($$012$i) + -1|0);
      HEAP8[$238>>0] = $237;
      $240 = (_bitshift64Lshr(($232|0),($239|0),4)|0);
      $241 = tempRet0;
      $242 = ($240|0)==(0);
      $243 = ($241|0)==(0);
      $244 = $242 & $243;
      if ($244) {
       break;
      } else {
       $$012$i = $238;$232 = $240;$239 = $241;
      }
     }
     $245 = $fl$3 & 8;
     $246 = ($245|0)==(0);
     if ($246) {
      $307 = $207;$310 = $228;$a$0 = $238;$fl$4 = $fl$3;$p$2 = $p$1;$pl$1 = 0;$prefix$1 = 145216;
      label = 94;
     } else {
      $247 = $t$1 >> 4;
      $248 = (145216 + ($247)|0);
      $307 = $207;$310 = $228;$a$0 = $238;$fl$4 = $fl$3;$p$2 = $p$1;$pl$1 = 2;$prefix$1 = $248;
      label = 94;
     }
    }
   }
   else if ((label|0) == 89) {
    label = 0;
    $277 = $276;
    $279 = ($278>>>0)>(0);
    $280 = ($278|0)==(0);
    $281 = ($277>>>0)>(4294967295);
    $282 = $280 & $281;
    $283 = $279 | $282;
    if ($283) {
     $$05$i = $2;$284 = $277;$285 = $278;
     while(1) {
      $286 = (___uremdi3(($284|0),($285|0),10,0)|0);
      $287 = tempRet0;
      $288 = $286 | 48;
      $289 = $288&255;
      $290 = (($$05$i) + -1|0);
      HEAP8[$290>>0] = $289;
      $291 = (___udivdi3(($284|0),($285|0),10,0)|0);
      $292 = tempRet0;
      $293 = ($285>>>0)>(9);
      $294 = ($285|0)==(9);
      $295 = ($284>>>0)>(4294967295);
      $296 = $294 & $295;
      $297 = $293 | $296;
      if ($297) {
       $$05$i = $290;$284 = $291;$285 = $292;
      } else {
       break;
      }
     }
     $$0$lcssa$i45 = $290;$$01$lcssa$off0$i = $291;
    } else {
     $$0$lcssa$i45 = $2;$$01$lcssa$off0$i = $277;
    }
    $298 = ($$01$lcssa$off0$i|0)==(0);
    if ($298) {
     $307 = $276;$310 = $278;$a$0 = $$0$lcssa$i45;$fl$4 = $fl$1$;$p$2 = $p$0;$pl$1 = $pl$0;$prefix$1 = $prefix$0;
     label = 94;
    } else {
     $$12$i = $$0$lcssa$i45;$y$03$i = $$01$lcssa$off0$i;
     while(1) {
      $299 = (($y$03$i>>>0) % 10)&-1;
      $300 = $299 | 48;
      $301 = $300&255;
      $302 = (($$12$i) + -1|0);
      HEAP8[$302>>0] = $301;
      $303 = (($y$03$i>>>0) / 10)&-1;
      $304 = ($y$03$i>>>0)<(10);
      if ($304) {
       $307 = $276;$310 = $278;$a$0 = $302;$fl$4 = $fl$1$;$p$2 = $p$0;$pl$1 = $pl$0;$prefix$1 = $prefix$0;
       label = 94;
       break;
      } else {
       $$12$i = $302;$y$03$i = $303;
      }
     }
    }
   }
   else if ((label|0) == 99) {
    label = 0;
    $325 = (_memchr($a$1,0,$p$0)|0);
    $326 = ($325|0)==(0|0);
    if ($326) {
     $327 = (($a$1) + ($p$0)|0);
     $1053 = $228;$1054 = $207;$a$2 = $a$1;$fl$6 = $206;$p$5 = $p$0;$pl$2 = 0;$prefix$2 = 145216;$z$2 = $327;
     break;
    } else {
     $328 = $325;
     $329 = $a$1;
     $330 = (($328) - ($329))|0;
     $1053 = $228;$1054 = $207;$a$2 = $a$1;$fl$6 = $206;$p$5 = $330;$pl$2 = 0;$prefix$2 = 145216;$z$2 = $325;
     break;
    }
   }
   else if ((label|0) == 104) {
    label = 0;
    $i$0168 = 0;$l$1167 = 0;$ws$0169 = $1055;
    while(1) {
     $336 = HEAP32[$ws$0169>>2]|0;
     $337 = ($336|0)==(0);
     if ($337) {
      $i$0$lcssa = $i$0168;$l$1$lcssa = $l$1167;
      break;
     }
     $338 = (_wctomb($mb,$336)|0);
     $339 = ($338|0)>(-1);
     if (!($339)) {
      $$0 = -1;
      label = 362;
      break L1;
     }
     $340 = (($p$4296) - ($i$0168))|0;
     $341 = ($338>>>0)>($340>>>0);
     $334 = (($338) + ($i$0168))|0;
     if ($341) {
      $1057 = $1055;$1058 = $1056;$i$0166 = $i$0168;
      label = 110;
      break L445;
     }
     $333 = (($ws$0169) + 4|0);
     $335 = ($334>>>0)<($p$4296>>>0);
     if ($335) {
      $i$0168 = $334;$l$1167 = $338;$ws$0169 = $333;
     } else {
      $i$0$lcssa = $334;$l$1$lcssa = $338;
      break;
     }
    }
    $342 = ($l$1$lcssa|0)<(0);
    if ($342) {
     $$0 = -1;
     label = 362;
     break L1;
    } else {
     $1057 = $1055;$1058 = $1056;$i$0166 = $i$0$lcssa;
     label = 110;
    }
   }
  } while(0);
  if ((label|0) == 94) {
   label = 0;
   $305 = ($p$2|0)>(-1);
   $306 = $fl$4 & -65537;
   $$fl$4 = $305 ? $306 : $fl$4;
   $308 = $307;
   $309 = ($308|0)==(0);
   $311 = ($310|0)==(0);
   $312 = $309 & $311;
   $313 = ($p$2|0)==(0);
   $or$cond = $312 & $313;
   if ($or$cond) {
    $1053 = $310;$1054 = $307;$a$2 = $2;$fl$6 = $$fl$4;$p$5 = 0;$pl$2 = $pl$1;$prefix$2 = $prefix$1;$z$2 = $2;
   } else {
    $314 = $a$0;
    $315 = (($3) - ($314))|0;
    $316 = $312&1;
    $317 = (($316) + ($315))|0;
    $318 = ($p$2|0)>($317|0);
    $p$2$ = $318 ? $p$2 : $317;
    $1053 = $310;$1054 = $307;$a$2 = $a$0;$fl$6 = $$fl$4;$p$5 = $p$2$;$pl$2 = $pl$1;$prefix$2 = $prefix$1;$z$2 = $2;
   }
  }
  else if ((label|0) == 110) {
   label = 0;
   $343 = $fl$1$ & 73728;
   $344 = ($343|0)==(0);
   $345 = ($i$0166|0)<($w$1|0);
   $or$cond$i56 = $344 & $345;
   if ($or$cond$i56) {
    $346 = (($w$1) - ($i$0166))|0;
    $347 = ($346>>>0)>(256);
    $348 = $347 ? 256 : $346;
    _memset(($pad$i|0),32,($348|0))|0;
    $349 = ($346>>>0)>(255);
    if ($349) {
     $$01$i57 = $346;
     while(1) {
      (___fwritex($pad$i,256,$f)|0);
      $350 = (($$01$i57) + -256)|0;
      $351 = ($350>>>0)>(255);
      if ($351) {
       $$01$i57 = $350;
      } else {
       $$0$lcssa$i59 = $350;
       break;
      }
     }
    } else {
     $$0$lcssa$i59 = $346;
    }
    (___fwritex($pad$i,$$0$lcssa$i59,$f)|0);
   }
   $352 = ($i$0166|0)==(0);
   L481: do {
    if (!($352)) {
     $i$1174 = 0;$ws$1175 = $1057;
     while(1) {
      $353 = HEAP32[$ws$1175>>2]|0;
      $354 = ($353|0)==(0);
      if ($354) {
       break L481;
      }
      $355 = (_wctomb($mb,$353)|0);
      $356 = (($355) + ($i$1174))|0;
      $357 = ($356|0)>($i$0166|0);
      if ($357) {
       break L481;
      }
      $358 = (($ws$1175) + 4|0);
      (___fwritex($mb,$355,$f)|0);
      $359 = ($356>>>0)<($i$0166>>>0);
      if ($359) {
       $i$1174 = $356;$ws$1175 = $358;
      } else {
       break;
      }
     }
    }
   } while(0);
   $360 = ($343|0)==(8192);
   $or$cond$i63 = $360 & $345;
   if ($or$cond$i63) {
    $361 = (($w$1) - ($i$0166))|0;
    $362 = ($361>>>0)>(256);
    $363 = $362 ? 256 : $361;
    _memset(($pad$i|0),32,($363|0))|0;
    $364 = ($361>>>0)>(255);
    if ($364) {
     $$01$i64 = $361;
     while(1) {
      (___fwritex($pad$i,256,$f)|0);
      $365 = (($$01$i64) + -256)|0;
      $366 = ($365>>>0)>(255);
      if ($366) {
       $$01$i64 = $365;
      } else {
       $$0$lcssa$i66 = $365;
       break;
      }
     }
    } else {
     $$0$lcssa$i66 = $361;
    }
    (___fwritex($pad$i,$$0$lcssa$i66,$f)|0);
   }
   $367 = $345 ? $w$1 : $i$0166;
   $1045 = $228;$1046 = $1058;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $367;$l10n$0 = $l10n$3;
   continue;
  }
  $942 = $z$2;
  $943 = $a$2;
  $944 = (($942) - ($943))|0;
  $945 = ($p$5|0)<($944|0);
  $$p$5 = $945 ? $944 : $p$5;
  $946 = (($pl$2) + ($$p$5))|0;
  $947 = ($w$1|0)<($946|0);
  $w$2 = $947 ? $946 : $w$1;
  $948 = $fl$6 & 73728;
  $949 = ($948|0)==(0);
  $950 = ($946|0)<($w$2|0);
  $or$cond$i73 = $949 & $950;
  if ($or$cond$i73) {
   $951 = (($w$2) - ($946))|0;
   $952 = ($951>>>0)>(256);
   $953 = $952 ? 256 : $951;
   _memset(($pad$i|0),32,($953|0))|0;
   $954 = ($951>>>0)>(255);
   if ($954) {
    $$01$i74 = $951;
    while(1) {
     (___fwritex($pad$i,256,$f)|0);
     $955 = (($$01$i74) + -256)|0;
     $956 = ($955>>>0)>(255);
     if ($956) {
      $$01$i74 = $955;
     } else {
      $$0$lcssa$i76 = $955;
      break;
     }
    }
   } else {
    $$0$lcssa$i76 = $951;
   }
   (___fwritex($pad$i,$$0$lcssa$i76,$f)|0);
  }
  (___fwritex($prefix$2,$pl$2,$f)|0);
  $957 = ($948|0)==(65536);
  $or$cond$i49 = $957 & $950;
  if ($or$cond$i49) {
   $958 = (($w$2) - ($946))|0;
   $959 = ($958>>>0)>(256);
   $960 = $959 ? 256 : $958;
   _memset(($pad$i|0),48,($960|0))|0;
   $961 = ($958>>>0)>(255);
   if ($961) {
    $$01$i50 = $958;
    while(1) {
     (___fwritex($pad$i,256,$f)|0);
     $962 = (($$01$i50) + -256)|0;
     $963 = ($962>>>0)>(255);
     if ($963) {
      $$01$i50 = $962;
     } else {
      $$0$lcssa$i52 = $962;
      break;
     }
    }
   } else {
    $$0$lcssa$i52 = $958;
   }
   (___fwritex($pad$i,$$0$lcssa$i52,$f)|0);
  }
  $964 = ($944|0)<($$p$5|0);
  if ($964) {
   $965 = (($$p$5) - ($944))|0;
   $966 = ($965>>>0)>(256);
   $967 = $966 ? 256 : $965;
   _memset(($pad$i|0),48,($967|0))|0;
   $968 = ($965>>>0)>(255);
   if ($968) {
    $$01$i35 = $965;
    while(1) {
     (___fwritex($pad$i,256,$f)|0);
     $969 = (($$01$i35) + -256)|0;
     $970 = ($969>>>0)>(255);
     if ($970) {
      $$01$i35 = $969;
     } else {
      $$0$lcssa$i37 = $969;
      break;
     }
    }
   } else {
    $$0$lcssa$i37 = $965;
   }
   (___fwritex($pad$i,$$0$lcssa$i37,$f)|0);
  }
  (___fwritex($a$2,$944,$f)|0);
  $971 = ($948|0)==(8192);
  $or$cond$i = $971 & $950;
  if (!($or$cond$i)) {
   $1045 = $1053;$1046 = $1054;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $w$2;$l10n$0 = $l10n$3;
   continue;
  }
  $972 = (($w$2) - ($946))|0;
  $973 = ($972>>>0)>(256);
  $974 = $973 ? 256 : $972;
  _memset(($pad$i|0),32,($974|0))|0;
  $975 = ($972>>>0)>(255);
  if ($975) {
   $$01$i = $972;
   while(1) {
    (___fwritex($pad$i,256,$f)|0);
    $976 = (($$01$i) + -256)|0;
    $977 = ($976>>>0)>(255);
    if ($977) {
     $$01$i = $976;
    } else {
     $$0$lcssa$i = $976;
     break;
    }
   }
  } else {
   $$0$lcssa$i = $972;
  }
  (___fwritex($pad$i,$$0$lcssa$i,$f)|0);
  $1045 = $1053;$1046 = $1054;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $w$2;$l10n$0 = $l10n$3;
 }
 if ((label|0) == 344) {
  $978 = ($f|0)==(0|0);
  if (!($978)) {
   $$0 = $cnt$1;
   STACKTOP = sp;return ($$0|0);
  }
  $979 = ($l10n$0|0)==(0);
  if ($979) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $i$289 = 1;
  }
  while(1) {
   $980 = (($nl_type) + ($i$289<<2)|0);
   $981 = HEAP32[$980>>2]|0;
   $982 = ($981|0)==(0);
   if ($982) {
    $i$388 = $i$289;
    break;
   }
   $983 = (($nl_arg) + ($i$289<<3)|0);
   $984 = ($981>>>0)>(20);
   L531: do {
    if (!($984)) {
     do {
      switch ($981|0) {
      case 9:  {
       $arglist_current35 = HEAP32[$ap>>2]|0;
       $985 = HEAP32[$arglist_current35>>2]|0;
       $arglist_next36 = (($arglist_current35) + 4|0);
       HEAP32[$ap>>2] = $arglist_next36;
       HEAP32[$983>>2] = $985;
       break L531;
       break;
      }
      case 10:  {
       $arglist_current38 = HEAP32[$ap>>2]|0;
       $986 = HEAP32[$arglist_current38>>2]|0;
       $arglist_next39 = (($arglist_current38) + 4|0);
       HEAP32[$ap>>2] = $arglist_next39;
       $987 = ($986|0)<(0);
       $988 = $987 << 31 >> 31;
       $989 = $983;
       $990 = $989;
       HEAP32[$990>>2] = $986;
       $991 = (($989) + 4)|0;
       $992 = $991;
       HEAP32[$992>>2] = $988;
       break L531;
       break;
      }
      case 11:  {
       $arglist_current41 = HEAP32[$ap>>2]|0;
       $993 = HEAP32[$arglist_current41>>2]|0;
       $arglist_next42 = (($arglist_current41) + 4|0);
       HEAP32[$ap>>2] = $arglist_next42;
       $994 = $983;
       $995 = $994;
       HEAP32[$995>>2] = $993;
       $996 = (($994) + 4)|0;
       $997 = $996;
       HEAP32[$997>>2] = 0;
       break L531;
       break;
      }
      case 12:  {
       $arglist_current44 = HEAP32[$ap>>2]|0;
       $998 = $arglist_current44;
       $999 = $998;
       $1000 = HEAP32[$999>>2]|0;
       $1001 = (($998) + 4)|0;
       $1002 = $1001;
       $1003 = HEAP32[$1002>>2]|0;
       $arglist_next45 = (($arglist_current44) + 8|0);
       HEAP32[$ap>>2] = $arglist_next45;
       $1004 = $983;
       $1005 = $1004;
       HEAP32[$1005>>2] = $1000;
       $1006 = (($1004) + 4)|0;
       $1007 = $1006;
       HEAP32[$1007>>2] = $1003;
       break L531;
       break;
      }
      case 13:  {
       $arglist_current47 = HEAP32[$ap>>2]|0;
       $1008 = HEAP32[$arglist_current47>>2]|0;
       $arglist_next48 = (($arglist_current47) + 4|0);
       HEAP32[$ap>>2] = $arglist_next48;
       $1009 = $1008&65535;
       $1010 = $1009 << 16 >> 16;
       $1011 = ($1010|0)<(0);
       $1012 = $1011 << 31 >> 31;
       $1013 = $983;
       $1014 = $1013;
       HEAP32[$1014>>2] = $1010;
       $1015 = (($1013) + 4)|0;
       $1016 = $1015;
       HEAP32[$1016>>2] = $1012;
       break L531;
       break;
      }
      case 14:  {
       $arglist_current50 = HEAP32[$ap>>2]|0;
       $1017 = HEAP32[$arglist_current50>>2]|0;
       $arglist_next51 = (($arglist_current50) + 4|0);
       HEAP32[$ap>>2] = $arglist_next51;
       $$mask1$i = $1017 & 65535;
       $1018 = $983;
       $1019 = $1018;
       HEAP32[$1019>>2] = $$mask1$i;
       $1020 = (($1018) + 4)|0;
       $1021 = $1020;
       HEAP32[$1021>>2] = 0;
       break L531;
       break;
      }
      case 15:  {
       $arglist_current53 = HEAP32[$ap>>2]|0;
       $1022 = HEAP32[$arglist_current53>>2]|0;
       $arglist_next54 = (($arglist_current53) + 4|0);
       HEAP32[$ap>>2] = $arglist_next54;
       $1023 = $1022&255;
       $1024 = $1023 << 24 >> 24;
       $1025 = ($1024|0)<(0);
       $1026 = $1025 << 31 >> 31;
       $1027 = $983;
       $1028 = $1027;
       HEAP32[$1028>>2] = $1024;
       $1029 = (($1027) + 4)|0;
       $1030 = $1029;
       HEAP32[$1030>>2] = $1026;
       break L531;
       break;
      }
      case 16:  {
       $arglist_current56 = HEAP32[$ap>>2]|0;
       $1031 = HEAP32[$arglist_current56>>2]|0;
       $arglist_next57 = (($arglist_current56) + 4|0);
       HEAP32[$ap>>2] = $arglist_next57;
       $$mask$i = $1031 & 255;
       $1032 = $983;
       $1033 = $1032;
       HEAP32[$1033>>2] = $$mask$i;
       $1034 = (($1032) + 4)|0;
       $1035 = $1034;
       HEAP32[$1035>>2] = 0;
       break L531;
       break;
      }
      case 17:  {
       $arglist_current59 = HEAP32[$ap>>2]|0;
       HEAP32[tempDoublePtr>>2]=HEAP32[$arglist_current59>>2];HEAP32[tempDoublePtr+4>>2]=HEAP32[$arglist_current59+4>>2];$1036 = +HEAPF64[tempDoublePtr>>3];
       $arglist_next60 = (($arglist_current59) + 8|0);
       HEAP32[$ap>>2] = $arglist_next60;
       HEAPF64[$983>>3] = $1036;
       break L531;
       break;
      }
      case 18:  {
       $arglist_current62 = HEAP32[$ap>>2]|0;
       HEAP32[tempDoublePtr>>2]=HEAP32[$arglist_current62>>2];HEAP32[tempDoublePtr+4>>2]=HEAP32[$arglist_current62+4>>2];$1037 = +HEAPF64[tempDoublePtr>>3];
       $arglist_next63 = (($arglist_current62) + 8|0);
       HEAP32[$ap>>2] = $arglist_next63;
       HEAPF64[$983>>3] = $1037;
       break L531;
       break;
      }
      default: {
       break L531;
      }
      }
     } while(0);
    }
   } while(0);
   $1038 = (($i$289) + 1)|0;
   $1039 = ($1038|0)<(10);
   if ($1039) {
    $i$289 = $1038;
   } else {
    $$0 = 1;
    label = 362;
    break;
   }
  }
  if ((label|0) == 362) {
   STACKTOP = sp;return ($$0|0);
  }
  while(1) {
   $1042 = (($nl_type) + ($i$388<<2)|0);
   $1043 = HEAP32[$1042>>2]|0;
   $1044 = ($1043|0)==(0);
   $1040 = (($i$388) + 1)|0;
   if (!($1044)) {
    $$0 = -1;
    label = 362;
    break;
   }
   $1041 = ($1040|0)<(10);
   if ($1041) {
    $i$388 = $1040;
   } else {
    $$0 = 1;
    label = 362;
    break;
   }
  }
  if ((label|0) == 362) {
   STACKTOP = sp;return ($$0|0);
  }
 }
 else if ((label|0) == 362) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _vsnprintf($s,$n,$fmt,$ap) {
 $s = $s|0;
 $n = $n|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 var $$$02 = 0, $$0 = 0, $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b = 0, $f = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $b = sp + 112|0;
 $f = sp;
 dest=$f+0|0; src=145320+0|0; stop=dest+112|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $0 = (($n) + -1)|0;
 $1 = ($0>>>0)>(2147483646);
 if ($1) {
  $2 = ($n|0)==(0);
  if ($2) {
   $$01 = $b;$$02 = 1;
  } else {
   $3 = (___errno_location()|0);
   HEAP32[$3>>2] = 75;
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $$01 = $s;$$02 = $n;
 }
 $4 = $$01;
 $5 = (-2 - ($4))|0;
 $6 = ($$02>>>0)>($5>>>0);
 $$$02 = $6 ? $5 : $$02;
 $7 = (($f) + 48|0);
 HEAP32[$7>>2] = $$$02;
 $8 = (($f) + 20|0);
 HEAP32[$8>>2] = $$01;
 $9 = (($f) + 44|0);
 HEAP32[$9>>2] = $$01;
 $10 = (($$01) + ($$$02)|0);
 $11 = (($f) + 16|0);
 HEAP32[$11>>2] = $10;
 $12 = (($f) + 28|0);
 HEAP32[$12>>2] = $10;
 $13 = (_MUSL_vfprintf($f,$fmt,$ap)|0);
 $14 = ($$$02|0)==(0);
 if ($14) {
  $$0 = $13;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = HEAP32[$8>>2]|0;
 $16 = HEAP32[$11>>2]|0;
 $17 = ($15|0)==($16|0);
 $18 = $17 << 31 >> 31;
 $19 = (($15) + ($18)|0);
 HEAP8[$19>>0] = 0;
 $$0 = $13;
 STACKTOP = sp;return ($$0|0);
}
function _sn_write($f,$s,$l) {
 $f = $f|0;
 $s = $s|0;
 $l = $l|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($f) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($f) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = ($6>>>0)>($l>>>0);
 $l$ = $7 ? $l : $6;
 _memcpy(($3|0),($s|0),($l$|0))|0;
 $8 = HEAP32[$2>>2]|0;
 $9 = (($8) + ($l$)|0);
 HEAP32[$2>>2] = $9;
 STACKTOP = sp;return ($l|0);
}
function _vsprintf($s,$fmt,$ap) {
 $s = $s|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_vsnprintf($s,2147483647,$fmt,$ap)|0);
 STACKTOP = sp;return ($0|0);
}
function _memchr($src,$c,$n) {
 $src = $src|0;
 $c = $c|0;
 $n = $n|0;
 var $$0$lcssa = 0, $$0$lcssa34 = 0, $$013 = 0, $$1$lcssa = 0, $$17 = 0, $$24 = 0, $$3 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond12 = 0, $s$0$lcssa = 0, $s$0$lcssa33 = 0, $s$014 = 0, $s$15 = 0, $s$2 = 0, $w$0$lcssa = 0, $w$08 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $c & 255;
 $1 = $src;
 $2 = $1 & 3;
 $3 = ($2|0)==(0);
 $4 = ($n|0)==(0);
 $or$cond12 = $3 | $4;
 L1: do {
  if ($or$cond12) {
   $$0$lcssa = $n;$$lcssa = $4;$s$0$lcssa = $src;
   label = 5;
  } else {
   $5 = $c&255;
   $$013 = $n;$s$014 = $src;
   while(1) {
    $6 = HEAP8[$s$014>>0]|0;
    $7 = ($6<<24>>24)==($5<<24>>24);
    if ($7) {
     $$0$lcssa34 = $$013;$s$0$lcssa33 = $s$014;
     label = 6;
     break L1;
    }
    $8 = (($s$014) + 1|0);
    $9 = (($$013) + -1)|0;
    $10 = $8;
    $11 = $10 & 3;
    $12 = ($11|0)==(0);
    $13 = ($9|0)==(0);
    $or$cond = $12 | $13;
    if ($or$cond) {
     $$0$lcssa = $9;$$lcssa = $13;$s$0$lcssa = $8;
     label = 5;
     break;
    } else {
     $$013 = $9;$s$014 = $8;
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  if ($$lcssa) {
   $$3 = 0;$s$2 = $s$0$lcssa;
  } else {
   $$0$lcssa34 = $$0$lcssa;$s$0$lcssa33 = $s$0$lcssa;
   label = 6;
  }
 }
 L8: do {
  if ((label|0) == 6) {
   $14 = HEAP8[$s$0$lcssa33>>0]|0;
   $15 = $c&255;
   $16 = ($14<<24>>24)==($15<<24>>24);
   if ($16) {
    $$3 = $$0$lcssa34;$s$2 = $s$0$lcssa33;
   } else {
    $17 = Math_imul($0, 16843009)|0;
    $18 = ($$0$lcssa34>>>0)>(3);
    L11: do {
     if ($18) {
      $$17 = $$0$lcssa34;$w$08 = $s$0$lcssa33;
      while(1) {
       $19 = HEAP32[$w$08>>2]|0;
       $20 = $19 ^ $17;
       $21 = (($20) + -16843009)|0;
       $22 = $20 & -2139062144;
       $23 = $22 ^ -2139062144;
       $24 = $23 & $21;
       $25 = ($24|0)==(0);
       if (!($25)) {
        $$1$lcssa = $$17;$w$0$lcssa = $w$08;
        break L11;
       }
       $26 = (($w$08) + 4|0);
       $27 = (($$17) + -4)|0;
       $28 = ($27>>>0)>(3);
       if ($28) {
        $$17 = $27;$w$08 = $26;
       } else {
        $$1$lcssa = $27;$w$0$lcssa = $26;
        break;
       }
      }
     } else {
      $$1$lcssa = $$0$lcssa34;$w$0$lcssa = $s$0$lcssa33;
     }
    } while(0);
    $29 = ($$1$lcssa|0)==(0);
    if ($29) {
     $$3 = 0;$s$2 = $w$0$lcssa;
    } else {
     $$24 = $$1$lcssa;$s$15 = $w$0$lcssa;
     while(1) {
      $30 = HEAP8[$s$15>>0]|0;
      $31 = ($30<<24>>24)==($15<<24>>24);
      if ($31) {
       $$3 = $$24;$s$2 = $s$15;
       break L8;
      }
      $32 = (($s$15) + 1|0);
      $33 = (($$24) + -1)|0;
      $34 = ($33|0)==(0);
      if ($34) {
       $$3 = 0;$s$2 = $32;
       break;
      } else {
       $$24 = $33;$s$15 = $32;
      }
     }
    }
   }
  }
 } while(0);
 $35 = ($$3|0)!=(0);
 $36 = $35 ? $s$2 : 0;
 STACKTOP = sp;return ($36|0);
}
function _strcmp($l,$r) {
 $l = $l|0;
 $r = $r|0;
 var $$014 = 0, $$05 = 0, $$lcssa = 0, $$lcssa2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$l>>0]|0;
 $1 = HEAP8[$r>>0]|0;
 $2 = ($0<<24>>24)!=($1<<24>>24);
 $3 = ($0<<24>>24)==(0);
 $or$cond3 = $2 | $3;
 if ($or$cond3) {
  $$lcssa = $0;$$lcssa2 = $1;
 } else {
  $$014 = $l;$$05 = $r;
  while(1) {
   $4 = (($$014) + 1|0);
   $5 = (($$05) + 1|0);
   $6 = HEAP8[$4>>0]|0;
   $7 = HEAP8[$5>>0]|0;
   $8 = ($6<<24>>24)!=($7<<24>>24);
   $9 = ($6<<24>>24)==(0);
   $or$cond = $8 | $9;
   if ($or$cond) {
    $$lcssa = $6;$$lcssa2 = $7;
    break;
   } else {
    $$014 = $4;$$05 = $5;
   }
  }
 }
 $10 = $$lcssa&255;
 $11 = $$lcssa2&255;
 $12 = (($10) - ($11))|0;
 STACKTOP = sp;return ($12|0);
}
function runPostSets() {
 
}
function _i64Subtract(a, b, c, d) {
    a = a|0; b = b|0; c = c|0; d = d|0;
    var l = 0, h = 0;
    l = (a - c)>>>0;
    h = (b - d)>>>0;
    h = (b - d - (((c>>>0) > (a>>>0))|0))>>>0; // Borrow one from high word to low word on underflow.
    return ((tempRet0 = h,l|0)|0);
}
function _memset(ptr, value, num) {
    ptr = ptr|0; value = value|0; num = num|0;
    var stop = 0, value4 = 0, stop4 = 0, unaligned = 0;
    stop = (ptr + num)|0;
    if ((num|0) >= 20) {
      // This is unaligned, but quite large, so work hard to get to aligned settings
      value = value & 0xff;
      unaligned = ptr & 3;
      value4 = value | (value << 8) | (value << 16) | (value << 24);
      stop4 = stop & ~3;
      if (unaligned) {
        unaligned = (ptr + 4 - unaligned)|0;
        while ((ptr|0) < (unaligned|0)) { // no need to check for stop, since we have large num
          HEAP8[((ptr)>>0)]=value;
          ptr = (ptr+1)|0;
        }
      }
      while ((ptr|0) < (stop4|0)) {
        HEAP32[((ptr)>>2)]=value4;
        ptr = (ptr+4)|0;
      }
    }
    while ((ptr|0) < (stop|0)) {
      HEAP8[((ptr)>>0)]=value;
      ptr = (ptr+1)|0;
    }
    return (ptr-num)|0;
}
function _bitshift64Shl(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      tempRet0 = (high << bits) | ((low&(ander << (32 - bits))) >>> (32 - bits));
      return low << bits;
    }
    tempRet0 = low << (bits - 32);
    return 0;
}
function _strlen(ptr) {
    ptr = ptr|0;
    var curr = 0;
    curr = ptr;
    while (((HEAP8[((curr)>>0)])|0)) {
      curr = (curr + 1)|0;
    }
    return (curr - ptr)|0;
}
function _i64Add(a, b, c, d) {
    /*
      x = a + b*2^32
      y = c + d*2^32
      result = l + h*2^32
    */
    a = a|0; b = b|0; c = c|0; d = d|0;
    var l = 0, h = 0;
    l = (a + c)>>>0;
    h = (b + d + (((l>>>0) < (a>>>0))|0))>>>0; // Add carry from low word to high word on overflow.
    return ((tempRet0 = h,l|0)|0);
}
function _saveSetjmp(env, label, table) {
    // Not particularly fast: slow table lookup of setjmpId to label. But setjmp
    // prevents relooping anyhow, so slowness is to be expected. And typical case
    // is 1 setjmp per invocation, or less.
    env = env|0;
    label = label|0;
    table = table|0;
    var i = 0;
    setjmpId = (setjmpId+1)|0;
    HEAP32[((env)>>2)]=setjmpId;
    while ((i|0) < 20) {
      if (((HEAP32[(((table)+((i<<3)))>>2)])|0) == 0) {
        HEAP32[(((table)+((i<<3)))>>2)]=setjmpId;
        HEAP32[(((table)+((i<<3)+4))>>2)]=label;
        // prepare next slot
        HEAP32[(((table)+((i<<3)+8))>>2)]=0;
        return 0;
      }
      i = i+1|0;
    }
    _putchar(116);_putchar(111);_putchar(111);_putchar(32);_putchar(109);_putchar(97);_putchar(110);_putchar(121);_putchar(32);_putchar(115);_putchar(101);_putchar(116);_putchar(106);_putchar(109);_putchar(112);_putchar(115);_putchar(32);_putchar(105);_putchar(110);_putchar(32);_putchar(97);_putchar(32);_putchar(102);_putchar(117);_putchar(110);_putchar(99);_putchar(116);_putchar(105);_putchar(111);_putchar(110);_putchar(32);_putchar(99);_putchar(97);_putchar(108);_putchar(108);_putchar(44);_putchar(32);_putchar(98);_putchar(117);_putchar(105);_putchar(108);_putchar(100);_putchar(32);_putchar(119);_putchar(105);_putchar(116);_putchar(104);_putchar(32);_putchar(97);_putchar(32);_putchar(104);_putchar(105);_putchar(103);_putchar(104);_putchar(101);_putchar(114);_putchar(32);_putchar(118);_putchar(97);_putchar(108);_putchar(117);_putchar(101);_putchar(32);_putchar(102);_putchar(111);_putchar(114);_putchar(32);_putchar(77);_putchar(65);_putchar(88);_putchar(95);_putchar(83);_putchar(69);_putchar(84);_putchar(74);_putchar(77);_putchar(80);_putchar(83);_putchar(10);
    abort(0);
    return 0;
}
function _bitshift64Lshr(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      tempRet0 = high >>> bits;
      return (low >>> bits) | ((high&ander) << (32 - bits));
    }
    tempRet0 = 0;
    return (high >>> (bits - 32))|0;
}
function _testSetjmp(id, table) {
    id = id|0;
    table = table|0;
    var i = 0, curr = 0;
    while ((i|0) < 20) {
      curr = ((HEAP32[(((table)+((i<<3)))>>2)])|0);
      if ((curr|0) == 0) break;
      if ((curr|0) == (id|0)) {
        return ((HEAP32[(((table)+((i<<3)+4))>>2)])|0);
      }
      i = i+1|0;
    }
    return 0;
}
function _memcpy(dest, src, num) {

    dest = dest|0; src = src|0; num = num|0;
    var ret = 0;
    if ((num|0) >= 4096) return _emscripten_memcpy_big(dest|0, src|0, num|0)|0;
    ret = dest|0;
    if ((dest&3) == (src&3)) {
      while (dest & 3) {
        if ((num|0) == 0) return ret|0;
        HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
        dest = (dest+1)|0;
        src = (src+1)|0;
        num = (num-1)|0;
      }
      while ((num|0) >= 4) {
        HEAP32[((dest)>>2)]=((HEAP32[((src)>>2)])|0);
        dest = (dest+4)|0;
        src = (src+4)|0;
        num = (num-4)|0;
      }
    }
    while ((num|0) > 0) {
      HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
      dest = (dest+1)|0;
      src = (src+1)|0;
      num = (num-1)|0;
    }
    return ret|0;
}
function _bitshift64Ashr(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      tempRet0 = high >> bits;
      return (low >>> bits) | ((high&ander) << (32 - bits));
    }
    tempRet0 = (high|0) < 0 ? -1 : 0;
    return (high >> (bits - 32))|0;
  }
function _llvm_ctlz_i32(x) {
    x = x|0;
    var ret = 0;
    ret = ((HEAP8[(((ctlz_i8)+(x >>> 24))>>0)])|0);
    if ((ret|0) < 8) return ret|0;
    ret = ((HEAP8[(((ctlz_i8)+((x >> 16)&0xff))>>0)])|0);
    if ((ret|0) < 8) return (ret + 8)|0;
    ret = ((HEAP8[(((ctlz_i8)+((x >> 8)&0xff))>>0)])|0);
    if ((ret|0) < 8) return (ret + 16)|0;
    return (((HEAP8[(((ctlz_i8)+(x&0xff))>>0)])|0) + 24)|0;
  }

function _llvm_cttz_i32(x) {
    x = x|0;
    var ret = 0;
    ret = ((HEAP8[(((cttz_i8)+(x & 0xff))>>0)])|0);
    if ((ret|0) < 8) return ret|0;
    ret = ((HEAP8[(((cttz_i8)+((x >> 8)&0xff))>>0)])|0);
    if ((ret|0) < 8) return (ret + 8)|0;
    ret = ((HEAP8[(((cttz_i8)+((x >> 16)&0xff))>>0)])|0);
    if ((ret|0) < 8) return (ret + 16)|0;
    return (((HEAP8[(((cttz_i8)+(x >>> 24))>>0)])|0) + 24)|0;
  }

// ======== compiled code from system/lib/compiler-rt , see readme therein
function ___muldsi3($a, $b) {
  $a = $a | 0;
  $b = $b | 0;
  var $1 = 0, $2 = 0, $3 = 0, $6 = 0, $8 = 0, $11 = 0, $12 = 0;
  $1 = $a & 65535;
  $2 = $b & 65535;
  $3 = Math_imul($2, $1) | 0;
  $6 = $a >>> 16;
  $8 = ($3 >>> 16) + (Math_imul($2, $6) | 0) | 0;
  $11 = $b >>> 16;
  $12 = Math_imul($11, $1) | 0;
  return (tempRet0 = (($8 >>> 16) + (Math_imul($11, $6) | 0) | 0) + ((($8 & 65535) + $12 | 0) >>> 16) | 0, 0 | ($8 + $12 << 16 | $3 & 65535)) | 0;
}
function ___divdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $1$0 = 0, $1$1 = 0, $2$0 = 0, $2$1 = 0, $4$0 = 0, $4$1 = 0, $6$0 = 0, $7$0 = 0, $7$1 = 0, $8$0 = 0, $10$0 = 0;
  $1$0 = $a$1 >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $1$1 = (($a$1 | 0) < 0 ? -1 : 0) >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $2$0 = $b$1 >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $2$1 = (($b$1 | 0) < 0 ? -1 : 0) >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $4$0 = _i64Subtract($1$0 ^ $a$0, $1$1 ^ $a$1, $1$0, $1$1) | 0;
  $4$1 = tempRet0;
  $6$0 = _i64Subtract($2$0 ^ $b$0, $2$1 ^ $b$1, $2$0, $2$1) | 0;
  $7$0 = $2$0 ^ $1$0;
  $7$1 = $2$1 ^ $1$1;
  $8$0 = ___udivmoddi4($4$0, $4$1, $6$0, tempRet0, 0) | 0;
  $10$0 = _i64Subtract($8$0 ^ $7$0, tempRet0 ^ $7$1, $7$0, $7$1) | 0;
  return (tempRet0 = tempRet0, $10$0) | 0;
}
function ___remdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $rem = 0, $1$0 = 0, $1$1 = 0, $2$0 = 0, $2$1 = 0, $4$0 = 0, $4$1 = 0, $6$0 = 0, $10$0 = 0, $10$1 = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  $rem = __stackBase__ | 0;
  $1$0 = $a$1 >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $1$1 = (($a$1 | 0) < 0 ? -1 : 0) >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $2$0 = $b$1 >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $2$1 = (($b$1 | 0) < 0 ? -1 : 0) >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $4$0 = _i64Subtract($1$0 ^ $a$0, $1$1 ^ $a$1, $1$0, $1$1) | 0;
  $4$1 = tempRet0;
  $6$0 = _i64Subtract($2$0 ^ $b$0, $2$1 ^ $b$1, $2$0, $2$1) | 0;
  ___udivmoddi4($4$0, $4$1, $6$0, tempRet0, $rem) | 0;
  $10$0 = _i64Subtract(HEAP32[$rem >> 2] ^ $1$0, HEAP32[$rem + 4 >> 2] ^ $1$1, $1$0, $1$1) | 0;
  $10$1 = tempRet0;
  STACKTOP = __stackBase__;
  return (tempRet0 = $10$1, $10$0) | 0;
}
function ___muldi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $x_sroa_0_0_extract_trunc = 0, $y_sroa_0_0_extract_trunc = 0, $1$0 = 0, $1$1 = 0, $2 = 0;
  $x_sroa_0_0_extract_trunc = $a$0;
  $y_sroa_0_0_extract_trunc = $b$0;
  $1$0 = ___muldsi3($x_sroa_0_0_extract_trunc, $y_sroa_0_0_extract_trunc) | 0;
  $1$1 = tempRet0;
  $2 = Math_imul($a$1, $y_sroa_0_0_extract_trunc) | 0;
  return (tempRet0 = ((Math_imul($b$1, $x_sroa_0_0_extract_trunc) | 0) + $2 | 0) + $1$1 | $1$1 & 0, 0 | $1$0 & -1) | 0;
}
function ___udivdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $1$0 = 0;
  $1$0 = ___udivmoddi4($a$0, $a$1, $b$0, $b$1, 0) | 0;
  return (tempRet0 = tempRet0, $1$0) | 0;
}
function ___uremdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $rem = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  $rem = __stackBase__ | 0;
  ___udivmoddi4($a$0, $a$1, $b$0, $b$1, $rem) | 0;
  STACKTOP = __stackBase__;
  return (tempRet0 = HEAP32[$rem + 4 >> 2] | 0, HEAP32[$rem >> 2] | 0) | 0;
}
function ___udivmoddi4($a$0, $a$1, $b$0, $b$1, $rem) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  $rem = $rem | 0;
  var $n_sroa_0_0_extract_trunc = 0, $n_sroa_1_4_extract_shift$0 = 0, $n_sroa_1_4_extract_trunc = 0, $d_sroa_0_0_extract_trunc = 0, $d_sroa_1_4_extract_shift$0 = 0, $d_sroa_1_4_extract_trunc = 0, $4 = 0, $17 = 0, $37 = 0, $49 = 0, $51 = 0, $57 = 0, $58 = 0, $66 = 0, $78 = 0, $86 = 0, $88 = 0, $89 = 0, $91 = 0, $92 = 0, $95 = 0, $105 = 0, $117 = 0, $119 = 0, $125 = 0, $126 = 0, $130 = 0, $q_sroa_1_1_ph = 0, $q_sroa_0_1_ph = 0, $r_sroa_1_1_ph = 0, $r_sroa_0_1_ph = 0, $sr_1_ph = 0, $d_sroa_0_0_insert_insert99$0 = 0, $d_sroa_0_0_insert_insert99$1 = 0, $137$0 = 0, $137$1 = 0, $carry_0203 = 0, $sr_1202 = 0, $r_sroa_0_1201 = 0, $r_sroa_1_1200 = 0, $q_sroa_0_1199 = 0, $q_sroa_1_1198 = 0, $147 = 0, $149 = 0, $r_sroa_0_0_insert_insert42$0 = 0, $r_sroa_0_0_insert_insert42$1 = 0, $150$1 = 0, $151$0 = 0, $152 = 0, $154$0 = 0, $r_sroa_0_0_extract_trunc = 0, $r_sroa_1_4_extract_trunc = 0, $155 = 0, $carry_0_lcssa$0 = 0, $carry_0_lcssa$1 = 0, $r_sroa_0_1_lcssa = 0, $r_sroa_1_1_lcssa = 0, $q_sroa_0_1_lcssa = 0, $q_sroa_1_1_lcssa = 0, $q_sroa_0_0_insert_ext75$0 = 0, $q_sroa_0_0_insert_ext75$1 = 0, $q_sroa_0_0_insert_insert77$1 = 0, $_0$0 = 0, $_0$1 = 0;
  $n_sroa_0_0_extract_trunc = $a$0;
  $n_sroa_1_4_extract_shift$0 = $a$1;
  $n_sroa_1_4_extract_trunc = $n_sroa_1_4_extract_shift$0;
  $d_sroa_0_0_extract_trunc = $b$0;
  $d_sroa_1_4_extract_shift$0 = $b$1;
  $d_sroa_1_4_extract_trunc = $d_sroa_1_4_extract_shift$0;
  if (($n_sroa_1_4_extract_trunc | 0) == 0) {
    $4 = ($rem | 0) != 0;
    if (($d_sroa_1_4_extract_trunc | 0) == 0) {
      if ($4) {
        HEAP32[$rem >> 2] = ($n_sroa_0_0_extract_trunc >>> 0) % ($d_sroa_0_0_extract_trunc >>> 0);
        HEAP32[$rem + 4 >> 2] = 0;
      }
      $_0$1 = 0;
      $_0$0 = ($n_sroa_0_0_extract_trunc >>> 0) / ($d_sroa_0_0_extract_trunc >>> 0) >>> 0;
      return (tempRet0 = $_0$1, $_0$0) | 0;
    } else {
      if (!$4) {
        $_0$1 = 0;
        $_0$0 = 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      HEAP32[$rem >> 2] = $a$0 & -1;
      HEAP32[$rem + 4 >> 2] = $a$1 & 0;
      $_0$1 = 0;
      $_0$0 = 0;
      return (tempRet0 = $_0$1, $_0$0) | 0;
    }
  }
  $17 = ($d_sroa_1_4_extract_trunc | 0) == 0;
  do {
    if (($d_sroa_0_0_extract_trunc | 0) == 0) {
      if ($17) {
        if (($rem | 0) != 0) {
          HEAP32[$rem >> 2] = ($n_sroa_1_4_extract_trunc >>> 0) % ($d_sroa_0_0_extract_trunc >>> 0);
          HEAP32[$rem + 4 >> 2] = 0;
        }
        $_0$1 = 0;
        $_0$0 = ($n_sroa_1_4_extract_trunc >>> 0) / ($d_sroa_0_0_extract_trunc >>> 0) >>> 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      if (($n_sroa_0_0_extract_trunc | 0) == 0) {
        if (($rem | 0) != 0) {
          HEAP32[$rem >> 2] = 0;
          HEAP32[$rem + 4 >> 2] = ($n_sroa_1_4_extract_trunc >>> 0) % ($d_sroa_1_4_extract_trunc >>> 0);
        }
        $_0$1 = 0;
        $_0$0 = ($n_sroa_1_4_extract_trunc >>> 0) / ($d_sroa_1_4_extract_trunc >>> 0) >>> 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      $37 = $d_sroa_1_4_extract_trunc - 1 | 0;
      if (($37 & $d_sroa_1_4_extract_trunc | 0) == 0) {
        if (($rem | 0) != 0) {
          HEAP32[$rem >> 2] = 0 | $a$0 & -1;
          HEAP32[$rem + 4 >> 2] = $37 & $n_sroa_1_4_extract_trunc | $a$1 & 0;
        }
        $_0$1 = 0;
        $_0$0 = $n_sroa_1_4_extract_trunc >>> ((_llvm_cttz_i32($d_sroa_1_4_extract_trunc | 0) | 0) >>> 0);
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      $49 = _llvm_ctlz_i32($d_sroa_1_4_extract_trunc | 0) | 0;
      $51 = $49 - (_llvm_ctlz_i32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
      if ($51 >>> 0 <= 30) {
        $57 = $51 + 1 | 0;
        $58 = 31 - $51 | 0;
        $sr_1_ph = $57;
        $r_sroa_0_1_ph = $n_sroa_1_4_extract_trunc << $58 | $n_sroa_0_0_extract_trunc >>> ($57 >>> 0);
        $r_sroa_1_1_ph = $n_sroa_1_4_extract_trunc >>> ($57 >>> 0);
        $q_sroa_0_1_ph = 0;
        $q_sroa_1_1_ph = $n_sroa_0_0_extract_trunc << $58;
        break;
      }
      if (($rem | 0) == 0) {
        $_0$1 = 0;
        $_0$0 = 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      HEAP32[$rem >> 2] = 0 | $a$0 & -1;
      HEAP32[$rem + 4 >> 2] = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
      $_0$1 = 0;
      $_0$0 = 0;
      return (tempRet0 = $_0$1, $_0$0) | 0;
    } else {
      if (!$17) {
        $117 = _llvm_ctlz_i32($d_sroa_1_4_extract_trunc | 0) | 0;
        $119 = $117 - (_llvm_ctlz_i32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
        if ($119 >>> 0 <= 31) {
          $125 = $119 + 1 | 0;
          $126 = 31 - $119 | 0;
          $130 = $119 - 31 >> 31;
          $sr_1_ph = $125;
          $r_sroa_0_1_ph = $n_sroa_0_0_extract_trunc >>> ($125 >>> 0) & $130 | $n_sroa_1_4_extract_trunc << $126;
          $r_sroa_1_1_ph = $n_sroa_1_4_extract_trunc >>> ($125 >>> 0) & $130;
          $q_sroa_0_1_ph = 0;
          $q_sroa_1_1_ph = $n_sroa_0_0_extract_trunc << $126;
          break;
        }
        if (($rem | 0) == 0) {
          $_0$1 = 0;
          $_0$0 = 0;
          return (tempRet0 = $_0$1, $_0$0) | 0;
        }
        HEAP32[$rem >> 2] = 0 | $a$0 & -1;
        HEAP32[$rem + 4 >> 2] = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
        $_0$1 = 0;
        $_0$0 = 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      $66 = $d_sroa_0_0_extract_trunc - 1 | 0;
      if (($66 & $d_sroa_0_0_extract_trunc | 0) != 0) {
        $86 = (_llvm_ctlz_i32($d_sroa_0_0_extract_trunc | 0) | 0) + 33 | 0;
        $88 = $86 - (_llvm_ctlz_i32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
        $89 = 64 - $88 | 0;
        $91 = 32 - $88 | 0;
        $92 = $91 >> 31;
        $95 = $88 - 32 | 0;
        $105 = $95 >> 31;
        $sr_1_ph = $88;
        $r_sroa_0_1_ph = $91 - 1 >> 31 & $n_sroa_1_4_extract_trunc >>> ($95 >>> 0) | ($n_sroa_1_4_extract_trunc << $91 | $n_sroa_0_0_extract_trunc >>> ($88 >>> 0)) & $105;
        $r_sroa_1_1_ph = $105 & $n_sroa_1_4_extract_trunc >>> ($88 >>> 0);
        $q_sroa_0_1_ph = $n_sroa_0_0_extract_trunc << $89 & $92;
        $q_sroa_1_1_ph = ($n_sroa_1_4_extract_trunc << $89 | $n_sroa_0_0_extract_trunc >>> ($95 >>> 0)) & $92 | $n_sroa_0_0_extract_trunc << $91 & $88 - 33 >> 31;
        break;
      }
      if (($rem | 0) != 0) {
        HEAP32[$rem >> 2] = $66 & $n_sroa_0_0_extract_trunc;
        HEAP32[$rem + 4 >> 2] = 0;
      }
      if (($d_sroa_0_0_extract_trunc | 0) == 1) {
        $_0$1 = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
        $_0$0 = 0 | $a$0 & -1;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      } else {
        $78 = _llvm_cttz_i32($d_sroa_0_0_extract_trunc | 0) | 0;
        $_0$1 = 0 | $n_sroa_1_4_extract_trunc >>> ($78 >>> 0);
        $_0$0 = $n_sroa_1_4_extract_trunc << 32 - $78 | $n_sroa_0_0_extract_trunc >>> ($78 >>> 0) | 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
    }
  } while (0);
  if (($sr_1_ph | 0) == 0) {
    $q_sroa_1_1_lcssa = $q_sroa_1_1_ph;
    $q_sroa_0_1_lcssa = $q_sroa_0_1_ph;
    $r_sroa_1_1_lcssa = $r_sroa_1_1_ph;
    $r_sroa_0_1_lcssa = $r_sroa_0_1_ph;
    $carry_0_lcssa$1 = 0;
    $carry_0_lcssa$0 = 0;
  } else {
    $d_sroa_0_0_insert_insert99$0 = 0 | $b$0 & -1;
    $d_sroa_0_0_insert_insert99$1 = $d_sroa_1_4_extract_shift$0 | $b$1 & 0;
    $137$0 = _i64Add($d_sroa_0_0_insert_insert99$0, $d_sroa_0_0_insert_insert99$1, -1, -1) | 0;
    $137$1 = tempRet0;
    $q_sroa_1_1198 = $q_sroa_1_1_ph;
    $q_sroa_0_1199 = $q_sroa_0_1_ph;
    $r_sroa_1_1200 = $r_sroa_1_1_ph;
    $r_sroa_0_1201 = $r_sroa_0_1_ph;
    $sr_1202 = $sr_1_ph;
    $carry_0203 = 0;
    while (1) {
      $147 = $q_sroa_0_1199 >>> 31 | $q_sroa_1_1198 << 1;
      $149 = $carry_0203 | $q_sroa_0_1199 << 1;
      $r_sroa_0_0_insert_insert42$0 = 0 | ($r_sroa_0_1201 << 1 | $q_sroa_1_1198 >>> 31);
      $r_sroa_0_0_insert_insert42$1 = $r_sroa_0_1201 >>> 31 | $r_sroa_1_1200 << 1 | 0;
      _i64Subtract($137$0, $137$1, $r_sroa_0_0_insert_insert42$0, $r_sroa_0_0_insert_insert42$1) | 0;
      $150$1 = tempRet0;
      $151$0 = $150$1 >> 31 | (($150$1 | 0) < 0 ? -1 : 0) << 1;
      $152 = $151$0 & 1;
      $154$0 = _i64Subtract($r_sroa_0_0_insert_insert42$0, $r_sroa_0_0_insert_insert42$1, $151$0 & $d_sroa_0_0_insert_insert99$0, ((($150$1 | 0) < 0 ? -1 : 0) >> 31 | (($150$1 | 0) < 0 ? -1 : 0) << 1) & $d_sroa_0_0_insert_insert99$1) | 0;
      $r_sroa_0_0_extract_trunc = $154$0;
      $r_sroa_1_4_extract_trunc = tempRet0;
      $155 = $sr_1202 - 1 | 0;
      if (($155 | 0) == 0) {
        break;
      } else {
        $q_sroa_1_1198 = $147;
        $q_sroa_0_1199 = $149;
        $r_sroa_1_1200 = $r_sroa_1_4_extract_trunc;
        $r_sroa_0_1201 = $r_sroa_0_0_extract_trunc;
        $sr_1202 = $155;
        $carry_0203 = $152;
      }
    }
    $q_sroa_1_1_lcssa = $147;
    $q_sroa_0_1_lcssa = $149;
    $r_sroa_1_1_lcssa = $r_sroa_1_4_extract_trunc;
    $r_sroa_0_1_lcssa = $r_sroa_0_0_extract_trunc;
    $carry_0_lcssa$1 = 0;
    $carry_0_lcssa$0 = $152;
  }
  $q_sroa_0_0_insert_ext75$0 = $q_sroa_0_1_lcssa;
  $q_sroa_0_0_insert_ext75$1 = 0;
  $q_sroa_0_0_insert_insert77$1 = $q_sroa_1_1_lcssa | $q_sroa_0_0_insert_ext75$1;
  if (($rem | 0) != 0) {
    HEAP32[$rem >> 2] = 0 | $r_sroa_0_1_lcssa;
    HEAP32[$rem + 4 >> 2] = $r_sroa_1_1_lcssa | 0;
  }
  $_0$1 = (0 | $q_sroa_0_0_insert_ext75$0) >>> 31 | $q_sroa_0_0_insert_insert77$1 << 1 | ($q_sroa_0_0_insert_ext75$1 << 1 | $q_sroa_0_0_insert_ext75$0 >>> 31) & 0 | $carry_0_lcssa$1;
  $_0$0 = ($q_sroa_0_0_insert_ext75$0 << 1 | 0 >>> 31) & -2 | $carry_0_lcssa$0;
  return (tempRet0 = $_0$1, $_0$0) | 0;
}
// =======================================================================



// EMSCRIPTEN_END_FUNCS

  
  function dynCall_iiii(index,a1,a2,a3) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0;
    return FUNCTION_TABLE_iiii[index&7](a1|0,a2|0,a3|0)|0;
  }


  function dynCall_viiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0;
    FUNCTION_TABLE_viiiiiii[index&3](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0);
  }


  function dynCall_viiiii(index,a1,a2,a3,a4,a5) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0;
    FUNCTION_TABLE_viiiii[index&15](a1|0,a2|0,a3|0,a4|0,a5|0);
  }


  function dynCall_vi(index,a1) {
    index = index|0;
    a1=a1|0;
    FUNCTION_TABLE_vi[index&63](a1|0);
  }


  function dynCall_vii(index,a1,a2) {
    index = index|0;
    a1=a1|0; a2=a2|0;
    FUNCTION_TABLE_vii[index&15](a1|0,a2|0);
  }


  function dynCall_iiiiiii(index,a1,a2,a3,a4,a5,a6) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0;
    return FUNCTION_TABLE_iiiiiii[index&3](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0)|0;
  }


  function dynCall_ii(index,a1) {
    index = index|0;
    a1=a1|0;
    return FUNCTION_TABLE_ii[index&7](a1|0)|0;
  }


  function dynCall_viii(index,a1,a2,a3) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0;
    FUNCTION_TABLE_viii[index&15](a1|0,a2|0,a3|0);
  }


  function dynCall_viiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0;
    FUNCTION_TABLE_viiiiiiii[index&3](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0);
  }


  function dynCall_iiiii(index,a1,a2,a3,a4) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0;
    return FUNCTION_TABLE_iiiii[index&3](a1|0,a2|0,a3|0,a4|0)|0;
  }


  function dynCall_iii(index,a1,a2) {
    index = index|0;
    a1=a1|0; a2=a2|0;
    return FUNCTION_TABLE_iii[index&15](a1|0,a2|0)|0;
  }


  function dynCall_iiiiii(index,a1,a2,a3,a4,a5) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0;
    return FUNCTION_TABLE_iiiiii[index&3](a1|0,a2|0,a3|0,a4|0,a5|0)|0;
  }


  function dynCall_viiii(index,a1,a2,a3,a4) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0;
    FUNCTION_TABLE_viiii[index&15](a1|0,a2|0,a3|0,a4|0);
  }

function b0(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; abort(0);return 0; }
  function b1(p0,p1,p2,p3,p4,p5,p6) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0; abort(1); }
  function b2(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; abort(2); }
  function b3(p0) { p0 = p0|0; abort(3); }
  function b4(p0,p1) { p0 = p0|0;p1 = p1|0; abort(4); }
  function b5(p0,p1,p2,p3,p4,p5) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0; abort(5);return 0; }
  function b6(p0) { p0 = p0|0; abort(6);return 0; }
  function _putenv__wrapper(p0) { p0 = p0|0; return _putenv(p0|0)|0; }
  function b7(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; abort(7); }
  function b8(p0,p1,p2,p3,p4,p5,p6,p7) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0; abort(8); }
  function b9(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; abort(9);return 0; }
  function b10(p0,p1) { p0 = p0|0;p1 = p1|0; abort(10);return 0; }
  function b11(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; abort(11);return 0; }
  function b12(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; abort(12); }
  // EMSCRIPTEN_END_FUNCS
  var FUNCTION_TABLE_iiii = [b0,_sn_write,_alloc_small,_alloc_large,_jpeg_write_scanlines,_do_read,b0,b0];
  var FUNCTION_TABLE_viiiiiii = [b1,_pre_process_context,_pre_process_data,b1];
  var FUNCTION_TABLE_viiiii = [b2,_grayscale_convert,_jsimd_rgb_gray_convert,_rgb_gray_convert,_null_convert,_rgb_rgb_convert,_jsimd_rgb_ycc_convert,_rgb_ycc_convert,_cmyk_ycck_convert,_sep_downsample,_setCompDefaults,b2,b2,b2,b2,b2];
  var FUNCTION_TABLE_vi = [b3,_finish_pass,_null_method,_rgb_ycc_start,_start_pass_fdctmgr,_jsimd_fdct_islow,_jpeg_fdct_islow,_jsimd_fdct_ifast,_jpeg_fdct_ifast,_jsimd_fdct_float,_jpeg_fdct_float,_finish_pass_gather,_finish_pass_huff,_write_file_header,_write_frame_header,_write_scan_header,_write_file_trailer,_write_tables_only,_prepare_for_pass,_pass_startup,_finish_pass_master,_finish_pass_phuff,_finish_pass_gather_phuff,_start_pass_downsample,_init_mem_destination,_term_mem_destination,_init_mem_destination38,_term_mem_destination40,_error_exit
  ,_output_message,_reset_error_mgr,_realize_virt_arrays,_self_destruct,_my_error_exit,_my_output_message,_free,_jpeg_finish_compress,_jpeg_abort_compress,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
  ,b3,b3,b3,b3,b3];
  var FUNCTION_TABLE_vii = [b4,_start_pass,_start_pass_coef,_preprocess_deringing,_float_preprocess_deringing,_start_pass_huff,_start_pass_main,_write_marker_byte,_start_pass_phuff,_start_pass_prep,_emit_message,_format_message,_free_pool,_jpeg_start_compress,b4,b4];
  var FUNCTION_TABLE_iiiiiii = [b5,_request_virt_sarray,_request_virt_barray,b5];
  var FUNCTION_TABLE_ii = [b6,_empty_mem_output_buffer,_empty_mem_output_buffer39,_jpeg_std_error,_putenv__wrapper,_malloc,b6,b6];
  var FUNCTION_TABLE_viii = [b7,_jsimd_convsamp,_convsamp,_jsimd_quantize,_quantize,_jsimd_convsamp_float,_convsamp_float,_jsimd_quantize_float,_quantize_float,_write_marker_header,_jpeg_CreateCompress,b7,b7,b7,b7,b7];
  var FUNCTION_TABLE_viiiiiiii = [b8,_forward_DCT,_forward_DCT_float,b8];
  var FUNCTION_TABLE_iiiii = [b9,_alloc_sarray,_alloc_barray,_snprintf];
  var FUNCTION_TABLE_iii = [b10,_encode_mcu_DC_first,_encode_mcu_AC_first,_encode_mcu_DC_refine,_encode_mcu_AC_refine,_encode_mcu,_compress_data,_compress_first_pass,_compress_output,_compress_trellis_pass,_encode_mcu_gather,_encode_mcu_huff,_encode_mcu_DC_first24,_encode_mcu_AC_first25,_encode_mcu_DC_refine26,_encode_mcu_AC_refine27];
  var FUNCTION_TABLE_iiiiii = [b11,_access_virt_sarray,_access_virt_barray,b11];
  var FUNCTION_TABLE_viiii = [b12,_process_data_simple_main,_fullsize_smooth_downsample,_fullsize_downsample,_jsimd_h2v1_downsample,_h2v1_downsample,_h2v2_smooth_downsample,_jsimd_h2v2_downsample,_h2v2_downsample,_int_downsample,_jpeg_mem_dest_tj,b12,b12,b12,b12,b12];

  return { _testSetjmp: _testSetjmp, _saveSetjmp: _saveSetjmp, _free: _free, _realloc: _realloc, _i64Add: _i64Add, _i64Subtract: _i64Subtract, _memset: _memset, _malloc: _malloc, _bitshift64Lshr: _bitshift64Lshr, _tjGetErrorStr: _tjGetErrorStr, _memcpy: _memcpy, _strlen: _strlen, _tjInitCompress: _tjInitCompress, _tjCompress2: _tjCompress2, _bitshift64Shl: _bitshift64Shl, runPostSets: runPostSets, stackAlloc: stackAlloc, stackSave: stackSave, stackRestore: stackRestore, setThrew: setThrew, setTempRet0: setTempRet0, getTempRet0: getTempRet0, dynCall_iiii: dynCall_iiii, dynCall_viiiiiii: dynCall_viiiiiii, dynCall_viiiii: dynCall_viiiii, dynCall_vi: dynCall_vi, dynCall_vii: dynCall_vii, dynCall_iiiiiii: dynCall_iiiiiii, dynCall_ii: dynCall_ii, dynCall_viii: dynCall_viii, dynCall_viiiiiiii: dynCall_viiiiiiii, dynCall_iiiii: dynCall_iiiii, dynCall_iii: dynCall_iii, dynCall_iiiiii: dynCall_iiiiii, dynCall_viiii: dynCall_viiii };
})
// EMSCRIPTEN_END_ASM
(Module.asmGlobalArg, Module.asmLibraryArg, buffer);
var _testSetjmp = Module["_testSetjmp"] = asm["_testSetjmp"];
var _saveSetjmp = Module["_saveSetjmp"] = asm["_saveSetjmp"];
var _free = Module["_free"] = asm["_free"];
var _realloc = Module["_realloc"] = asm["_realloc"];
var _i64Add = Module["_i64Add"] = asm["_i64Add"];
var _i64Subtract = Module["_i64Subtract"] = asm["_i64Subtract"];
var _memset = Module["_memset"] = asm["_memset"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _bitshift64Lshr = Module["_bitshift64Lshr"] = asm["_bitshift64Lshr"];
var _tjGetErrorStr = Module["_tjGetErrorStr"] = asm["_tjGetErrorStr"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _strlen = Module["_strlen"] = asm["_strlen"];
var _tjInitCompress = Module["_tjInitCompress"] = asm["_tjInitCompress"];
var _tjCompress2 = Module["_tjCompress2"] = asm["_tjCompress2"];
var _bitshift64Shl = Module["_bitshift64Shl"] = asm["_bitshift64Shl"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_viiiiiii = Module["dynCall_viiiiiii"] = asm["dynCall_viiiiiii"];
var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_iiiiiii = Module["dynCall_iiiiiii"] = asm["dynCall_iiiiiii"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_viiiiiiii = Module["dynCall_viiiiiiii"] = asm["dynCall_viiiiiiii"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_iiiiii = Module["dynCall_iiiiii"] = asm["dynCall_iiiiii"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];

Runtime.stackAlloc = asm['stackAlloc'];
Runtime.stackSave = asm['stackSave'];
Runtime.stackRestore = asm['stackRestore'];
Runtime.setTempRet0 = asm['setTempRet0'];
Runtime.getTempRet0 = asm['getTempRet0'];


// TODO: strip out parts of this we do not need

//======= begin closure i64 code =======

// Copyright 2009 The Closure Library Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

/**
 * @fileoverview Defines a Long class for representing a 64-bit two's-complement
 * integer value, which faithfully simulates the behavior of a Java "long". This
 * implementation is derived from LongLib in GWT.
 *
 */

var i64Math = (function() { // Emscripten wrapper
  var goog = { math: {} };


  /**
   * Constructs a 64-bit two's-complement integer, given its low and high 32-bit
   * values as *signed* integers.  See the from* functions below for more
   * convenient ways of constructing Longs.
   *
   * The internal representation of a long is the two given signed, 32-bit values.
   * We use 32-bit pieces because these are the size of integers on which
   * Javascript performs bit-operations.  For operations like addition and
   * multiplication, we split each number into 16-bit pieces, which can easily be
   * multiplied within Javascript's floating-point representation without overflow
   * or change in sign.
   *
   * In the algorithms below, we frequently reduce the negative case to the
   * positive case by negating the input(s) and then post-processing the result.
   * Note that we must ALWAYS check specially whether those values are MIN_VALUE
   * (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
   * a positive number, it overflows back into a negative).  Not handling this
   * case would often result in infinite recursion.
   *
   * @param {number} low  The low (signed) 32 bits of the long.
   * @param {number} high  The high (signed) 32 bits of the long.
   * @constructor
   */
  goog.math.Long = function(low, high) {
    /**
     * @type {number}
     * @private
     */
    this.low_ = low | 0;  // force into 32 signed bits.

    /**
     * @type {number}
     * @private
     */
    this.high_ = high | 0;  // force into 32 signed bits.
  };


  // NOTE: Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the
  // from* methods on which they depend.


  /**
   * A cache of the Long representations of small integer values.
   * @type {!Object}
   * @private
   */
  goog.math.Long.IntCache_ = {};


  /**
   * Returns a Long representing the given (32-bit) integer value.
   * @param {number} value The 32-bit integer in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromInt = function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }

    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  };


  /**
   * Returns a Long representing the given value, provided that it is a finite
   * number.  Otherwise, zero is returned.
   * @param {number} value The number in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromNumber = function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(
          (value % goog.math.Long.TWO_PWR_32_DBL_) | 0,
          (value / goog.math.Long.TWO_PWR_32_DBL_) | 0);
    }
  };


  /**
   * Returns a Long representing the 64-bit integer that comes by concatenating
   * the given high and low bits.  Each is assumed to use 32 bits.
   * @param {number} lowBits The low 32-bits.
   * @param {number} highBits The high 32-bits.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromBits = function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  };


  /**
   * Returns a Long representation of the given string, written using the given
   * radix.
   * @param {string} str The textual representation of the Long.
   * @param {number=} opt_radix The radix in which the text is written.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromString = function(str, opt_radix) {
    if (str.length == 0) {
      throw Error('number format error: empty string');
    }

    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }

    if (str.charAt(0) == '-') {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf('-') >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }

    // Do several (8) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));

    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  };


  // NOTE: the compiler should inline these constant values below and then remove
  // these variables, so there should be no runtime penalty for these.


  /**
   * Number used repeated below in calculations.  This must appear before the
   * first call to any from* function below.
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_32_DBL_ =
      goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_31_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ / 2;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_48_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_64_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_63_DBL_ =
      goog.math.Long.TWO_PWR_64_DBL_ / 2;


  /** @type {!goog.math.Long} */
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);


  /** @type {!goog.math.Long} */
  goog.math.Long.ONE = goog.math.Long.fromInt(1);


  /** @type {!goog.math.Long} */
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);


  /** @type {!goog.math.Long} */
  goog.math.Long.MAX_VALUE =
      goog.math.Long.fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0);


  /** @type {!goog.math.Long} */
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 0x80000000 | 0);


  /**
   * @type {!goog.math.Long}
   * @private
   */
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);


  /** @return {number} The value, assuming it is a 32-bit integer. */
  goog.math.Long.prototype.toInt = function() {
    return this.low_;
  };


  /** @return {number} The closest floating-point representation to this value. */
  goog.math.Long.prototype.toNumber = function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ +
           this.getLowBitsUnsigned();
  };


  /**
   * @param {number=} opt_radix The radix in which the text should be written.
   * @return {string} The textual representation of this value.
   */
  goog.math.Long.prototype.toString = function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }

    if (this.isZero()) {
      return '0';
    }

    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        // We need to change the Long value before it can be negated, so we remove
        // the bottom-most digit in this base and then recurse to do the rest.
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return '-' + this.negate().toString(radix);
      }
    }

    // Do several (6) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));

    var rem = this;
    var result = '';
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);

      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = '0' + digits;
        }
        result = '' + digits + result;
      }
    }
  };


  /** @return {number} The high 32-bits as a signed value. */
  goog.math.Long.prototype.getHighBits = function() {
    return this.high_;
  };


  /** @return {number} The low 32-bits as a signed value. */
  goog.math.Long.prototype.getLowBits = function() {
    return this.low_;
  };


  /** @return {number} The low 32-bits as an unsigned value. */
  goog.math.Long.prototype.getLowBitsUnsigned = function() {
    return (this.low_ >= 0) ?
        this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  };


  /**
   * @return {number} Returns the number of bits needed to represent the absolute
   *     value of this Long.
   */
  goog.math.Long.prototype.getNumBitsAbs = function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & (1 << bit)) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  };


  /** @return {boolean} Whether this value is zero. */
  goog.math.Long.prototype.isZero = function() {
    return this.high_ == 0 && this.low_ == 0;
  };


  /** @return {boolean} Whether this value is negative. */
  goog.math.Long.prototype.isNegative = function() {
    return this.high_ < 0;
  };


  /** @return {boolean} Whether this value is odd. */
  goog.math.Long.prototype.isOdd = function() {
    return (this.low_ & 1) == 1;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long equals the other.
   */
  goog.math.Long.prototype.equals = function(other) {
    return (this.high_ == other.high_) && (this.low_ == other.low_);
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long does not equal the other.
   */
  goog.math.Long.prototype.notEquals = function(other) {
    return (this.high_ != other.high_) || (this.low_ != other.low_);
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than the other.
   */
  goog.math.Long.prototype.lessThan = function(other) {
    return this.compare(other) < 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than or equal to the other.
   */
  goog.math.Long.prototype.lessThanOrEqual = function(other) {
    return this.compare(other) <= 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than the other.
   */
  goog.math.Long.prototype.greaterThan = function(other) {
    return this.compare(other) > 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than or equal to the other.
   */
  goog.math.Long.prototype.greaterThanOrEqual = function(other) {
    return this.compare(other) >= 0;
  };


  /**
   * Compares this Long with the given one.
   * @param {goog.math.Long} other Long to compare against.
   * @return {number} 0 if they are the same, 1 if the this is greater, and -1
   *     if the given one is greater.
   */
  goog.math.Long.prototype.compare = function(other) {
    if (this.equals(other)) {
      return 0;
    }

    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }

    // at this point, the signs are the same, so subtraction will not overflow
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  };


  /** @return {!goog.math.Long} The negation of this value. */
  goog.math.Long.prototype.negate = function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  };


  /**
   * Returns the sum of this and the given Long.
   * @param {goog.math.Long} other Long to add to this one.
   * @return {!goog.math.Long} The sum of this and the given Long.
   */
  goog.math.Long.prototype.add = function(other) {
    // Divide each number into 4 chunks of 16 bits, and then sum the chunks.

    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;

    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;

    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 + b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };


  /**
   * Returns the difference of this and the given Long.
   * @param {goog.math.Long} other Long to subtract from this.
   * @return {!goog.math.Long} The difference of this and the given Long.
   */
  goog.math.Long.prototype.subtract = function(other) {
    return this.add(other.negate());
  };


  /**
   * Returns the product of this and the given long.
   * @param {goog.math.Long} other Long to multiply with this.
   * @return {!goog.math.Long} The product of this and the other.
   */
  goog.math.Long.prototype.multiply = function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }

    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }

    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }

    // If both longs are small, use float multiplication
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) &&
        other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }

    // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
    // We can skip products that would overflow.

    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;

    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;

    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };


  /**
   * Returns this Long divided by the given one.
   * @param {goog.math.Long} other Long by which to divide.
   * @return {!goog.math.Long} This Long divided by the given one.
   */
  goog.math.Long.prototype.div = function(other) {
    if (other.isZero()) {
      throw Error('division by zero');
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }

    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) ||
          other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;  // recall that -MIN_VALUE == MIN_VALUE
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }

    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }

    // Repeat the following until the remainder is less than other:  find a
    // floating-point that approximates remainder / other *from below*, add this
    // into the result, and subtract it from the remainder.  It is critical that
    // the approximate value is less than or equal to the real value so that the
    // remainder never becomes negative.
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      // Approximate the result of division. This may be a little greater or
      // smaller than the actual value.
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));

      // We will tweak the approximate result by changing it in the 48-th digit or
      // the smallest non-fractional digit, whichever is larger.
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = (log2 <= 48) ? 1 : Math.pow(2, log2 - 48);

      // Decrease the approximation until it is smaller than the remainder.  Note
      // that if it is too large, the product overflows and is negative.
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }

      // We know the answer can't be zero... and actually, zero would cause
      // infinite recursion since we would make no progress.
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }

      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  };


  /**
   * Returns this Long modulo the given one.
   * @param {goog.math.Long} other Long by which to mod.
   * @return {!goog.math.Long} This Long modulo the given one.
   */
  goog.math.Long.prototype.modulo = function(other) {
    return this.subtract(this.div(other).multiply(other));
  };


  /** @return {!goog.math.Long} The bitwise-NOT of this value. */
  goog.math.Long.prototype.not = function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  };


  /**
   * Returns the bitwise-AND of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to AND.
   * @return {!goog.math.Long} The bitwise-AND of this and the other.
   */
  goog.math.Long.prototype.and = function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_,
                                   this.high_ & other.high_);
  };


  /**
   * Returns the bitwise-OR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to OR.
   * @return {!goog.math.Long} The bitwise-OR of this and the other.
   */
  goog.math.Long.prototype.or = function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_,
                                   this.high_ | other.high_);
  };


  /**
   * Returns the bitwise-XOR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to XOR.
   * @return {!goog.math.Long} The bitwise-XOR of this and the other.
   */
  goog.math.Long.prototype.xor = function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_,
                                   this.high_ ^ other.high_);
  };


  /**
   * Returns this Long with bits shifted to the left by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the left by the given amount.
   */
  goog.math.Long.prototype.shiftLeft = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(
            low << numBits,
            (high << numBits) | (low >>> (32 - numBits)));
      } else {
        return goog.math.Long.fromBits(0, low << (numBits - 32));
      }
    }
  };


  /**
   * Returns this Long with bits shifted to the right by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount.
   */
  goog.math.Long.prototype.shiftRight = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >> numBits);
      } else {
        return goog.math.Long.fromBits(
            high >> (numBits - 32),
            high >= 0 ? 0 : -1);
      }
    }
  };


  /**
   * Returns this Long with bits shifted to the right by the given amount, with
   * the new top bits matching the current sign bit.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount, with
   *     zeros placed into the new leading bits.
   */
  goog.math.Long.prototype.shiftRightUnsigned = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> (numBits - 32), 0);
      }
    }
  };

  //======= begin jsbn =======

  var navigator = { appName: 'Modern Browser' }; // polyfill a little

  // Copyright (c) 2005  Tom Wu
  // All Rights Reserved.
  // http://www-cs-students.stanford.edu/~tjw/jsbn/

  /*
   * Copyright (c) 2003-2005  Tom Wu
   * All Rights Reserved.
   *
   * Permission is hereby granted, free of charge, to any person obtaining
   * a copy of this software and associated documentation files (the
   * "Software"), to deal in the Software without restriction, including
   * without limitation the rights to use, copy, modify, merge, publish,
   * distribute, sublicense, and/or sell copies of the Software, and to
   * permit persons to whom the Software is furnished to do so, subject to
   * the following conditions:
   *
   * The above copyright notice and this permission notice shall be
   * included in all copies or substantial portions of the Software.
   *
   * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
   * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
   * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
   *
   * IN NO EVENT SHALL TOM WU BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
   * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER
   * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF
   * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
   * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   *
   * In addition, the following condition applies:
   *
   * All redistributions must retain an intact copy of this copyright notice
   * and disclaimer.
   */

  // Basic JavaScript BN library - subset useful for RSA encryption.

  // Bits per digit
  var dbits;

  // JavaScript engine analysis
  var canary = 0xdeadbeefcafe;
  var j_lm = ((canary&0xffffff)==0xefcafe);

  // (public) Constructor
  function BigInteger(a,b,c) {
    if(a != null)
      if("number" == typeof a) this.fromNumber(a,b,c);
      else if(b == null && "string" != typeof a) this.fromString(a,256);
      else this.fromString(a,b);
  }

  // return new, unset BigInteger
  function nbi() { return new BigInteger(null); }

  // am: Compute w_j += (x*this_i), propagate carries,
  // c is initial carry, returns final carry.
  // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
  // We need to select the fastest one that works in this environment.

  // am1: use a single mult and divide to get the high bits,
  // max digit bits should be 26 because
  // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
  function am1(i,x,w,j,c,n) {
    while(--n >= 0) {
      var v = x*this[i++]+w[j]+c;
      c = Math.floor(v/0x4000000);
      w[j++] = v&0x3ffffff;
    }
    return c;
  }
  // am2 avoids a big mult-and-extract completely.
  // Max digit bits should be <= 30 because we do bitwise ops
  // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
  function am2(i,x,w,j,c,n) {
    var xl = x&0x7fff, xh = x>>15;
    while(--n >= 0) {
      var l = this[i]&0x7fff;
      var h = this[i++]>>15;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
      c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
      w[j++] = l&0x3fffffff;
    }
    return c;
  }
  // Alternately, set max digit bits to 28 since some
  // browsers slow down when dealing with 32-bit numbers.
  function am3(i,x,w,j,c,n) {
    var xl = x&0x3fff, xh = x>>14;
    while(--n >= 0) {
      var l = this[i]&0x3fff;
      var h = this[i++]>>14;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x3fff)<<14)+w[j]+c;
      c = (l>>28)+(m>>14)+xh*h;
      w[j++] = l&0xfffffff;
    }
    return c;
  }
  if(j_lm && (navigator.appName == "Microsoft Internet Explorer")) {
    BigInteger.prototype.am = am2;
    dbits = 30;
  }
  else if(j_lm && (navigator.appName != "Netscape")) {
    BigInteger.prototype.am = am1;
    dbits = 26;
  }
  else { // Mozilla/Netscape seems to prefer am3
    BigInteger.prototype.am = am3;
    dbits = 28;
  }

  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = ((1<<dbits)-1);
  BigInteger.prototype.DV = (1<<dbits);

  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2,BI_FP);
  BigInteger.prototype.F1 = BI_FP-dbits;
  BigInteger.prototype.F2 = 2*dbits-BI_FP;

  // Digit conversions
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array();
  var rr,vv;
  rr = "0".charCodeAt(0);
  for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;

  function int2char(n) { return BI_RM.charAt(n); }
  function intAt(s,i) {
    var c = BI_RC[s.charCodeAt(i)];
    return (c==null)?-1:c;
  }

  // (protected) copy this to r
  function bnpCopyTo(r) {
    for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }

  // (protected) set from integer value x, -DV <= x < DV
  function bnpFromInt(x) {
    this.t = 1;
    this.s = (x<0)?-1:0;
    if(x > 0) this[0] = x;
    else if(x < -1) this[0] = x+DV;
    else this.t = 0;
  }

  // return bigint initialized to value
  function nbv(i) { var r = nbi(); r.fromInt(i); return r; }

  // (protected) set from string and radix
  function bnpFromString(s,b) {
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 256) k = 8; // byte array
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else { this.fromRadix(s,b); return; }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while(--i >= 0) {
      var x = (k==8)?s[i]&0xff:intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if(sh == 0)
        this[this.t++] = x;
      else if(sh+k > this.DB) {
        this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
        this[this.t++] = (x>>(this.DB-sh));
      }
      else
        this[this.t-1] |= x<<sh;
      sh += k;
      if(sh >= this.DB) sh -= this.DB;
    }
    if(k == 8 && (s[0]&0x80) != 0) {
      this.s = -1;
      if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
    }
    this.clamp();
    if(mi) BigInteger.ZERO.subTo(this,this);
  }

  // (protected) clamp off excess high words
  function bnpClamp() {
    var c = this.s&this.DM;
    while(this.t > 0 && this[this.t-1] == c) --this.t;
  }

  // (public) return string representation in given radix
  function bnToString(b) {
    if(this.s < 0) return "-"+this.negate().toString(b);
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else return this.toRadix(b);
    var km = (1<<k)-1, d, m = false, r = "", i = this.t;
    var p = this.DB-(i*this.DB)%k;
    if(i-- > 0) {
      if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r = int2char(d); }
      while(i >= 0) {
        if(p < k) {
          d = (this[i]&((1<<p)-1))<<(k-p);
          d |= this[--i]>>(p+=this.DB-k);
        }
        else {
          d = (this[i]>>(p-=k))&km;
          if(p <= 0) { p += this.DB; --i; }
        }
        if(d > 0) m = true;
        if(m) r += int2char(d);
      }
    }
    return m?r:"0";
  }

  // (public) -this
  function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }

  // (public) |this|
  function bnAbs() { return (this.s<0)?this.negate():this; }

  // (public) return + if this > a, - if this < a, 0 if equal
  function bnCompareTo(a) {
    var r = this.s-a.s;
    if(r != 0) return r;
    var i = this.t;
    r = i-a.t;
    if(r != 0) return (this.s<0)?-r:r;
    while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
    return 0;
  }

  // returns bit length of the integer x
  function nbits(x) {
    var r = 1, t;
    if((t=x>>>16) != 0) { x = t; r += 16; }
    if((t=x>>8) != 0) { x = t; r += 8; }
    if((t=x>>4) != 0) { x = t; r += 4; }
    if((t=x>>2) != 0) { x = t; r += 2; }
    if((t=x>>1) != 0) { x = t; r += 1; }
    return r;
  }

  // (public) return the number of bits in "this"
  function bnBitLength() {
    if(this.t <= 0) return 0;
    return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
  }

  // (protected) r = this << n*DB
  function bnpDLShiftTo(n,r) {
    var i;
    for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
    for(i = n-1; i >= 0; --i) r[i] = 0;
    r.t = this.t+n;
    r.s = this.s;
  }

  // (protected) r = this >> n*DB
  function bnpDRShiftTo(n,r) {
    for(var i = n; i < this.t; ++i) r[i-n] = this[i];
    r.t = Math.max(this.t-n,0);
    r.s = this.s;
  }

  // (protected) r = this << n
  function bnpLShiftTo(n,r) {
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<cbs)-1;
    var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
    for(i = this.t-1; i >= 0; --i) {
      r[i+ds+1] = (this[i]>>cbs)|c;
      c = (this[i]&bm)<<bs;
    }
    for(i = ds-1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t+ds+1;
    r.s = this.s;
    r.clamp();
  }

  // (protected) r = this >> n
  function bnpRShiftTo(n,r) {
    r.s = this.s;
    var ds = Math.floor(n/this.DB);
    if(ds >= this.t) { r.t = 0; return; }
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<bs)-1;
    r[0] = this[ds]>>bs;
    for(var i = ds+1; i < this.t; ++i) {
      r[i-ds-1] |= (this[i]&bm)<<cbs;
      r[i-ds] = this[i]>>bs;
    }
    if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
    r.t = this.t-ds;
    r.clamp();
  }

  // (protected) r = this - a
  function bnpSubTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]-a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c -= a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c -= a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = (c<0)?-1:0;
    if(c < -1) r[i++] = this.DV+c;
    else if(c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }

  // (protected) r = this * a, r != this,a (HAC 14.12)
  // "this" should be the larger one if appropriate.
  function bnpMultiplyTo(a,r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i+y.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
    r.s = 0;
    r.clamp();
    if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
  }

  // (protected) r = this^2, r != this (HAC 14.16)
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2*x.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < x.t-1; ++i) {
      var c = x.am(i,x[i],r,2*i,0,1);
      if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
        r[i+x.t] -= x.DV;
        r[i+x.t+1] = 1;
      }
    }
    if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
    r.s = 0;
    r.clamp();
  }

  // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
  // r != q, this != m.  q or r may be null.
  function bnpDivRemTo(m,q,r) {
    var pm = m.abs();
    if(pm.t <= 0) return;
    var pt = this.abs();
    if(pt.t < pm.t) {
      if(q != null) q.fromInt(0);
      if(r != null) this.copyTo(r);
      return;
    }
    if(r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
    if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
    else { pm.copyTo(y); pt.copyTo(r); }
    var ys = y.t;
    var y0 = y[ys-1];
    if(y0 == 0) return;
    var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
    var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
    var i = r.t, j = i-ys, t = (q==null)?nbi():q;
    y.dlShiftTo(j,t);
    if(r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t,r);
    }
    BigInteger.ONE.dlShiftTo(ys,t);
    t.subTo(y,y);	// "negative" y so we can replace sub with am later
    while(y.t < ys) y[y.t++] = 0;
    while(--j >= 0) {
      // Estimate quotient digit
      var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
      if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
        y.dlShiftTo(j,t);
        r.subTo(t,r);
        while(r[i] < --qd) r.subTo(t,r);
      }
    }
    if(q != null) {
      r.drShiftTo(ys,q);
      if(ts != ms) BigInteger.ZERO.subTo(q,q);
    }
    r.t = ys;
    r.clamp();
    if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
    if(ts < 0) BigInteger.ZERO.subTo(r,r);
  }

  // (public) this mod a
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a,null,r);
    if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
    return r;
  }

  // Modular reduction using "classic" algorithm
  function Classic(m) { this.m = m; }
  function cConvert(x) {
    if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
    else return x;
  }
  function cRevert(x) { return x; }
  function cReduce(x) { x.divRemTo(this.m,null,x); }
  function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;

  // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
  // justification:
  //         xy == 1 (mod m)
  //         xy =  1+km
  //   xy(2-xy) = (1+km)(1-km)
  // x[y(2-xy)] = 1-k^2m^2
  // x[y(2-xy)] == 1 (mod m^2)
  // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
  // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
  // JS multiply "overflows" differently from C/C++, so care is needed here.
  function bnpInvDigit() {
    if(this.t < 1) return 0;
    var x = this[0];
    if((x&1) == 0) return 0;
    var y = x&3;		// y == 1/x mod 2^2
    y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
    y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
    y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
    // last step - calculate inverse mod DV directly;
    // assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
    y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
    // we really want the negative inverse, and -DV < y < DV
    return (y>0)?this.DV-y:-y;
  }

  // Montgomery reduction
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp&0x7fff;
    this.mph = this.mp>>15;
    this.um = (1<<(m.DB-15))-1;
    this.mt2 = 2*m.t;
  }

  // xR mod m
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t,r);
    r.divRemTo(this.m,null,r);
    if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
    return r;
  }

  // x/R mod m
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }

  // x = x/R mod m (HAC 14.32)
  function montReduce(x) {
    while(x.t <= this.mt2)	// pad x so am has enough room later
      x[x.t++] = 0;
    for(var i = 0; i < this.m.t; ++i) {
      // faster way of calculating u0 = x[i]*mp mod DV
      var j = x[i]&0x7fff;
      var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
      // use am to combine the multiply-shift-add into one call
      j = i+this.m.t;
      x[j] += this.m.am(0,u0,x,i,0,this.m.t);
      // propagate carry
      while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
    }
    x.clamp();
    x.drShiftTo(this.m.t,x);
    if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
  }

  // r = "x^2/R mod m"; x != r
  function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

  // r = "xy/R mod m"; x,y != r
  function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }

  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;

  // (protected) true iff this is even
  function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }

  // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
  function bnpExp(e,z) {
    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
    g.copyTo(r);
    while(--i >= 0) {
      z.sqrTo(r,r2);
      if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
      else { var t = r; r = r2; r2 = t; }
    }
    return z.revert(r);
  }

  // (public) this^e % m, 0 <= e < 2^32
  function bnModPowInt(e,m) {
    var z;
    if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e,z);
  }

  // protected
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;

  // public
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;

  // "constants"
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);

  // jsbn2 stuff

  // (protected) convert from radix string
  function bnpFromRadix(s,b) {
    this.fromInt(0);
    if(b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
    for(var i = 0; i < s.length; ++i) {
      var x = intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b*w+x;
      if(++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w,0);
        j = 0;
        w = 0;
      }
    }
    if(j > 0) {
      this.dMultiply(Math.pow(b,j));
      this.dAddOffset(w,0);
    }
    if(mi) BigInteger.ZERO.subTo(this,this);
  }

  // (protected) return x s.t. r^x < DV
  function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }

  // (public) 0 if this == 0, 1 if this > 0
  function bnSigNum() {
    if(this.s < 0) return -1;
    else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
    else return 1;
  }

  // (protected) this *= n, this >= 0, 1 < n < DV
  function bnpDMultiply(n) {
    this[this.t] = this.am(0,n-1,this,0,0,this.t);
    ++this.t;
    this.clamp();
  }

  // (protected) this += n << w words, this >= 0
  function bnpDAddOffset(n,w) {
    if(n == 0) return;
    while(this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while(this[w] >= this.DV) {
      this[w] -= this.DV;
      if(++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }

  // (protected) convert to radix string
  function bnpToRadix(b) {
    if(b == null) b = 10;
    if(this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b,cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d,y,z);
    while(y.signum() > 0) {
      r = (a+z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d,y,z);
    }
    return z.intValue().toString(b) + r;
  }

  // (public) return value as integer
  function bnIntValue() {
    if(this.s < 0) {
      if(this.t == 1) return this[0]-this.DV;
      else if(this.t == 0) return -1;
    }
    else if(this.t == 1) return this[0];
    else if(this.t == 0) return 0;
    // assumes 16 < DB < 32
    return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
  }

  // (protected) r = this + a
  function bnpAddTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]+a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c += a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c += a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = (c<0)?-1:0;
    if(c > 0) r[i++] = c;
    else if(c < -1) r[i++] = this.DV+c;
    r.t = i;
    r.clamp();
  }

  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;

  //======= end jsbn =======

  // Emscripten wrapper
  var Wrapper = {
    abs: function(l, h) {
      var x = new goog.math.Long(l, h);
      var ret;
      if (x.isNegative()) {
        ret = x.negate();
      } else {
        ret = x;
      }
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
    },
    ensureTemps: function() {
      if (Wrapper.ensuredTemps) return;
      Wrapper.ensuredTemps = true;
      Wrapper.two32 = new BigInteger();
      Wrapper.two32.fromString('4294967296', 10);
      Wrapper.two64 = new BigInteger();
      Wrapper.two64.fromString('18446744073709551616', 10);
      Wrapper.temp1 = new BigInteger();
      Wrapper.temp2 = new BigInteger();
    },
    lh2bignum: function(l, h) {
      var a = new BigInteger();
      a.fromString(h.toString(), 10);
      var b = new BigInteger();
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger();
      c.fromString(l.toString(), 10);
      var d = new BigInteger();
      c.addTo(b, d);
      return d;
    },
    stringify: function(l, h, unsigned) {
      var ret = new goog.math.Long(l, h).toString();
      if (unsigned && ret[0] == '-') {
        // unsign slowly using jsbn bignums
        Wrapper.ensureTemps();
        var bignum = new BigInteger();
        bignum.fromString(ret, 10);
        ret = new BigInteger();
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    },
    fromString: function(str, base, min, max, unsigned) {
      Wrapper.ensureTemps();
      var bignum = new BigInteger();
      bignum.fromString(str, base);
      var bigmin = new BigInteger();
      bigmin.fromString(min, 10);
      var bigmax = new BigInteger();
      bigmax.fromString(max, 10);
      if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
        var temp = new BigInteger();
        bignum.addTo(Wrapper.two64, temp);
        bignum = temp;
      }
      var error = false;
      if (bignum.compareTo(bigmin) < 0) {
        bignum = bigmin;
        error = true;
      } else if (bignum.compareTo(bigmax) > 0) {
        bignum = bigmax;
        error = true;
      }
      var ret = goog.math.Long.fromString(bignum.toString()); // min-max checks should have clamped this to a range goog.math.Long can handle well
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
      if (error) throw 'range error';
    }
  };
  return Wrapper;
})();

//======= end closure i64 code =======



// === Auto-generated postamble setup entry stuff ===

if (memoryInitializer) {
  if (typeof Module['locateFile'] === 'function') {
    memoryInitializer = Module['locateFile'](memoryInitializer);
  } else if (Module['memoryInitializerPrefixURL']) {
    memoryInitializer = Module['memoryInitializerPrefixURL'] + memoryInitializer;
  }
  if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
    var data = Module['readBinary'](memoryInitializer);
    HEAPU8.set(data, STATIC_BASE);
  } else {
    addRunDependency('memory initializer');
    Browser.asyncLoad(memoryInitializer, function(data) {
      HEAPU8.set(data, STATIC_BASE);
      removeRunDependency('memory initializer');
    }, function(data) {
      throw 'could not load memory initializer ' + memoryInitializer;
    });
  }
}

function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;

var initialStackTop;
var preloadStartTime = null;
var calledMain = false;

dependenciesFulfilled = function runCaller() {
  // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
  if (!Module['calledRun'] && shouldRunNow) run();
  if (!Module['calledRun']) dependenciesFulfilled = runCaller; // try this again later, after new deps are fulfilled
}

Module['callMain'] = Module.callMain = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(__ATPRERUN__.length == 0, 'cannot call main when preRun functions remain to be called');

  args = args || [];

  ensureInitRuntime();

  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString(Module['thisProgram']), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);

  initialStackTop = STACKTOP;

  try {

    var ret = Module['_main'](argc, argv, 0);


    // if we're not running an evented main loop, it's time to exit
    exit(ret);
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
      throw e;
    }
  } finally {
    calledMain = true;
  }
}




function run(args) {
  args = args || Module['arguments'];

  if (preloadStartTime === null) preloadStartTime = Date.now();

  if (runDependencies > 0) {
    return;
  }

  preRun();

  if (runDependencies > 0) return; // a preRun added a dependency, run will be called later
  if (Module['calledRun']) return; // run may have just been called through dependencies being fulfilled just in this very frame

  function doRun() {
    if (Module['calledRun']) return; // run may have just been called while the async setStatus time below was happening
    Module['calledRun'] = true;

    if (ABORT) return; 

    ensureInitRuntime();

    preMain();

    if (ENVIRONMENT_IS_WEB && preloadStartTime !== null) {
      Module.printErr('pre-main prep time: ' + (Date.now() - preloadStartTime) + ' ms');
    }

    if (Module['_main'] && shouldRunNow) {
      Module['callMain'](args);
    }

    postRun();
  }

  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      doRun();
    }, 1);
  } else {
    doRun();
  }
}
Module['run'] = Module.run = run;

function exit(status) {
  if (Module['noExitRuntime']) {
    return;
  }

  ABORT = true;
  EXITSTATUS = status;
  STACKTOP = initialStackTop;

  // exit the runtime
  exitRuntime();

  if (ENVIRONMENT_IS_NODE) {
    // Work around a node.js bug where stdout buffer is not flushed at process exit:
    // Instead of process.exit() directly, wait for stdout flush event.
    // See https://github.com/joyent/node/issues/1669 and https://github.com/kripken/emscripten/issues/2582
    // Workaround is based on https://github.com/RReverser/acorn/commit/50ab143cecc9ed71a2d66f78b4aec3bb2e9844f6
    process['stdout']['once']('drain', function () {
      process['exit'](status);
    });
    console.log(' '); // Make sure to print something to force the drain event to occur, in case the stdout buffer was empty.
    // Work around another node bug where sometimes 'drain' is never fired - make another effort
    // to emit the exit status, after a significant delay (if node hasn't fired drain by then, give up)
    setTimeout(function() {
      process['exit'](status);
    }, 500);
  } else
  if (ENVIRONMENT_IS_SHELL && typeof quit === 'function') {
    quit(status);
  }
  // if we reach here, we must throw an exception to halt the current execution
  throw new ExitStatus(status);
}
Module['exit'] = Module.exit = exit;

function abort(text) {
  if (text) {
    Module.print(text);
    Module.printErr(text);
  }

  ABORT = true;
  EXITSTATUS = 1;

  var extra = '\nIf this abort() is unexpected, build with -s ASSERTIONS=1 which can give more information.';

  throw 'abort() at ' + stackTrace() + extra;
}
Module['abort'] = Module.abort = abort;

// {{PRE_RUN_ADDITIONS}}

if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}

// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}


run();

// {{POST_RUN_ADDITIONS}}






// {{MODULE_ADDITIONS}}



